diff --git a/docs/en_US/getting_started.rst b/docs/en_US/getting_started.rst
index 700e8d48b..11ae656dc 100644
--- a/docs/en_US/getting_started.rst
+++ b/docs/en_US/getting_started.rst
@@ -33,6 +33,7 @@ Mode is pre-configured for security.
 
    deployment
    login
+   mfa
    user_management
    change_user_password
    restore_locked_user
diff --git a/docs/en_US/mfa.rst b/docs/en_US/mfa.rst
new file mode 100644
index 000000000..96e34d5d7
--- /dev/null
+++ b/docs/en_US/mfa.rst
@@ -0,0 +1,35 @@
+.. _mfa:
+
+*************************************************
+`Enabling two-factor authentication (2FA)`:index:
+*************************************************
+
+About two-factor authentication
+===============================
+Two-factor authentication (2FA) is an extra layer of security used when logging
+into websites or apps. With 2FA, you have to log in with your username and
+password and provide another form of authentication that only you know or have
+access to.
+
+
+Setup two-factor authentication
+===============================
+To set up 2FA for pgAdmin 4, you must configure the Two-factor Authentication
+settings in *config_local.py* or *config_system.py* (see the
+:ref:`config.py <config_py>` documentation) on the system where pgAdmin is
+installed in Server mode. You can copy these settings from *config.py* file and
+modify the values for the following parameters.
+
+.. csv-table::
+   :header: "**Parameter**", "**Description**"
+   :class: longtable
+   :widths: 35, 55
+
+   "MFA_ENABLED","The default value for this parameter is False.
+   To enable 2FA, set the value to *True*"
+   "SUPPORTED_MFA_LIST", "Set the authentication methods to be supported "
+   "MFA_EMAIL_SUBJECT", "<APP_NAME> - Verification Code"
+
+*NOTE: You must set the 'Mail server settings' in config_local.py or
+config_system.py in order to use 'email' as two-factor authentication method
+(see the* :ref:`config.py <config_py>` *documentation).*
diff --git a/docs/en_US/release_notes_5_7.rst b/docs/en_US/release_notes_5_7.rst
index e102b6954..9c0196c72 100644
--- a/docs/en_US/release_notes_5_7.rst
+++ b/docs/en_US/release_notes_5_7.rst
@@ -13,6 +13,7 @@ New features
 | `Issue #4264 <https://redmine.postgresql.org/issues/4264>`_ -  Make code folding case insensitive in the code mirror.
 | `Issue #4629 <https://redmine.postgresql.org/issues/4629>`_ -  Added database and server information on the Maintenance process watcher dialog.
 | `Issue #6495 <https://redmine.postgresql.org/issues/6495>`_ -  Allow the referenced table to be the same as the local table in one to many relationship for ERD Tool.
+| `Issue #6495 <https://redmine.postgresql.org/issues/6543>`_ -  Added support for Two-factor authentication for improving security.
 | `Issue #6691 <https://redmine.postgresql.org/issues/6691>`_ -  Set PSQLRC and PSQL_HISTORY env vars to apt. user storage path in the server mode.
 
 Housekeeping
diff --git a/requirements.txt b/requirements.txt
index d45566a0b..535736738 100644
--- a/requirements.txt
+++ b/requirements.txt
@@ -43,3 +43,6 @@ user-agents==2.2.0
 pywinpty==1.1.1; sys_platform=="win32"
 Authlib==0.15.*
 requests==2.25.*
+pyotp==2.*
+qrcode==7.*
+Pillow==8.3.*
diff --git a/web/.eslintignore b/web/.eslintignore
index 676a4f03f..eab18762b 100644
--- a/web/.eslintignore
+++ b/web/.eslintignore
@@ -4,3 +4,4 @@ vendor
 templates/
 templates\
 ycache
+regression/htmlcov
diff --git a/web/config.py b/web/config.py
index d797e26f7..faeb459fd 100644
--- a/web/config.py
+++ b/web/config.py
@@ -724,6 +724,29 @@ OAUTH2_CONFIG = [
 
 OAUTH2_AUTO_CREATE_USER = True
 
+##########################################################################
+# Two-factor Authentication Configuration
+##########################################################################
+
+# Set it to True, to enable the two-factor authentication
+MFA_ENABLED = False
+
+# Set it to True, to ask the users to register forcefully for the
+# two-authentication methods on logged-in.
+MFA_FORCE_REGISTRATION = False
+
+# pgAdmin supports Two-factor authentication by either sending an one-time code
+# to an email, or using the TOTP based application like Google Authenticator.
+SUPPORTED_MFA_LIST = ["email", "authenticator"]
+
+# NOTE: Please set the 'Mail server settings' to use 'email' as two-factor
+#       authentication method.
+
+# Subject for the email verification code
+# Default: <APP_NAME> - Verification Code
+# e.g.  pgAdmin 4 - Verification Code
+MFA_EMAIL_SUBJECT = None
+
 ##########################################################################
 # PSQL tool settings
 ##########################################################################
diff --git a/web/migrations/script.py.mako b/web/migrations/script.py.mako
index 8cda71380..340757c99 100644
--- a/web/migrations/script.py.mako
+++ b/web/migrations/script.py.mako
@@ -14,8 +14,7 @@ Revises: ${down_revision | comma,n}
 Create Date: ${create_date}
 
 """
-from alembic import op
-import sqlalchemy as sa
+from pgadmin.model import db
 ${imports if imports else ""}
 
 # revision identifiers, used by Alembic.
diff --git a/web/migrations/versions/15c88f765bc8_.py b/web/migrations/versions/15c88f765bc8_.py
new file mode 100644
index 000000000..9775cd63d
--- /dev/null
+++ b/web/migrations/versions/15c88f765bc8_.py
@@ -0,0 +1,44 @@
+##########################################################################
+#
+# pgAdmin 4 - PostgreSQL Tools
+#
+# Copyright (C) 2013 - 2021, The pgAdmin Development Team
+# This software is released under the PostgreSQL Licence
+#
+##########################################################################
+
+"""Update DB to version 14
+
+Added a table `user_mfa` for saving the options on MFA for different sources.
+
+Revision ID: 15c88f765bc8
+Revises: 6650c52670c2
+Create Date: 2021-06-22 17:33:12.533825
+
+"""
+from pgadmin.model import db
+
+
+# revision identifiers, used by Alembic.
+revision = '15c88f765bc8'
+down_revision = '6650c52670c2'
+branch_labels = None
+depends_on = None
+
+
+def upgrade():
+    db.engine.execute("""
+CREATE TABLE user_mfa(
+    user_id  INTEGER NOT NULL,
+    mfa_auth VARCHAR(256) NOT NULL,
+    options  TEXT,
+    PRIMARY KEY (user_id, mfa_auth),
+    FOREIGN KEY(user_id) REFERENCES user (id)
+)
+    """)
+    # ### end Alembic commands ###
+
+
+def downgrade():
+    # pgAdmin only upgrades, downgrade not implemented.
+    pass
diff --git a/web/pgadmin/__init__.py b/web/pgadmin/__init__.py
index 37eb26ccc..bd7f07ece 100644
--- a/web/pgadmin/__init__.py
+++ b/web/pgadmin/__init__.py
@@ -34,6 +34,7 @@ from werkzeug.datastructures import ImmutableDict
 from werkzeug.local import LocalProxy
 from werkzeug.utils import find_modules
 
+from pgadmin.authenticate.mfa.utils import is_mfa_enabled
 from pgadmin.model import db, Role, Server, SharedServer, ServerGroup, \
     User, Keys, Version, SCHEMA_VERSION as CURRENT_SCHEMA_VERSION
 from pgadmin.utils import PgAdminModule, driver, KeyManager
diff --git a/web/pgadmin/authenticate/__init__.py b/web/pgadmin/authenticate/__init__.py
index 82c5ea9b0..a74aa094c 100644
--- a/web/pgadmin/authenticate/__init__.py
+++ b/web/pgadmin/authenticate/__init__.py
@@ -19,7 +19,7 @@ from flask_security.views import _security
 from flask_security.utils import get_post_logout_redirect, \
     get_post_login_redirect, logout_user
 
-from pgadmin import db, User
+from pgadmin.model import db, User
 from pgadmin.utils import PgAdminModule
 from pgadmin.utils.constants import KERBEROS, INTERNAL, OAUTH2, LDAP
 from pgadmin.authenticate.registry import AuthSourceRegistry
@@ -27,6 +27,20 @@ from pgadmin.authenticate.registry import AuthSourceRegistry
 MODULE_NAME = 'authenticate'
 auth_obj = None
 
+_URL_WITH_NEXT_PARAM = "{0}?next={1}"
+
+
+def get_logout_url():
+    BROWSER_INDEX = 'browser.index'
+    if config.SERVER_MODE and\
+            session['auth_source_manager']['current_source'] == \
+            KERBEROS:
+        return _URL_WITH_NEXT_PARAM.format(url_for(
+            'authenticate.kerberos_logout'), url_for(BROWSER_INDEX))
+
+    return _URL_WITH_NEXT_PARAM.format(
+        url_for('security.logout'), url_for(BROWSER_INDEX))
+
 
 class AuthenticateModule(PgAdminModule):
     def get_exposed_url_endpoints(self):
diff --git a/web/pgadmin/authenticate/mfa/__init__.py b/web/pgadmin/authenticate/mfa/__init__.py
new file mode 100644
index 000000000..2eeba08ab
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/__init__.py
@@ -0,0 +1,85 @@
+##############################################################################
+#
+# pgAdmin 4 - PostgreSQL Tools
+#
+# Copyright (C) 2013 - 2021, The pgAdmin Development Team
+# This software is released under the PostgreSQL Licence
+#
+##############################################################################
+"""Multi-factor Authentication (MFA) implementation"""
+
+from flask import Blueprint, session
+from flask_babelex import gettext as _
+
+import config
+from .utils import mfa_enabled, segregate_valid_and_invalid_mfa_list
+
+from .registry import MultiFactorAuthRegistry
+from .views import validate_view, registration_view
+
+
+def __create_blueprint():
+    blueprint = Blueprint(
+        "mfa", __name__, url_prefix="/mfa",
+        static_folder="static",
+        template_folder="templates"
+    )
+
+    blueprint.add_url_rule(
+        "/validate", "validate", validate_view, methods=("GET", "POST",)
+    )
+
+    blueprint.add_url_rule(
+        "/register", "register", registration_view, methods=("GET", "POST",)
+    )
+
+    return blueprint
+
+
+def init_app(app):
+
+    if getattr(config, "MFA_ENABLED", False) is False:
+        return
+
+    MultiFactorAuthRegistry.load_modules(app)
+
+    def remove_invalid_mfa_auth_methods():
+
+        supported_methods = getattr(config, "SUPPORTED_MFA_LIST", [])
+        invalid_auth_methods = []
+
+        supported_methods, invalid_auth_methods = \
+            segregate_valid_and_invalid_mfa_list(supported_methods)
+
+        for auth_method in invalid_auth_methods:
+            app.logger.warning(_(
+                "'{}' is not a valid multi-factor authentication method"
+            ).format(auth_method))
+
+        config.SUPPORTED_MFA_LIST = supported_methods
+        blueprint = __create_blueprint()
+
+        for mfa_method in supported_methods:
+            mfa = MultiFactorAuthRegistry.get(mfa_method)
+            mfa.register_url_endpoints(blueprint)
+
+        app.register_blueprint(blueprint)
+        app.register_logout_hook(blueprint)
+
+        from flask_login import user_logged_in, user_logged_out
+
+        @user_logged_in.connect_via(app)
+        @user_logged_out.connect_via(app)
+        def clear_session_on_login(sender, user):
+            session['mfa_authenticated'] = False
+
+    def disable_mfa():
+        if getattr(config, 'MFA_ENABLED', False) is True and \
+                getattr(config, 'SERVER_MODE', False) is not False:
+            app.logger.warning(_(
+                "No valid multi-factor authentication found, hence - "
+                "disabling it."
+            ))
+        config.MFA_ENABLED = False
+
+    mfa_enabled(remove_invalid_mfa_auth_methods, disable_mfa)
diff --git a/web/pgadmin/authenticate/mfa/authenticator.py b/web/pgadmin/authenticate/mfa/authenticator.py
new file mode 100644
index 000000000..01bdcbaf1
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/authenticator.py
@@ -0,0 +1,145 @@
+##############################################################################
+#
+# pgAdmin 4 - PostgreSQL Tools
+#
+# Copyright (C) 2013 - 2021, The pgAdmin Development Team
+# This software is released under the PostgreSQL Licence
+#
+##############################################################################
+"""Multi-factor Authentication implementation for Google Authenticator"""
+
+import base64
+from io import BytesIO
+
+from flask import url_for, session, flash
+from flask_babelex import gettext as _
+from flask_login import current_user
+import pyotp
+import qrcode
+
+import config
+from pgadmin.model import UserMFA
+
+from .registry import BaseMFAuth
+from .utils import ValidationException, fetch_auth_option, mfa_add
+
+
+_GOOGLE_AUTH_METHOD = "authenticator"
+_GOOGLE_AUTHENTICATOR = _("Google Authenticator")
+
+
+class GoogleAuthenticator(BaseMFAuth):
+
+    @classmethod
+    def __fetch_user_topt(cls):
+        options, found = fetch_auth_option(GOOGLE_AUTH_METHOD)
+
+        if found is False:
+            raise ValidationException(_(
+                "User has not registered the Google Authenticator for "
+                "authentication."
+            ))
+
+        if options is None or options == '':
+            raise ValidationException(_(
+                "User does not have valid HASH to generate the OTP."
+            ))
+
+        return pyotp.TOTP(options)
+
+    @property
+    def name(self):
+        return GOOGLE_AUTH_METHOD
+
+    @property
+    def label(self):
+        return _(_GOOGLE_AUTHENTICATOR)
+
+    def validate(self, **kwargs):
+        code = kwargs.get('code', None)
+        totp = GoogleAuthenticator.__fetch_user_topt()
+
+        if totp.verify(code) is False:
+            raise ValidationException("Invalid Code")
+
+    def validation_view(self):
+        return (
+            "<h5 class='form-group text-center'>" +
+            _(_GOOGLE_AUTHENTICATOR) +
+            "</h5>" +
+            "<div class='form-group'>" +
+            _("Enter your Google Authenticator passcode") +
+            "</div><div class='form-group'>" +
+            "<input class='form-control' placeholder='" +
+            _("Enter code") +
+            "' name='code' type='text' autofocus='' pattern='\\d*' " +
+            "require></div>"
+        )
+
+    def _registration_view(self):
+
+        option = session.pop('mfa_authenticator_opt', None)
+        if option is None:
+            option = pyotp.random_base32()
+        session['mfa_authenticator_opt'] = option
+        totp = pyotp.TOTP(option)
+
+        uri = totp.provisioning_uri(
+            current_user.username, issuer_name=getattr(
+                config, "APP_NAME", "pgAdmin 4"
+            )
+        )
+
+        img = qrcode.make(uri)
+        buffered = BytesIO()
+        img.save(buffered, format="JPEG")
+        img_base64 = base64.b64encode(buffered.getvalue())
+
+        return (
+            "<h5 class='form-group text-center'>" +
+            _(_GOOGLE_AUTHENTICATOR) +
+            "</h5>" +
+            "<input type='hidden' name='" + GOOGLE_AUTH_METHOD +
+            "' value='SETUP'/>" +
+            "<input type='hidden' name='VALIDATE' value='validate'/>" +
+            "<img src='data:image/jpeg;base64," + img_base64.decode("utf-8") +
+            "' alt='" + _("Google Authenticator QRCode") +
+            "' class='w-100'/><div class='form-group pt-3'>" +
+            _(
+                "Scan the QR code and the enter the code from the "
+                "Google Authenticator"
+            ) +
+            "</div>" +
+            "<div class='form-group'>" +
+            "<input class='form-control' placeholder='" +
+            _("Enter code") + "' name='code' type='text' autofocus=''" +
+            "pattern='\\d*' require></div>"
+        )
+
+    def registration_view(self, form_data):
+
+        if 'VALIDATE' not in form_data:
+            return self._registration_view()
+
+        code = form_data.get('code', None)
+        totp = pyotp.TOTP(session['mfa_authenticator_opt'])
+
+        if totp.verify(code) is False:
+            flash(_("Failed to validate the code"), "danger")
+            return self._registration_view()
+
+        mfa_add(GOOGLE_AUTH_METHOD, session['mfa_authenticator_opt'])
+        flash(_(
+            "Google Authenticator registered successfully for authentication."
+        ), "success")
+        session.pop('mfa_authenticator_opt', None)
+
+        return None
+
+    @property
+    def icon(self):
+        # Reference:
+        # https://upload.wikimedia.org/wikipedia/commons/6/6e/ \
+        # Google_Authenticator_for_Android_icon.svg
+        # Changed: height -> 30px, width -> 30px
+        return url_for("mfa.static", filename="ga.svg")
diff --git a/web/pgadmin/authenticate/mfa/email.py b/web/pgadmin/authenticate/mfa/email.py
new file mode 100644
index 000000000..aeb30598f
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/email.py
@@ -0,0 +1,248 @@
+##############################################################################
+#
+# pgAdmin 4 - PostgreSQL Tools
+#
+# Copyright (C) 2013 - 2021, The pgAdmin Development Team
+# This software is released under the PostgreSQL Licence
+#
+##############################################################################
+"""Multi-factor Authentication implementation by sending OTP through email"""
+
+from flask import url_for, session, Response, render_template, current_app, \
+    flash
+from flask_babelex import gettext as _
+from flask_login import current_user
+from flask_security import send_mail
+
+import config
+from pgadmin.utils.csrf import pgCSRFProtect
+from .registry import BaseMFAuth
+from .utils import ValidationException, mfa_add, fetch_auth_option
+
+
+def __generate_code():
+    import time
+    import base64
+    import codecs
+    import random
+
+    code = codecs.encode("{}{}{}".format(
+        time.time(), current_user.username, random.randint(1000, 9999)
+    ).encode(), "hex")
+
+    res = 0
+    idx = 0
+
+    while idx < len(code):
+        res += int((code[idx:idx + 6]).decode('utf-8'), base=16)
+        res %= 1000000
+        idx += 5
+
+    return str(res).zfill(6)
+
+
+def _send_code_to_email(_email=None):
+
+    if not current_user.is_authenticated:
+        return False, 401, _("Not accessible")
+
+    if _email is None:
+        _email = getattr(current_user, 'email', None)
+
+    if _email is None:
+        return False, 401, _("No email-id unavailable.")
+
+    try:
+        session["mfa_email_code"] = __generate_code()
+        subject = getattr(config, 'MFA_EMAIL_SUBJECT', None)
+
+        if subject is None:
+            subject = _("{} - Verification Code").format(config.APP_NAME)
+
+        send_mail(
+            subject,
+            _email,
+            "send_email_otp",
+            user=current_user,
+            code=session["mfa_email_code"]
+        )
+    except OSError as ose:
+        current_app.logger.exception(ose)
+        return False, 503, _("Failed to send the code to email.") + \
+            "\n" + str(ose)
+
+    message = _(
+        "A verification code was sent to {}. Check your email and enter "
+        "the code."
+    ).format(_mask_email(_email))
+
+    return True, 200, message
+
+
+def _mask_email(_email):
+    import re
+    email_split = re.split('@', _email)
+    username, domain = email_split
+    domain_front, *domain_back_list = re.split('[.]', domain)
+    users = re.split('[.]', username)
+
+    def _mask_except_first_char(_str):
+        return _str[0] + '*' * (len(_str) - 1)
+
+    return '.'.join([_mask_except_first_char(user) for user in users]) + \
+        '@' + _mask_except_first_char(domain_front) + '.' + \
+        '.'.join(domain_back_list)
+
+
+def send_email_code():
+
+    options, found = fetch_auth_option(EMAIL_AUTH_METHOD)
+
+    if found is False:
+        raise ValidationException(_(
+            "User has not registered for email authentication"
+        ))
+
+    success, http_code, message = _send_code_to_email(options)
+
+    if success is False:
+        return Response(message, http_code, mimetype='text/html')
+
+    return Response(render_template(
+        "mfa/email_code_sent.html", _=_,
+        message=message,
+    ), http_code, mimetype='text/html')
+
+
+@pgCSRFProtect.exempt
+def javascript():
+    if not current_user.is_authenticated:
+        return Response(_("Not accessible"), 401, mimetype="text/plain")
+
+    return Response(render_template(
+        "mfa/email.js", _=_, url_for=url_for,
+    ), 200, mimetype="text/javascript")
+
+
+EMAIL_AUTH_METHOD = 'email'
+
+
+class EmailAuthenticator(BaseMFAuth):
+
+    @property
+    def name(self):
+        return EMAIL_AUTH_METHOD
+
+    @property
+    def label(self):
+        return _("Email Authentication")
+
+    def validate(self, **kwargs):
+        code = kwargs.get('code', None)
+        if code == session.get("mfa_email_code", 'unknown'):
+            session.pop("mfa_email_code")
+            return
+        raise ValidationException("Invalid code")
+
+    def validation_view(self):
+        if session.get("code_sent", False) is True:
+            return render_template(
+                "mfa/email_view.html", _=_
+            )
+        return render_template(
+            "mfa/email_view.html", _=_
+        )
+
+    def _registration_view(self):
+        email = getattr(current_user, 'email', '')
+        return "\n".join([
+            "<h5 class='form-group text-center'>",
+            _("Email Authenticator"),
+            "</h5>",
+            "<input type='hidden' name='" +
+            EMAIL_AUTH_METHOD +
+            "' value='SETUP'/>",
+            "<input type='hidden' name='validate' value='send_code'/>",
+            "<div class='form-group pt-3'>",
+            _("Enter the email-id for the user."),
+            "</div>",
+            "<div class='form-group'>",
+            "<input class='form-control' placeholder='" +
+            _("Enter the email-id for the user") +
+            "' name='send_to' " +
+            "type='email' autofocus='' value='" + email + "' " +
+            "pattern='[a-z0-9._%+-]+@[a-z0-9.-]+\\.[a-z]{2,}$' require/>",
+            "</div><div class='alert alert-warning alert-dismissible fade ",
+            "show' role='alert'> <strong>" + _("Note") + ":</strong>",
+            _("This will not update the email-id of the user."),
+            "</div>",
+        ])
+
+    def _registration_view_after_code_sent(self, _form_data):
+
+        session['mfa_email_id'] = _form_data.get('send_to', None)
+        success, http_code, message = _send_code_to_email(
+            session['mfa_email_id']
+        )
+
+        if success is False:
+            flash(message, 'danger')
+            return None
+
+        return (
+            "<h5 class='form-group text-center'>" +
+            _("Email Authenticator") +
+            "</h5>" +
+            "<input type='hidden' name='" + EMAIL_AUTH_METHOD +
+            "' value='SETUP'/>" +
+            "<input type='hidden' name='validate' value='verify_code'/>" +
+            "<div class='form-group pt-3'>" + message +
+            "</div><div class='form-group'>" +
+            "<input class='form-control' placeholder='" +
+            _("Enter code here") + "' name='code' " +
+            "type='text' autofocus='' " +
+            "pattern='\\d{6}' require></div>"
+        )
+
+    def registration_view(self, _form_data):
+
+        if 'validate' in _form_data:
+            if _form_data['validate'] == 'send_code':
+                return self._registration_view_after_code_sent(_form_data)
+
+            code = _form_data.get('code', None)
+
+            if code == session.get("mfa_email_code", None):
+                mfa_add(EMAIL_AUTH_METHOD, session['mfa_email_id'])
+
+                flash(_(
+                    "Email Authenticator registered successfully for "
+                    "authentication."
+                ), "success")
+
+                session.pop('mfa_email_code', None)
+
+                return None
+
+            flash(_('Invalid code'), 'danger')
+
+        return self._registration_view()
+
+    def register_url_endpoints(self, blueprint):
+        blueprint.add_url_rule(
+            "/send_email_code", "send_email_code", send_email_code,
+            methods=("POST", )
+        )
+        blueprint.add_url_rule(
+            "/email.js", "email_js", javascript, methods=("GET", )
+        )
+
+    @property
+    def icon(self):
+        # Reference: https://commons.wikimedia.org/wiki/File:At_(@)_symbol.svg
+        # Changed: height -> 30px, width -> 30px
+        return url_for("mfa.static", filename="at.svg")
+
+    @property
+    def validate_script(self):
+        return url_for("mfa.email_js")
diff --git a/web/pgadmin/authenticate/mfa/registry.py b/web/pgadmin/authenticate/mfa/registry.py
new file mode 100644
index 000000000..037efe11d
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/registry.py
@@ -0,0 +1,80 @@
+##########################################################################
+#
+# pgAdmin 4 - PostgreSQL Tools
+#
+# Copyright (C) 2013 - 2021, The pgAdmin Development Team
+# This software is released under the PostgreSQL Licence
+#
+##########################################################################
+
+"""External 2FA Authentication Registry."""
+from abc import abstractmethod, abstractproperty
+import six
+
+from pgadmin.utils.dynamic_registry import create_registry_metaclass
+
+
+MultiFactorAuthRegistry = create_registry_metaclass(
+    'MultiFactorAuthRegistry', __package__, decorate_as_module=True
+)
+
+
+@six.add_metaclass(MultiFactorAuthRegistry)
+class BaseMFAuth():
+
+    @abstractproperty
+    def name(self):
+        """Name must not contain special characters"""
+        pass
+
+    @abstractproperty
+    def label(self):
+        pass
+
+    @property
+    def icon(self):
+        return ""
+
+    @property
+    def validate_script(self):
+        return None
+
+    @abstractmethod
+    def validate(self, **kwargs):
+        pass
+
+    @abstractmethod
+    def validation_view(self):
+        pass
+
+    @abstractmethod
+    def registration_view(self, form_data):
+        pass
+
+    def register_url_endpoints(self, blueprint):
+        """
+        Override this method in case, you would like to expose some url
+        end-points for this auth method.
+        """
+        pass
+
+    def to_dict(self):
+        return {
+            "id": self.name,
+            "label": self.label,
+            "icon": self.icon,
+        }
+
+    def validation_view_dict(self, selected_mfa):
+        res = self.to_dict()
+
+        res['view'] = self.validation_view()
+        res['selected'] = selected_mfa == self.name
+        res['script'] = self.validate_script
+
+        return res
+
+    def deleted(self):
+        # Override this method in case, you need to do any action to do on
+        # authentication deletion.
+        pass
diff --git a/web/pgadmin/authenticate/mfa/static/at.svg b/web/pgadmin/authenticate/mfa/static/at.svg
new file mode 100644
index 000000000..9ef836880
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/static/at.svg
@@ -0,0 +1,459 @@
+<svg xmlns="http://www.w3.og/2000/svg" xmlns:cc="http://ceativecommons.og/ns#" xmlns:dc="http://pul.og/dc/elements/1.1/" xmlns:inkscape="http://www.inkscape.og/namespaces/inkscape" xmlns:df="http://www.w3.og/1999/02/22-df-syntax-ns#" xmlns:sodipodi="http://sodipodi.soucefoge.net/DTD/sodipodi-0.dtd" xmlns:svg="http://www.w3.og/2000/svg" xmlns:xlink="http://www.w3.og/1999/xlink" width="30px" height="30px" viewBox="-27 140 751 831" inkscape:expot-xdpi="76.235291" inkscape:expot-ydpi="76.235291" inkscape:output_extension="og.inkscape.output.svg.inkscape" inkscape:vesion="0.47pe1" sodipodi:vesion="0.32" vesion="1.1">
+  <defs id="defs4">
+    <lineaGadient id="lineaGadient3998">
+      <stop id="stop4000" offset="0" style="stop-colo:#729fcf;stop-opacity:1;"/>
+      <stop id="stop4002" offset="0.31578946" style="stop-colo:#a5bfda;stop-opacity:1;"/>
+      <stop id="stop4004" offset="1" style="stop-colo:#376ca4;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient3990">
+      <stop id="stop3992" offset="0" style="stop-colo:#729fcf;stop-opacity:1;"/>
+      <stop id="stop3994" offset="0.31578946" style="stop-colo:#a5bfda;stop-opacity:1;"/>
+      <stop id="stop3996" offset="1" style="stop-colo:#376ca4;stop-opacity:1;"/>
+    </lineaGadient>
+    <inkscape:pespective id="pespective8097" inkscape:pesp3d-oigin="372.04724 : 350.78739 : 1" inkscape:vp_x="0 : 526.18109 : 1" inkscape:vp_y="0 : 1000 : 0" inkscape:vp_z="744.09448 : 526.18109 : 1" sodipodi:type="inkscape:pesp3d"/>
+    <lineaGadient id="lineaGadient6924" inkscape:collect="always">
+      <stop id="stop6926" offset="0" style="stop-colo:#ffffff;stop-opacity:1;"/>
+      <stop id="stop6928" offset="1" style="stop-colo:#ffffff;stop-opacity:0;"/>
+    </lineaGadient>
+    <lineaGadient gadientTansfom="matix(21.14292,0,0,21.14292,-152.982,9.37161)" gadientUnits="useSpaceOnUse" id="lineaGadient6930" inkscape:collect="always" x1="16.071430" x2="15.785715" xlink:hef="#lineaGadient6924" y1="19.500000" y2="30.000000"/>
+    <lineaGadient id="lineaGadient6932">
+      <stop id="stop6934" offset="0.0000000" style="stop-colo:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop6936" offset="1" style="stop-colo:#aeb2e7;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient gadientTansfom="matix(21.14292,0,0,21.14292,-149.9615,-46.50619)" gadientUnits="useSpaceOnUse" id="lineaGadient4182" inkscape:collect="always" x1="17.160095" x2="37.969398" xlink:hef="#lineaGadient2682" y1="14.004482" y2="56.575912"/>
+    <lineaGadient id="lineaGadient4162">
+      <stop id="stop4164" offset="0.0000000" style="stop-colo:#f79403;stop-opacity:1.0000000;"/>
+      <stop id="stop4170" offset="0.18691589" style="stop-colo:#fdb343;stop-opacity:1.0000000;"/>
+      <stop id="stop4172" offset="0.43008122" style="stop-colo:#fdb74f;stop-opacity:1.0000000;"/>
+      <stop id="stop4166" offset="1.0000000" style="stop-colo:#8f5601;stop-opacity:1.0000000;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient4206">
+      <stop id="stop4208" offset="0" style="stop-colo:#204a87;stop-opacity:1;"/>
+      <stop id="stop4210" offset="1" style="stop-colo:#3465a4;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient gadientTansfom="matix(21.14292,0,0,21.14292,-149.9615,-46.50619)" gadientUnits="useSpaceOnUse" id="lineaGadient4198" inkscape:collect="always" x1="25.064732" x2="25.207588" xlink:hef="#lineaGadient4206" y1="21.857143" y2="25.428572"/>
+    <lineaGadient id="lineaGadient4134">
+      <stop id="stop4136" offset="0.0000000" style="stop-colo:#7e807a;stop-opacity:1.0000000;"/>
+      <stop id="stop4148" offset="0.25000000" style="stop-colo:#babbb8;stop-opacity:1.0000000;"/>
+      <stop id="stop4142" offset="0.50000000" style="stop-colo:#a5a6a3;stop-opacity:1.0000000;"/>
+      <stop id="stop4138" offset="1.0000000" style="stop-colo:#333432;stop-opacity:1.0000000;"/>
+    </lineaGadient>
+    <lineaGadient gadientTansfom="matix(21.14292,0,0,21.14292,-149.9615,-46.50619)" gadientUnits="useSpaceOnUse" id="lineaGadient4140" inkscape:collect="always" x1="9.3030529" x2="38.826412" xlink:hef="#lineaGadient9910" y1="26.71875" y2="26.71875"/>
+    <lineaGadient id="lineaGadient4126">
+      <stop id="stop4128" offset="0.0000000" style="stop-colo:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop4130" offset="1.0000000" style="stop-colo:#ffffff;stop-opacity:0.16494845;"/>
+    </lineaGadient>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1558" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1554" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1550" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1546" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1542" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1538" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1536" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1532" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1528" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1526" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1522" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1518" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1514" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1510" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1506" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1502" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1498" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1494" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1490" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1486" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1482" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1478" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1474" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1470" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1466" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1462" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <lineaGadient id="lineaGadient4750">
+      <stop id="stop4752" offset="0" style="stop-colo:#ffffff;stop-opacity:1;"/>
+      <stop id="stop4758" offset="0.37931034" style="stop-colo:#fefefe;stop-opacity:1.0000000;"/>
+      <stop id="stop4754" offset="1.0000000" style="stop-colo:#1d1d1d;stop-opacity:1.0000000;"/>
+    </lineaGadient>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient1460" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <lineaGadient id="lineaGadient3962">
+      <stop id="stop3964" offset="0.0000000" style="stop-colo:#d3e9ff;stop-opacity:1.0000000;"/>
+      <stop id="stop4134" offset="0.15517241" style="stop-colo:#d3e9ff;stop-opacity:1.0000000;"/>
+      <stop id="stop4346" offset="0.75000000" style="stop-colo:#4074ae;stop-opacity:1.0000000;"/>
+      <stop id="stop3966" offset="1.0000000" style="stop-colo:#36486c;stop-opacity:1.0000000;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient2265" inkscape:collect="always">
+      <stop id="stop2267" offset="0" style="stop-colo:#000000;stop-opacity:1;"/>
+      <stop id="stop2269" offset="1" style="stop-colo:#000000;stop-opacity:0;"/>
+    </lineaGadient>
+    <lineaGadient gadientTansfom="matix(0.878099,-1.73237e-2,1.73237e-2,0.878099,1021.3138,469.27875)" gadientUnits="useSpaceOnUse" id="lineaGadient2271" inkscape:collect="always" x1="14.017542" x2="15.415793" xlink:hef="#lineaGadient2265" y1="36.942543" y2="38.268368"/>
+    <lineaGadient id="lineaGadient2257" inkscape:collect="always">
+      <stop id="stop2259" offset="0" style="stop-colo:#ffffff;stop-opacity:1;"/>
+      <stop id="stop2261" offset="1" style="stop-colo:#ffffff;stop-opacity:0;"/>
+    </lineaGadient>
+    <lineaGadient gadientTansfom="matix(1.007254,-2.636526e-2,2.636526e-2,1.007254,1020.7435,465.29004)" gadientUnits="useSpaceOnUse" id="lineaGadient2263" inkscape:collect="always" x1="12.004697" x2="10.650805" xlink:hef="#lineaGadient2257" y1="35.688461" y2="33.194965"/>
+    <lineaGadient id="lineaGadient3087">
+      <stop id="stop3089" offset="0" style="stop-colo:#3465a4;stop-opacity:1;"/>
+      <stop id="stop3095" offset="0" style="stop-colo:#9fbce1;stop-opacity:1;"/>
+      <stop id="stop2242" offset="0" style="stop-colo:#6b95ca;stop-opacity:1;"/>
+      <stop id="stop2244" offset="0.75" style="stop-colo:#3d6aa5;stop-opacity:1;"/>
+      <stop id="stop3091" offset="1" style="stop-colo:#386eb4;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient gadientTansfom="matix(0.87827,0,0,0.87827,1021.6871,470.17853)" gadientUnits="useSpaceOnUse" id="lineaGadient3093" inkscape:collect="always" x1="9.7503242" x2="16.915297" xlink:hef="#lineaGadient3087" y1="32.28376" y2="39.443218"/>
+    <lineaGadient id="lineaGadient2250" inkscape:collect="always">
+      <stop id="stop2252" offset="0" style="stop-colo:#ffffff;stop-opacity:1;"/>
+      <stop id="stop2254" offset="1" style="stop-colo:#ffffff;stop-opacity:0;"/>
+    </lineaGadient>
+    <lineaGadient gadientTansfom="tanslate(1019.1501,465.21085)" gadientUnits="useSpaceOnUse" id="lineaGadient2256" inkscape:collect="always" x1="31.177404" x2="40.859177" xlink:hef="#lineaGadient2250" y1="19.821514" y2="9.6568537"/>
+    <lineaGadient id="lineaGadient3077">
+      <stop id="stop3079" offset="0" style="stop-colo:#98a0a9;stop-opacity:1;"/>
+      <stop id="stop3081" offset="1" style="stop-colo:#c3d0dd;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient gadientTansfom="matix(0.87827,0,0,0.87827,1021.9976,470.79956)" gadientUnits="useSpaceOnUse" id="lineaGadient3083" inkscape:collect="always" x1="38.227654" x2="37.53537" xlink:hef="#lineaGadient3077" y1="13.602527" y2="6.6285896"/>
+    <lineaGadient id="lineaGadient3061">
+      <stop id="stop3063" offset="0" style="stop-colo:#ffffff;stop-opacity:1;"/>
+      <stop id="stop3065" offset="1" style="stop-colo:#000000;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient gadientTansfom="matix(0.8782699,0,0,0.8782699,1049.7965,-403.53398)" gadientUnits="useSpaceOnUse" id="lineaGadient3067" inkscape:collect="always" x1="50.152931" x2="25.291086" xlink:hef="#lineaGadient3061" y1="-3.6324477" y2="-4.3002653"/>
+    <lineaGadient id="lineaGadient3049">
+      <stop id="stop3051" offset="0" style="stop-colo:#b6b6b6;stop-opacity:1;"/>
+      <stop id="stop2262" offset="0.5" style="stop-colo:#f2f2f2;stop-opacity:1;"/>
+      <stop id="stop2264" offset="0.67612958" style="stop-colo:#fafafa;stop-opacity:1;"/>
+      <stop id="stop2268" offset="0.84051722" style="stop-colo:#d8d8d8;stop-opacity:1;"/>
+      <stop id="stop2266" offset="0.875" style="stop-colo:#f2f2f2;stop-opacity:1;"/>
+      <stop id="stop3053" offset="1" style="stop-colo:#dbdbdb;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient gadientTansfom="matix(0.87827,0,0,0.87827,1021.6871,470.17853)" gadientUnits="useSpaceOnUse" id="lineaGadient3055" inkscape:collect="always" x1="19.648342" x2="20.631224" xlink:hef="#lineaGadient3049" y1="42.253601" y2="6.7758031"/>
+    <adialGadient cx="24.8125" cy="39.125" fx="24.8125" fy="39.125" gadientTansfom="matix(1,0,0,0.374558,0,24.47041)" gadientUnits="useSpaceOnUse" id="adialGadient3047" inkscape:collect="always" ="17.6875" xlink:hef="#lineaGadient3041"/>
+    <lineaGadient id="lineaGadient3041" inkscape:collect="always">
+      <stop id="stop3043" offset="0" style="stop-colo:#000000;stop-opacity:1;"/>
+      <stop id="stop3045" offset="1" style="stop-colo:#000000;stop-opacity:0;"/>
+    </lineaGadient>
+    <adialGadient cx="24.8125" cy="39.125" fx="24.8125" fy="39.125" gadientTansfom="matix(1,0,0,0.374558,0,24.47041)" gadientUnits="useSpaceOnUse" id="adialGadient2260" inkscape:collect="always" ="17.6875" xlink:hef="#lineaGadient3041"/>
+    <lineaGadient gadientTansfom="tanslate(131.91072,132.23618)" gadientUnits="useSpaceOnUse" id="SVGID_1_" x1="43.944302" x2="411.3941" y1="733.39258" y2="425.06561">
+      <stop id="stop2170" offset="0.0562" style="stop-colo:#003F90"/>
+      <stop id="stop2172" offset="0.5674" style="stop-colo:#0093D2"/>
+      <stop id="stop2174" offset="0.9551" style="stop-colo:#EDF3F7"/>
+    </lineaGadient>
+    <lineaGadient gadientTansfom="matix(0.9169564,0,0,0.9120098,60.201795,153.71221)" gadientUnits="useSpaceOnUse" id="SVGID_2_" x1="43.943802" x2="411.39359" y1="733.39258" y2="425.06561">
+      <stop id="stop2179" offset="0.0562" style="stop-colo:#525252;stop-opacity:1;"/>
+      <stop id="stop2181" offset="0.56739998" style="stop-colo:#8e8e8e;stop-opacity:1;"/>
+      <stop id="stop2183" offset="0.9551" style="stop-colo:#c9c9c9;stop-opacity:1;"/>
+    </lineaGadient>
+    <adialGadient cx="605.71429" cy="486.64789" fx="605.71429" fy="486.64789" gadientTansfom="matix(-2.774389,0,0,1.969706,112.7623,-872.8854)" gadientUnits="useSpaceOnUse" id="adialGadient5020" inkscape:collect="always" ="117.14286" xlink:hef="#lineaGadient5060"/>
+    <lineaGadient gadientTansfom="matix(2.774389,0,0,1.969706,-1892.179,-872.8854)" gadientUnits="useSpaceOnUse" id="lineaGadient5016" inkscape:collect="always" x1="302.85715" x2="302.85715" xlink:hef="#lineaGadient5048" y1="366.64789" y2="609.50507"/>
+    <adialGadient cx="605.71429" cy="486.64789" fx="605.71429" fy="486.64789" gadientTansfom="matix(2.774389,0,0,1.969706,-1891.633,-872.8854)" gadientUnits="useSpaceOnUse" id="adialGadient5013" inkscape:collect="always" ="117.14286" xlink:hef="#lineaGadient5060"/>
+    <lineaGadient id="lineaGadient2795">
+      <stop id="stop2797" offset="0.0000000" style="stop-colo:#000000;stop-opacity:0.068627454;"/>
+      <stop id="stop2799" offset="1.0000000" style="stop-colo:#ffffff;stop-opacity:1.0000000;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient2803">
+      <stop id="stop2805" offset="0" style="stop-colo:#ffffff;stop-opacity:1;"/>
+      <stop id="stop2807" offset="1.0000000" style="stop-colo:#cbcbcb;stop-opacity:1.0000000;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient2094">
+      <stop id="stop2096" offset="0.0000000" style="stop-colo:#d6e3f0;stop-opacity:1.0000000;"/>
+      <stop id="stop2098" offset="1.0000000" style="stop-colo:#95b1cf;stop-opacity:1.0000000;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient12512">
+      <stop id="stop12513" offset="0.0000000" style="stop-colo:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop12517" offset="0.50000000" style="stop-colo:#fff520;stop-opacity:0.89108908;"/>
+      <stop id="stop12514" offset="1.0000000" style="stop-colo:#fff300;stop-opacity:0.0000000;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient5048">
+      <stop id="stop5050" offset="0" style="stop-colo:black;stop-opacity:0;"/>
+      <stop id="stop5056" offset="0.5" style="stop-colo:black;stop-opacity:1;"/>
+      <stop id="stop5052" offset="1" style="stop-colo:black;stop-opacity:0;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient5060" inkscape:collect="always">
+      <stop id="stop5062" offset="0" style="stop-colo:black;stop-opacity:1;"/>
+      <stop id="stop5064" offset="1" style="stop-colo:black;stop-opacity:0;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient2994">
+      <stop id="stop2996" offset="0" style="stop-colo:#000000;stop-opacity:1;"/>
+      <stop id="stop2998" offset="1" style="stop-colo:#c9c9c9;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient2974">
+      <stop id="stop2976" offset="0" style="stop-colo:#c1c1c1;stop-opacity:1;"/>
+      <stop id="stop2978" offset="1" style="stop-colo:#acacac;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient2966">
+      <stop id="stop2968" offset="0" style="stop-colo:#ffd1d1;stop-opacity:1;"/>
+      <stop id="stop3006" offset="0.5" style="stop-colo:#ff1d1d;stop-opacity:1;"/>
+      <stop id="stop2970" offset="1" style="stop-colo:#6f0000;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient2846">
+      <stop id="stop2848" offset="0.0000000" style="stop-colo:#8a8a8a;stop-opacity:1.0000000;"/>
+      <stop id="stop2850" offset="1.0000000" style="stop-colo:#484848;stop-opacity:1.0000000;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient2366">
+      <stop id="stop2368" offset="0" style="stop-colo:#ffffff;stop-opacity:1;"/>
+      <stop id="stop2374" offset="0.50000000" style="stop-colo:#ffffff;stop-opacity:0.21904762;"/>
+      <stop id="stop2370" offset="1.0000000" style="stop-colo:#ffffff;stop-opacity:1.0000000;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient4467">
+      <stop id="stop4469" offset="0" style="stop-colo:#ffffff;stop-opacity:1;"/>
+      <stop id="stop4471" offset="1.0000000" style="stop-colo:#ffffff;stop-opacity:0.24761905;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient4454">
+      <stop id="stop4456" offset="0.0000000" style="stop-colo:#729fcf;stop-opacity:0.20784314;"/>
+      <stop id="stop4458" offset="1.0000000" style="stop-colo:#729fcf;stop-opacity:0.67619050;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient4440">
+      <stop id="stop4442" offset="0" style="stop-colo:#7d7d7d;stop-opacity:1;"/>
+      <stop id="stop4448" offset="0.50000000" style="stop-colo:#b1b1b1;stop-opacity:1.0000000;"/>
+      <stop id="stop4444" offset="1.0000000" style="stop-colo:#686868;stop-opacity:1.0000000;"/>
+    </lineaGadient>
+    <adialGadient cx="24.306795" cy="42.07798" fx="24.306795" fy="42.07798" gadientTansfom="matix(1.000000,0.000000,0.000000,0.284916,0.000000,30.08928)" gadientUnits="useSpaceOnUse" id="adialGadient4548" inkscape:collect="always" ="15.821514" xlink:hef="#lineaGadient4542"/>
+    <lineaGadient id="lineaGadient259">
+      <stop id="stop260" offset="0.0000000" style="stop-colo:#fafafa;stop-opacity:1.0000000;"/>
+      <stop id="stop261" offset="1.0000000" style="stop-colo:#bbbbbb;stop-opacity:1.0000000;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient269">
+      <stop id="stop270" offset="0.0000000" style="stop-colo:#a3a3a3;stop-opacity:1.0000000;"/>
+      <stop id="stop271" offset="1.0000000" style="stop-colo:#4c4c4c;stop-opacity:1.0000000;"/>
+    </lineaGadient>
+    <adialGadient cx="20.8921" cy="114.5684" fx="20.8921" fy="114.5684" gadientUnits="useSpaceOnUse" id="aigd2" ="5.256">
+      <stop id="stop15566" offset="0" style="stop-colo:#F0F0F0"/>
+      <stop id="stop15568" offset="1.0000000" style="stop-colo:#9a9a9a;stop-opacity:1.0000000;"/>
+    </adialGadient>
+    <adialGadient cx="20.8921" cy="64.5679" fx="20.8921" fy="64.5679" gadientUnits="useSpaceOnUse" id="aigd3" ="5.257">
+      <stop id="stop15573" offset="0" style="stop-colo:#F0F0F0"/>
+      <stop id="stop15575" offset="1.0000000" style="stop-colo:#9a9a9a;stop-opacity:1.0000000;"/>
+    </adialGadient>
+    <lineaGadient id="lineaGadient15662">
+      <stop id="stop15664" offset="0.0000000" style="stop-colo:#ffffff;stop-opacity:1.0000000;"/>
+      <stop id="stop15666" offset="1.0000000" style="stop-colo:#f8f8f8;stop-opacity:1.0000000;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient4542" inkscape:collect="always">
+      <stop id="stop4544" offset="0" style="stop-colo:#000000;stop-opacity:1;"/>
+      <stop id="stop4546" offset="1" style="stop-colo:#000000;stop-opacity:0;"/>
+    </lineaGadient>
+    <lineaGadient gadientTansfom="matix(2.774389,0,0,1.969706,-1892.179,-872.8854)" gadientUnits="useSpaceOnUse" id="lineaGadient2659" inkscape:collect="always" x1="302.85715" x2="302.85715" xlink:hef="#lineaGadient5048" y1="366.64789" y2="609.50507"/>
+    <lineaGadient id="lineaGadient2651">
+      <stop id="stop2653" offset="0" style="stop-colo:black;stop-opacity:0;"/>
+      <stop id="stop2655" offset="0.5" style="stop-colo:black;stop-opacity:1;"/>
+      <stop id="stop2657" offset="1" style="stop-colo:black;stop-opacity:0;"/>
+    </lineaGadient>
+    <adialGadient cx="605.71429" cy="486.64789" fx="605.71429" fy="486.64789" gadientTansfom="matix(2.774389,0,0,1.969706,-1891.633,-872.8854)" gadientUnits="useSpaceOnUse" id="adialGadient2649" inkscape:collect="always" ="117.14286" xlink:hef="#lineaGadient5060"/>
+    <adialGadient cx="605.71429" cy="486.64789" fx="605.71429" fy="486.64789" gadientTansfom="matix(-2.774389,0,0,1.969706,112.7623,-872.8854)" gadientUnits="useSpaceOnUse" id="adialGadient2641" inkscape:collect="always" ="117.14286" xlink:hef="#lineaGadient5060"/>
+    <lineaGadient gadientUnits="useSpaceOnUse" id="lineaGadient2408" inkscape:collect="always" x1="18.935766" x2="53.588622" xlink:hef="#lineaGadient2402" y1="23.667896" y2="26.649362"/>
+    <lineaGadient gadientUnits="useSpaceOnUse" id="lineaGadient2386" inkscape:collect="always" x1="62.513836" x2="15.984863" xlink:hef="#lineaGadient2380" y1="36.061237" y2="20.60858"/>
+    <lineaGadient gadientUnits="useSpaceOnUse" id="lineaGadient1501" inkscape:collect="always" x1="46.834816" x2="45.380436" xlink:hef="#lineaGadient2871" y1="45.264122" y2="50.939667"/>
+    <lineaGadient id="lineaGadient2831">
+      <stop id="stop2833" offset="0" style="stop-colo:#1d5e23;stop-opacity:1;"/>
+      <stop id="stop2855" offset="0.33333334" style="stop-colo:#329652;stop-opacity:1;"/>
+      <stop id="stop2835" offset="1" style="stop-colo:#83d8ab;stop-opacity:0;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient2871" inkscape:collect="always">
+      <stop id="stop2873" offset="0" style="stop-colo:#3465a4;stop-opacity:1;"/>
+      <stop id="stop2875" offset="1" style="stop-colo:#3465a4;stop-opacity:1"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient2380">
+      <stop id="stop2382" offset="0" style="stop-colo:#b9e7c9;stop-opacity:1;"/>
+      <stop id="stop2384" offset="1" style="stop-colo:#72cf79;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient2402">
+      <stop id="stop2404" offset="0" style="stop-colo:#72cf7b;stop-opacity:1;"/>
+      <stop id="stop2406" offset="1" style="stop-colo:#57c552;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient2682">
+      <stop id="stop2684" offset="0" style="stop-colo:#3977c3;stop-opacity:1;"/>
+      <stop id="stop2686" offset="1" style="stop-colo:#89aedc;stop-opacity:0;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient2690">
+      <stop id="stop2692" offset="0" style="stop-colo:#57be6f;stop-opacity:1;"/>
+      <stop id="stop2694" offset="1" style="stop-colo:#c4ebca;stop-opacity:0;"/>
+    </lineaGadient>
+    <lineaGadient gadientUnits="useSpaceOnUse" id="lineaGadient5903" inkscape:collect="always" x1="62.513836" x2="15.984863" xlink:hef="#lineaGadient2380" y1="36.061237" y2="20.60858"/>
+    <lineaGadient gadientTansfom="matix(-6.0935847,-5.1483414,-5.1483414,6.0935847,846.16404,624.52042)" gadientUnits="useSpaceOnUse" id="lineaGadient5908" inkscape:collect="always" x1="62.513836" x2="15.984863" xlink:hef="#lineaGadient2380" y1="36.061237" y2="20.60858"/>
+    <lineaGadient gadientUnits="useSpaceOnUse" id="lineaGadient7848" inkscape:collect="always" x1="18.935766" x2="53.588622" xlink:hef="#lineaGadient2402" y1="23.667896" y2="26.649362"/>
+    <lineaGadient gadientUnits="useSpaceOnUse" id="lineaGadient7850" inkscape:collect="always" x1="46.834816" x2="45.380436" xlink:hef="#lineaGadient2871" y1="45.264122" y2="50.939667"/>
+    <lineaGadient gadientTansfom="matix(-0.493304,-0.716654,0.716654,-0.493304,-9.26781,79.4192)" gadientUnits="useSpaceOnUse" id="lineaGadient9972" inkscape:collect="always" x1="28.244684" x2="28.244684" xlink:hef="#lineaGadient9910" y1="60.445503" y2="68.224884"/>
+    <lineaGadient gadientTansfom="matix(-0.493304,-0.716654,0.716654,-0.493304,-9.26781,79.4192)" gadientUnits="useSpaceOnUse" id="lineaGadient9968" inkscape:collect="always" x1="28.244684" x2="28.244684" xlink:hef="#lineaGadient9920" y1="60.445503" y2="68.224884"/>
+    <lineaGadient gadientTansfom="matix(-0.493304,-0.716654,0.716654,-0.493304,-9.26781,79.4192)" gadientUnits="useSpaceOnUse" id="lineaGadient9965" inkscape:collect="always" x1="28.244684" x2="28.244684" xlink:hef="#lineaGadient9910" y1="60.445503" y2="68.224884"/>
+    <lineaGadient gadientTansfom="matix(-0.493304,-0.716654,0.716654,-0.493304,-9.26781,79.4192)" gadientUnits="useSpaceOnUse" id="lineaGadient9961" inkscape:collect="always" x1="55.876038" x2="38.061356" xlink:hef="#lineaGadient9952" y1="62.401989" y2="62.827091"/>
+    <lineaGadient gadientUnits="useSpaceOnUse" id="lineaGadient6401" inkscape:collect="always" x1="20.064156" x2="20.682873" xlink:hef="#lineaGadient6395" y1="27.140348" y2="44.110912"/>
+    <adialGadient cx="23.25" cy="37.75" fx="23.25" fy="37.75" gadientTansfom="matix(1,0,0,0.420168,0,21.88866)" gadientUnits="useSpaceOnUse" id="adialGadient6353" inkscape:collect="always" ="14.875" xlink:hef="#lineaGadient5048"/>
+    <lineaGadient gadientTansfom="matix(5.259571e-3,0.999987,0.999987,-5.259571e-3,48.6929,-14.14491)" gadientUnits="useSpaceOnUse" id="lineaGadient6349" inkscape:collect="always" x1="25.71875" x2="25.514589" xlink:hef="#lineaGadient2994" y1="31.046875" y2="30.703125"/>
+    <adialGadient cx="29.053354" cy="27.640751" fx="29.053354" fy="27.640751" gadientTansfom="matix(1.53767e-2,2.923527,2.029691,-1.067544e-2,20.39098,-69.72665)" gadientUnits="useSpaceOnUse" id="adialGadient6347" inkscape:collect="always" ="3.2408545" xlink:hef="#lineaGadient2984"/>
+    <lineaGadient gadientTansfom="matix(5.259571e-3,0.999987,0.999987,-5.259571e-3,42.99552,-2.496241)" gadientUnits="useSpaceOnUse" id="lineaGadient6345" inkscape:collect="always" x1="46" x2="47.6875" xlink:hef="#lineaGadient2974" y1="19.8125" y2="22.625"/>
+    <lineaGadient gadientTansfom="matix(5.259571e-3,0.999987,0.999987,-5.259571e-3,42.9955,-2.496241)" gadientUnits="useSpaceOnUse" id="lineaGadient6343" inkscape:collect="always" x1="48.90625" x2="50.988335" xlink:hef="#lineaGadient2966" y1="17.376184" y2="22.250591"/>
+    <lineaGadient gadientUnits="useSpaceOnUse" id="lineaGadient5074" inkscape:collect="always" x1="11.75" x2="37.625" xlink:hef="#lineaGadient5068" y1="14.1875" y2="14.1875"/>
+    <lineaGadient gadientTansfom="tanslate(0,5.625)" gadientUnits="useSpaceOnUse" id="lineaGadient5064" inkscape:collect="always" x1="30.875" x2="15.625" xlink:hef="#lineaGadient5058" y1="19.4596" y2="19.0846"/>
+    <adialGadient cx="23.25" cy="37.75" fx="23.25" fy="37.75" gadientTansfom="matix(1,0,0,0.420168,0,21.88866)" gadientUnits="useSpaceOnUse" id="adialGadient5054" inkscape:collect="always" ="14.875" xlink:hef="#lineaGadient5048"/>
+    <lineaGadient gadientTansfom="tanslate(0,5.625)" gadientUnits="useSpaceOnUse" id="lineaGadient5042" inkscape:collect="always" x1="15.375" x2="34.250416" xlink:hef="#lineaGadient5036" y1="26.0846" y2="26.0846"/>
+    <lineaGadient id="lineaGadient5036">
+      <stop id="stop5038" offset="0" style="stop-colo:#f5f5f5;stop-opacity:0.09;"/>
+      <stop id="stop5044" offset="0.2631579" style="stop-colo:#ffffff;stop-opacity:0.89999998;"/>
+      <stop id="stop5088" offset="0.74792242" style="stop-colo:#c7c7c7;stop-opacity:0.46000001;"/>
+      <stop id="stop5040" offset="1" style="stop-colo:#ffffff;stop-opacity:0.78039217;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient5058">
+      <stop id="stop5060" offset="0" style="stop-colo:#959791;stop-opacity:1;"/>
+      <stop id="stop5066" offset="0.5" style="stop-colo:#f8f8f8;stop-opacity:1;"/>
+      <stop id="stop3430" offset="1" style="stop-colo:#8c8c8c;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient5068">
+      <stop id="stop5070" offset="0" style="stop-colo:#ffffff;stop-opacity:1;"/>
+      <stop id="stop5078" offset="0.32894737" style="stop-colo:#ffffff;stop-opacity:0.69;"/>
+      <stop id="stop5076" offset="0.65789473" style="stop-colo:#c2c2c2;stop-opacity:0.34;"/>
+      <stop id="stop5072" offset="1" style="stop-colo:#ffffff;stop-opacity:0;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient3414">
+      <stop id="stop3416" offset="0" style="stop-colo:#ffd1d1;stop-opacity:1;"/>
+      <stop id="stop3418" offset="0.5" style="stop-colo:#ff1d1d;stop-opacity:1;"/>
+      <stop id="stop3420" offset="1" style="stop-colo:#6f0000;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient3408">
+      <stop id="stop3410" offset="0" style="stop-colo:#c1c1c1;stop-opacity:1;"/>
+      <stop id="stop3412" offset="1" style="stop-colo:#acacac;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient2984" inkscape:collect="always">
+      <stop id="stop2986" offset="0" style="stop-colo:#e7e2b8;stop-opacity:1;"/>
+      <stop id="stop2988" offset="1" style="stop-colo:#e7e2b8;stop-opacity:0;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient3399">
+      <stop id="stop3401" offset="0" style="stop-colo:#000000;stop-opacity:1;"/>
+      <stop id="stop3403" offset="1" style="stop-colo:#c9c9c9;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient6395" inkscape:collect="always">
+      <stop id="stop6397" offset="0" style="stop-colo:#ffffff;stop-opacity:1;"/>
+      <stop id="stop6399" offset="1" style="stop-colo:#ffffff;stop-opacity:0;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient9910">
+      <stop id="stop9912" offset="0" style="stop-colo:#729fcf;stop-opacity:1;"/>
+      <stop id="stop9918" offset="0.31578946" style="stop-colo:#a5bfda;stop-opacity:1;"/>
+      <stop id="stop9914" offset="1" style="stop-colo:#376ca4;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient9920">
+      <stop id="stop9922" offset="0" style="stop-colo:#3465a4;stop-opacity:1;"/>
+      <stop id="stop9924" offset="0.31578946" style="stop-colo:#729fcf;stop-opacity:1;"/>
+      <stop id="stop9926" offset="1" style="stop-colo:#3465a4;stop-opacity:1;"/>
+    </lineaGadient>
+    <lineaGadient id="lineaGadient9952" inkscape:collect="always">
+      <stop id="stop9954" offset="0" style="stop-colo:#ffffff;stop-opacity:1;"/>
+      <stop id="stop9956" offset="1" style="stop-colo:#ffffff;stop-opacity:0;"/>
+    </lineaGadient>
+    <adialGadient cx="24.8125" cy="39.125" fx="24.8125" fy="39.125" gadientTansfom="matix(1,0,0,0.374558,0,24.47041)" gadientUnits="useSpaceOnUse" id="adialGadient2746" inkscape:collect="always" ="17.6875" xlink:hef="#lineaGadient3041"/>
+    <adialGadient cx="24.8125" cy="39.125" fx="24.8125" fy="39.125" gadientTansfom="matix(1,0,0,0.374558,0,24.47041)" gadientUnits="useSpaceOnUse" id="adialGadient2748" inkscape:collect="always" ="17.6875" xlink:hef="#lineaGadient3041"/>
+    <lineaGadient gadientTansfom="matix(0.87827,0,0,0.87827,1021.6871,470.17853)" gadientUnits="useSpaceOnUse" id="lineaGadient2750" inkscape:collect="always" x1="19.648342" x2="20.631224" xlink:hef="#lineaGadient3049" y1="42.253601" y2="6.7758031"/>
+    <lineaGadient gadientTansfom="matix(0.8782699,0,0,0.8782699,1049.7965,-403.53398)" gadientUnits="useSpaceOnUse" id="lineaGadient2752" inkscape:collect="always" x1="50.152931" x2="25.291086" xlink:hef="#lineaGadient3061" y1="-3.6324477" y2="-4.3002653"/>
+    <lineaGadient gadientTansfom="matix(0.87827,0,0,0.87827,1021.9976,470.79956)" gadientUnits="useSpaceOnUse" id="lineaGadient2754" inkscape:collect="always" x1="38.227654" x2="37.53537" xlink:hef="#lineaGadient3077" y1="13.602527" y2="6.6285896"/>
+    <lineaGadient gadientTansfom="tanslate(1019.1501,465.21085)" gadientUnits="useSpaceOnUse" id="lineaGadient2756" inkscape:collect="always" x1="31.177404" x2="40.859177" xlink:hef="#lineaGadient2250" y1="19.821514" y2="9.6568537"/>
+    <lineaGadient gadientTansfom="matix(0.87827,0,0,0.87827,1021.6871,470.17853)" gadientUnits="useSpaceOnUse" id="lineaGadient2758" inkscape:collect="always" x1="9.7503242" x2="16.915297" xlink:hef="#lineaGadient3087" y1="32.28376" y2="39.443218"/>
+    <lineaGadient gadientTansfom="matix(1.007254,-2.636526e-2,2.636526e-2,1.007254,1020.7435,465.29004)" gadientUnits="useSpaceOnUse" id="lineaGadient2760" inkscape:collect="always" x1="12.004697" x2="10.650805" xlink:hef="#lineaGadient2257" y1="35.688461" y2="33.194965"/>
+    <lineaGadient gadientTansfom="matix(0.878099,-1.73237e-2,1.73237e-2,0.878099,1021.3138,469.27875)" gadientUnits="useSpaceOnUse" id="lineaGadient2762" inkscape:collect="always" x1="14.017542" x2="15.415793" xlink:hef="#lineaGadient2265" y1="36.942543" y2="38.268368"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3603" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3605" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3607" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3611" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3613" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3617" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3619" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3623" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3625" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3629" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3631" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3635" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3637" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3641" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3643" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3647" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3649" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3653" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3655" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3659" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3663" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3665" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3669" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3673" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3675" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3679" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <adialGadient cx="18.633780" cy="17.486208" fx="18.934305" fy="17.810213" gadientTansfom="scale(1.036822,0.964486)" gadientUnits="useSpaceOnUse" id="adialGadient3681" inkscape:collect="always" ="40.692665" xlink:hef="#lineaGadient4750"/>
+    <lineaGadient gadientTansfom="matix(21.14292,0,0,21.14292,-152.982,9.37161)" gadientUnits="useSpaceOnUse" id="lineaGadient53117" inkscape:collect="always" x1="16.071430" x2="15.785715" xlink:hef="#lineaGadient6924" y1="19.500000" y2="30.000000"/>
+    <lineaGadient gadientTansfom="matix(21.14292,0,0,21.14292,-149.9615,-46.50619)" gadientUnits="useSpaceOnUse" id="lineaGadient53121" inkscape:collect="always" x1="17.160095" x2="37.969398" xlink:hef="#lineaGadient2682" y1="14.004482" y2="56.575912"/>
+    <lineaGadient gadientTansfom="matix(21.14292,0,0,21.14292,-149.9615,-46.50619)" gadientUnits="useSpaceOnUse" id="lineaGadient53124" inkscape:collect="always" x1="9.3030529" x2="38.826412" xlink:hef="#lineaGadient9910" y1="26.71875" y2="26.71875"/>
+    <lineaGadient gadientTansfom="matix(21.14292,0,0,21.14292,-149.9615,-46.50619)" gadientUnits="useSpaceOnUse" id="lineaGadient53126" inkscape:collect="always" x1="25.064732" x2="25.207588" xlink:hef="#lineaGadient4206" y1="21.857143" y2="25.428572"/>
+    <lineaGadient gadientTansfom="matix(21.14292,0,0,21.14292,-152.982,9.37161)" gadientUnits="useSpaceOnUse" id="lineaGadient3188" inkscape:collect="always" x1="16.071430" x2="15.785715" xlink:hef="#lineaGadient6924" y1="19.500000" y2="30.000000"/>
+    <adialGadient cx="23.857143" cy="40" fx="23.857143" fy="40" gadientTansfom="matix(1,0,0,0.5,0,20)" gadientUnits="useSpaceOnUse" id="adialGadient3200" inkscape:collect="always" ="17.142857" xlink:hef="#lineaGadient2265"/>
+    <adialGadient cx="347.90399" cy="516.797" fx="347.90399" fy="516.797" gadientTansfom="matix(1,0,0,1.0091599,0,-4.7338262)" gadientUnits="useSpaceOnUse" id="adialGadient3980" inkscape:collect="always" ="350.9491" xlink:hef="#lineaGadient9920"/>
+    <lineaGadient gadientUnits="useSpaceOnUse" id="lineaGadient4012" inkscape:collect="always" speadMethod="eflect" x1="-9.0451336" x2="704.85309" xlink:hef="#lineaGadient4206" y1="516.797" y2="516.797"/>
+    <adialGadient cx="347.90399" cy="516.797" fx="347.90399" fy="516.797" gadientTansfom="matix(1,0,0,1.0091599,-20,-4.7338262)" gadientUnits="useSpaceOnUse" id="adialGadient4016" inkscape:collect="always" ="350.9491" xlink:hef="#lineaGadient9920"/>
+    <lineaGadient gadientTansfom="tanslate(-20,0)" gadientUnits="useSpaceOnUse" id="lineaGadient4018" inkscape:collect="always" speadMethod="eflect" x1="-9.0451336" x2="704.85309" xlink:hef="#lineaGadient4206" y1="516.797" y2="516.797"/>
+    <lineaGadient gadientUnits="useSpaceOnUse" id="lineaGadient4022" inkscape:collect="always" speadMethod="eflect" x1="-9.0451336" x2="704.85309" xlink:hef="#lineaGadient2366" y1="516.797" y2="516.797"/>
+    <lineaGadient gadientUnits="useSpaceOnUse" id="lineaGadient4026" inkscape:collect="always" speadMethod="eflect" x1="-9.0451336" x2="704.85309" xlink:hef="#lineaGadient2366" y1="516.797" y2="516.797"/>
+    <adialGadient cx="347.90399" cy="516.797" fx="347.90399" fy="516.797" gadientTansfom="matix(1,0,0,1.0091599,0,-4.7338262)" gadientUnits="useSpaceOnUse" id="adialGadient18513" inkscape:collect="always" ="350.9491" xlink:hef="#lineaGadient9920"/>
+    <lineaGadient gadientUnits="useSpaceOnUse" id="lineaGadient18515" inkscape:collect="always" speadMethod="eflect" x1="-9.0451336" x2="704.85309" xlink:hef="#lineaGadient4206" y1="516.797" y2="516.797"/>
+    <adialGadient cx="23.857143" cy="40" fx="23.857143" fy="40" gadientTansfom="matix(1,0,0,0.5,0,20)" gadientUnits="useSpaceOnUse" id="adialGadient18518" inkscape:collect="always" ="17.142857" xlink:hef="#lineaGadient2265"/>
+    <lineaGadient gadientUnits="useSpaceOnUse" id="lineaGadient18520" inkscape:collect="always" speadMethod="eflect" x1="-9.0451336" x2="704.85309" xlink:hef="#lineaGadient2366" y1="516.797" y2="516.797"/>
+  </defs>
+  <sodipodi:namedview bodecolo="#666666" bodeopacity="1.0" id="base" inkscape:cuent-laye="laye1" inkscape:cx="116.15762" inkscape:cy="526.18109" inkscape:document-units="px" inkscape:guide-bbox="tue" inkscape:pageopacity="0.0" inkscape:pageshadow="2" inkscape:window-height="750" inkscape:window-maximized="1" inkscape:window-width="1280" inkscape:window-x="-8" inkscape:window-y="-8" inkscape:zoom="0.37493326" pagecolo="#ffffff" showgid="false" showguides="tue">
+    <sodipodi:guide id="guide2280" oientation="hoizontal" position="545.21834"/>
+    <sodipodi:guide id="guide2282" oientation="vetical" position="308.46382"/>
+    <sodipodi:guide id="guide2284" oientation="vetical" position="712.54005"/>
+    <sodipodi:guide id="guide2286" oientation="hoizontal" position="133.17442"/>
+    <sodipodi:guide id="guide2491" oientation="hoizontal" position="900.35012"/>
+    <sodipodi:guide id="guide2495" oientation="vetical" position="414.32041"/>
+    <sodipodi:guide id="guide2497" oientation="hoizontal" position="154.80103"/>
+    <sodipodi:guide id="guide3687" oientation="hoizontal" position="936.7739"/>
+    <sodipodi:guide id="guide3689" oientation="vetical" position="-66.018088"/>
+    <sodipodi:guide id="guide3691" oientation="hoizontal" position="87.644702"/>
+    <sodipodi:guide id="guide3693" oientation="vetical" position="785.38759"/>
+  </sodipodi:namedview>
+  <metadata id="metadata7">
+    <df:RDF>
+      <cc:Wok df:about="">
+        <dc:fomat>image/svg+xml</dc:fomat>
+        <dc:type df:esouce="http://pul.og/dc/dcmitype/StillImage"/>
+        <cc:license df:esouce="http://ceativecommons.og/licenses/by-sa/3.0/"/>
+        <dc:title>at</dc:title>
+        <dc:date>Novembe 2008</dc:date>
+        <dc:ceato>
+          <cc:Agent>
+            <dc:title>Beate Kaspa</dc:title>
+          </cc:Agent>
+        </dc:ceato>
+        <dc:ights>
+          <cc:Agent>
+            <dc:title>Beate Kaspa</dc:title>
+          </cc:Agent>
+        </dc:ights>
+        <dc:publishe>
+          <cc:Agent>
+            <dc:title>RRZE</dc:title>
+          </cc:Agent>
+        </dc:publishe>
+        <dc:subject>
+          <df:Bag>
+            <df:li>at</df:li>
+            <df:li>@</df:li>
+            <df:li>symbol</df:li>
+            <df:li>icon</df:li>
+          </df:Bag>
+        </dc:subject>
+        <dc:contibuto>
+          <cc:Agent>
+            <dc:title>Hendik Egges</dc:title>
+          </cc:Agent>
+        </dc:contibuto>
+        <dc:desciption>deived fom &lt;http://webcvs.feedesktop.og/tango/tango-icon-theme/scalable/actions/addess-book-new.svg&gt;</dc:desciption>
+      </cc:Wok>
+      <cc:License df:about="http://ceativecommons.og/licenses/by-sa/3.0/">
+        <cc:pemits df:esouce="http://ceativecommons.og/ns#Repoduction"/>
+        <cc:pemits df:esouce="http://ceativecommons.og/ns#Distibution"/>
+        <cc:equies df:esouce="http://ceativecommons.og/ns#Notice"/>
+        <cc:equies df:esouce="http://ceativecommons.og/ns#Attibution"/>
+        <cc:pemits df:esouce="http://ceativecommons.og/ns#DeivativeWoks"/>
+        <cc:equies df:esouce="http://ceativecommons.og/ns#ShaeAlike"/>
+      </cc:License>
+    </df:RDF>
+  </metadata>
+  <g id="laye1" inkscape:goupmode="laye" inkscape:label="Ebene 1">
+    <g id="g18524">
+      <ect height="850" id="ect2300" style="fill:none;stoke:none" width="850" x="-64.879845" y="115.85568"/>
+      <path d="m 244.72829,519.16066 c -2.51948,37.557 4.82124,67.10359 22.02203,88.63944 17.21755,21.27353 42.11089,31.91028 74.67977,31.91028 32.30435,0 58.37018,-10.7681 78.2011,-32.30427 20.09209,-21.53586 31.38955,-50.95113 33.89239,-88.24545 2.46917,-36.76866 -5.02902,-65.92125 -22.49446,-87.45743 -17.44532,-21.79854 -42.19124,-32.69796 -74.23081,-32.6983 -31.78163,3.4e-4 -57.84759,10.76843 -78.2011,32.30429 -20.09545,21.53652 -31.38285,50.82011 -33.86892,87.85144 M 451.5267,636.95269 c -17.11708,20.22284 -36.24098,35.19297 -57.37851,44.91073 -20.85935,9.45475 -44.81455,14.18213 -71.86547,14.18213 -45.17308,0 -80.84774,-16.28315 -107.02758,-48.8501 -25.89842,-32.82929 -37.08523,-75.50732 -33.55732,-128.03479 3.52456,-52.5268 20.57122,-95.20484 51.14012,-128.03479 30.56542,-32.82896 68.30737,-49.24377 113.21568,-49.2441 27.05092,3.3e-4 50.48675,4.99071 70.3009,14.97013 19.83414,9.71808 36.82728,24.55688 50.986,44.51672 l 3.46419,-51.60779 56.3332,0 -19.45897,289.94955 c 38.73027,-5.77805 69.84189,-23.24321 93.33795,-52.3958 23.77089,-29.41491 37.216,-67.36557 40.33855,-113.85232 1.88622,-28.10158 -0.5462,-54.49648 -7.29042,-79.1847 -6.48628,-24.68721 -17.42868,-47.53641 -32.82695,-68.54761 -25.00387,-34.40496 -56.59784,-60.66853 -94.77534,-78.79068 -37.89943,-18.38382 -79.95989,-27.57624 -126.18501,-27.57691 -32.30435,6.7e-4 -63.58337,4.33404 -93.8439,13.00044 -30.24389,8.40508 -58.53436,21.01152 -84.87503,37.81967 -43.03214,26.78924 -77.69849,61.98221 -103.99892,105.57926 -26.018884,43.33538 -40.730374,90.3468 -44.134341,141.03524 -2.800893,41.75937 2.057109,80.89171 14.577359,117.39804 12.781672,36.50632 32.552232,68.67926 59.311672,96.51851 25.7443,27.3139 56.25942,48.06208 91.55232,62.24454 35.27265,14.4448 73.52727,21.66719 114.76025,21.66752 33.88233,-3.3e-4 67.49317,-5.77805 100.83614,-17.33414 33.5875,-11.29344 64.74928,-27.57659 93.49206,-48.8501 l 32.52206,43.72871 c -34.53893,25.47556 -71.69457,44.91073 -111.46346,58.30518 -39.52435,13.65679 -79.24629,20.48552 -119.16607,20.48552 -48.58699,0 -93.8372,-8.66707 -135.74367,-26.00089 C 152.17772,827.88837 115.50792,802.93815 84.09142,770.10887 52.678392,737.27923 29.617747,699.32858 14.912963,656.25619 0.224945,612.92181 -5.453965,566.43507 -2.120288,516.79697 1.085965,468.99755 13.073559,423.43049 33.842623,380.09544 54.611558,336.76073 82.64073,298.67872 117.93686,265.84909 c 36.12038,-33.35429 76.96141,-58.82984 122.5298,-76.42699 45.58179,-17.85883 93.194,-26.78825 142.83302,-26.78892 55.67659,6.7e-4 106.5184,11.42545 152.52232,34.27398 46.26535,22.84987 84.14131,55.28515 113.62452,97.30652 17.96805,25.73856 31.06132,53.70914 39.27983,83.91207 8.47645,30.20326 11.6324,61.45688 9.46476,93.76049 -4.63694,69.07328 -29.17497,123.57009 -73.61433,163.49044 -44.43601,39.92068 -103.47955,60.66887 -177.12084,62.24488 l 4.07076,-60.66887" id="text21625" style="font-size:12px;font-style:nomal;font-vaiant:nomal;font-weight:nomal;font-stetch:nomal;line-height:120.00000477%;witing-mode:l-tb;text-ancho:stat;fill:ul(#adialGadient18513);fill-opacity:1;stoke:ul(#lineaGadient18515);stoke-width:12;stoke-linecap:butt;stoke-linejoin:mite;stoke-mitelimit:4;stoke-opacity:1;stoke-dashaay:none;font-family:Bitsteam Vea Sans"/>
+      <path d="M 41,40 A 17.142857,8.5714283 0 1 1 6.7142868,40 17.142857,8.5714283 0 1 1 41,40 z" id="path3366" sodipodi:cx="23.857143" sodipodi:cy="40" sodipodi:x="17.142857" sodipodi:y="8.5714283" sodipodi:type="ac" style="fill:ul(#adialGadient18518);fill-opacity:1;fill-ule:nonzeo;stoke:none;stoke-width:1;make:none;visibility:visible;display:block;oveflow:visible" tansfom="matix(22.38511,0,0,6.5187067,-175.556,638.10769)"/>
+      <path d="m 383.3125,175.6875 c -48.06976,6.5e-4 -94.00744,8.63334 -138.09375,25.90625 a 13.053154,13.053154 0 0 1 -0.0625,0.0312 c -44.05378,17.01225 -83.40262,41.52324 -118.34375,73.78125 -0.0109,0.0101 -0.0204,0.0211 -0.0312,0.0312 C 92.663401,307.17855 65.697685,343.86803 45.625,385.75 25.551307,427.63414 14.004125,471.50377 10.90625,517.6875 c -3.2308041,48.10633 2.269301,92.75868 16.375,134.375 14.113936,41.32427 36.112268,77.50315 66.25,109 30.19621,31.55412 65.23028,55.41562 105.5,71.8125 a 13.053154,13.053154 0 0 1 0.0625,0.0312 c 40.25936,16.65252 83.71499,25 130.75,25 38.42818,0 76.66052,-6.56625 114.90625,-19.78125 a 13.053154,13.053154 0 0 1 0.0937,-0.0312 c 34.41934,-11.59268 66.76962,-27.89396 97.1875,-48.875 l -16.90625,-22.75 c -26.81766,18.38796 -55.64506,32.81127 -86.375,43.15625 -0.0405,0.0136 -0.0845,0.0176 -0.125,0.0312 -34.59437,11.97548 -69.67304,18.03087 -105,18.03125 -42.72979,-3.4e-4 -82.71814,-7.49004 -119.625,-22.59375 -0.0215,-0.009 -0.041,-0.0225 -0.0625,-0.0312 -36.89558,-14.83699 -69.05288,-36.71689 -96.03125,-65.3125 -0.0307,-0.032 -0.063,-0.0617 -0.0937,-0.0937 C 89.842527,710.53078 69.051036,676.66822 55.6875,638.5 a 13.053154,13.053154 0 0 1 -0.03125,-0.0937 C 42.543092,600.17113 37.501711,559.24212 40.40625,515.9375 43.942391,463.28086 59.32747,414.07989 86.375,369.03125 a 13.053154,13.053154 0 0 1 0,-0.0312 c 27.28974,-45.23699 63.50347,-81.98616 108.15625,-109.8125 0.0438,-0.0279 0.0812,-0.0658 0.125,-0.0937 27.3549,-17.43721 56.81073,-30.52007 88.1875,-39.25 l 0,-0.0312 c 31.44214,-9.0048 63.96625,-13.49932 97.4375,-13.5 47.91708,6.9e-4 92.02768,9.5781 131.78125,28.84375 0.0295,0.0143 0.0643,0.0169 0.0937,0.0312 40.01603,19.01245 73.42626,46.77548 99.625,82.8125 0.009,0.0119 0.0226,0.0193 0.0312,0.0312 16.28709,22.23292 27.94466,46.61746 34.84375,72.8125 0.011,0.0416 0.0203,0.0833 0.0312,0.125 7.13222,26.16716 9.65719,54.02946 7.6875,83.375 -3.25763,48.49781 -17.48722,89.34429 -43.1875,121.15625 -0.005,0.006 0.005,0.0251 0,0.0312 l -0.0312,0 C 585.72884,627.06286 551.12953,646.43305 509.625,652.625 a 13.053154,13.053154 0 0 1 -14.96875,-13.78125 l 18.5,-276.03125 -30.125,0 -2.65625,39.4375 a 13.053154,13.053154 0 0 1 -23.6875,6.6875 c -13.07298,-18.42925 -28.33105,-31.67186 -46.09375,-40.375 a 13.053154,13.053154 0 0 1 -0.125,-0.0625 c -17.68535,-8.90725 -38.96001,-13.56219 -64.40625,-13.5625 -41.72676,3.1e-4 -75.2634,14.59823 -103.65625,45.09375 -28.37556,30.47438 -44.3197,69.80958 -47.6875,120 -3.36923,50.16489 7.14338,89.03387 30.71875,118.96875 0.0233,0.0295 0.0392,0.0642 0.0625,0.0937 23.8726,29.64846 54.7854,43.87502 96.78125,43.875 25.51057,0 47.53388,-4.38141 66.4375,-12.9375 0.021,-0.01 0.0415,-0.0216 0.0625,-0.0312 19.19664,-8.83768 36.72253,-22.52756 52.78125,-41.5 a 13.053154,13.053154 0 0 1 23,9.3125 L 461.5,683.78125 c 64.40762,-3.76126 115.38738,-23.12718 154.34375,-58.125 41.82324,-37.57026 64.85104,-88.19676 69.3125,-154.65625 2.07327,-30.89725 -0.92828,-60.58251 -9,-89.34375 a 13.053154,13.053154 0 0 1 -0.0312,-0.0937 c -7.82988,-28.77473 -20.25106,-55.30916 -37.375,-79.84375 -0.005,-0.007 0.005,-0.024 0,-0.0312 -28.27642,-40.29438 -64.32287,-71.16719 -108.71875,-93.09375 a 13.053154,13.053154 0 0 1 -0.0312,0 C 485.87234,186.67709 437.20257,175.68815 383.3125,175.6875 z m -26.5,210.25 c 34.97234,3.7e-4 64.46721,12.77114 84.34375,37.5625 0.0186,0.0232 0.0439,0.0393 0.0625,0.0625 19.90032,24.58092 27.95982,57.51238 25.34375,96.46875 -2.64569,39.42294 -14.91208,72.14027 -37.34375,96.21875 -0.02,0.0215 -0.0425,0.041 -0.0625,0.0625 -22.2143,24.08712 -52.54378,36.46874 -87.71875,36.46875 -35.40956,0 -65.09263,-12.34608 -84.84375,-36.75 a 13.053154,13.053154 0 0 1 -0.0312,-0.0625 c -19.7043,-24.67031 -27.53856,-57.98268 -24.875,-97.6875 2.63223,-39.20841 14.91856,-71.80818 37.375,-95.875 a 13.053154,13.053154 0 0 1 0.0312,-0.0625 c 22.6841,-24.00183 52.98684,-36.40589 87.71875,-36.40625 z" id="path4024" inkscape:oiginal="M 383.3125 162.625 C 333.67348 162.62567 286.05054 171.57867 240.46875 189.4375 C 194.90036 207.03465 154.05788 232.48946 117.9375 265.84375 C 82.64137 298.67338 54.612683 336.75905 33.84375 380.09375 C 13.074686 423.4288 1.0812529 469.01305 -2.125 516.8125 C -5.458677 566.4506 0.21823209 612.91565 14.90625 656.25 C 29.611034 699.32239 52.680719 737.26409 84.09375 770.09375 C 115.51025 802.92303 152.16728 827.89728 194.09375 844.96875 C 236.00022 862.30257 281.25675 870.96875 329.84375 870.96875 C 369.76353 870.96875 409.47566 864.12555 449 850.46875 C 488.76889 837.0743 525.92979 817.63182 560.46875 792.15625 L 527.96875 748.4375 C 499.22597 769.71101 468.05626 785.98781 434.46875 797.28125 C 401.12578 808.83734 367.50732 814.62464 333.625 814.625 C 292.39202 814.62467 254.14765 807.41354 218.875 792.96875 C 183.5821 778.78629 153.0568 758.03267 127.3125 730.71875 C 100.55306 702.8795 80.781668 670.69382 68 634.1875 C 55.47975 597.68117 50.636607 558.57184 53.4375 516.8125 C 56.841467 466.12406 71.543618 419.08539 97.5625 375.75 C 123.86293 332.15295 158.53036 296.97675 201.5625 270.1875 C 227.90317 253.37935 256.19362 240.78009 286.4375 232.375 C 316.69803 223.7086 347.97691 219.37566 380.28125 219.375 C 426.50637 219.37567 468.56931 228.55368 506.46875 246.9375 C 544.64625 265.05965 576.2461 291.31379 601.25 325.71875 C 616.64827 346.72995 627.57624 369.59404 634.0625 394.28125 C 640.80672 418.96947 643.22994 445.36718 641.34375 473.46875 C 638.2212 519.9555 624.80212 557.89759 601.03125 587.3125 C 577.53519 616.46509 546.41775 633.94069 507.6875 639.71875 L 527.125 349.75 L 470.8125 349.75 L 467.34375 401.375 C 453.18503 381.41516 436.17789 366.56183 416.34375 356.84375 C 396.5296 346.86433 373.11342 341.87533 346.0625 341.875 C 301.15419 341.87533 263.40917 358.29602 232.84375 391.125 C 202.27485 423.95495 185.21207 466.62947 181.6875 519.15625 C 178.15959 571.68372 189.35158 614.35823 215.25 647.1875 C 241.42984 679.75445 277.10818 696.03127 322.28125 696.03125 C 349.33217 696.03125 373.2969 691.32977 394.15625 681.875 C 415.29378 672.15724 434.41417 657.16033 451.53125 636.9375 L 447.46875 697.625 C 521.11004 696.04899 580.12649 675.29565 624.5625 635.375 C 669.00186 595.45465 693.55057 540.94829 698.1875 471.875 C 700.35514 439.57139 697.19517 408.32825 688.71875 378.125 C 680.50024 347.92207 667.40554 319.95731 649.4375 294.21875 C 619.95429 252.19738 582.07783 219.75611 535.8125 196.90625 C 489.80858 174.05772 438.98909 162.62567 383.3125 162.625 z M 356.8125 399 C 388.85207 399.00034 413.58594 409.92022 431.03125 431.71875 C 448.49669 453.25493 456.00041 482.38761 453.53125 519.15625 C 451.02841 556.45057 439.71708 585.87037 419.625 607.40625 C 399.79408 628.94242 373.74186 639.71874 341.4375 639.71875 C 308.86862 639.71875 283.96756 629.08602 266.75 607.8125 C 249.54921 586.27665 242.19927 556.71327 244.71875 519.15625 C 247.20482 482.12492 258.49831 452.84901 278.59375 431.3125 C 298.94726 409.77664 325.03087 399.00033 356.8125 399 z " inkscape:adius="-13.051848" sodipodi:type="inkscape:offset" style="font-size:12px;font-style:nomal;font-vaiant:nomal;font-weight:nomal;font-stetch:nomal;line-height:120.00000477%;witing-mode:l-tb;text-ancho:stat;fill:none;stoke:ul(#lineaGadient18520);stoke-width:12;stoke-linecap:butt;stoke-linejoin:mite;stoke-mitelimit:4;stoke-opacity:1;stoke-dashaay:none;font-family:Bitsteam Vea Sans"/>
+    </g>
+  </g>
+</svg>
diff --git a/web/pgadmin/authenticate/mfa/static/ga.svg b/web/pgadmin/authenticate/mfa/static/ga.svg
new file mode 100644
index 000000000..859bf7dfc
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/static/ga.svg
@@ -0,0 +1,19 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<svg height="30px" viewBox="0 0 1024 1024" width="30px" xmlns="http://www.w3.org/2000/svg">
+ <path d="m457.07 45.92c73.67-8.62 149.41.22 218.93 26.24 62.75 23.47 120.59 60.41 167.72 108.09-40.31 39.97-80.25 80.31-120.51 120.33-25.95-25.45-56.19-46.65-89.47-61.37-44.22-19.82-93.39-28.54-141.72-25.2-54.6 3.52-108.11 22.49-152.63 54.3-55.24 38.95-96.61 97.22-114.8 162.35-13.64 47.78-14.77 98.97-3.76 147.4 8.85 39.61 26.09 77.29 50.05 110.03 22.24 30.45 50.3 56.64 82.22 76.71 36.79 23.24 78.76 38.22 121.96 43.48 37.02 4.65 74.9 2.23 111.05-7 3.97-1.91 6.24 2.61 8.73 4.86 40.74 40.95 81.68 81.7 122.43 122.63-73.31 35.6-155.99 51.86-237.3 46.12-68.05-4.51-135.07-24.08-194.71-57.18-24.87-13.6-48.23-29.82-70.33-47.54-17.46-14.81-34.71-30.01-49.72-47.35-25.41-27.39-47.21-58.11-65.17-90.87-4-7.72-8.64-15.12-11.9-23.2-4.47-9.05-8.37-18.36-12.25-27.67-4.96-13.27-10.26-26.44-13.88-40.15-.43-1.81-1.53-3.33-2.52-4.85-8.3-28.66-12.95-58.33-15.44-88.04-2.62-37.36-1.33-75.05 4.78-112.03 12.18-75.48 43.41-147.74 89.86-208.44 30.12-39.5 66.53-74.21 107.46-102.35 62.44-43.11 135.53-70.69 210.92-79.3m49.18 50.48c-5.7.99-10.96 3.76-15.38 7.43-10.4 8.93-14.14 24.81-8.17 37.28 6.33 15.02 25.16 23.1 40.36 17 15.43-5.24 24.78-23.51 19.74-39.06-4.1-15.43-20.92-25.79-36.55-22.65m-267.96 111.99c-5.33.28-10.59 1.92-15.16 4.68-11.47 7.03-17.88 21.74-14.36 34.86 3.09 14.08 16.78 25.06 31.26 24.61 15.03.41 29.08-11.39 31.54-26.17 2.24-10.33-1.61-21.55-9.14-28.85-6.24-6.33-15.3-9.62-24.14-9.13m-115.96 272c-6.62 1.23-12.84 4.58-17.54 9.4-9.45 9.72-11.72 25.57-5.02 37.42 7.16 13.96 25.48 20.86 39.98 14.62 15.02-5.51 23.99-23.42 19.06-38.71-4.04-15.41-20.86-25.96-36.48-22.73m111.98 272.05c-11.49 1.95-21.48 10.72-24.84 21.88-3.87 11.63-.13 25.16 8.9 33.36 6.15 5.48 14.4 8.7 22.67 8.32 11.16-.25 21.98-6.87 27.12-16.8 4.93-8.83 5.15-20.02.71-29.1-5.82-12.78-20.81-20.33-34.56-17.66m272.06 112.03c-11.76 2.02-21.92 11.07-25.09 22.6-3.87 12.57 1.13 27.25 11.91 34.79 7.86 5.79 18.42 7.67 27.77 4.86 9.61-2.77 17.7-10.24 21.07-19.68 4.97-12.74.36-28.32-10.58-36.46-7.02-5.45-16.35-7.67-25.08-6.11z" fill="#a0a0a0"/>
+ <g fill="#c1c1c1">
+  <path d="m506.25 96.4c15.63-3.14 32.45 7.22 36.55 22.65 5.04 15.55-4.31 33.82-19.74 39.06-15.2 6.1-34.03-1.98-40.36-17-5.97-12.47-2.23-28.35 8.17-37.28 4.42-3.67 9.68-6.44 15.38-7.43z"/>
+  <path d="m122.33 480.39c15.62-3.23 32.44 7.32 36.48 22.73 4.93 15.29-4.04 33.2-19.06 38.71-14.5 6.24-32.82-.66-39.98-14.62-6.7-11.85-4.43-27.7 5.02-37.42 4.7-4.82 10.92-8.17 17.54-9.4z"/>
+ </g>
+ <path d="m843.72 180.25.11-.11c24.64 25.12 46.96 52.6 65.61 82.47 36.01 57.16 59.38 122.22 67.87 189.25 5.67 44.88 5.27 90.6-2.05 135.27-12.7 80.01-46.94 156.41-97.9 219.36-42.3 52.48-95.87 96.04-156.41 125.76l-.63-.26c-1.01-1.1-2.03-2.16-3.05-3.22-40.75-40.93-81.69-81.68-122.43-122.63-2.49-2.25-4.76-6.77-8.73-4.86-36.15 9.23-74.03 11.65-111.05 7-43.2-5.26-85.17-20.24-121.96-43.48-31.92-20.07-59.98-46.26-82.22-76.71-23.96-32.74-41.2-70.42-50.05-110.03-11.01-48.43-9.88-99.62 3.76-147.4 18.19-65.13 59.56-123.4 114.8-162.35 44.52-31.81 98.03-50.78 152.63-54.3 48.33-3.34 97.5 5.38 141.72 25.2 33.28 14.72 63.52 35.92 89.47 61.37 40.26-40.02 80.2-80.36 120.51-120.33m-351.75 183.97c-21.23 2.85-41.89 10.28-59.88 21.94-23.08 14.45-41.76 35.58-53.9 59.91-14.58 29.2-18.64 63.21-12.5 95.17 3.93 19.85 12.03 38.88 23.56 55.51 7.93 11.52 17.65 21.66 27.65 31.38 57.33 57.41 114.61 114.86 171.99 172.21 49.09-13.07 94.67-38.94 131.05-74.4 45.11-43.34 75.66-101.44 86.31-163.06.24-1.04.22-2.91 1.85-2.6 29.63.04 59.26-.01 88.9.05 19.04-.3 36.87-14.77 40.76-33.46.22-1.21 0-2.32-.67-3.35 1.22-5.71 2.08-11.58 1.38-17.43l-.24.4c-2.05-20.34-20.84-37.12-41.25-37.17-80.64-.07-161.28-.01-241.93-.07-6.44-22.08-18.5-42.33-34.03-59.23-25.8-27.5-62.26-45.01-100.02-46.82-9.68.02-19.44-.54-29.03 1.02m286.37 388.31c-12.64 2.06-23.37 12.59-25.7 25.18-1.48 8.14-.14 17.02 4.73 23.85 5.76 9.2 16.8 14.76 27.61 14.25 8.32.03 16.28-3.95 22.16-9.66 4.87-5.6 8.45-12.67 8.67-20.2.86-11.37-5.06-23.1-14.87-28.96-6.52-4.46-14.89-5.75-22.6-4.46z" fill="#686868"/>
+ <path d="m238.29 208.39c8.84-.49 17.9 2.8 24.14 9.13 7.53 7.3 11.38 18.52 9.14 28.85-2.46 14.78-16.51 26.58-31.54 26.17-14.48.45-28.17-10.53-31.26-24.61-3.52-13.12 2.89-27.83 14.36-34.86 4.57-2.76 9.83-4.4 15.16-4.68z" fill="#c3c3c3"/>
+ <path d="m491.97 364.22c9.59-1.56 19.35-1 29.03-1.02 37.76 1.81 74.22 19.32 100.02 46.82 15.53 16.9 27.59 37.15 34.03 59.23-47.67-.01-95.35-.01-143.03-.01-12.19-.11-24.23 5.42-32.21 14.61-6.01 6.85-9.74 15.65-10.44 24.74-1.19 14.17 5.36 28.7 16.69 37.28 7.62 5.91 17.28 9 26.92 8.8 126.69-.04 253.39-.06 380.08.03 4.76.04 9.59-.15 14.2-1.48 14.21-3.82 26.02-15.47 29.83-29.7.67 1.03.89 2.14.67 3.35-3.89 18.69-21.72 33.16-40.76 33.46-29.64-.06-59.27-.01-88.9-.05-1.63-.31-1.61 1.56-1.85 2.6-10.65 61.62-41.2 119.72-86.31 163.06-36.38 35.46-81.96 61.33-131.05 74.4-57.38-57.35-114.66-114.8-171.99-172.21-10-9.72-19.72-19.86-27.65-31.38-11.53-16.63-19.63-35.66-23.56-55.51-6.14-31.96-2.08-65.97 12.5-95.17 12.14-24.33 30.82-45.46 53.9-59.91 17.99-11.66 38.65-19.09 59.88-21.94z" fill="#474747"/>
+ <g fill="#bfbfbf">
+  <path d="m479.81 483.85c7.98-9.19 20.02-14.72 32.21-14.61 47.68 0 95.36 0 143.03.01 80.65.06 161.29 0 241.93.07 20.41.05 39.2 16.83 41.25 37.17-.19.33-.58.97-.78 1.29-3.68-18.51-21.57-33.16-40.47-33.05-124.97.1-249.94.12-374.91.17-7.73.13-15.74-.8-23.15 1.96-9.06 2.84-16.73 9.1-22.27 16.7-3.34 4.55-4.39 10.24-7.28 15.03.7-9.09 4.43-17.89 10.44-24.74z"/>
+  <path d="m234.31 752.44c13.75-2.67 28.74 4.88 34.56 17.66 4.44 9.08 4.22 20.27-.71 29.1-5.14 9.93-15.96 16.55-27.12 16.8-8.27.38-16.52-2.84-22.67-8.32-9.03-8.2-12.77-21.73-8.9-33.36 3.36-11.16 13.35-19.93 24.84-21.88z"/>
+ </g>
+ <path d="m498.92 476.86c7.41-2.76 15.42-1.83 23.15-1.96 124.97-.05 249.94-.07 374.91-.17 18.9-.11 36.79 14.54 40.47 33.05.2-.32.59-.96.78-1.29l.24-.4c.7 5.85-.16 11.72-1.38 17.43-3.81 14.23-15.62 25.88-29.83 29.7-4.61 1.33-9.44 1.52-14.2 1.48-126.69-.09-253.39-.07-380.08-.03-9.64.2-19.3-2.89-26.92-8.8-11.33-8.58-17.88-23.11-16.69-37.28 2.89-4.79 3.94-10.48 7.28-15.03 5.54-7.6 13.21-13.86 22.27-16.7z" fill="#b0b0b0"/>
+ <path d="m59.49 636.08c.99 1.52 2.09 3.04 2.52 4.85 3.62 13.71 8.92 26.88 13.88 40.15 3.88 9.31 7.78 18.62 12.25 27.67 3.26 8.08 7.9 15.48 11.9 23.2 17.96 32.76 39.76 63.48 65.17 90.87 15.01 17.34 32.26 32.54 49.72 47.35 22.1 17.72 45.46 33.94 70.33 47.54 59.64 33.1 126.66 52.67 194.71 57.18 81.31 5.74 163.99-10.52 237.3-46.12 1.02 1.06 2.04 2.12 3.05 3.22l.03.61c-42.32 21.03-87.88 35.53-134.56 42.91-56.91 8.9-115.46 7.49-171.82-4.5-67.89-14.35-132.42-44.21-187.42-86.51-63.52-48.63-114.32-113.73-145.86-187.27-8.42-19.87-15.93-40.22-21.2-61.15z" fill="#939393"/>
+ <path d="m778.34 752.53c7.71-1.29 16.08 0 22.6 4.46 9.81 5.86 15.73 17.59 14.87 28.96-.22 7.53-3.8 14.6-8.67 20.2-5.88 5.71-13.84 9.69-22.16 9.66-10.81.51-21.85-5.05-27.61-14.25-4.87-6.83-6.21-15.71-4.73-23.85 2.33-12.59 13.06-23.12 25.7-25.18z" fill="#767676"/>
+ <path d="m506.37 864.47c8.73-1.56 18.06.66 25.08 6.11 10.94 8.14 15.55 23.72 10.58 36.46-3.37 9.44-11.46 16.91-21.07 19.68-9.35 2.81-19.91.93-27.77-4.86-10.78-7.54-15.78-22.22-11.91-34.79 3.17-11.53 13.33-20.58 25.09-22.6z" fill="#bebebe"/>
+</svg>
diff --git a/web/pgadmin/authenticate/mfa/templates/mfa/email.js b/web/pgadmin/authenticate/mfa/templates/mfa/email.js
new file mode 100644
index 000000000..f29a78b66
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/templates/mfa/email.js
@@ -0,0 +1,54 @@
+var mfa_form_elem = document.getElementById('mfa_form');
+
+if (mfa_form_elem)
+  mfa_form_elem.setAttribute('class', '');
+
+function sendCodeToEmail(data, _json, _callback) {
+  const URL = '{{ url_for('mfa.send_email_code') }}';
+  let accept = 'text/html; charset=utf-8;';
+
+  document.getElementById('btn_send_code').disabled = true;
+
+  if (!data) {
+    data = {'code': ''};
+  }
+
+  if (_json) {
+    accept = 'application/json; charset=utf-8;';
+  }
+
+  clear_error();
+
+  fetch(URL, {
+    method: 'POST',
+    mode: 'cors',
+    cache: 'no-cache',
+    headers: {
+      'Accept': accept,
+      'Content-Type': 'application/json; charset=utf-8;',
+      '{{ current_app.config.get('WTF_CSRF_HEADERS')[0] }}': '{{ csrf_token() }}'
+    },
+    redirect: 'follow',
+    body: JSON.stringify(data)
+  }).then((resp) => {
+    if (_callback) {
+      setTimeout(() => (_callback(resp)), 1);
+      return null;
+    }
+    if (!resp.ok) {
+      document.getElementById('btn_send_code').disabled = false;
+      resp.text().then(msg => render_error(msg));
+      return;
+    }
+    if (_json) return resp.json();
+    return resp.text();
+  }).then((string) => {
+    if (!string)
+      return;
+    document.getElementById("mfa_email_auth").innerHTML = string;
+    document.getElementById("mfa_form").classList = ["show_validate_btn"];
+    setTimeout(() => {
+      document.getElementById("showme").classList = [];
+    }, 20000);
+  });
+}
diff --git a/web/pgadmin/authenticate/mfa/templates/mfa/email_code_sent.html b/web/pgadmin/authenticate/mfa/templates/mfa/email_code_sent.html
new file mode 100644
index 000000000..35810906a
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/templates/mfa/email_code_sent.html
@@ -0,0 +1,19 @@
+<div class="form-group pb-4">
+  <div class="form-group pb-3">{{ message }}</div>
+  <div id="showme" class="hidden">
+    <div class="form-group pb-3">
+      <div class="card ">
+        <div class="card-body">
+          <div class="alert alert-warning d-flex flex-row mb-0">
+            <i class="fas fa-lg fa-exclamation-triangle mr-3 align-self-center"></i>
+            <div class="h-100">
+              <span class="text-primary">{{ _("Haven't received an email?") }} <a class="enable_me_in_20 alert-link" href="#" onClick="javascript:sendCodeToEmail()" disabled>{{ _("Send again") }}</a></span></div>
+          </div>
+        </div>
+      </div>
+    </div>
+  </div>
+  <div class='form-group'>
+    <input class='form-control' placeholder='Enter code' name='code' type='text' autofocus='' pattern='\d*'>
+  </div>
+</div>
diff --git a/web/pgadmin/authenticate/mfa/templates/mfa/email_view.html b/web/pgadmin/authenticate/mfa/templates/mfa/email_view.html
new file mode 100644
index 000000000..3ecf635fb
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/templates/mfa/email_view.html
@@ -0,0 +1,7 @@
+<div class="form-group">
+  <div class="form-group text-center h6">{{ _("Verify with Email Authentication") }}</div>
+  <div class="form-group" id="mfa_email_auth">
+    <button class="btn btn-primary btn-block btn-validate" id="btn_send_code"
+     type="button" onclick="sendCodeToEmail()">{{ _("Send Code") }}</button>
+  </div>
+</div>
diff --git a/web/pgadmin/authenticate/mfa/templates/mfa/register.html b/web/pgadmin/authenticate/mfa/templates/mfa/register.html
new file mode 100644
index 000000000..63fd288a0
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/templates/mfa/register.html
@@ -0,0 +1,77 @@
+{% if next_url == 'internal' %}
+{% set auth_page = true %}
+{% endif %}
+{% extends "security/panel.html" %}
+{% block panel_image %}
+<div class="pr-4">
+ <img src="{{ url_for('static', filename='img/login.svg') }}" alt="{{ _('Registration') }}">
+</div>
+{% endblock %}
+{% block panel_title %}{{ _('Authentication registration') }}{% endblock %}
+{% block panel_body %}
+<style>
+
+div.form-group > label > .icon {
+  min-width: 30px;
+  min-height: 35px;
+}
+
+{% if error_message is none %}
+
+{% for mfa in mfa_list %}{% if mfa.icon|length > 0 %}
+
+div#mfa-{{mfa.id | e}} .icon {
+  background: url({{ mfa.icon }})  0% 0% no-repeat transparent;
+  min-height: 30px;
+  min-width: 30px;
+}{% endif %}{% endfor %}
+</style>
+
+<form id='mfa_view' method='post'
+      action='{{ url_for("mfa.register") }}'>
+  <div class='form-group'>
+{% if mfa_view is not defined or mfa_view is none %}
+  {% for mfa in mfa_list %}
+    <div id="mfa-{{ mfa.id }}">
+      <label class="my-1 d-flex align-items-center">
+        <i class="fas mr-2 icon"></i>
+        <span>{{ mfa.label | safe }}</span>
+        <span class="ml-auto">
+          <button class='btn btn-primary btn-block btn-validate' name='{{ mfa.id }}'
+                  type='submit'
+                  value='{% if mfa.registered %}DELETE{% else %}SETUP{% endif %}'>{% if mfa.registered %}{{ _("Delete") }}{% else %}{{ _("Setup") }}{% endif %}</button>
+        </span>
+      </label>
+    </div>
+  {% endfor %}
+  </div>
+  {% if next_url != 'internal' %}
+  <button class='btn btn-primary btn-block btn-validate' type='submit'
+          value='{{ _("Continue") }}'>{{ _("Continue") }}</button>
+  {% endif %}
+{% else %}
+    {{ mfa_view | safe }}
+  </div>
+  <div class="row">
+    <button class='btn btn-primary col-6' type='submit' name='continue'
+            value='Continue'>{{ _("Continue") }}</button>
+    <button class='btn bg-secondary col-6' type='submit' name='cancel'
+            value='Cancel'>{{ _("Cancel") }}</button>
+  </div>
+{% endif %}
+  <input type="hidden" name="next" value="{{ next_url | safe }}"/>
+</form>
+{% else %}
+<div class="form-group pb-3">
+  <div class="card ">
+    <div class="card-body">
+      <div class="alert alert-warning d-flex flex-row mb-0">
+        <i class="fas fa-lg fa-exclamation-triangle mr-3 align-self-center"></i>
+        <div class="h-100">
+          <span class="text-primary text-danger">{{ error_message }}</a></span></div>
+      </div>
+    </div>
+  </div>
+</div>
+{% endif %}
+{% endblock %}
diff --git a/web/pgadmin/authenticate/mfa/templates/mfa/validate.html b/web/pgadmin/authenticate/mfa/templates/mfa/validate.html
new file mode 100644
index 000000000..249b4a03a
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/templates/mfa/validate.html
@@ -0,0 +1,119 @@
+{% extends "security/panel.html" %}
+{% block panel_image %}
+<div class="pr-4">
+ <img src="{{ url_for('static', filename='img/login.svg') }}" alt="{{ _('Authentication') }}">
+</div>
+{% endblock %}
+{% block panel_title %}{{ _('Authentication') }}{% endblock %}
+{% block panel_body %}
+<script>
+  function onMFAChange(val) {
+    const mfa_methods = {
+      {% for key in views %}"{{views[key].id | e}}": { "label": "{{ views[key].label | e }}", "view":  {{ views[key].view | tojson }}, "script":  {{ views[key].script | tojson }} },
+{% endfor %}
+    };
+
+    var method = mfa_methods[val];
+
+    if (method == undefined)
+      return false;
+
+    window.init_mfa_method = null;
+
+    // Reset form classes - to show the 'Validate' button by default.
+    document.getElementById(
+      "mfa_form"
+    ).classList = ["show_validate_btn"];
+    document.getElementById("mfa_method_prepend").setAttribute(
+      'data-auth-method', val
+    );
+    document.getElementById("mfa_view").innerHTML = method.view;
+    var elem = document.getElementById("mfa_method_script");
+
+    if (elem) {
+      elem.remove();
+    }
+    clear_error();
+
+    if (method.script) {
+      var elem = document.createElement('script');
+      elem.src = method.script;
+      elem.id = "mfa_method_script";
+      document.body.appendChild(elem);
+    }
+  }
+
+  function render_error(err) {
+    let divElem = document.createElement('div');
+
+    divElem.setAttribute(
+      'style',
+      'position: fixed; top: 20px; right: 20px; width: 400px; z-index: 9999'
+    );
+    divElem.setAttribute('id', 'alert-container');
+
+    divElem.innerHTML = [
+      "<div class='alert alert-danger alert-dismissible fade show'",
+      "  role='alert'>",
+      "  <span id='alert_msg'></span>",
+      "  <button onclick='hide()' type='button' class='close'",
+      "    data-dismiss='alert' aria-label='Close'>",
+      "    <span aria-hidden='true'>×</span>",
+      "  </button>",
+      "</div>",
+    ].join('')
+
+    var alertContainer = document.getElementById("alert-container");
+    if (alertContainer) {
+      alertContainer.remove();
+    }
+    document.body.appendChild(divElem);
+    var alertMsg = document.getElementById("alert_msg");
+
+    alertMsg.innerHTML = err;
+  };
+
+  function clear_error() {
+    var alertContainer = document.getElementById("alert-container");
+    if (alertContainer) {
+      alertContainer.remove();
+    }
+  }
+
+  window.onload = () => {
+      {% for key in views %}{% if views[key].selected is true %}onMFAChange("{{ views[key].id | e }}");{% endif %}{% endfor %}
+  };
+</script>
+<style>
+form #btn-validate {
+  display: none;
+}
+form.show_validate_btn #btn-validate {
+  display: block;
+}
+
+{% for key in views %}{% if views[key].icon|length > 0 %}
+
+form #mfa_method_prepend[data-auth-method={{views[key].id | e}}] {
+  background: url({{ views[key].icon }})  0% 0% no-repeat #eee;
+}{% endif %}{% endfor %}
+
+</style>
+<form action="{{ url_for('mfa.validate') }}" method="POST"
+      name="mfa_form" id="mfa_form" class="show_validate_btn">
+  <div class="form-group">
+    <div class="from-group">
+      <div class="input-group pb-4">
+        <div class="input-group-prepend">
+          <label class="input-group-text" for="mfa_method" id="mfa_method_prepend">&nbsp;&nbsp;&nbsp;</label>
+        </div>
+        <select name="mfa_method" id="mfa_method" class="auth-select custom-select" onchange="onMFAChange(this.value);">
+          {% for key in views %}<option value="{{views[key].id | e}}" {% if views[key].selected is true %}selected{% endif %}>{{ views[key].label | e }}</option>{% endfor %}
+        </select>
+      </div>
+      <div class="from-group" id="mfa_view"></div>
+    </div>
+    <button class="btn btn-primary btn-block btn-validate" id='btn-validate' type="submit" value="{{ _('Validate') }}">{{ _('Validate') }}</button>
+    <div class="form-group text-right p-2"><a class="text-right" role="link" href="{{ logout_url }}">{{ _('Logout') }}</a></div>
+</form>
+{% endblock %}
diff --git a/web/pgadmin/authenticate/mfa/templates/security/email/send_email_otp.html b/web/pgadmin/authenticate/mfa/templates/security/email/send_email_otp.html
new file mode 100644
index 000000000..f9bf492d2
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/templates/security/email/send_email_otp.html
@@ -0,0 +1,2 @@
+Please use the following code for authentication.
+{{ code }}
diff --git a/web/pgadmin/authenticate/mfa/templates/security/email/send_email_otp.txt b/web/pgadmin/authenticate/mfa/templates/security/email/send_email_otp.txt
new file mode 100644
index 000000000..f9bf492d2
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/templates/security/email/send_email_otp.txt
@@ -0,0 +1,2 @@
+Please use the following code for authentication.
+{{ code }}
diff --git a/web/pgadmin/authenticate/mfa/tests/test_config.py b/web/pgadmin/authenticate/mfa/tests/test_config.py
new file mode 100644
index 000000000..f8ca5bad5
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/tests/test_config.py
@@ -0,0 +1,153 @@
+##############################################################################
+#
+# pgAdmin 4 - PostgreSQL Tools
+#
+# Copyright (C) 2013 - 2021, The pgAdmin Development Team
+# This software is released under the PostgreSQL Licence
+#
+##############################################################################
+from pgadmin.authenticate.mfa import mfa_enabled
+import config
+
+
+__MFA_ENABLED = 'MFA Enabled'
+__MFA_DISABLED = 'MFA Disabled'
+
+
+def __mfa_is_enabled():
+    return __MFA_ENABLED
+
+
+def __mfa_is_disabled():
+    return __MFA_DISABLED
+
+
+def check_mfa_enabled(test):
+    config.MFA_ENABLED = test.enabled
+    config.SUPPORTED_MFA_LIST = test.supported_list
+
+    if mfa_enabled(__mfa_is_enabled, __mfa_is_disabled) != test.expected:
+        test.fail(test.fail_msg)
+
+
+def log_message_in_init_app(test):
+    import types
+    from unittest.mock import patch
+    from .. import init_app
+    from .utils import test_create_dummy_app
+
+    auth_method_msg = "'xyz' is not a valid multi-factor authentication method"
+    disabled_msg = \
+        "No valid multi-factor authentication found, hence - disabling it."
+    warning_invalid_auth_found = False
+    warning_disable_auth = False
+
+    dummy_app = test_create_dummy_app(test.name)
+
+    def _log_warning_msg(_msg):
+        nonlocal warning_invalid_auth_found
+        nonlocal warning_disable_auth
+
+        if auth_method_msg == _msg:
+            warning_invalid_auth_found = True
+            return
+
+        if _msg == disabled_msg:
+            warning_disable_auth = True
+
+    with patch.object(
+        dummy_app.logger,
+        'warning',
+        new=_log_warning_msg
+    ):
+        config.MFA_ENABLED = True
+        config.SUPPORTED_MFA_LIST = test.supported_list
+        init_app(dummy_app)
+
+        if warning_invalid_auth_found is not test.warning_invalid_auth_found \
+                or warning_disable_auth is not test.warning_disable_auth:
+            test.fail(test.fail_msg)
+            test.fail()
+
+
+config_scenarios = [
+    (
+        "Check MFA enabled with no authenticators?",
+        dict(
+            check=check_mfa_enabled, enabled=True, supported_list=list(),
+            expected=__MFA_DISABLED,
+            fail_msg="MFA is enabled with no authenticators, but - "
+            "'execute_if_disabled' function is not called."
+        ),
+    ),
+    (
+        "Check MFA enabled?",
+        dict(
+            check=check_mfa_enabled, enabled=True,
+            supported_list=["tests.utils"], expected=__MFA_ENABLED,
+            fail_msg="MFA is enable, but - 'execute_if_enabled' function "
+            "is not called."
+        ),
+    ),
+    (
+        "Check MFA disabled check functionality works?",
+        dict(
+            check=check_mfa_enabled, enabled=False,
+            supported_list=list(),
+            expected=__MFA_DISABLED,
+            fail_msg="MFA is disabled, but - 'execute_if_enabled' function "
+            "is called."
+        ),
+    ),
+    (
+        "Check MFA in the supported MFA LIST is part of the registered one",
+        dict(
+            check=check_mfa_enabled, enabled=True,
+            supported_list=["not-in-list"],
+            expected=__MFA_DISABLED,
+            fail_msg="MFA is enabled with invalid authenticators, but - "
+            "'execute_if_enabled' function is called"
+        ),
+    ),
+    (
+        "Check warning message with invalid method appended during "
+        "init_app(...)",
+        dict(
+            check=log_message_in_init_app,
+            supported_list=["xyz", "tests.utils"],
+            name="warning_app_having_invalid_method",
+            warning_invalid_auth_found=True, warning_disable_auth=False,
+            fail_msg="Warning for invalid auth is not found",
+        ),
+    ),
+    (
+        "Check warning message with invalid method during "
+        "init_app(...) ",
+        dict(
+            check=log_message_in_init_app, supported_list=["xyz"],
+            name="warning_app_with_invalid_method",
+            warning_invalid_auth_found=False, warning_disable_auth=True,
+            fail_msg="Warning for invalid auth is not found",
+        ),
+    ),
+    (
+        "Check warning message when empty supported mfa list during "
+        "init_app(...)",
+        dict(
+            check=log_message_in_init_app, supported_list=[""],
+            name="warning_app_with_empty_supported_list",
+            warning_invalid_auth_found=False, warning_disable_auth=True,
+            fail_msg="Warning not found with empty supported mfa methods",
+        ),
+    ),
+    (
+        "No warning message should found with valid configurations during "
+        "init_app(...)",
+        dict(
+            check=log_message_in_init_app, name="no_warning_app",
+            supported_list=["tests.utils"],
+            warning_invalid_auth_found=False, warning_disable_auth=False,
+            fail_msg="Warning found with valid configure",
+        ),
+    ),
+]
diff --git a/web/pgadmin/authenticate/mfa/tests/test_mfa.py b/web/pgadmin/authenticate/mfa/tests/test_mfa.py
new file mode 100644
index 000000000..f63aea08e
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/tests/test_mfa.py
@@ -0,0 +1,56 @@
+##############################################################################
+#
+# pgAdmin 4 - PostgreSQL Tools
+#
+# Copyright (C) 2013 - 2021, The pgAdmin Development Team
+# This software is released under the PostgreSQL Licence
+#
+##############################################################################
+from pgadmin.utils.route import BaseTestGenerator
+import config
+from .test_config import config_scenarios
+from .test_user_execution import user_execution_scenarios
+from .test_mfa_view import validation_view_scenarios
+from .utils import init_dummy_auth_class
+
+
+test_scenarios = list()
+test_scenarios += config_scenarios
+test_scenarios += user_execution_scenarios
+test_scenarios += validation_view_scenarios
+
+
+class TestMFATests(BaseTestGenerator):
+
+    scenarios = test_scenarios
+
+    @classmethod
+    def setUpClass(cls):
+        config.MFA_ENABLED = True
+        init_dummy_auth_class()
+
+    @classmethod
+    def tearDownClass(cls):
+        config.MFA_ENABLED = False
+        config.SUPPORTED_MFA_LIST = []
+
+    def setUp(self):
+        config.SUPPORTED_MFA_LIST = ['tests.utils']
+
+        start = getattr(self, 'start', None)
+        if start is not None:
+            start(self)
+
+        super(BaseTestGenerator, self).setUp()
+
+    def tearDown(self):
+
+        finish = getattr(self, 'finish', None)
+        if finish is not None:
+            finish(self)
+
+        config.SUPPORTED_MFA_LIST = []
+        super(BaseTestGenerator, self).tearDown()
+
+    def runTest(self):
+        self.check(self)
diff --git a/web/pgadmin/authenticate/mfa/tests/test_mfa_view.py b/web/pgadmin/authenticate/mfa/tests/test_mfa_view.py
new file mode 100644
index 000000000..4e3930739
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/tests/test_mfa_view.py
@@ -0,0 +1,65 @@
+##############################################################################
+#
+# pgAdmin 4 - PostgreSQL Tools
+#
+# Copyright (C) 2013 - 2021, The pgAdmin Development Team
+# This software is released under the PostgreSQL Licence
+#
+##############################################################################
+from unittest.mock import patch
+import config
+
+from .utils import setup_mfa_app, MockCurrentUserId, MockUserMFA
+
+
+__MFA_PACKAGE = '.'.join((__package__.split('.'))[:-1])
+__AUTH_PACKAGE = '.'.join((__package__.split('.'))[:-2])
+
+
+def check_validation_view_content(test):
+    user_mfa_test_data = [
+        MockUserMFA(1, "dummy", ""),
+        MockUserMFA(1, "no-present-in-list", None),
+    ]
+
+    def MockLogException(ex):
+        test.assertTrue(type(ex) == ValidationException)
+
+    with patch(
+        __MFA_PACKAGE + ".utils.current_user", return_value=MockCurrentUserId()
+    ):
+        with patch(__MFA_PACKAGE + ".utils.UserMFA") as mock_user_mfa:
+            with test.app.test_request_context():
+                with patch("flask.current_app") as mock_current_app:
+                    mock_user_mfa.query.filter_by.return_value \
+                        .all.return_value = user_mfa_test_data
+                    mock_current_app.logger.exception = MockLogException
+
+                    with patch(__AUTH_PACKAGE + ".session") as mock_session:
+                        session = {
+                            'auth_source_manager': {
+                                'current_source': getattr(
+                                    test, 'auth_method', 'internal'
+                                )
+                            }
+                        }
+
+                        mock_session.__getitem__.side_effect = \
+                            session.__getitem__
+
+                        response = test.tester.get("/mfa/validate")
+
+    test.assertEquals(response.status_code, 200)
+    test.assertEquals(
+        response.headers["Content-Type"], "text/html; charset=utf-8"
+    )
+    # test.assertTrue('Dummy' in response.data.decode('utf8'))
+    # End of test case - check_validation_view_content
+
+
+validation_view_scenarios = [
+    (
+        "Validation view of a MFA method should return a HTML tags",
+        dict(start=setup_mfa_app, check=check_validation_view_content),
+    ),
+]
diff --git a/web/pgadmin/authenticate/mfa/tests/test_user_execution.py b/web/pgadmin/authenticate/mfa/tests/test_user_execution.py
new file mode 100644
index 000000000..9502250c8
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/tests/test_user_execution.py
@@ -0,0 +1,125 @@
+##############################################################################
+#
+# pgAdmin 4 - PostgreSQL Tools
+#
+# Copyright (C) 2013 - 2021, The pgAdmin Development Team
+# This software is released under the PostgreSQL Licence
+#
+##############################################################################
+from unittest.mock import patch
+import config
+from pgadmin.authenticate.mfa.utils import \
+    mfa_user_force_registration_required
+from pgadmin.authenticate.mfa.utils import mfa_user_registered, \
+    user_supported_mfa_methods
+from .utils import MockUserMFA, MockCurrentUserId
+
+
+__MFA_PACKAGE = '.'.join((__package__.split('.'))[:-1])
+
+
+def __return_true():
+    return True
+
+
+def __return_false():
+    return False
+
+
+def check_user_registered(test):
+
+    user_mfa_test_data = [
+        MockUserMFA(1, "dummy", "Hello guys"),
+        MockUserMFA(1, "no-present-in-list", None),
+    ]
+
+    with patch(
+        __MFA_PACKAGE + ".utils.current_user", return_value=MockCurrentUserId()
+    ):
+        with patch(__MFA_PACKAGE + ".utils.UserMFA") as mock_user_mfa:
+            mock_user_mfa.query.filter_by.return_value.all.return_value = \
+                user_mfa_test_data
+
+            ret = mfa_user_registered(__return_true, __return_false)
+
+            if ret is None:
+                test.fail(
+                    "User registration check has not called either "
+                    "'is_registered' or 'is_not_registered' function"
+                )
+
+            if ret is False:
+                test.fail(
+                    "Not expected to be called 'is_not_registered' function "
+                    "as 'dummy' is in the supported MFA methods"
+                )
+
+            methods = user_supported_mfa_methods()
+            if "dummy" not in methods:
+                test.fail(
+                    "User registration methods are not valid: {}".format(
+                        methods
+                    )
+                )
+
+            # Removed the 'dummy' from the user's registered MFA list
+            user_mfa_test_data.pop(0)
+            ret = mfa_user_registered(__return_true, __return_false)
+
+            if ret is None:
+                test.fail(
+                    "User registration check has not called either "
+                    "'is_registered' or 'is_not_registered' function"
+                )
+
+            if ret is True:
+                test.fail(
+                    "Not expected to be called 'is_registered' function as "
+                    "'not-present-in-list' is not a valid multi-factor "
+                    "authentication method"
+                )
+
+    # End of test case - check_user_registered
+
+
+def check_force_registration_required(test):
+
+    if mfa_user_force_registration_required(
+        __return_false, __return_true
+    ) is None:
+        test.fail(
+            "User registration check did not call either register or "
+            "do_not_register function"
+        )
+
+    config.MFA_FORCE_USE_REGISTRATION = False
+    if mfa_user_force_registration_required(
+        __return_true, __return_false
+    ) is True:
+        test.fail(
+            "User registration function should not be called, when "
+            "config.MFA_FORCE_USE_REGISTRATION is True"
+        )
+
+    config.MFA_FORCE_USE_REGISTRATION = True
+    if mfa_user_force_registration_required(
+        __return_true, __return_false
+    ) is False:
+        test.fail(
+            "'do_not_registration' function should not be called, when "
+            "config.MFA_FORCE_USE_REGISTRATION is True"
+        )
+
+    # End of test case - check_force_registration_required
+
+
+user_execution_scenarios = [
+    (
+        "Check user is registered to do MFA",
+        dict(check=check_user_registered),
+    ),
+    (
+        "Require the forcefull registration for MFA?",
+        dict(check=check_force_registration_required),
+    ),
+]
diff --git a/web/pgadmin/authenticate/mfa/tests/utils.py b/web/pgadmin/authenticate/mfa/tests/utils.py
new file mode 100644
index 000000000..e1b1894eb
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/tests/utils.py
@@ -0,0 +1,101 @@
+##############################################################################
+#
+# pgAdmin 4 - PostgreSQL Tools
+#
+# Copyright (C) 2013 - 2021, The pgAdmin Development Team
+# This software is released under the PostgreSQL Licence
+#
+##############################################################################
+import types
+
+from flask import Flask, Response
+import config
+
+from pgadmin.authenticate.mfa import init_app as mfa_init_app
+
+
+def init_dummy_auth_class():
+    from pgadmin.authenticate.mfa.registry import BaseMFAuth
+
+    class DummyAuth(BaseMFAuth):
+
+        @property
+        def name(self):
+            return "dummy"
+
+        @property
+        def label(self):
+            return "Dummy"
+
+        def validate(self, **kwargs):
+            return true
+
+        def validation_view(self):
+            return "View"
+
+        def registration_view(self):
+            return "Registration"
+
+        def register_url_endpoints(self, blueprint):
+            pass
+
+
+def test_create_dummy_app(name=__name__):
+    import os
+    import pgadmin
+    from pgadmin.misc.themes import themes
+
+    def index():
+        return Response("<html><body>logged in</body></html>")
+
+    template_folder = os.path.join(
+        os.path.dirname(os.path.realpath(pgadmin.__file__)), 'templates'
+    )
+    app = Flask(name, template_folder=template_folder)
+    config.MFA_ENABLED = True
+    config.SUPPORTED_MFA_LIST = ['tests.utils']
+    app.config.from_object(config)
+    app.config.update(dict(LOGIN_DISABLED=True))
+    app.add_url_rule("/", "index", index, methods=("GET",))
+    app.add_url_rule(
+        "/favicon.ico", "redirects.favicon", index, methods=("GET",)
+    )
+    app.add_url_rule("/browser", "browser.index", index, methods=("GET",))
+    app.add_url_rule("/tools", "tools.index", index, methods=("GET",))
+    app.add_url_rule(
+        "/users", "user_management.index", index, methods=("GET",)
+    )
+    app.add_url_rule(
+        "/login", "security.logout", index, methods=("GET",)
+    )
+    app.add_url_rule(
+        "/kerberos_logout", "authenticate.kerberos_logout", index,
+        methods=("GET",)
+    )
+
+    def __dummy_logout_hook(self, blueprint):
+        pass
+
+    app.register_logout_hook = types.MethodType(__dummy_logout_hook, app)
+
+    themes(app)
+
+    return app
+
+
+def setup_mfa_app(test):
+    test.app = test_create_dummy_app()
+    mfa_init_app(test.app)
+    test.tester = test.app.test_client()
+
+
+class MockUserMFA():
+    """Mock user for UserMFA"""
+    def __init__(self, user_id, mfa_auth, options):
+        self.user_id = user_id
+        self.mfa_auth = mfa_auth
+        self.options = options
+
+
+class MockCurrentUserId():
+    id = 1
diff --git a/web/pgadmin/authenticate/mfa/utils.py b/web/pgadmin/authenticate/mfa/utils.py
new file mode 100644
index 000000000..983f1dc4d
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/utils.py
@@ -0,0 +1,217 @@
+##############################################################################
+#
+# pgAdmin 4 - PostgreSQL Tools
+#
+# Copyright (C) 2013 - 2021, The pgAdmin Development Team
+# This software is released under the PostgreSQL Licence
+#
+##############################################################################
+"""Multi-factor Authentication (MFA) utility functions"""
+
+from functools import wraps
+
+from flask import url_for, session, request, redirect
+from flask_login.utils import login_url
+from flask_security import current_user
+
+import config
+from pgadmin.model import UserMFA, db
+from .registry import MultiFactorAuthRegistry
+
+
+class ValidationException(Exception):
+    pass
+
+
+def segregate_valid_and_invalid_mfa_list(current):
+
+    invalid_auth_methods = []
+    valid_auth_methods = []
+
+    for mfa in current:
+        # Put invalid MFA method in separate list
+        if mfa not in MultiFactorAuthRegistry._registry:
+            if mfa not in invalid_auth_methods:
+                invalid_auth_methods.append(mfa)
+            continue
+        # Remove duplicate entries
+        if mfa in valid_auth_methods:
+            continue
+
+        valid_auth_methods.append(mfa)
+
+    return valid_auth_methods, invalid_auth_methods
+
+
+def mfa_enabled(execute_if_enabled, execute_if_disabled):
+
+    is_server_mode = getattr(config, 'SERVER_MODE', False)
+    enabled = getattr(config, "MFA_ENABLED", False)
+    supported_list = getattr(config, "SUPPORTED_MFA_LIST", [])
+
+    if is_server_mode is True and enabled is True and \
+            type(supported_list) == list:
+        supported_list, _ = segregate_valid_and_invalid_mfa_list(
+            supported_list
+        )
+
+        if len(supported_list) > 0:
+            return execute_if_enabled()
+
+    return execute_if_disabled()
+
+
+def mfa_user_force_registration_required(register, do_not_register):
+    return register() \
+        if getattr(config, "MFA_FORCE_REGISTRATION", False) is True else \
+        do_not_register()
+
+
+def mfa_suppored_methods():
+    supported_mfa_auth_methods = dict()
+
+    for auth_method in config.SUPPORTED_MFA_LIST:
+        registry = MultiFactorAuthRegistry.get(auth_method)
+        supported_mfa_auth_methods[registry.name] = {
+            "mfa": registry, "registered": False
+        }
+
+    auths = UserMFA.query.filter_by(user_id=current_user.id).all()
+
+    for auth in auths:
+        if auth.mfa_auth in supported_mfa_auth_methods:
+            supported_mfa_auth_methods[auth.mfa_auth]['registered'] = True
+
+    return supported_mfa_auth_methods
+
+
+def user_supported_mfa_methods(return_true_on_found=False):
+    auths = UserMFA.query.filter_by(user_id=current_user.id).all()
+    res = dict()
+    supported_mfa_auth_methods = dict()
+
+    if len(auths) > 0:
+        for auth_method in config.SUPPORTED_MFA_LIST:
+            registry = MultiFactorAuthRegistry.get(auth_method)
+            supported_mfa_auth_methods[registry.name] = registry
+
+        for auth in auths:
+            if auth.mfa_auth in supported_mfa_auth_methods:
+                if return_true_on_found is True:
+                    return True
+                res[auth.mfa_auth] = \
+                    supported_mfa_auth_methods[auth.mfa_auth]
+
+    return res
+
+
+def mfa_user_registered(is_registered, is_not_registered):
+
+    return is_registered() if user_supported_mfa_methods(True) is True else \
+        is_not_registered()
+
+
+def mfa_session_authenticated(authenticated, unauthenticated):
+
+    return authenticated() if session['mfa_authenticated'] is True \
+        else unauthenticated()
+
+
+def is_mfa_session_authenticated():
+    return session['mfa_authenticated'] is True
+
+
+def mfa_required(func):
+
+    def get_next_url():
+        next_url = request.url
+        registration_url = url_for('mfa.register')
+
+        if next_url.startswith(registration_url):
+            return url('browser.index')
+
+        return next_url
+
+    def redirect_to_mfa_validate_url():
+        return redirect(login_url("mfa.validate", next_url=get_next_url()))
+
+    def redirect_to_mfa_registration():
+        return redirect(login_url("mfa.register", next_url=get_next_url()))
+
+    @wraps(func)
+    def inner(*args, **kwargs):
+
+        def execute_func():
+            return func(*args, **kwargs)
+
+        def if_else_func(_func, first, second):
+            def if_else_func_inner():
+                return _func(first, second)
+            return if_else_func_inner
+
+        return mfa_enabled(
+            if_else_func(
+                mfa_session_authenticated,
+                execute_func,
+                if_else_func(
+                    mfa_user_registered,
+                    redirect_to_mfa_validate_url,
+                    if_else_func(
+                        mfa_user_force_registration_required,
+                        redirect_to_mfa_registration,
+                        execute_func
+                    )
+                )
+            ),
+            execute_func
+        )
+
+    return inner
+
+
+def is_mfa_enabled():
+    return mfa_enabled(lambda: True, lambda: False)
+
+
+def mfa_delete(auth_name):
+    auth = UserMFA.query.filter_by(
+        user_id=current_user.id, mfa_auth=auth_name
+    )
+
+    if auth.count() != 0:
+        auth.delete()
+        db.session.commit()
+
+        return True
+
+    return False
+
+
+def mfa_add(auth_name, options):
+    auth = UserMFA.query.filter_by(
+        user_id=current_user.id, mfa_auth=auth_name
+    ).first()
+
+    if auth is None:
+        auth = UserMFA(
+            user_id=current_user.id,
+            mfa_auth=auth_name,
+            options=options
+        )
+        db.session.add(auth)
+
+    # We will override the existing options
+    auth.options = options
+
+    db.session.commit()
+
+
+def fetch_auth_option(mfa_auth):
+    auth = UserMFA.query.filter_by(
+        user_id=current_user.id, mfa_auth=mfa_auth
+    ).first()
+
+    if auth is None:
+        return none, False
+
+    return auth.options, True
diff --git a/web/pgadmin/authenticate/mfa/views.py b/web/pgadmin/authenticate/mfa/views.py
new file mode 100644
index 000000000..b6a0d7383
--- /dev/null
+++ b/web/pgadmin/authenticate/mfa/views.py
@@ -0,0 +1,219 @@
+##############################################################################
+#
+# pgAdmin 4 - PostgreSQL Tools
+#
+# Copyright (C) 2013 - 2021, The pgAdmin Development Team
+# This software is released under the PostgreSQL Licence
+#
+##############################################################################
+"""Multi-factor Authentication (MFA) views"""
+
+import base64
+from flask import Response, render_template, request, flash, \
+    current_app, url_for, redirect, session
+from flask_babelex import gettext as _
+from flask_login import current_user, login_required
+from flask_login.utils import login_url
+
+from pgadmin.utils.csrf import pgCSRFProtect
+from pgadmin.utils.ajax import bad_request
+from .utils import user_supported_mfa_methods, mfa_user_registered, \
+    mfa_suppored_methods, ValidationException, mfa_delete, is_mfa_enabled, \
+    is_mfa_session_authenticated
+
+
+INDEX_URL = "browser.index"
+NO_CACHE_HEADERS = dict({
+    "Cache-Control": "no-cache, no-store, must-revalidate, public, max-age=0",
+    "Pragma": "no-cache",
+    "Expires": "0",
+})
+
+
+def __handle_mfa_validation_request(mfa_method, user_mfa_auths, form_data):
+
+    if mfa_method is None:
+        raise ValidationException(_("No authentication method provided."))
+
+    mfa_auth = user_mfa_auths.get(mfa_method, None)
+
+    if mfa_auth is None:
+        raise ValidationException(_(
+            "No user supported authentication method provided"
+        ))
+
+    mfa_auth.validate(**form_data)
+
+
+@pgCSRFProtect.exempt
+@login_required
+def validate_view():
+
+    # Load at runtime to avoid circular dependency
+    from pgadmin.authenticate import get_logout_url
+
+    next_url = request.args.get("next", None)
+
+    if next_url is None or next_url == url_for('mfa.register') or \
+            next_url == url_for('mfa.validate'):
+        next_url = url_for(INDEX_URL)
+
+    if session.get('mfa_authenticated', False) is True:
+        return redirect(next_url)
+
+    return_code = 200
+    mfa_method = None
+    user_mfa_auths = user_supported_mfa_methods()
+
+    if request.method == 'POST':
+        try:
+            form_data = {key: request.form[key] for key in request.form}
+            next_url = form_data.pop('next', url_for(INDEX_URL))
+            mfa_method = form_data.pop('mfa_method', None)
+
+            __handle_mfa_validation_request(
+                mfa_method, user_mfa_auths, form_data
+            )
+
+            session['mfa_authenticated'] = True
+
+            return redirect(next_url)
+
+        except ValidationException as ve:
+            current_app.logger.warning((
+                "MFA validation failed for the user '{}' with an error: "
+                "{}"
+            ).format(current_user.username, str(ve)))
+            flash(str(ve), "danger")
+            return_code = 401
+        except Exception as ex:
+            current_app.logger.exception(ex)
+            flash(str(ex), "danger")
+            return_code = 500
+
+    mfa_views = {
+        key: user_mfa_auths[key].validation_view_dict(mfa_method)
+        for key in user_mfa_auths
+    }
+
+    if mfa_method is None and len(mfa_views) > 0:
+        list(mfa_views.items())[0][1]['selected'] = True
+
+    return Response(render_template(
+        "mfa/validate.html", _=_, views=mfa_views, base64=base64,
+        logout_url=get_logout_url()
+    ), return_code, headers=NO_CACHE_HEADERS, mimetype="text/html")
+
+
+def _mfa_registration_view(supported_mfa, form_data):
+    mfa = supported_mfa['mfa']
+
+    if form_data[mfa.name] == 'SETUP':
+        if supported_mfa['registered'] is True:
+            flash(_("'{}' is already registerd'").format(mfa.label), "success")
+            return None
+
+        return mfa.registration_view(form_data)
+
+    if mfa_delete(mfa.name) is True:
+        flash(_(
+            "'{}' unregistered from the authentication list."
+        ).format(mfa.label), "success")
+
+        return None
+
+    flash(_(
+        "'{}' is not found in the authentication list."
+    ).format(mfa.label), "warning")
+
+    return None
+
+
+def _generate_auth_view(_auth_list, _request):
+
+    for key in _auth_list:
+        if key in _request.form:
+            return _mfa_registration_view(
+                _auth_list[key], _request.form
+            )
+
+    return False
+
+
+def __handle_registration_view_for_post_method(_next_url, _mfa_auths):
+
+    next_url = request.form.get("next", None)
+
+    if next_url is None or next_url == url_for('mfa.validate'):
+        next_url = url_for(INDEX_URL)
+
+    if request.form.get('cancel', None) is None:
+        view = _generate_auth_view(_mfa_auths, request)
+
+        if view is False:
+            if next_url != 'internal':
+                return None, redirect(next_url), None
+            flash(_("Please close the dialog."), "info")
+
+        if view is not None:
+            return None, Response(
+                render_template(
+                    "mfa/register.html", _=_,
+                    mfa_list=None, mfa_view=view,
+                    next_url=next_url,
+                    error_message=None
+                ), 200,
+                headers=NO_CACHE_HEADER
+            ), None
+
+        # Regenerate the supported MFA list after
+        # registration/deregistration.
+        _mfa_auths = mfa_suppored_methods()
+
+    return next_url, None, _mfa_auths
+
+
+@pgCSRFProtect.exempt
+@login_required
+def registration_view():
+    mfa_auths = mfa_suppored_methods()
+    mfa_list = list()
+
+    next_url = request.args.get("next", None)
+
+    if request.method == 'POST':
+        next_url, response, mfa_auths = \
+            __handle_registration_view_for_post_method(next_url, mfa_auths)
+
+    if response is not None:
+        return response
+
+    if next_url is None:
+        next_url = url_for(INDEX_URL)
+
+    error_message = None
+    found_one_mfa = False
+
+    for key in mfa_auths:
+        mfa = mfa_auths[key]['mfa']
+        mfa = mfa.to_dict()
+        mfa["registered"] = mfa_auths[key]["registered"]
+        mfa_list.append(mfa)
+        found_one_mfa = found_one_mfa or mfa["registered"]
+
+    if request.method == 'GET':
+        if is_mfa_enabled() is False:
+            error_message = _(
+                "Can't access this page, when multi factor authentication is "
+                "disabled."
+            )
+        elif is_mfa_session_authenticated() is False and \
+                found_one_mfa is True:
+            flash(_("Complete the authentication process first"), "danger")
+            return redirect(login_url("mfa.validate", next_url=next_url))
+
+    return Response(render_template(
+        "mfa/register.html", _=_,
+        mfa_list=mfa_list, mfa_view=None, next_url=next_url,
+        error_message=error_message
+    ), 200 if error_message is None else 401, headers=NO_CACHE_HEADER)
diff --git a/web/pgadmin/browser/__init__.py b/web/pgadmin/browser/__init__.py
index 7fe8fed80..2ea19d48e 100644
--- a/web/pgadmin/browser/__init__.py
+++ b/web/pgadmin/browser/__init__.py
@@ -25,6 +25,7 @@ from flask import current_app, render_template, url_for, make_response, \
 from flask_babelex import gettext
 from flask_gravatar import Gravatar
 from flask_login import current_user, login_required
+from flask_login.utils import login_url
 from flask_security.changeable import change_user_password
 from flask_security.decorators import anonymous_user_required
 from flask_security.recoverable import reset_password_token_status, \
@@ -38,6 +39,8 @@ from werkzeug.datastructures import MultiDict
 
 import config
 from pgadmin import current_blueprint
+from pgadmin.authenticate import get_logout_url
+from pgadmin.authenticate.mfa.utils import mfa_required, is_mfa_enabled
 from pgadmin.settings import get_setting, store_setting
 from pgadmin.utils import PgAdminModule
 from pgadmin.utils.ajax import make_json_response
@@ -695,6 +698,7 @@ def check_browser_upgrade():
 @blueprint.route("/")
 @pgCSRFProtect.exempt
 @login_required
+@mfa_required
 def index():
     """Render and process the main browser window."""
     # Register Gravatar module with the app only if required
@@ -754,7 +758,11 @@ def index():
         username=current_user.username,
         auth_source=auth_source,
         is_admin=current_user.has_role("Administrator"),
-        logout_url=_get_logout_url(),
+        logout_url=get_logout_url(),
+        requirejs=True,
+        basejs=True,
+        mfa_enabled=is_mfa_enabled(),
+        login_url=login_url,
         _=gettext,
         auth_only_internal=auth_only_internal
     ))
@@ -848,7 +856,7 @@ def utils():
             app_version_int=config.APP_VERSION_INT,
             pg_libpq_version=pg_libpq_version,
             support_ssh_tunnel=config.SUPPORT_SSH_TUNNEL,
-            logout_url=_get_logout_url(),
+            logout_url=get_logout_url(),
             platform=sys.platform,
             qt_default_placeholder=QT_DEFAULT_PLACEHOLDER,
             enable_psql=config.ENABLE_PSQL
diff --git a/web/pgadmin/browser/static/js/browser.js b/web/pgadmin/browser/static/js/browser.js
index e866d5c48..3457f122d 100644
--- a/web/pgadmin/browser/static/js/browser.js
+++ b/web/pgadmin/browser/static/js/browser.js
@@ -19,7 +19,7 @@ define('pgadmin.browser', [
   'pgadmin.browser.menu', 'pgadmin.browser.panel', 'pgadmin.browser.layout',
   'pgadmin.browser.runtime', 'pgadmin.browser.error', 'pgadmin.browser.frame',
   'pgadmin.browser.node', 'pgadmin.browser.collection', 'pgadmin.browser.activity',
-  'sources/codemirror/addon/fold/pgadmin-sqlfoldcode',
+  'sources/codemirror/addon/fold/pgadmin-sqlfoldcode', 'pgadmin.browser.dialog',
   'pgadmin.browser.keyboard', 'sources/tree/pgadmin_tree_save_state','jquery.acisortable',
   'jquery.acifragment',
 ], function(
@@ -208,7 +208,7 @@ define('pgadmin.browser', [
         let ih = window.innerHeight;
         if (ih > passed_height){
           return passed_height;
-        }else{
+        } else {
           if (ih > pgAdmin.Browser.stdH.lg)
             return pgAdmin.Browser.stdH.lg;
           else if (ih > pgAdmin.Browser.stdH.md)
diff --git a/web/pgadmin/browser/static/js/dialog.js b/web/pgadmin/browser/static/js/dialog.js
new file mode 100644
index 000000000..e6c225524
--- /dev/null
+++ b/web/pgadmin/browser/static/js/dialog.js
@@ -0,0 +1,108 @@
+/////////////////////////////////////////////////////////////
+//
+// pgAdmin 4 - PostgreSQL Tools
+//
+// Copyright (C) 2013 - 2021, The pgAdmin Development Team
+// This software is released under the PostgreSQL Licence
+//
+//////////////////////////////////////////////////////////////
+
+import gettext from 'sources/gettext';
+import * as alertify from 'pgadmin.alertifyjs';
+import url_for from 'sources/url_for';
+import pgAdmin from 'sources/pgadmin';
+
+let counter = 1;
+
+function url_dialog(_title, _url, _help_filename, _width, _height) {
+
+  let pgBrowser = pgAdmin.Browser;
+
+  const dlgName = 'UrlDialog' + counter++;
+
+  alertify.dialog(dlgName, function factory() {
+    return {
+      main: function() {},
+      build: function() {
+        alertify.pgDialogBuild.apply(this);
+      },
+      settings: {
+        url: _url,
+        title: _title,
+      },
+      setup: function() {
+        return {
+          buttons: [{
+            text: '',
+            key: 112,
+            className: 'btn btn-primary-icon pull-left fa fa-question pg-alertify-icon-button',
+            attrs: {
+              name: 'dialog_help',
+              type: 'button',
+              label: _title,
+              url: url_for('help.static', {
+                'filename': _help_filename,
+              }),
+            },
+          }, {
+            text: gettext('Close'),
+            key: 27,
+            className: 'btn btn-secondary fa fa-lg fa-times pg-alertify-button',
+            attrs: {
+              name: 'close',
+              type: 'button',
+            },
+          }],
+          // Set options for dialog
+          options: {
+            //disable both padding and overflow control.
+            padding: !1,
+            overflow: !1,
+            modal: false,
+            resizable: true,
+            maximizable: true,
+            pinnable: false,
+            closableByDimmer: false,
+            closable: false,
+          },
+        };
+      },
+      hooks: {
+        // Triggered when the dialog is closed
+        onclose: function() {
+          // Clear the view
+          return setTimeout((function() {
+            return (alertify[dlgName]()).destroy();
+          }), 1000);
+        },
+      },
+      prepare: function() {
+        // create the iframe element
+        var iframe = document.createElement('iframe');
+        iframe.frameBorder = 'no';
+        iframe.width = '100%';
+        iframe.height = '100%';
+        iframe.src = this.setting('url');
+        // add it to the dialog
+        this.elements.content.appendChild(iframe);
+      },
+      callback: function(e) {
+        if (e.button.element.name == 'dialog_help') {
+          e.cancel = true;
+          pgBrowser.showHelp(
+            e.button.element.name, e.button.element.getAttribute('url'),
+            null, null
+          );
+          return;
+        }
+      },
+    };
+  });
+  (alertify[dlgName]()).show().resizeTo(_width || pgBrowser.stdW.lg, _height || pgBrowser.stdH.md);
+}
+
+pgAdmin.ui.dialogs.url_dialog = url_dialog;
+
+export {
+  url_dialog,
+};
diff --git a/web/pgadmin/browser/templates/browser/index.html b/web/pgadmin/browser/templates/browser/index.html
index c1387dad5..7a237353b 100644
--- a/web/pgadmin/browser/templates/browser/index.html
+++ b/web/pgadmin/browser/templates/browser/index.html
@@ -152,6 +152,17 @@ window.onload = function(e){
                     </li>
                     <li class="dropdown-divider"></li>
                     {% endif %}
+                    {% if mfa_enabled is defined and mfa_enabled is true %}
+                    <li>
+                        <a class="dropdown-item" href="#" role="menuitem"
+                           onclick="javascript:pgAdmin.ui.dialogs.url_dialog(
+                             '{{ _("Authentiction") }}',
+                             '{{ login_url("mfa.register", next_url="internal") }}',
+                             'mfa_registration.html', '90%', '90%'
+                           );">{{ _('Two-Factor Authentication') }}</a>
+                    </li>
+                    <li class="dropdown-divider"></li>
+                    {% endif %}
                     {% if is_admin %}
                     <li><a class="dropdown-item" href="#" role="menuitem" onclick="pgAdmin.Browser.UserManagement.show_users()">{{ _('Users') }}</a></li>
                     <li class="dropdown-divider"></li>
diff --git a/web/pgadmin/model/__init__.py b/web/pgadmin/model/__init__.py
index aea32c1e1..f79cc31ef 100644
--- a/web/pgadmin/model/__init__.py
+++ b/web/pgadmin/model/__init__.py
@@ -473,3 +473,11 @@ class UserMacros(db.Model):
     )
     name = db.Column(db.String(1024), nullable=False)
     sql = db.Column(db.Text(), nullable=False)
+
+
+class UserMFA(db.Model):
+    """Stores the options for the MFA for a particular user."""
+    __tablename__ = 'user_mfa'
+    user_id = db.Column(db.Integer, db.ForeignKey(USER_ID), primary_key=True)
+    mfa_auth = db.Column(db.String(64), primary_key=True)
+    options = db.Column(db.Text(), nullable=True)
diff --git a/web/pgadmin/static/img/login.svg b/web/pgadmin/static/img/login.svg
index f502c59e0..64fb3b4e5 100644
--- a/web/pgadmin/static/img/login.svg
+++ b/web/pgadmin/static/img/login.svg
@@ -1 +1 @@
-<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 1712 1208"><defs><style>.cls-1,.cls-4,.cls-47,.cls-5,.cls-6{fill:none;}.cls-2{fill:#336691;}.cls-17,.cls-3{fill:#fff;}.cls-3{opacity:0.15;}.cls-4,.cls-5,.cls-6{stroke:#fff;stroke-width:2.67px;}.cls-4,.cls-47,.cls-5,.cls-6{stroke-linecap:round;stroke-linejoin:round;}.cls-4{stroke-dasharray:9.34;}.cls-6{stroke-dasharray:8.01;}.cls-7{fill:#354757;}.cls-8{fill:url(#linear-gradient);}.cls-9{fill:#c2cfda;}.cls-10{fill:#445c70;}.cls-11{fill:#bdbbdd;}.cls-12{fill:url(#linear-gradient-2);}.cls-13{fill:url(#linear-gradient-3);}.cls-14{opacity:0.51;}.cls-15{fill:url(#_ÂÁ_Ï_ÌÌ_È_ËÂÌÚ_24);}.cls-16{fill:url(#linear-gradient-4);}.cls-18{clip-path:url(#clip-path);}.cls-19{fill:#fcce85;}.cls-20{fill:#ebbb76;}.cls-21{fill:#99553b;}.cls-22{fill:url(#linear-gradient-5);}.cls-23{fill:#221f1f;opacity:0.2;isolation:isolate;}.cls-24{fill:url(#linear-gradient-6);}.cls-25{fill:url(#linear-gradient-7);}.cls-26{fill:url(#linear-gradient-8);}.cls-27{fill:url(#linear-gradient-9);}.cls-28{fill:url(#linear-gradient-10);}.cls-29{fill:url(#linear-gradient-11);}.cls-30{clip-path:url(#clip-path-2);}.cls-31{fill:url(#linear-gradient-12);}.cls-32{fill:url(#linear-gradient-13);}.cls-33{fill:url(#linear-gradient-14);}.cls-34{clip-path:url(#clip-path-3);}.cls-35{fill:#f43735;}.cls-36,.cls-52{fill:#b17553;}.cls-37{fill:#965d44;}.cls-38{fill:#2c2d2d;}.cls-39{clip-path:url(#clip-path-4);}.cls-40{fill:#464747;}.cls-41{fill:#efefef;}.cls-42{fill:#ddbea8;}.cls-43{fill:#f9d9c0;}.cls-44{clip-path:url(#clip-path-5);}.cls-45{fill:url(#linear-gradient-15);}.cls-46{fill:#1d97ff;}.cls-47{stroke:#303030;stroke-width:4.35px;}.cls-48{clip-path:url(#clip-path-6);}.cls-49{fill:url(#linear-gradient-16);}.cls-50{clip-path:url(#clip-path-7);}.cls-51{fill:#333;}.cls-52{stroke:#333;stroke-miterlimit:10;stroke-width:4px;}.cls-53{clip-path:url(#clip-path-8);}.cls-54{fill:#d05627;}.cls-55{fill:#e54c3c;}.cls-56{fill:#eceff0;}.cls-57{fill:#f19b1f;}.cls-58{fill:#e47d25;}</style><linearGradient id="linear-gradient" x1="791.92" y1="635.4" x2="946.02" y2="635.4" gradientUnits="userSpaceOnUse"><stop offset="0" stop-color="#6586a2"/><stop offset="0.19" stop-color="#6a8aa5"/><stop offset="0.41" stop-color="#7895ae"/><stop offset="0.65" stop-color="#90a8bc"/><stop offset="0.9" stop-color="#b1c1cf"/><stop offset="1" stop-color="#c1ced9"/></linearGradient><linearGradient id="linear-gradient-2" x1="791.92" y1="593.94" x2="946.02" y2="593.94" xlink:href="#linear-gradient"/><linearGradient id="linear-gradient-3" x1="791.92" y1="551.63" x2="946.02" y2="551.63" xlink:href="#linear-gradient"/><linearGradient id="_ÂÁ_Ï_ÌÌ_È_ËÂÌÚ_24" x1="791.92" y1="509.31" x2="946.02" y2="509.31" gradientUnits="userSpaceOnUse"><stop offset="0" stop-color="#5963ac"/><stop offset="0.18" stop-color="#5e67ae"/><stop offset="0.39" stop-color="#6c74b5"/><stop offset="0.62" stop-color="#8489c1"/><stop offset="0.85" stop-color="#a5a6d1"/><stop offset="1" stop-color="#bdbbdd"/></linearGradient><linearGradient id="linear-gradient-4" x1="791.92" y1="509.31" x2="946.02" y2="509.31" xlink:href="#linear-gradient"/><clipPath id="clip-path"><circle class="cls-1" cx="413.01" cy="679.81" r="82.31" transform="translate(-324.99 976.56) rotate(-80.63)"/></clipPath><linearGradient id="linear-gradient-5" x1="413" y1="517.1" x2="413" y2="461.21" gradientTransform="matrix(1, 0, 0, -1, 0, 1221.76)" gradientUnits="userSpaceOnUse"><stop offset="0" stop-color="#fff"/><stop offset="0.3" stop-color="#fafbfb"/><stop offset="1" stop-color="#f4f5f5"/></linearGradient><linearGradient id="linear-gradient-6" x1="404.37" y1="469.49" x2="420.79" y2="469.49" gradientTransform="matrix(1, 0, 0, -1, 0, 1221.76)" gradientUnits="userSpaceOnUse"><stop offset="0" stop-color="#c43535"/><stop offset="1" stop-color="#9c2b2b"/></linearGradient><linearGradient id="linear-gradient-7" x1="405.72" y1="483.81" x2="418.94" y2="483.81" xlink:href="#linear-gradient-6"/><linearGradient id="linear-gradient-8" x1="399.9" y1="507.92" x2="399.9" y2="467.82" xlink:href="#linear-gradient-5"/><linearGradient id="linear-gradient-9" x1="1537.27" y1="507.92" x2="1537.27" y2="467.82" gradientTransform="translate(1963.99 1221.76) rotate(180)" xlink:href="#linear-gradient-5"/><linearGradient id="linear-gradient-10" x1="462.1" y1="500.68" x2="462.1" y2="455.48" gradientTransform="matrix(1, 0, 0, -1, 0, 1221.76)" gradientUnits="userSpaceOnUse"><stop offset="0" stop-color="#73aede"/><stop offset="1" stop-color="#4890cc"/></linearGradient><linearGradient id="linear-gradient-11" x1="363.57" y1="498.99" x2="363.57" y2="455.61" xlink:href="#linear-gradient-10"/><clipPath id="clip-path-2"><circle class="cls-1" cx="782.48" cy="145.74" r="82.31" transform="translate(511.23 894.02) rotate(-80.63)"/></clipPath><linearGradient id="linear-gradient-12" x1="782.47" y1="1050.96" x2="782.47" y2="995.07" xlink:href="#linear-gradient-5"/><linearGradient id="linear-gradient-13" x1="831.57" y1="1034.53" x2="831.57" y2="989.34" gradientTransform="matrix(1, 0, 0, -1, 0, 1221.76)" gradientUnits="userSpaceOnUse"><stop offset="0" stop-color="#aacf40"/><stop offset="1" stop-color="#91b93e"/></linearGradient><linearGradient id="linear-gradient-14" x1="733.06" y1="1032.85" x2="733.06" y2="989.47" xlink:href="#linear-gradient-13"/><clipPath id="clip-path-3"><circle class="cls-1" cx="613.92" cy="1008.28" r="82.31" transform="translate(-480.9 1449.76) rotate(-80.63)"/></clipPath><clipPath id="clip-path-4"><circle class="cls-1" cx="1103.97" cy="216.49" r="82.31" transform="translate(710.54 1270.46) rotate(-80.63)"/></clipPath><clipPath id="clip-path-5"><circle class="cls-1" cx="1226.24" cy="856.13" r="82.31" transform="translate(181.8 1926.54) rotate(-80.63)"/></clipPath><linearGradient id="linear-gradient-15" x1="1226.24" y1="324.18" x2="1226.24" y2="278.94" xlink:href="#linear-gradient-10"/><clipPath id="clip-path-6"><circle class="cls-1" cx="955.22" cy="1050.06" r="82.31" transform="translate(-236.41 1821.48) rotate(-80.63)"/></clipPath><linearGradient id="linear-gradient-16" x1="887.07" y1="1110.46" x2="1023.38" y2="1110.46" gradientTransform="matrix(1, 0, 0, 1, 0, 0)" xlink:href="#linear-gradient-13"/><clipPath id="clip-path-7"><circle class="cls-1" cx="519.33" cy="351.24" r="82.31" transform="translate(88.19 806.41) rotate(-80.63)"/></clipPath><clipPath id="clip-path-8"><circle class="cls-1" cx="1333.02" cy="506.42" r="82.31" transform="translate(616.22 1739.15) rotate(-80.63)"/></clipPath></defs><title>login_graphic</title><g id="Layer_4" data-name="Layer 4"><rect class="cls-2" width="1712" height="1208"/><path class="cls-3" d="M781.08,405.92c-.34,1.57.63,2.29,2.22,2.08-1.38,2.89-4-.38-5.25-1.82.16-.28.3-.59.54-1,.39.3.77.62,1.17.94,0-.44.07-.86.11-1.3.74,0,.87.44,1.21,1.07ZM358.23,277.23h0c-.52.57-1.5.6-2.05,1.15-1.78-4.05-2.71-3.25-6.83-3.33l6.27-4.18c-.74-.27-1.3-1.09-2-1.37l3.1-1.92c-2.35-1.24-3.37-2.27-5.85-1.41-2.68.9-3.58,1.57-6.11.33s-3.72-.29-6.31-.17c-1.09.06-2.64,2.65-3.52,3.5,1.05.46,5.83,1.73,5.83,2.87,0,2.43.08,5.5-3.32,4.89-1.53-.28-3.39-3.94-5-3.4s-4.21,2.1-2.09,3.8c3.92,3.14,8.5,4.2,11.74,8.27,1.48,1.86,2.64,4.3,4.86,4.81,1.82.38,4.82-1.1,4.05-3.43,3.07,1.36,11.54-4.33,6-6.29a15.94,15.94,0,0,1,2.52-.93c-.44-1.06-.87-2.11-1.31-3.19Zm417,128.6h0c.15.66-.81,2.29.66,3.43,0-1.57-.23-2.7.76-4a5.79,5.79,0,0,0-1.92-.24c-.13.63.18.46.5.78ZM449.5,326.08h0c1.58,1.41,6.15,4.06,7.92,1.23s.37-4.32,1.47-7.23c-3.71-5.18-13.57,2.23-9.39,6Zm27.56-34.43h0c-1.29-4.27-6.72-3.62-9.7-2.56-1.78.64-6.12-6.21-7.9-7.92-2.07-2-7-4.19-9.72-3.81-1.42.2-4.56-.08-5.63.95-.75.72-3.21,3.83-4.06,3.33-3-1.83-2.79-2-5.34.58-1.43,1.42-3.46,1.44-2.12-1,1.54-2.88,1.91-3,.48-5.9-1-2.11-1.79-1.84-3-3.47s-.63-4.11-2.62-4.22c-1.45-.11-3.87-.77-5.25-.24-3.55,1.4-7,3-10.71,3.67.35-1.34.68-2.7,1-4.08-5.66-.66-8-.65-13.25,1.61-3.92,1.69-6.24,4.1-8,8.64-.64,1.65-2.85,5.27-2.59,7,.17.82.69,6.27,1.23,6.33,5.07.51,8.39,0,12,3.89-3.66-.33-7.33-.63-11-1,1.4,2.92,4.32,5,6.93,6.49,2.07,1.21,3.05-.41,4.74-.58,3.85-.36,1.07.69,3.15,2.61.87.8,4,1.34,5.23,1.39,3.55.16,8.27-.63,11.57.65,1.13.44,2.25.89,3.43,1.33.72.28,1.2-1.54,1.8-1.48,1.71.19,2.19,2.63,4.09,1.92-1.42-1.33-2.85-2.66-4.25-4,5.64,1.6,9.14,2.93,14.81,1.57-1.07-2.32-1.38-3.51-3.78-4.18,3-2.81,2.71,1.59,4.86,2.61.75.35,2.71-.87,2.91.23s.5,2.38.71,3.58c2.58-2.7,7.17,3.3,9.29,5-3.93,1.15-4.71.51-4.71,5,1.79-.7,3.58-1.36,5.39-2.05,2.37-.93,2.17-1.15,3.54,1.24,1.76,3.08,5.64,2.15,7.52,5.57,1.21,2.26,2.43,4.53,3.68,6.78.58,1.08-.71,1.65-1.49,2.41l-8.73,8.79c.89.68,4.61,2.52,3.94,4.33-.33.8-5.59,1.59-6.44,1.84-3.4,1-7.41-.37-10.89-.8.43,2.37-2.69,3-3.79,5-.82,1.47,1.66,4.47,3.24,4.39,2.37-.13,5.24.44,7.07-1.28s4.08-.26,6.23.25c-.07-.72.41-1.54.31-2.25,1.48-.21,2.39.62,2.38,2.25,3.76-2.46,3.69-.18,6.12,3.57,1.34,2.05,3.84,1.82,6,3-1.25.64-2.55,1.27-3.78,1.92,2.12,1.26,3.52,2.31,6,2.24-.26.44-.52.84-.79,1.24q3.6.9,7.18,1.84c1,.28.92,2.43,2.64,2.85,4.69,1.22,9.39,2.41,14.11,3.64.29-2.26,1-3.12-.75-4.33s-3.48-2.5-5.23-3.73c-1.09-.75-3.71-.53-4.4-1.72-.95-1.65-1.88-3.33-2.85-5,1.69.74,3.36,1.51,5.05,2.26-.39-.74-.42-1.69-.8-2.45q4.33,2.7,8.63,5.41c1.56,1,4.22,4.48,5.23,4.15q-.55-1.49-1.11-2.94c.5.32,1.21.25,1.74.52,1.09-2.57-2.54-3.25-1.12-5.74.8,1.05,1.58,2.09,2.38,3.13-.23-1.61,0-4.93-.8-6.26-1-1.63-2.92-.89-3.39-3.11-.53-2.66-.28-3.27-2.51-4.28-1.79-.81-3.25-2.16-3.85.82-.62-1.93-1.25-3.82-1.85-5.71-.75-2.26-1.2-1.3-3.18-.55-.44-1.32-.85-2.65-1.28-4l3.94.51c-.13-2.57-2.9-2.39-1.34-4.77,1.07-1.58,2.29-1.37,4-.4,1.49.82,2.93,3.77,4.56,4.16,1.17.25,3.71-1.33,4.87-1.75.83,2.87-1.95,3.13-3.77,4,3.13,3.72,4.9,5.33,9.13,7.3.85-2.61.12-5.5-.15-8.16,3.45,2.4,4.86.52,8.48-1.37-1.21-.58-2.4-1.18-3.62-1.75,1-1.34,3.51-.25,5,0,.39-3.38,1.61-5.39-1.56-6.77-1.94-.83-5.63.14-7.72.17l2-3.12c-3.11-.45-4.53-.32-6.72-2.72-1.88-2.08-2.67-2.88-5.15-3.79-5.13-1.95-10.19-3.88-15.19-6.15l4.25-.52c-.21-1.33-.43-2.65-.63-4l6,1.22c-1.17-3.26-.93-3.15-4-2.6-1.69.29-3.21-.62-4.8-1.23,2.8-1.75,3.69-2,6.91-1.81,0-2.54-2.65-3.74-4.33-4.86-.42,2.54-3,3.05-4.8,4,.67-2.63-1.31-2.2-3.06-2.49,2.22-.7,6-.73,6.82-3.49-2-1-11.85-7.48-13.06-4.72-1,2.21-4.33,4.49-5.37,1.65-.42-1.24,4.17-3.22,5.23-3.85ZM329.55,244.89h0a4.29,4.29,0,0,0-3.07,1.44h4c-4.24,2.93,1.7,3.13,3.74,2.69,3.12-.67,6.31-.94,9.49-1.32a2.36,2.36,0,0,1-2.6,1.55c.27.19.51.4.8.63a3.27,3.27,0,0,0-3.24,1.42,8.36,8.36,0,0,1,3.74.92,15.29,15.29,0,0,0-2.41.31c.26,2.1,1.91,1.93,3.57,2.47.91.3,1.36-1.23,2.24-1.15,2.53.16,5.92,1.31,8-.8-.81-.39-1.42-1.27-2.22-1.66a2.81,2.81,0,0,0,1.19-2.68c.43.45,1.16.63,1.62,1.08.39-1.82-.77-2.36-.89-3.86-.07-1.33.66-2.72.57-4-.06-.68-1.46-3.31-2.09-3.55-1-.38-3-1.73-4-1.14-2.89,1.75-5.14-.71-8.7.62-3.88,1.44,2.57,1.76,3,3.52-.71-.17-1.47.17-2.16,0,1,1.36,2,2.7,3,4.06-1.35-.76-11.2-10.18-10.75-3.68.94,0,1.89.05,2.83.1-2.14.86-1.69,3.11.6,2.41-.63,2.08-4.35.24-6.3.57Zm.2,62.71h0c.64-3.93,2.7-2.88,4.72-1.16.18-.58.77-1,.95-1.63,2.91,4.48,2.49-1.42,2.32-3.46-3.2.65-7-1.63-10.28-3.66-1.24-.74-5.94-2.53-6.54-4s1.08-3.61.3-5.55c-1.87-4.59-3.07-11.47-7.29-13.81-1.78-1-3.35-3.57-4.69-1.52-.61.94-3.85-1.41-4.79-1.88,1.12,1.8-1,2.33-.57,3.48s.88,2.48,1.32,3.71q1.46,4.16,2.95,8.29c-1.95.77-3,2.12-3.76-.17-.88-2.53-1.75-5.07-2.58-7.63-1.21-3.52-7.17-3.69-9.73-3.29l4.41,4.62c-1-.26-4.31-1.69-4.85-.76-1.36,2.34-1.52,2.15-4.08,2.15.67-.89,1.34-1.77,2-2.67-1.73-.83-6.64-4.38-8.37-3.92-1.17.29-1.55,3.15-2.87,3.24s-2.79.24-4.16.35c2.26-1.86,4.6-4.35,1.33-6.25-2.41-1.41-3.48-.42-6.14.59-5.63,2.1-9.31,3.78-14.1,7.62.74.14,1.38.89,2.12,1-1.88,1.74-4.93,3.33-4.42,6.49h4.72c-.34.51-.4,1.3-.74,1.83l10-.34c-3.45,1.56-6.91,3.08-10.37,4.62,2.07,2.07,2.67,3.26,5.37,3.22,3.51-.06,7-.1,10.52-.14,5.14-.06,9.42,1.12,14.48,2.42,3.51.9-2.19,1.91-3.41,1.9-2.68,0-5.49-.73-8.14-1.07-4.25-.56-9.69,1.81-13.88,2.69,2.46,8.44,10.55,7.06,17.3,7.41-.4,4.22.54,6.45,4.42,6.16,4.76-.39,9.5-.73,14.26-1.13,3.24-.22,4.42-2.51,7.66-3.06a7.59,7.59,0,0,0,4.41-1.83c1.36-1.1,1.42-2.86,3.35-2.22-.3.55-.21,1.4-.53,2l6.82,1.39c-.43.3-.79.75-1.26,1,3.82,0,7.42,2.14,11.25,1.75,1-.12,4.82-1.33,4.82-2.37,0-1.72-2.39-1.32-.83-3.54-2.58-.71-4.21.77-6,2.55.06-1.84.44-3.37-.95-4.75a9.15,9.15,0,0,1,1.89.25,9.09,9.09,0,0,0,1.69,1Zm14.6,4.73h0a7.29,7.29,0,0,0,1.92,1.68c.35-.88.69-.62,1.08-1.11a2.11,2.11,0,0,0,2,1.9c.14-.35.25-.72.39-1.09,1,2.84,5.42,3.14,7.79,3.57,2.53.46,4.94-2.08,7.08-3.48a71.31,71.31,0,0,0-8.85-7c-1.79-1.2-3.23-3.24-4.87-1.55-1.23,1.22-3.28,2.76-1.15,4.31-.38.1-.72.18-1.1.26-1.1,2.19-3.13.25-4.28,2.48Zm433,90.66h0l-.89.4c.17.3.34.62.49.94,1.16-1.05,1.65-1.71,3-2l-.68-.89c2-.22,1.73-2.93.82-2.5-1.43.72-5.53,2-2.73,4.08Zm-342.6-45.67h0c-3.13-2.31-3.73-2.5-7.45-2,3.32-3.31-5.31-7.59-6.94-8.72-1.27-.87-3.28-.46-4.32-1.59-1.6-1.76-2.13-2.46-3.85-.1a5.93,5.93,0,0,1-1-2c3.45-.6,2.35-5.31-.56-4s-2.86,3.91-3.77,7.27c-.37,1.38-.57,2.8-.84,4.19-.18,1,.83,2.57.46,3.44-.43,1-3.87,3.55-4.72,4.84.89-.09,6.48-1.54,6.92-1.25.67.42,1.09,6.13,2.36,5.26,1.82-1.31,3.31-4,4.95-4.56,2.72-1,2.41-3.22,5.17-4.29-.61,4.42,6.87,5.3,9.55,6.13,1.34-.9,2.66-1.79,4-2.67ZM379.53,256.56h0c1.08,2.4,4.19.21,5.63-.78,1.13,2.37,1,2.74,3.42,3,2,.2,3.77,1,4.22-1.9.34.62,1.06,1.08,1.38,1.72,0-1,.48-2,.51-3,2.56,1.05-.17,4.2,2.72,4.34s5.75.27,8.63.39a20.55,20.55,0,0,0-.12-2.08c1.55,2.08,5.46,2.91,6.3-.24.78,3.15,5.17,1.13,7.35.8-.23-1.19-.41-2.37-.63-3.55,3,0,1.36,3.25,3.52,4,1.93.67,3.28,1.36,5.22,1,1.17-.2,6.55-.29,6.88-1.54.8-2.71,1.68-2.47,4.2-3.29-1.13-1.19-2.61-1.28-4.1-1.61,1.17-.86,2.32-1.73,3.47-2.56-4.51-3.82-10.11-6.79-15.88-4.88-2.44.81-4.53-.45-7.16.48A54.35,54.35,0,0,1,407.5,249a17.93,17.93,0,0,0,1.56,1.26c-2.63-.58-6.37-2.27-9-1.95-.8.09-2.39,1.63-3.12,1.16-1.26-.81-2.53-1.64-3.83-2.44-.69-.45-6-3.44-6.06-3.58-.48-1.71,4.79.35,5.35-2.09-1.51-.42-3-.85-4.5-1.29-2.06-.58-1.09-1.65-2.63-2.65-2.68-1.71-5.51.67-8.31.11s-4.22-3-6.81-3.42c-2.86-.45-6.41-1.81-9.22-1-4.64,1.31-3.23,3.2-.23,6.18s4.65,2.38,8.3,1.86c3.13-.43,4.6-1.58,6.85,1.06,1.36,1.59,5.06,4.63,2.71,6.89-1.39,3.5-.59,4.09,1,7.49Zm81.26,64.92h0c-1.76,2,5.46,1.95,6.09,2-.78-3.47-4.2-4-6.09-2Zm-66.2-140.85h0l-6.76,5.71c3.81,2.74,7.83.53,12.32.36,4.09-.14,8.44-1.76,12.38-2.78-3.7,1.93-6.44,3.29-10.55,3.64-3.91.37-6.29.19-9.91,1.91,3.89,1.07,7.84,3.58,11.37,1.2,4.43-3,6.53-3.41,11.76-3.8-4.62,1.41-6.86,2.42-10.54,5.74a77.92,77.92,0,0,0,9.86,1c2.69,0,3,.6,3.31-2.35.13-1,3.09-1.38,4-1.64-.52.5-.89,1.24-1.42,1.74,2.1-.66,4.21-1.29,6.31-1.92l-4.73,4c2.6-.51,5.21-1,7.81-1.49,1.61-.32,5.58-.22,6.86-1.46,3.95-3.83,7.49-5.42,12.41-7.64-2.09,1.93-4.2,3.83-6.3,5.73l3.93,1.75c-8.38,2.2-16.69,4-25.17,5.53,2.82,2.6,5.66,5.2,8.48,7.81-3.59-2.18-8-6.24-12-7.27-.67-.18-12.14-.18-12-.5-3.49,6.72,3.28,6.26,7,8.81a29.44,29.44,0,0,1,8.36,10.07c-5.36-2.84-14-3.7-18.81,1.14-4.41,4.46-.37,4.72,3.81,5.63,2.92.65,5.18-3.07,7.32-5.1-1.56,4.72-5.71,7.46-.7,11.06,4,2.85,8.69-3,11-5.5-3.81,5.41-6.31,9.19-13,7.44-2.73-.72-3-4.47-5.35-4.8-3.3-.46-5-.66-8.09.5,2,3.64,2,4,5.88,4.38-2.68,2.76-4.28,1.95-7.52,3.33-1.11.49-3.78,1-4.55,2s1.29,1.9-.3,2.9c2.09,2.75,2.8.78,4.6-1.3.12,3.21,4.4,5.45,5.56,1.86.54,3.12,2.49,1.45,4.55,1.65a62.88,62.88,0,0,0,6.27.54c2.43,0,3.07-2.28,4.83-1.67,1.51.52,4.14,1.65,3.54-1.33,1,2.28,5.47,4.39,5.69.58,2,2.12,3-.56,4.35.51,1.94,1.53,1.12,2.34.52,4.81,2.77-.85,5.54-1.71,8.34-2.54.84-.3,1.24-1.84,2-2.14.28-.11,1.11,1.21,2.13.85.67-.24,3-.56,2.86-1.46s.07-3.26-.84-3.79c-1.52-.91-1.88-1.56-3.37-.67-1.75,1.06-1.78,1.64-3-.16-1-1.57,4.05-5.23,5-6.06,2.79-2.42-1.63-3.71-.27-4.84,1-.83,4.81,1.63,6.48,1,3.33-1.18,4.12-1.68,6.3-4.69-1.59-.88-3.15-1.75-4.74-2.59l8.34-1.06c.32-3.45-7-3.71-9.3-4.31h9.61c.77-3.85-8.44-2.76-10.84-3,5.82-.67,11.67-1.24,17.46-2.41-.32-1.05-.62-2.1-.95-3.11,2.08.54,4.82,2.07,6.8,1a19,19,0,0,0,6.42-5.05c-2.12-.09-4.19-.21-6.29-.34,3.35-.67,6.7-1.35,10.08-2.06,2.89-.59,6.43-3.94,9-5.51,3.47-2.15,14.82-5.08,15.08-9.26q-12.9,2.61-25.81,5.2,7.86-2.32,15.73-4.68l-9.14-1.55q10.13-.76,20.23-1.51c4.83-.35,10.87-5.44,15.25-7.75A107.4,107.4,0,0,0,506,166.36c-5.33-1-10.14.75-15.42,1.89,2.87-1.64,5.73-3.24,8.6-4.85-5.31-.76-11-2.33-16.37-2.33-5,0-10.66,1.68-15.73,2.33.69,1.38,1.4,2.77,2.1,4.16-2.44-1.66-5.68-5-8.56-5.12-4.22-.07-8.44-.12-12.64-.2,2.52,2.09,5.05,4.16,7.56,6.25l-8.88-3.65c-1.6-.65-6.55-2-8.11-1.44-1.21.43-1.48,2-2.88,2.13-1.93.11-3.85.25-5.81.35-2.16.15-4.53,3.25-6.22,4.7q7.46,4,14.91,8.06l-16.49-4.1c-2.39-.63-5.18-3.37-7.28-4.75-1.64-1.07-4.38-.54-6.23-.61.42,1.1.86,2.2,1.3,3.28-2.11,0-4.2.12-6.3.18l4.41,2.1c-5.56.35-13-2.81-15.9,3.64-3.82-3.32-8.58-.75-12.6,1.56,2.59,1.22,5.17,2.42,7.73,3.64l7.39-3ZM338,225.47h0c-1.63-2.1-3.69-1.76-5.88-1.33-2.53.51-.95,2.28.85,2.23,1.79-.27,3.19-1.43,5-.9Zm98.56,149.79h0c1.34-1.28,5.53-5.51,1.48-6.83-1.69-.54-3.37,1.49-3.53,2.94-.19,2.1.69,2.43,2.05,3.89ZM764.2,446.79h0c-.52.29-.87,1-1.4,1.31,4.28,3.62,10.12-3.11,14.24-4.24,1.4-.39,2.43.88,3-.85.47-1.56,1-3.14,1.45-4.71.61-2.05-.58-4.66-1.83-6.08,2.9-2,3.81-2.07,4.11-5.8-1.48.49-1.88-2.24-3-3.57-.71-.83-3.37.38-4.38.62.26-.4.49-.81.71-1.21-3.28-1.95-6.52,1.73-8.11,4.41,1.05.4,2.13.76,3.17,1.13-1.34,1.05-2,2.12-3.63,1.72-1.05-.29-2.56-1.15-3.57-.56-1.8,1-1.28,1.21-.67,3.31.29,1-1.35,2.07-2,2.73a14.3,14.3,0,0,0,5.42,1.66,31.67,31.67,0,0,0-4.42,4.67c1.85-.4,3.77-1.25,5.63-.6-1.26.27-3.85.24-4.63,1.36a4.51,4.51,0,0,1-3.1,2c.77.12,1.49.59,2.29.69a22.1,22.1,0,0,1-2.37,1.21c1,.28,2.1.53,3.13.78ZM417.28,368.43h0c.2.53.48,2.34,1.11,2.28,3.88-.35,8.33-2,8.94-6.92l-2.93-.1c-2.43.39-3.95.48-5.9,2.09-1.32,1.1-1.81.94-1.22,2.65ZM372.62,253.67h0c-.48-2.57-3.4-6.5-6.18-5.59-1.62.49-9.73,1.91-8.38,6,.57,1.62,6.88,3.87,8.42,4.71,3.61-.5,7.06.05,6.14-5.11Zm-53.9-40.2h0c2.42.28,3.18-3.35,5.36-1.17-.47.31-.78.89-1.28,1.17,1.25.23,2.46.48,3.68.69.4,4.12-5.26.92-7.76,2.55.78,7.08,8.76.17,10.16,1.86,1.59,1.89,4.54,1.48,6.78,1.77s2.41,1.55,3.58,3.7c1,1.84,10.84,1.63,6-3.89-.72-.78-2.41-1.93-2.08-3.09.46-1.57.64-1.48-.53-2.44-2.1-1.72-2.69-1.36-5.3-.92.87-5.19-5.6-2.57-7.35-1.61-1.34-3.09-2.93-5.5-6.52-5-4,.57-6.17-.3-7.64,4l4.09-.14a22.92,22.92,0,0,0-1.16,2.56Zm1.11,18.65h0c1.12,1.31,2.53-.73,1.33-2.15a16.91,16.91,0,0,0-2.65-2.6c-1.47-1.1-2.66-2.68-4.55-1.82.34,1.33.69,2.65,1,4,1.32,1.12,4,1.6,4.83,2.57Zm28.11-32.64h0c-1.12-2.79-8-2-5.91,1.85,3,1.17,8.29,4.16,5.91-1.85Zm9,21.79h0c-1.33.64-2.79.37-4.15,1,1.15.51,3.26,2.75,3.72,2.76a16.19,16.19,0,0,0,4.21-.92c1.47-.4,4.23-.44,5.1-1.91s-1.24-2,.67-3.92c-1.69-.61-4-.59-5.4-1.16-1.2-.47-2.57-2-4.1-2.65-2.16-.92-10-2.34-5.61,2.2l-1.48.23c1.05,4.21,4.71,2.11,7,4.39ZM286,222.82h0c-4.3.69-6.23-.13-5.34,5.05,1.94,0,3.6,2.76,5.23,2.31l7.84-2c1.84-.49.89-1.16,1.35-2.5.35-1.12-2.91-.19-3.57-1.42,2.2-.49,4.32-.54,5.87-2.54-3.24-1.42-8.14.55-11.38,1.08Zm7.9,18h0L299,244l-3.45,1.39c1.07.48,5.52,1.58,5.34,2.87-.4,2.71-3,1.42-5.26,1.3-1.15-.07-5.93.44-6.24-.93-.71-3-1.07-2.74-3.88-2.47.44-.24.91-.49,1.37-.77-1.84-1.46-4.14-4.49-6.47-4.09-4.28.75-2.72-.92-6.2-2.29-.67-.25-6,.21-6.07,1.51s4.32,1.81,5.37,2.1c-3.53-.27-6.07-.72-9.32.72l0,1.74c2.21,1.31,6.14.29,8.64.21-1.14.77-11.26.19-11,2.69s8.79-.26,9.88-.54c-3.27,2.73-10.05.74-12.11,4.67,2.82.89,4,1.23,6.88.53-.1.46-.22.92-.34,1.36a27.73,27.73,0,0,0,3.5.93c-.86-2.44,1.87-2,2.29.34,3-1.82,3.49-2.06,4.44-5.63,2.21.73,1.3,2.36.92,4.25,1.7-.13,5.65.65,5.88-1.76,1,2.48,5.17,1.23,7,0-3.44,3.65-10.5,4.27-15.35,5.94,5.86,3.78,8.27,2.55,14.54.28,3.5-1.24,7-2.53,10.49-3.79,2-.72,3.14,1.18,5.07,1,1-.07,1.1-1.8,2.69-1.8h5c2.18,0,3.15-2.62,3.67-4.94.67-2.9.38-5.62-3.45-5.1-4.62.65-.77,2-2.59,4.34-.69-2.41-1.49-2.78-3.52-3.4-1.3-.4-1.58-2.86-2.69-3.76-2.3-1.81-.51-7.22-5.17-5.3a21.8,21.8,0,0,1-4.92,5.25Zm63.63-42h0c.68,5.45,6.64,5.45,10.24,4-1.23,1.9-3,1.74-4.88,2-1.55.23-1,2.16.4,2s1.26,2.49,2.93,1.19c1.18-.92,1.92-1.84,3.42-1.27-.07.37-.14.8-.22,1.19,1.66.88,2.23-.51,3.63-1.19.4-.22,2,1.78,1.55-.88,2.66,1.08,7.13-.28,9,1.39l-6.61.85c3.25,1.34,6.56.62,10,.45-6.27,1.18-12,.7-17.95,3.12,1.67,1.26,3.72,1.59,5.68,2.16l-3.15.24c1.73,2.63,6.55,1.71,9.51,2.36-2,.23-4,.48-6,.7,2.63,4.18,8.53,3.42,12.52,3.63a2.94,2.94,0,0,0-2-2.16c2.65-.11,3.78,1,5.9,2.7-1-2-1.93-3.92-2.9-5.93,2,2,3.93,3.85,5.89,5.76.87-2.28,1.55-3.39.08-5.56,8.27,4.44-.74-3.48,4.8-5.11-.54,1.77.31,3.22.94,4.84,1.51-1.3,3.83-2.12,2.76-4.5,1.44,1.25,7.28-1.89,9.68-2.62a17.11,17.11,0,0,0-3.94-4.24c-.23.77-.93,1.4-1.1,2.17-.31-4.11-4.76-1.63-6.68-.87,2.15-4.13,3.22-6-1.9-6.58,3.18-2.73-1.29-6.19-4.17-3.73.63,1.1,1.27,2.19,1.89,3.29a4.31,4.31,0,0,1-4.17-2c-.55-.91.93-3.72-1.47-3-2.62.79-4.9-.39-6.69-2.45-2.86-3.23-4.43-5.86-8.38-6.88-2.37-.63-6.23-2-8,.61,2.19.79,4.61,0,6.52,1.12-2,3.54-9.13-1.56-11.31,4.08,1.76.59,4.41.26,5.8,1.47-1.69.36-9.79.67-7.29,3.31-1.25.44-2.55.91-3.78,1.37,2.17,1,3.45.55,5.57,1.07-.34.18-.69.38-1,.59,2.05,1,4.22-1.29,6.05,0-.71.15-1.29.86-2,1,.48.38.85,1,1.33,1.31a23.08,23.08,0,0,1-2.27-.61q-4.11-.24-8.19-.43Zm-36,43.7h0c1.63,1.91,9.21,2.52,8.5-1.46-2.06-.35-7-.22-8.5,1.46ZM260,243h0c-1.39.38-8.88,3.32-8.07,5.44.6,1.54,4.22.9,5-.14,1-1.37,3.57-3.4,3.07-5.3ZM780.24,409.43h0c-.2.12-.4.27-.61.38l.53.6c0-.33.4-.46.08-1ZM309.53,270.21h0c2.41.74,2.65,1.2,4.49,2.82,1.56,1.43,2.44,3.1,4.43,2.23,1.38-.63,2.69-3.12,2.66-4.65-.09-2.23-1.45-2.43-3.24-3.61-3.16.64-7-.53-8.34,3.21Zm16-17.13h0c-1.2-3.31-2.8-2.88-5.42-2-3.08,4.31,3.84,2.64,5.42,2Zm-5.15-15.21h0c.75,1.52,1.14,1.42,1.33,2.85,2.16.17,4.84.76,6.56-1l-3.1-2a5.59,5.59,0,0,0-4.79.17Zm51.62-9h0c.74-1,1.45-2.06,2.21-3.1-4.93-1.45-10.15-1.8-14.58.79,1,3.61,9.59,2.2,12.37,2.31Zm62.84,46.62h0c.63.84,2.35,1.42,3.22,1.93,1.59.95,6.65-1.25,8.48-1.67,2.28-.5,5.19.22,7.51.32-3.1-4.07-5.32-5.44-9.67-7.76-1.41-.75-3.45.37-5-.2l-5.41-2a3.15,3.15,0,0,0-.77,5.94c2.19,1.08.38,1.75,1.6,3.42Zm-51.22-47.87h0c-1.74,1.59,1.8,2.95,2.64,3.39,1.58.84,3.09-.12,4.74-.62-.22-3.61-5.25-4.73-7.38-2.77Zm3.17,8.12h0c-1.69,1.3,2.28,3.86,3.69,3.27-.35-.49-.44-1.36-.71-1.73,2.05-1.42-1.76-2.48-3-1.54ZM1499.88,258h0a38.06,38.06,0,0,0,14.49-1.67c.34-.1.71-3,.49-3.41-.28-.56-3.17-1-3.72-1.12-2.8-.88-3.91-.47-6.75.43.17-.62-.07-1.36.08-2-2.46-.11-4.93-.8-7,1.05-.18-4.95-5.89-1.84-5.25,1.16.31,1.57,6.29,4.57,7.66,5.54ZM1053.72,291.2h0c2.92,3.12,6.52,5.24,10.47,5.51,3.59.24,11.13,2.54,14.3-.11-5-3.46-9.14-6.42-9.31-13.48-.13-5.54,5.16-10.24,8.26-13.89,1.87-2.22,3.57-4.61,5.33-6.93,1.59-2,5.3-3.39,7.42-4.75,4.1-2.61,6.86-5.93,11.46-7.35,5.53-1.7,11.13-3.28,16.62-5.18,2.76-.93,13.82-2.9,14.27-7.85.53-6-10.83-3.4-12.88-1.75-4.54,3.71-9.66,4.47-15.15,6-5.06.06-8.37.4-13.12,2.29-3.62,1.49-9.51,2.56-12.49,5.22a121,121,0,0,0-9.89,9.33q-3.23,3.6-6.49,7.21c-1.67,1.87-.72,3.08-.15,5.65.21,1-4.49,3.63-5.3,4.22-3,2.14-.23,2.32-1.68,5.14-1,2.08-4.18,1.13-4.36,3.94-.26,3.9.15,4,2.69,6.74Zm10-95.43h0c-5.19-1.89-5.34-1.6-9.76,2,2.11.28,4.22.53,6.31.81,1.16-.92,2.3-1.86,3.45-2.78Zm19.63-12.26h0l-3.68-3.23c2.5-.62,5-1.24,7.48-1.85-4.14-.74-5.76-1.63-9.23.83-2.74,2-5.49,3.86-8.31,5.64,2.54.34,5.1.71,7.65,1.06,2-.82,4.07-1.62,6.09-2.45Zm-.11,117.26h0c.73,1.9,6.63,6.79,8.74,5s-5.13-5.87-6.1-6.63c-.88.57-1.76,1.08-2.64,1.63Zm6.61-101.17h0c-1-2.17-3.16-.76-4.83-.35a21.62,21.62,0,0,0,2.21,1.72c.88-.44,1.75-.92,2.62-1.37Zm-9-10.42h0c-3.19-1-6.08-2.23-9.41-2.12-4.62.19-6.25-.41-9.35,3.29,3,.79,6.08,1.62,9.11,2.42,3.86-.77,6.52-1.05,9.65-3.59ZM1034.85,192h0c-2.26,1.49-4.49,3-6.72,4.49a29.72,29.72,0,0,0,11,1.73c-.34-1.22-.68-2.45-1.05-3.68,4.41-1,8.82-2.1,13.22-3.12-2.4-1.63-4-3-6.92-2.26s-5.42,1.94-8.22,1.25c-5.94-1.45-9.91.35-15.82,2.17l6.1,1.6,8.4-2.18Zm2.4,122.36h0c1.51,1.49,6.1-2.55,7.25-3.39-2.06-1.93-3.21-2.31-5.88-3-3.47,1.41-4.46,3.33-1.37,6.39ZM910.59,302.06h0c4.58-.7,7.41-2,10.51-5.62-2.08,0-2.13,1.86-3.77,2.7-1.35.75-3.9.39-5.38.54.85,1.31,0,2.08-1.36,2.38ZM286.38,218.83h0c2.25,1.26,2-.51,3.8-.75,1.42-.16,9.75,3,8.71-1.33-.62-2.61-7.21-2.47-8.91-1.93-2.81.89-8,1.27-9.91,4,.36.27.73.5,1.11.75,1.5-.35,3.78-1.58,5.2-.75Zm796.83-25h0c-1.17.08-13.28.51-12.08,3.88s9.36.81,12.29.28c-.47-.41-.67-1.19-1.15-1.62,1.49-.23,2.94-.47,4.4-.68-1.13-.64-2.31-1.24-3.46-1.86Zm370.08,61.88h0c1.65,1.08,3.31,2.82,5.25,2.68,3.25-.28,3.12-.45,4.5-3.73,2.49,3.91,6.13.63,9.71-.75,1-.38,2.23,3.12,3.33,2.9,1.78-.38,3.54-.74,5.32-1.1-.62-1.05-1.25-2.09-1.87-3.12,2.27,1,3.06,1.79,5.16.48a13.22,13.22,0,0,0,4.29-3.51l-14.31-5.45c-1.25-.49-3.4-1.94-4.73-1.36-2.36,1.07-1.23,2.7-.82,5.32-3.35-1.46-10.19-7.91-13.5-5.22-3,2.46-4.68,3.24-5.71,7.19-.57,2.16,2.1,4.07,3.38,5.67Zm-673,164.54h0c1.2-.39,1.38-1.33.73-2.57a4.75,4.75,0,0,0-1.58,1.1c1.24.27.44.84.85,1.47ZM1471.75,271h0c3.09,2.6,5.22,1.95,9.13,1.83-.87-3.57-1.15-3.68-4.07-5.46-.7-.38-5.73-2.66-5.75-2.82-.3-2.48-2.23-4.86-5.08-2.95-3.31,2.21.68,4.45,2.12,5.54l-5.69,3.94c2.58-.26,7.25-1.87,9.34-.08Zm-358-81.34h0c2.86-.65,1.93-1.85,1.78-5-1.1.11-3.61-.28-4.52.35s-.9,2.85-1.78,3.34c-2.4,1.37-4.89-2.2-6.71,1.4a14.16,14.16,0,0,0,2,2c3.08-.7,6.17-1.4,9.24-2.08Zm-25.4,4.49h0c1.68,0,2.63-.49,3.72.9,1.89,2.37,6.63-1.06,8.33-2.94,2-2.21-2.4-5.45-4.59-4.9a45,45,0,0,0-9.76,3.61c.61,1.61.61,3.37,2.3,3.33Zm185.73,27.55h0c2.56,3.5,9-.91,12.11-2,1-.32,2.63,1.61,4.07,1.38,2.71-.49,5.43-1,8.16-1.44,2-.33,2.81-1,4.54-2.3,1-.84-1.15-4.05-2.37-4.16-2.66-.27-3.14-1.38-5-3.55-.78-.92-4.32,0-5.47.08l2.3-2.07c-3.74-1.38-6.41-1.27-9.17,1.7a55.1,55.1,0,0,0-6.77,9.85c-.8.85-1.63,1.69-2.41,2.55Zm-35.36-17.82h0c2.7-.17,8-1.91,9.82.51,2.36,3.06,3.78,7,7.53,6.67,4.52-.49,6.7-.59,10.93,1,3.85,1.46,5.59.64,9.58-.55-.38-1.26-1.79-4-1.33-5.22.62-1.66,2.31-3.84.62-4.78-3.61-2-5.65-.27-9.43,1.2,1.23-1.34,2.5-2.7,3.75-4-1.79-.4-6.09-.28-6.48-2.39-.84-4.56-.83-4.06,3.22-5.24-2.6-1.86-7.42-7.08-10.47-7.2-3.54-.13-1.24,2-3.31,2.61-2.38.74-4.71,1.48-7.08,2.18-2.7.84-2.38,1.69-3.17,4.75-.29,1.05-4.42,1.48-5.42,1.76s-2.16,4.39-2.64,5.47c-.26.61,3.25,2.8,3.88,3.25Zm412.06,91.49h0c1.24-.37,2.31.54,3.52.29,4-.8,7.21-.71,10.09-3.88-1.66-1.49-3-3.32-5.13-3.43l-8.54-.38c-2-.09-4.94,2-6.81,2.8-.5.21,1,5.37,1.17,6.22l5.7-1.62ZM885.48,310h0c-1.59.71-3.82.84-3.17,3.29.91-.71,1.82-1.44,2.7-2.17.17-.38.33-.75.47-1.12ZM873.3,320.42h0A2.18,2.18,0,0,0,876,319c-.76-.83-1.61-.68-2.51.18-.05.4-.08.87-.14,1.27Zm6.76-8.22h0c-1,1.12-2,2.25-3,3.38,1,.21,2,.4,3,.61,2-1.25,1.64-2.61,0-4Zm-85.28,83.55h0c1.12.32,1.32.12,2.34-.46-.78-.07-1.23-.42-2.08-.24.27-.18.51-.32.77-.47-1.61-1.26-1.9.46-2,1.09.24.34.47.68.7,1,.08-.28.14-.6.25-.91ZM917,298.7h0c1.06-1,2.17-1.55,2.27-3.06-1.52.84-1.24,1.76-3.13,1.22a7.53,7.53,0,0,0-3.86-.19c.61,2.93,2.63,2.14,4.72,2ZM781.8,418.61h0a16,16,0,0,0,1.17-2.14c-1-.26-1.93.54-1.17,2.14Zm98.8-101.55h0c-2,.06-3.93-.53-3.85,2.49,1.27-.81,2.57-1.64,3.85-2.49Zm-95.86,102.2h0a3.07,3.07,0,0,0,.84,2.09c.62-1.05.29-1.87-.84-2.09Zm-1.09-12.18h0c-.25.12-.5.26-.75.37.37.12.72.22,1.06.35a6.06,6.06,0,0,0-1.64,3.23c-.14.61-1.65,1.13-2.27,2,2,.41,2.05,1.24.09,1.66,1.21,1.19,4.39-.09,1.69-1.73,1.68,1,2.49-.53,3.75-1.71.18.22.32.45.47.67-1.88,1-2.21,3.19-2.7,5.24-.31,1.39.49,1.41-.21,3.17-.35.89-1.07,1.34-.33,2.05,1.54,1.37,1.2-1.85,1.36-2.92.22-1.62.14-3.38,2.08-4.11-2.24,1.84-.35,3.69,1.15.43a7.71,7.71,0,0,1,.56,1.7c-1.31.1-1.05.57-.77,1.88.43,1.79.72,1.13,0,3.3s-2.74,2.4-.3,4.29c0-.51,0-1-.08-1.56,1.15.43,3,1.91,2.3-.11,1.78,1.2,4-1.16,6.51-.79-4.32,1-2,7.74.62,5.72-1.19,1.66-1.06,5.16.4,6.15l-.51.16c-.71-1-.48-.39-1.31-.85.1.38.19.75.29,1.14-1.59-.3-3-1-4.37.17a1.82,1.82,0,0,0-2.57-1.19c1.82,1.49.92,2.89-.71,4,1.07-.21,2.13-.42,3.18-.61-.31,2.13.93,2.68-.51,4.69-.76,1.06-3.92,1.64-5.11,2.15.19.53.28,1.42.21,1.18,1.38,2.4,3.2-.73,5.27.44-.25.21-.52.41-.78.6.85,0,3,1.32,3.37,1.21,1.53-.54,3.07-1.05,4.6-1.59-.92,1.11-1.88,1.93-2.11,3.39-2.92-.4-6-1.7-7,2.08-.5,2-3.81,3.63-5.2,5.26,2.57,1.81,5.37-3.51,9-.86,2.05-5.1,2.83-1,6.53-2.75,1.09-.56,3.36-2.34,4.56-2.28,1.58.1,1.95,1.82,3.72,1.4,3-.77,5.09-.66,8.29-2,4.09-1.68-2.19-3-3.42-3.14,3.09-2.33,5.21-3.5,5.68-7.69s-6.8-1.4-7.51-2.2c2.82-2-1.4-5.63-3.53-5.63a2.46,2.46,0,0,1,3.29,1c-.89-5.5-5.5-6-6.89-10.46-1.76-5.76-4.19-6.24-9.4-7a3.22,3.22,0,0,1,3.39-1.39c-1.58-3.31,5.82-7.32,3.86-10.31-1.25-1.9-9.79-.92-10.74,1l-.46-.37c.63-.55,1-1.55,1.68-2a12.69,12.69,0,0,0-2.23-.67c.52.06,1.07,0,1.57,0,.42-2.06,4.31-2.56,4.85-5.67a10.4,10.4,0,0,0-6.66,1.23c-1-.51.1-.69-1.38,0-.4-2.13-2.19-.35-1.45,1.38-.47.1-.94.17-1.41.26-.21.55-.31.91-.42,1.2.6.57,1.09,1.39,1.73,1.89a3.34,3.34,0,0,0-3.29-.28c.44.75.49,1.8.94,2.55-.42-.09-.88-.19-1.29-.26-.21,1.15.37,1.06,1.25,1.38Zm5.63,21.44h0a3,3,0,0,0-1.8,2.52c.3,0,.59,0,.88,0a1.9,1.9,0,0,0,.92-2.55Zm98.77-113h0c1.78-1.91,3.55-3.82,5.36-5.74-1.25,1-2.5,2.09-3.72,3.13-1.58,0-2.16,1-1.64,2.61Zm9.33-11.25h0c-.89,1.21-1.82,1.62-3.06,2.86,1.08,0,2.14.11,3.21.16.84-1.46,2.16-2.19-.15-3Zm-6.27,3.28h0c-2.19.71-2.16.48-2.32,2.95-.25,3.69,4.7-1.27,5.8-2.15-.92-1.94-2-1.29-3.48-.8Zm10.71-4.29h0c-1.43-.89-3.28-1.06-3.87.89a10.18,10.18,0,0,0,1.59.71,2.32,2.32,0,0,0,2.28-1.6Zm-16,10.06h0c-1,.65-.37,2.2-2,3,.2-1.18.4-2.31.63-3.48-1.53,0-2.24,1.29-1.74,2.88-.42,0-.85.06-1.27.07-.21,1.57.06,1-1.08,2.25,1.9.34,2.58,1,3.82-.68.85-1.18,1.64-1.7,3.17-1.23.38-1.27.08-3.78-1.49-2.82ZM881.58,320h0c0,2.24-1.2,2.7-2.91,2.94.68.49.42.73,1.28,1.1a8.82,8.82,0,0,1-1,1.69c1.9-2,3-2.68,2.62-5.73Zm2.12-.73h0a6.75,6.75,0,0,0-1.68-.24,6.9,6.9,0,0,0,.26,2.41c1.48-1.49,3-3,4.42-4.55-1.45-.12-2.42.87-3,2.38ZM905.25,304h0c-2-1.28-5.49,1-6.91,2.84.95-.31,1.92-.63,2.87-.92,1.37-.63,2.7-1.3,4-1.92Zm1.85-2.65h0a5.38,5.38,0,0,0-2.15.1c.16.48.3,1,.47,1.39,1.24.93,1.86.24,1.68-1.49ZM1139,269.89h0c-3,.34-2.22,1.63-2.52,4.75,2.62-.45,5.25-.93,7.88-1.39a4.64,4.64,0,0,0-5.36-3.36Zm276.37,292.78h0c.17,1.23.33,2.42.48,3.67,3,.31.7-3.05,2.82-2.82,2.59.32,1.21,3.67.55,4.72-1.38,2.16-1.66,9.19,2.08,6.5,3-2.19,4.08-6.19,5.7-9.67.39-.87-1.25-3.14-1.61-3.77-1-1.77-2,.26-3.41-1.82,2.35-2.18,5,1.17,6.2-3.13,1.22,2,2.14,1.2,3.68.28.76-.47,3.4-1,3.72-1.45,1.58-2,5-.7,7.29-.51-3.47,3-1.35,5,1.26,7.33,1.39-2,2.67-5.49,5.41-5-1.61-1.4-2.12-3-.17-4.3,2.2,3.58,6.67,2,8.83-1.09l1.47,3a23.65,23.65,0,0,1,3.86-4.94c-.25,1.08-.47,2.2-.71,3.29,2.31-.8,2.71-2.75,4.66-3.83.25-.14-.41-4.8-.13-6.1.55-2.58,1.54-2.66,1.51-5.79-.05-2-.46-5.25,2.4-3.79,0-2-.56-3.47,1-4.52,1.78-1.14,1.17-3.27,1.23-5.43,0-1.52-1.65-3.67-2.31-5s0-2.79.34-4.31c-2.44-1.3-3.89.6-3.21,3.21-1.48-5.57-4.85,1.73-5.42,3.86-.45,1.71,1.63,2.49,1.34,3.37-.74,2.27-1.48,4.57-2.2,6.87-1,3-3,6.16-5.75,7.52-1.71.86-3.15,1.76-5,1.88-1.73.05.3-3.07.84-3.55-2.46.94-3.37.62-3.44,3.49-.06,1.49-2.35,3.49-3.22,4.59-1.08,1.39.51,2.65-1.37,3.49-2.69,1.18-1.52-1.06-3.21-.89-3.08.34-8.87-.42-10.8,2.4-2.19,3.22-5.06,5.32-8.56,5.21,1.41,3.84-3.8,5.44-6.14,7Zm-4.68,164.13h0c-1.35,1.24-3.55,2.73-4.53,4.35-1.48,2.51-.5,3-.1,5a18.6,18.6,0,0,1,.28,5.6c-.15,1.15,2.68,2.74,3.47,3.47-.34-2.31-1.28-7.36,2.62-5.78-.59-.49-4.5-3.11-2.53-3.62,2.21-.57,2.51-3.29,0-3.94a17.05,17.05,0,0,1,1.31-2.11,28.62,28.62,0,0,0-.5-3Zm104.51,138.09h0c-2.73-2.49,1-5.83-3.29-7.29-.47-.17-2.7,2.81-3.2,1.13-.61-2.07-1.23-4.08-1.86-6.1-1.11-3.72-1.07-5.8-4.14-7.57-1.22-.71-9.69-4.51-9.69-5.84,0-3.52.94-7.49-1.34-10.13-3.18-3.7-3-5.18-3.22-10.33-.19-3.26-4.18-5-6.37-3.16-1.15-7.4-3.24-13-6.09-19.88-3.49.84-3.76,7.22-4.64,10.36-.91,3.41-.16,7.5,0,11,.16,4.26-2.29,17.75-8.11,15.62-2.06-.74-3.85-4.39-6-5.7-3.9-2.31-7.79-4.61-11.67-6.94-3.59-2.13-2.06-3.39-1-7.79.82-3.54,2.78-5.34,5.06-8-3.66-3.57-4.57-3.77-9.42-4.24-3.74-.37-7.57-1-11.37-.86.13,1.77.27,3.53.43,5.32-4.22-.63-8-2.88-10.69,1s-3.3,7.43-4.43,12.16c-3.65-1.93-7.25-3.87-10.89-5.78-1.32-.7-5.82,4.37-6.85,5.25-5.9,5-13.83,9.38-16.78,17.09-1.48,4-1.5,7.17-5.3,8.08-5,1.17-10,2.35-15.06,3.49-3.44.82-5.31,2.29-8.33,4.47-3.74,2.72-4.45,3.73-6.26,8.35-.63-1.56-1.25-3.09-1.87-4.64-2.52,6.17-4.09,11.39-1.58,17.64,1.47,3.73,1.08,4.29-.2,8.2-.87,2.74.88,4.74,2,7.28a66.93,66.93,0,0,1,5.85,19.08c.37,2.6,2.56,9.32,1.65,11.62-.33.83-5.93,4-3.2,6.13,2.26,1.78,4.83,5,7.7,5s6.26,1,8.47-1.19c3.2-3.16,4-4.31,8.16-4.72,3-.3,5.9-.73,8.85-.83,2.25-.07,4.49-.12,6.73-.2.69,0,1.74-3.19,2.09-3.9,1.15-2.46,5.63-3.47,7.88-4.56,2.5-1.21,6,.69,8.24-.64,1.75-1,5.23-4.28,7.2-4,7,.93,13.24,1.66,19.88,4.18,4.2,1.61,4.49,2.39,6.86,6.65a65.3,65.3,0,0,0,4.93,7.86c3.74-4.26,6.88-7.92,9.66-12.95,1.71,5.29-1.71,9.46-4.39,13.88,4.41,1,4.2-1.54,6.28-5.78.25,2.68-.49,9.26,2.24,9.26,2.43,0,4.19,5.07,4.66,7.26,1.6,7.55,7,9.59,13.39,10.61,4.12.67,4.71,1.19,8-1.6,3.68-3.15,3.39-1.71,6.48,2,1.48,1.78,5.39.37,6.82-1.07,3.28-3.31,3.77-3.62,8.19-3.75,7.4-.25,6.74-10.35,7.9-16.7,1-5.5,7-9.54,8.36-15,1.58-6.44,4.93-14.24,5.13-20.9.21-6.34-2-13.63-2.93-19.9-2.94-2.69-5.9-5.37-8.86-8.08ZM1398.41,757.28h0c-1.46,4.17,5.42,2.34,6.3,2,.17-2.52-5.33-4.78-6.3-2Zm24.32,41.49h0c-2.33,1.58-5-1.71-5.29,2.73,2,0,4,1,5.58,0s2.13-3.34-.29-2.68Zm101.76-33.22h0c1.09-2.53,1.49-2.64.1-4.94-.23-.35-1.1.27-1.5-.31a7.72,7.72,0,0,0-1.18-1.87c-2.23-1.85-5-3.22-7.39-4.79-.89,2.91,10,4.34,8.86,9.68a14.48,14.48,0,0,0,1.11,2.23Zm-23.67,196.94h0c-1.44.56-5.74,3.3-7.11,2.67-2.53-1.12-5.07-2.25-7.57-3.38a25.76,25.76,0,0,0,1.45,12.27c2,4.6,4.19,5.62,8.34,6.39,5.06,1,10-16.31,4.89-18Zm7.51-193.42h0c-1.88.06-3.77-.48-5.58.17,1.21,3,7,4.48,9.71,3.82,2.08-.49,4.72-1.42,5.66-3.52.34-.71,4.44-.41,1.89-3,3.47-.76,1.88-3.54,0-4.82-2.55-1.66-2,3-1.94,4.26-.28-.05-8.58,6-6.51,1-.31-.7-1.46,2-3.19,2.08Zm-17.28-.52h0c-1.52-1.66-.53-4.28-2.65-5.59s-4.17-2.64-6.2-3.92c-3.07-1.93-7.21-2.77-10.52-4-5.37-2-10.72-4.09-16.07-6.13-2.59-1-6.8,1-8.55,3.32-.62.84-3.45,5.49-4.23,5.15-2.26-1.1-3.4-1.21-4.32-3.65a29.3,29.3,0,0,1-2-7.62c-.39-3.06-1.2-2.47-4-3.15-4.22-1-8.59-.08-10.92,4.43,1.49.27,3,.46,4.48.68.78.14,0,2.57,1,3.1,2.53,1.39,5.71.55,8.51.41a5.66,5.66,0,0,1-.21,2.2c-3.4-1.15-5.39-.48-8.92.35,1.47,2.53,2.93,5,4.41,7.52,1.28-1.6,2.57-3.15,3.89-4.76.66,3.76.62,3.62,3.76,4.95,3.7,1.57,7.36,3.15,11.06,4.7,1.52.64,5.37,1.38,6.09,3.1,1.27,3,2.49,5.94,3.73,8.9-4.34,1.23-4.75.76-5.34,5.64,3.32-.32,6.62-.65,9.93-1,1.72-.17,3,5,5.07,5.11,3.49.17,6.7,1.1,9.73-.86,1.7-1.08,2.45-6.37,4-6.13,1.89.25,7.49,0,8.84,1.38,2.63,2.79,5.27,5.57,7.93,8.37,2.11,2.19,4.86,2,7.7,2.46,2,.33,5,2.69,6.62,2.14-1.19-1.28-5-3.88-3.16-5.43-1.79-.42-4.36-.13-3.14-2.89-4.32-.15-4.11-1.25-6.17-5.41-.5-1-2.41-1.79-3.33-2.4s-1.24-2.83-1.62-3.87c1.4-.17,2.8-.31,4.2-.49.55-6-7.25-4.07-9.56-6.56ZM1474.17,453h0c0,3.3.35,6.33-1.07,9.24-1.8,3.77-.38,3.85.39,7.67.45,2.37.38,2.53-.87,4.55-.63,1,.29,2.69.3,3.87,0,3.71-.62,4.49.82,8.08.47-2,.46-5.15,2.83-5.53s3.58,2.58,3.47,4.62c2.29-2.39-.5-6.14-1.8-8.35-1.67-2.85-2.72-3.43-1.71-6.63,1.39-4.43,1-5.67,5.13-6.46,2.74-.51,2.46,4.16,5.1,4.21a44.45,44.45,0,0,1-4.25-11.79c-.54-2.07-1.06-4.14-1.59-6.23-.35-1.41-2-2.53-2.25-3.95-.75-4.55,2.81-6.78.5-11.31-1.23-2.38.24-9-4.05-5.69,1.64,1.63,2.66,4.24.9,5.89-.73.66-1-.78-2.32.31s-1,1.33-.48,3.2c.56,2.17-.76,5.84-1.13,8.07-.36,2.4,4.4,3.68,2.08,6.23Zm-84.64,238.25h0c2.16.44,3.59-2.91.79-3.21-.81.73-3.45,2.66-.79,3.21Zm-3.31.75h0a8.64,8.64,0,0,1,3-5.15c.89-.83.36-3.55.71-4.91l-.75.4c-.93,2.93-3.43,6.55-3,9.66Zm7.69-10.35h0a2.48,2.48,0,0,1-3.22-.82c.13,1.38,0,2.61.8,3.59,2-1.72.58,3.34,2.57,4.47-.11-.76,0-1.57-.15-2.29.31.64.66,1.28.93,2,1.21-1.82-1.1-4.45-.93-6.94Zm-6.93-4.28h0a6.44,6.44,0,0,0,2.53,2.73,10,10,0,0,0,.13-2.89c-1.89.14-1.45-2.1-4-1.92A3,3,0,0,1,1385,679a11.72,11.72,0,0,1,1.94-1.63Zm3.51-1.71h0c.06,1.84,1.48,2.43,2.75,3.5s-.13,1.36.76,2.54c3.16,4.19,2.79-1.43,2.3-4-.8-3.05-3.56-2.1-5.81-2Zm-11.21,4h0c.43,5.26-.26,9,5.2,6.41-1.39,1.83-4.56,4.92-1.58,6.28,1.17.54.76,2.15,2.18,1.89s.71-2.25.68-3.55c0-1.88,2.3-5.53,1.59-6.8-1.73-2.93-2.6-3.24-5.62-4.42a8.88,8.88,0,0,0-2.45.19Zm-12,67.55h0c-.64,2-.17,3.26-1.15,5.41-1.36,2.92-2.15,3.22-.37,5.84,1,1.44,3.49-.5,3,2.93-.21,1.41-1.8,6.88-1.14,7.94s4.36,1.58,5,.33c.33-.56-.71-2.38-.68-3.1s.93-1.67,1-2.53c.21-1.73-.2-4,0-6s-2.44-3.29,1.37-3.76c2.09-.23.45,3.72.72,4.64.73,2.24,3.35,1.85,2.72,4.15s.94,2.83,2.71,2.41c-.85.22,3.84-3.67,3.29-2.41,1.36-3.15-1.85-1.57-2.82-3.9-.25-.59,1.37-1.76,1-2.49-.57-1.11-1.17-2.19-1.75-3.3-1-1.81-1.9-1.7-3.14-3,4.25,1.59,5.8-7,9.58-4.52,1-3.74-2.23-1.48-3.6-1.44-1.79,0-1.86.8-3.24,1.18-1.65.43-.81-1.55-2.43.26-4.08,4.45-8.36-3.38-5.22-7.2,1.51-1.84,3.44.28,5.51.09,2.33-.17,5.4-1.17,7.54,0,5.23,3.07,8.19-2.74,9.8-7.31-2.19,0-4,3.44-5.86,4.71-1.07.68-2.9-.58-4.06-.64-1.43-.09-1.18.94-2.88.36-2.14-.74-6.07-3.06-8.17-1.69-2.76,1.79-3.38,3.34-4.93,6.43,1.93,2.86-1,4.12-1.82,6.6Zm5-76.32h0q2,3.45,4,6.93c2.72-3.23,2.32-4.91-.79-7l-3.23.09ZM1346,782.49h0c0,2.68,1.86,4.9,3.8,2.38s-2.11-3.07-3.8-2.38Zm120.24-281h0c-.19,1-.18,3.22-1,3.66-1.6.86-1.87.86-2.37,2.74-.14.5,1.61,6,2.11,6.16s1.51-2.18,2.52-1.91c.7.2,2.34.34,1.52-1-.93-1.67-4-.56-3.53-3.53,1.49-.51,3.08,1,3.88.62s2.89-1.71,3.68-.92c1.19,1.14,4.92,4.34,6.45,3.6a23.62,23.62,0,0,1,1.26-4,6.48,6.48,0,0,1,3.5-2c2.75.11,4.94-.36,6.87-2.68-5.14.16-1.27-4.18-2-6.36-3.55,3.7-3.69,2.7-8.15.44-3.15-1.61-4.69-4.48-6.88-7.47-2.76-3.74-1.59,4.59-1.22,5.83s-2,2.74-1.81,4.24.29,2.4-.51,3.73c-1.43-.39-2.87-.77-4.3-1.17ZM855.53,420.81h0c.17,1.19,2.15,3.87,3.35,3.58,1.79-.4,1.38-2.78-.09-3.11-.42-1.7-1.85-1.26-3.26-.47ZM971.41,548.54h0c-1.51.68-3.78,2.36-5.4,2.21-1-.09-4.56-.86-5.29.57-2.4,4.75,7.38,2,8.34,1.74-1.25-2.27,1-3.26,2.35-4.52Zm-38.73,3.83h0c.1-1.77-3.4-2.4-4.94-2.18-3.16.46-4-.14-6.84-1.82a7,7,0,0,0-1.1,2.42,36,36,0,0,0,12.88,1.58ZM861.83,419.89h0c-.41,1.31,0,3.66,1.59,3.56,2-.15,1.58,1.53,2,3.48.35-2.25.11-4.6,2.69-4.84-.55-.36-.88-1.15-1.44-1.51,6.42-1.32-4-7.13-1-1-1.36-.11-1.84-.75-1.15-2.09a4.2,4.2,0,0,0-1.58,0,2,2,0,0,1-1.13,2.43Zm57.29-21.15h0c-3.19-1-4.45-.74-7.66.22,1.1,1.2,1.94,2.37,1.17,4.27,1.38-2.44,4.28-3.07,6.49-4.49Zm-69.19,122h0c.13.68-1.12,2-1.28,2.77-.07.37,1.17,1,1.11,1.39-.34,2.18-2.19,2.37-.4,4.08,1.41,1.3,2.84,1.48,3-.74.1-1.28,2-.08,2.29-2.39s.6-4.77.88-7.16c.59-4.89-4.95-2-6.27-1.07-.48-.19-.95-.34-1.44-.53-.88,2.61,1.69,1.84,2.08,3.65Zm844.89-163h0c-1-.05-5.16-1-5.87-.3-1,1,0,3.15.74,3.76,2.59,2.06,6.13-1,7.79,1.14,2,2.48,5,3.46,6.37-.63-2.71-1.31-6-3.82-9-4ZM894.33,410.41h0a9.26,9.26,0,0,1,3.91-3.13c-1.53-1.73-.13-2.72.94-4.16-4.65-1.14-5.1,3.58-4.85,7.29Zm9.68-23.1h0c-.08-.52-.14-1.05-.24-1.56h.75c-.38-3.11-4.46-.82-.51,1.56Zm-54.32,122h0c-1.71,1.44,1.39,4.45,2.91,4.37a18.29,18.29,0,0,0,1.08-9.35c-1.35.28-.17,1.39-.95,2.43a17.65,17.65,0,0,1-3,2.55Zm685.8,261.84h0c-1.29-.65-1-2.61-3-3.22a4.61,4.61,0,0,0,1,3.73c.74.89.38,2.22.88,2.78,1.05,1.26,5.3,2.51,3.92-.64a8,8,0,0,0-2.8-2.65ZM1434.91,561.46h0c.63-.27,1.65,1.94,2.25,1.15s2.28-2.35,2.31-3.13c.3-5.69-7.3-.75-8.48-1.66-1.74,3.73-3.07,2.87-1.72,7.36,3,2,3.45-2.76,5.64-3.72Zm-27.56,195.4h0c-2.2,2.87,2.12,2.87,3.32,2.7.89-.11.52-2.07,1.35-1.74s2.21,1.16,3.19.9c2.81-.76,3.64.35,6.1,2,1.08-4.94-4.32-5.41-7.3-6.2-2.45.44-5,.21-6.66,2.3Zm211.81,209.76h0c.1-2-.68-3.52-1.46-5.31-2.2,1.21-3,1.22-3.61,3.82-.63,2.76-1.38,1.52-2.8,3.48-1,1.4-.82,3.84-1.76,5.31s-3,2.66-4.26,3.76c-1.39,1.18-2.67,2.62-4.28,3.34-1.18.54-3.94,1.17-4.78,2.26q-3.95,5.31-7.86,10.6c-2.72,3.62,5.2,2.65,6.28,3.9,1.58,1.82,7.28,3.77,8.89,1.08,1.8-2.94,5.08-6.58,6-10,1.24-4.75,2.94-5.47,6.71-8.26a2.43,2.43,0,0,0,2.12,2c-1.44-2.93-1.65-3.22.28-5.74s3.86-5,5.8-7.54c-.55-1.86-1.12-3.71-1.67-5.58-1.2,1-2.39,1.95-3.59,2.89Zm-24.71,33.25h0c-1.47.53-.52,2.42-1.71,3.93,1.56-1.48,5.87-.7,1.71-3.93Zm47.84-56.26h0c-3.75,2.41-4.45,2.12-8.74,1-2.6-.67-.87-5.56-3.57-6.86.28,2.73-1.5,4.9-3.2,1.52-.48-1,.4-2.54-.25-3.52a10.11,10.11,0,0,1-1.85-2.64c-1.14-3.6.89-3.14-3.06-4.66-2-.76-2.95-2.71-4.8-3.22,1,2.06,2,4.13,3,6.23l1.11-.88c1,2.24,3.3,10.37,5.75,9.55-.88,2.57.87,5.1,0,7.55-1.26,3.45-1.76,4.32-4.56,6.44a27.83,27.83,0,0,0,3.31,3c.74.45,3.17.56,3.58,1.32,1.35,2.54-1.82,5.92-3.11,7.36,2.43,1.53,5.12,2.79,6.91-.84,1.49-3,4.33-6.74,4.22-10.23-.08-2.14,2.49-2.34,3.71-1.74,1.46.7.3-1.27.78-1.77,1.64-1.6,4.55-7.12.84-7.6ZM821.11,525h0c.93.74,1.88,1.52,2.84,2.26.84-.7,1.69-1.38,2.51-2.08-1.73-3.23-2.83-1.63-5.35-.18Zm865.64-182.84h0c-.11,3.06.48,4-2.1,5.23-1.91.9-.27,3.76.2,5.71a12.25,12.25,0,0,1-7.52-3c-1.71-1.29-5.55,1-6.07-1.15-.77-3.09-.34-6-3.39-6.22l-9.95-.7c-2-.17,1.38-6.12-3-5.41-2.25.39-1.41,6-1.51,8.23-.17,3.5-11.24,4.5-14.24,5.32,2.58,1.83,5.58,2.65,5.78,6.18.25,4.11,1.84,5.75,4.14,9.06.24.32-1.62,2.79-2.07,3-.86.35-3.25-.65-4.14-.82-1.59-.32-5.3-1.93-6.78-1q-9.17,5.55-18.29,11.13c-4.77,2.89-9.9,4.46-12.17,10-4.23-4.2-4.48-4.72-10.06-4-5.29.69-5.59,1-8.83,5.73,0-1.69-.1-3.37-.16-5-1.62.8-4.66,3.15-6.42,2.92-2.26-.33-4.35-1.56-5.7.62-3.06,4.88-6.07,9.79-9.11,14.67,1.62.53,7.33,1.22,6.82,3.22-1.22,4.74-1.46,4.92,1.36,8.75-4.76,2.08-9,4.17-6.45,10.39.43,1-3.67,2.63-4.7,3-2.31.79-4.35.53-4.58,3.28-.24,3.24.64,5.95-2.39,6.75-3.81,1-4,.52-4.66,4.79s-5.88,8.42-8.39,11.53c-3.12-14.6-13.71-42.46,3.8-51,5-2.44,7.94-3.2,10.85-8.22,2.71-4.7,5.92-6.75,10.17-9.93,2.93-2.19,6.88-3.37,7.82-7.26.7-2.93,1.41-5.84,2.1-8.75.17-.68,4.18-1,4.94-1.2a18.58,18.58,0,0,0-7.43-.64c-2.17.26-3.34,3.68-4.53,5.57-2.42,3.87-7.49,6.65-10.88,9.46-1.64-4.36-1.21-6.06-.31-10.75-3.21,1.91-4.5,2.61-8.1,2.54s-4.59-.29-7.48,2.06c-4.61,3.72-8.31,8-12.29,12.57,1.21,1.07,4.24,2.52,3.31,4.17-.35.67-4.48,1-5.31,1.07-4.27.5-8.53,1-12.77,1.53,1.51-1.12,3-2.2,4.54-3.28-4-.83-8.09-1.62-12.14-2.41-1.11-.24-3.91,2.25-4.93,2.85-1.3.77-2.9,0-4.31-.19a50.94,50.94,0,0,0-10.83-.54c-2.33.11-9.08-1-10.9.75-6.28,5.86-12.47,11.68-18.46,17.92-5.57,5.76-11.79,9.94-18.23,14.57.88,2.2,2.33,2,4.18,2.16,2.37.23,2.6-.17,3.51,2.23.27.74,1.1,4.24,1.86,4.32,4.85.4,5.23,1.16,7.59-3.55,2-4,13.52,5.4,13,8.59-1.33,7.58-3,15.06-4.75,22.56-1.6,7.1-4.13,11-8,17.1-3.6,5.69-6.61,11.21-11.3,15.83-3.17,3.13-6.36,6.3-9.54,9.45-1.76,1.74-5.38,1.72-7.63,2.25-1.12.27-2.15-3-3.2-3.24-.83-.16-3.47,2-4.2,2.48-3.56,2.09-3.6,3.08-5,7.37-2.26,6.71-7.5,10.26-12.32,14.95,5.33,4.62,10,9.66,9,17.54-.72,5.3-.09,6.48-4.41,8.76-3.56,1.86-5.59,1.75-9.61,1.63.43-3,.83-6,1.24-9,.48-3.46-2.65-3.22,0-6.34,1.66-2,.78-4.68-1.61-4.45-2.23.24-5.8,1.74-6.54-1.74-.38-1.78,1.91-6.17,2.46-8,.07-.28-4.9-3.52-5.6-3.49-1.84.06-5.19,3.13-6.78,4.09l-6.78,4.07c-1.79-4.51,2.43-7.82,5-10.57-2.79-2.21-2.87-2.84-6-1.35a26.43,26.43,0,0,0-5.45,3.93c-2.3,2-3.72,3.15-6.45,4.07-.48.18-5.36,1.9-4,3.42a46.49,46.49,0,0,1,5.12,6.16c2.08,3.27,1.82,2.83,5.1,1.19,4.71-2.34,8.39-.33,13.38,1q-8.19,6.91-16.37,13.88c2.34,2,5.21,3.68,6.59,6.66,1.75,3.8,3.48,7.58,5.19,11.37-2.8-.53-5.63-1-8.47-1.57,3,2.21,6,4.39,9,6.6-2.17,1.55-4.39,3.1-6.61,4.7,2.73.78,5.48,1.6,8.2,2.41-3.38,6.27-6.28,14.21-10.61,19.69-4.65,5.88-8.19,12.41-14.85,15.2-7.18,3-14.32,6-21.6,8.63-2.24.8-4.49,1.63-6.72,2.44-1.85.66-1.42.68-1,2.87.29,1.41.32,4.34-2.19,3-.68-.34-1.42-3.67-1.74-4.51.82-.19,1.53-.84,2.35-1-2.52-2-7.06-3.44-9.86-1.19-2.39,1.92-8.14,4.77-9.13,7.91-.28,1-2.18,5.09-1.67,5.92,1.42,2.29,2.86,4.56,4.28,6.85a114.92,114.92,0,0,0,6.89,9.21c3,3.8,4.59,5.06,4.79,9.9.13,3,1.78,9.95-.42,12a237.73,237.73,0,0,1-19.11,16.19c-2.2-2.29.88-5.69-.72-7.38-2.13-2.34-4.29-4.64-6.43-7-3.85-4.12-6.82-6.45-12-6.67.16-1.28.33-2.56.48-3.81-5.09.22-4.15.91-4.57,6.44-.26,3.31-1.89,6.39-3.05,9.48-.48,1.31-.08,2.8,0,4.21.24,2.68.24,2.24,2.7,2.1,1.27-.06,2.84,8.08,3.27,9.56.74,2.46,5.55,4.72,7.44,6.17,1.64,1.28,4.74,4.26,5.51,6.26,1.12,2.89-.07,7,.63,10.08.7,2.91,2.37,5.88,3.47,8.68-4.3-.73-6.91-3.47-10.47-6.23-3.28-2.58-3.49-4.05-4.89-8.35-1-2.94-1.86-9.69-3.93-11.89l-9.2-9.8c-1.38-1.5.56-9.54.79-11.8.38-4.13-.56-8.88-.84-13-.55-8.26-3.15-15.24-5.62-23.06-1.63,2-3.27,4-4.9,6-2.09,2.55-1.89,2.49-5,1.77-3.3-.77-3-.46-2.52-4.06.2-1.55,1.5-5.61.88-7-2.19-5.09-3.38-9.56-7.52-12.86-3.62-2.9-4.83-7.91-6.73-12.29-1.82,1.27-4.41,4.07-6.57,4.36-3.78.54-7.6,1.07-11.41,1.59-.5.06-2.91,0-3.27.45-.63.74.48,3.32-.2,4.05l-5.6,5.76q-7.94,8.14-15.91,16.36c-1.77,1.84-5.43,2.72-7.61,3.81-2.83,1.38-1.78,3.48-1.74,6.86.07,2.86.91,7.1.16,9.86-.7,2.57-2.77,6.67-2.08,9.31,1.07,4.22,1.58,6,4.25,9.14,2.3,2.73,3.36,5.6,4.79,9,2.6,6.05-7.69,11.35-8.43,3.17a71.68,71.68,0,0,1-.32-10.56c.15-3.54-1.14-4.06-3.5-6.58-.3,2.48.16,5.05-1.85,6.37-2.16,1.38-4.32,2.83-6.48,4.24-6-11.34-11.06-23-16.26-34.81-1.36-3.08-3.64-6.63-4.36-10-.53-2.39-.19-5.48-.26-7.92q-.35-11.31-.7-22.59c-1.59,2.17-3.16,4.36-4.76,6.54s-1.77,1.91-4.42,1.81c-3-.12-6.36-5.78-8.44-8,2.12-.47,6.57-.19,6.92-3.12-1.11.1-2.7.58-3.78.33-3.06-.74-6.48-3.69-9.28-5.29-1.91-1.1-3.16-6.07-4.12-8.12-1-2.27-17,1.27-19.71,1.6-5.92.69-11.9-1.65-17.7-3-2.55-.58-5.48-.31-6.8-2.9-2.34-4.64-1.77-6-6.38-4.28-3.85,1.43-6.2.88-10.29.22-2.52-.4-4.12-3.5-6.43-4.59-4.14-2-4.59-2.45-6.6-6.86-1.37-2.91-1.92-6.7-5-7.17-5.33-.77-5.3-.55-9,3.77-1.25,1.52,3.17,6.88,4.13,8.45,3.33,5.56,6.16,11.44,9.18,17.2.44-2.61.83-5.2,1.26-7.81,2.19,3.89,1.74,7.77,1.88,12.32,3.81-.24,10.19.42,13.7-1.73s6.65-7.58,9.44-10.76c.25,3.27-.54,8.64,2.15,10.47,1.56,1.06,3.22,2.65,4.94,3.4,1.54.67,3.36.08,4.24,1.75.66,1.21,1.72,4.54,3,4.77,2.35.39,1.38,2,1.21,4.43s-5.1,6.5-6.62,8.3c-.11-.77-.69-1.47-.79-2.24-1.31,3-2,4.43-2,7.68,0,2.83-1,2.53-3.43,3.68s-4.89,2.35-7.3,3.49c-1.45.67-1.41,4.76-2.8,5.44-1.12.54-2.94-.94-4.14-.43l-5.34,2.34c-2.45,1.1-2.11,4.39-4.37,5.2-4.05,1.44-8.08,2.88-12.12,4.35-1.21.42-1.41,1.06-2.17,2.24-1,1.55-2.22,1.35-3.9,1.66-3.5.68-7,1.81-10.39,2.73-2.56.66-3.08,3.59-5.87,3.59-4.35,0-4.72,1-5.56-3.53s-1.7-9.11-2.54-13.66c-1.34-7.1-4.75-11.77-8.4-17.87-2.15-3.62-2.49-4.29-6.23-5.69-2.16-.81-2.13-7.36-2.54-9.65-.59-3.46-2.82-6.59-4.32-9.66-.93-1.84-3.06-2.74-4.2-4.77-2.4-4.32-4.8-8.61-7.22-13-1.21-2.13-2.12-5.84-5-5.1.34-2.65.73-5.32,1.08-8-1,3.18-2.09,6.35-3.14,9.54-3.59-3.81-5.47-7.12-7.87-12-2.56,3.25,2,8.67,3.42,11.61,2.93,6,5.9,12.06,8.86,18.09,1.76,3.61,1.13,7.65,3.75,10.49,1.12,1.19,3.92,3.18,4.21,4.93.45,3.07.93,6.09,1.42,9.17.26,1.78.1,5.18,1.44,6.47,1.66,1.59,4.17,3.27,5.42,5.24,2.49,3.87,3.6,9.86,5.23,14.24.54,1.52,4.82,1.27,5.89,2.53,1.63,1.91,3.3,3.83,4.93,5.76,2.75,3.18,8.3,6.69,4,10.82,2.9.88,6,6.83,8.34,6.24q11.85-3.18,23.7-6.34c1.46-.38,5.67-2.17,6.89,0,.75,1.32-2,8.9-2.39,10.53-1.43,6.32-6,12.29-9,17.83-2.56,4.73-4.67,9.86-8.29,13.66-9.55,10.05-20.71,19.31-27.86,31.61-1.61,2.69-11.81,16.63-10.16,19.11,2.85,4.28,2.88,5.07,2.56,10.39-.27,4.79,0,5.15,2.77,8.9,4.28,5.8,2.83,14.81,3.17,22.12.24,5.4-4.1,11.68-8.46,13.78-2.41,1.17-7.31,2.3-9.15,4.43-2.36,2.78-4.74,5.53-7.13,8.32-2.1,2.43-4.64,3.58-3.31,6.75.9,2.12,4.14,7,3.88,9.32-.3,2.76.17,9.05-1.25,11.27-1.22,2-7.2,3.44-9.22,4.41-3.36,1.6-2.62,3.14-3,7.26-.19,2.18.22,8.15-1,9.93-4,5.62-7.63,12.28-12.22,17.27-2.43,2.61-5.49,4.72-8.15,7-1.52,1.32-4.44,5.08-6.4,5.47q-10.59,2.24-21.19,4.45c-3.23.68-6.52,1.36-9.76,2.06-1.58.31-4.73-3.81-5.87-4.88-3.84-3.46-3.71-3.4-3.13-8.93.23-2.1-2.17-5.89-2.91-7.76-1.65-4.11-3.31-8.23-5-12.33-1-2.45-4-4.34-5.8-6.12-1.22-1.2-1.19-6.89-1.45-8.59-.72-4.72-1.43-9.39-2.16-14.09-1-6.3-4.12-11.28-6.89-16.88-1.82-3.69-3.64-7.35-5.42-11-.79-1.63.3-4.66.54-6.33,1.2-8.06,1.39-15.63,5.28-22.58,3.78-6.69,1.47-12-.15-18.94-1.76-7.5-3.49-15-5.24-22.47-.54-2.28-3.55-5-4.88-6.74-2.57-3.43-5.08-6.84-7.64-10.26-1.38-1.82-.4-4.22-.12-6.52.53-4.66,1.09-9.33,1.64-14,.48-4,.68-4.24-1.64-7.43-2.65-3.68-2.51-4-6.65-3.72-2.4.1-7.22,1.64-8.94-.47l-7.33-9c-1-1.29-16,1.06-17.84,2l-10.58,5.39c-2.76,1.42-4,.69-7-.11s-5.17-1.79-8.2-.72c-3.87,1.34-7.73,2.72-11.59,4.09-1.83.65-3.9-1.84-5.38-2.92q-5.56-4-11.12-8c-4.69-3.37-7-5-9.9-10-4.71-8.24-9.43-16.42-14.15-24.63q-2.25-3.94-4.53-7.89c-.7-1.24,1.81-5.83,2.26-7.09.8-2.17,3.25-6.17,2.73-8.57-.87-3.94-1.75-7.83-2.64-11.76-.59-2.63-2.58-7.35-2.24-10.06.23-1.64,2.24-4,3-5.43,4.55-8.19,9.07-16.42,13.63-24.64,3.2-5.78,7-7.46,12.48-10.94,2.83-1.8,4.1-1.83,4.63-5.32.65-4.33,1.32-8.68,2-13,.78-5.12,11-6.07,13-11.06,1.4-3.48,2-8.32,5.52-9.32.91-.25,3.44,4.48,6.27,3.87,1.25-.27,4.15-1.54,5.36-.91.65.36,3.24,2.28,3.85,1.92a97.22,97.22,0,0,1,8.37-4.95c5.27-2.39,11.83-4.73,17.51-5.43,1.54-.17,3.92-1,5.4-.58,1.22.44,3,1.49,4.31,1.42,1.45-.06,2.83-1.74,4.25-2a19.54,19.54,0,0,1,4,.22c3.84.22,6.49.87,9.83-1.13,2.7-1.64,5.21.52,8,1.7-2.06,4.55-2.48,4.72-.15,9.08,1.09,2-3.12,5-4.51,6.53,2.25,2,5,5.7,7.82,6.44l14.48,3.84c3.74,1,2.69,5.11,6.38,6.7,3.23,1.38,6.29.85,9.27,3,4.22,3,6.44,3.72,9.17-1.63.63-1.27-1.42-3.18-.78-4.34.54-.94,1.65-4,2.61-4.22,4.69-1.34,7-2.06,11.7-.8,1,.28.1,2.44,1.45,2.7,2.19.46,4.36.88,6.55,1.35,1.75.36,1.84,1.21,2.73,3,.47.92,2.16-1.11,2.94-.86l10.48,3.08c3.85,1.13,4.34,1.13,8-.65,4-2,4.42-2.59,8.38-.66,4.73,2.32,12.1,1.57,14.29-4.45,1.32-3.76,7.94-15.38,5.36-19.19-1.65-2.42,1.94-7.61,1.11-8.54s-2.34.63-3.1,1.27c-1,.82-2.3-1.25-3.32-1-1.35.25-2.45,3.07-3.72,3.68s-3.54.16-4.85.23c-3,.11-4.33-3.14-7.09-3.63-1.83-.33-3.37-1.43-4.08.62-.81,2.45-.79,2.32-3.18,2.76s-6.12-2.76-8-3.85c-3.45-2-9.42-12-5.7-16.17-1.22.16-2.47.28-3.71.44-.53-4.12,4.81-5.25,7-5.31,4.3-.14,6.49-.19,10.28-2.32-1.16-.6-2.35-1.17-3.53-1.8.73-2,5-1.15,7-.88,3.59.52,3.79-.48,6.65-2.4,1.82-1.19,4.46-3.09,6.68-2.94,2.91.24,5.58.72,8.37-.25-.67,1.17.5,2.22,1.76,2.84,2,1,1.24-1.67,3.24,1.15.74,1,6.2,1.85,7.95,2.59,3,1.17,4.82-.6,7.8-.22,3.35.39,5.73-.86,8.6-2.7,2.4-1.5,1-5.7-.44-7.39-2.13-2.4-4.76-2.85-7-5s-4.44-5.26-7.7-5.67a31,31,0,0,1-3.33-2c-1.32-.89-2.56-1.94-3.84-2.89.14-.27,1.06-1.49,1.06-1.51l3.66.74c-1.12-3.92,1.39-5.13,4.27-5.06-1.37-1.13-3.22-2.16-4-3.78l3.68-.11c-.88-2.8,2.76-.75,3.3-2.46.63-2-2.33-1.13-3.17-1-3,.5-6.32.58-8.47,3.41v-1c-3.38.82-4.7,1.38-7.32,3.86.2-.44.4-.88.61-1.3-3.47-.44-1.89,3.91-.48,5.57,1.76,2.12,4.52,1,7.37,1-2,3.65-4.36.94-6.57,2.13s-6.87,5.34-9.43,3.29c1.54-4.28-.44-3.75-4-5.44,1.75-.92,8.51-3.38,3.92-4.95-1.42-.48-3.1-.11-4.58-.05-1.06.07-2.54-1.58-3.45-2.22,1.88.13,4.25,1.13,5.24-1-2,1-7.2-1.33-8.41.05s-5.26,4.53-5.57,6.61c-.2,1.25-.14,4-.78,5s-3.3.84-3.54,2c-.77,3.69-.58,6.42-3.58,8.38s-2.25,5.36-.86,8.08c.9,1.75,5.63,3.95,5.37,4.77-.78,2.37-5.1-.65-6.65.84-2.33,2.14-4.63,4.31-6.95,6.47-.25-2.52,1.18-3,2.9-4.06-1.33-.56-2.9-.58-4.45-1.19-2.43-.92-3.81-.33-6-.92-1.09-.28-2.45.61-3.46,1s.37,2.14-.16,2.55c-1.9,1.59-3.24.16-4.88-1-1.78,2,.19,3.87,1.22,5.7,1.58,2.82,1.66,2.51-.57,4.8,2.91,2,6.13,2.76,5.48,7-1.74-1.35-2.95-3-4.79-.71,2.28.44,2.48,1.87.86,3.15s-.86,2.12-.17,4.23c-2-.37-3.44,0-4.29-2-.79-1.7-1.63-1.2-3.08,0-1.52-5.15-2.57-5.62,1.41-8.85-3.69,0-3.69-.45-5.93-3.81-1.26-1.88-2.17-5.07-3.82-6.42-2.93-2.41-1.86-4.23-1.49-8.19.32-3.67-.88-3.67-3.64-5.86-3.63-2.88-7.82-6.9-12.3-7.49-1.15-.17-3.77-3.63-4.17-4.87-1.07-3.58-1.37-4.51-4.13-6.66-1.23,3.76-2.73,1.88-3.22-.81s0-2-2.84-1.23-4.56,1.07-2.76,4.33c.62,1.14-1.61,3.82.41,5.37,1.67,1.25,4.43,2.55,5.68,4.26s1.08,4.62,2.76,6.11c2,1.76,3.07,3.18,5.63,3.31,1.66.09,4.58,0,2,2.1C886.52,515,898.43,520,895.4,524c-1.21-.63-4.65-5.34-6-4a5.34,5.34,0,0,0-2.09,3.67c-.38,1.72.71,1.59,1.93,2.54,3.46,2.69-2.36,3.44-2.14,5.07.3,2.32-4.36,6.39-4.25,2.62a4.85,4.85,0,0,0-1.65,6.53c1.16,2.32-3.57,3.08-4.11,1.22-1-3.4-12.38-3-7.93-7.93.63.74,6.78,1.29,8.2,1,1.64-.38,4.48-.41,5.9-1.37s.16-2,1.75-2.86c1.09-.55-1.58-7.62-2.36-7.72-.93-.11-3.21-.18-3-1.63.28-1.85-1.5-2.54-2.82-1.84.27-1.55-3.11-4.08-4.47-3.91-2.43.34-3.81-2.09-5.56-3.83-3.13-3-7.38-4.57-8.35-8.77-.92-3.93-.92-4.18-4.23-5.91-1.72-.92-3.85-1.59-5.1,0-.9,1.1-9.87,7.69-11,7.31-3-.95-5.92-1.95-8.89-2.93-1.52-.47-3.88,2.75-5,3.8-.6.53,1.18,5.07.06,6.67s-5.14,2.62-6.78,3.45c-4.82,2.52-6.3,6.39-9.2,11.37-.86,1.46,2.89,2.82,1.08,5.22-1.09,1.51-4,3.91-3.14,5.73-1.05.27-3.52.36-4.12,1.35s-1.69,3.62-2.66,3.71a66,66,0,0,1-9.22,0c-2.74-.12-4.35,3.24-6.51,3.93-2,.64-5.45-3.7-3-5.42-2.38,1.13-3.51-2.9-6.53-1.17-2.4,1.37-4.16-.69-6.32.94a19.59,19.59,0,0,0,.68-5.33c-.09-1-.16-2-.24-3s-1.11.25-1.51-.36c-1.83-2.79-.48-3.45.26-6.58s3-7.74,1.72-10.65c-1.17-2.73-.6-5.82-.07-8.61-1.68,1.34-2.79-1.22-2.11-2.83s3.77-1.49,4.86-1.66a6.64,6.64,0,0,0-.52-1c2.9-2.61,4.26.94,6.79.3,3.6-.89,4.89-1.09,8.39,0,2.72.88,5-.52,7.47.39a15.37,15.37,0,0,0,6.74.72c4.8-1,4.18-10.38,4.15-14.22,0-3.63.6-4.8-2.81-5.86-2-.61-2.25-4.17-1.82-5.25-1.83.44-1.12-.69-1.88-1s-2.93-.49-3.27-.75c-1.47-1.15-2-1.89-3.82-1.79a2.64,2.64,0,0,1-3-1.46c.52-.06,1-.42,1.53-.47a3.06,3.06,0,0,1-2-2.9c2.08-.15,4.27.18,6-1.07,3.66-2.58,1.57,2.06,4,1.45.85-.18,5.4-.94,5.2-2.2a21.07,21.07,0,0,0-1.86-5.67c1,.09,2.75-.25,3.11.83.48,1.49.3,1.59,1.66,1.76a10.23,10.23,0,0,0,6.43-.88c-.63,0-1.21-.49-1.82-.57,1.34-1.9,3.88-2.54,5.85-3.48,2.82-1.38-.14-3.22,1.24-5.47.61-1,5-2,6.23-2.58,2.23-1.05,3.54-.92,6-.74-.83-.27-3.16-.56-3.22-1.56,0-.21,2.19-.43,2.39-.64.38-.42,0-1.47.45-2a12,12,0,0,0,2.38-5.68c.25-1.18,2.24-.94,3-1.83,2.53-3,5-1.29,8-2.23.44-.15,0-1.58.75-1.71s1.65-.24,2.47-.37a14.41,14.41,0,0,1,3.9.43c-.45-2.38,1.55-1.76,3.21-2-.9-.34-3.41-2.45-2.18-3.43,2.05-1.59.26-1.47-.4-3.56s.63-3.42-1.23-4.95c-1.48-1.24-1.13-2.06-1.24-4.14-.14-3.43.53-7.29,4.13-7.44,2.75-.07,5-3,7.66-4.37-1.85,2.69-2.8,8.42,1.19,9.4-2.33,3.72-6.74,4.95-5.94,9.92.61,3.62,4,6.72,7.36,5.12-.45,1-.91,2-1.36,2.94,3.31,1.93,6.14-2.77,9-3.12,1-.13,3.75,1.6,4.12,2.7.57,1.93,2.28,2.35,3.9,3.26a5.46,5.46,0,0,0,.31-1.81c-.93-.08-1.85-.19-2.77-.27,2-1.29,9.18-1.43,10.59-3.29,2.27-3,8.94-4.89,12-2.27-.28-.2-1.42-.55-2-.88.07,3.12,4.31,3.55,5.9,1.65.62-.73.87-2.54,1.28-2.95s1.24-.06,1.63-.41c1.07-1,2.48-1.46,3.24-2.7a8.24,8.24,0,0,1-2,2.95c5.24,2.55,2.1-7.11,2-9.48a6.54,6.54,0,0,1,1.58-4.87c1.1-1.34.21-3.47,2-4.83,4.68-3.49,5.8,4.22,9.26,4.46,1.9.15,3.27-2.61,3-4.3-.2-1.11.72-5.49.44-5.71-.52-.42-1.51.82-1.88.54a22.26,22.26,0,0,1-2.08-2.23c-.51-.58-1.48-4.49-1-4.71,3.26-1.43,7.29-3.51,10.89-3l8,1c3.68.46.54-.88,2.74-2.29,1.41-.88,3.47-.33,5.12-1.36,1.13-.73,3.76.32,5.06.51-.77-2.48-5.7-3.36-7.84-4.27.38-.57.38-1.52.79-2-7.48,1.45-15.16,3.27-22.8,4.74-.78.16-3.94,1.31-4.42.5-1.51-2.4-1.91-2.82-4.36-3.82-3-1.2-2.72-.95-2.2-4.42a11.48,11.48,0,0,0-.1-5.74c-.39-1.58-2.07-5.24-1.73-6.88.3-1.47,3.36-3.81,4.32-4.94,2.43-2.78,5.7-4.53,8-7.45,1.2-1.46,3-4.94,4.63-5.73s3.84.77,3-2.27c-1-3.77-3.9-5.56-7.61-5.68-5.19-.19-5.65-.38-9.27,3.67-2.31,2.58-3.5,4.66-1.64,7.93,1.65,3-12.42,10.25-13.61,11.79-3.54,4.44-9.5,11.54-5.69,18.12,1.63,2.83,6.32,2.74,7.8,6,1,2.31-2.87,4.28-4.56,5.75-2.91,2.54-5.19,3.53-5.77,7.54-.48,3.22-.35,7.95-1.63,10.92-1.74,4-4.75,4-8.25,4.79-1.38.26-1.31,2-1.68,3.36-.47,1.72-1.49,1.19-3.08,1.29-2.47.18-2.71.78-3.11-1.94-.2-1.43-1-3.67-.46-5,1-2.84-3-6.25-4.7-8.46-.71-.93-.3-2.7-.8-3.81-.67-1.38-1.82-3-2.16-4.51s.95-4-.67-4.32c-1.4-.34-1.62-2.77-2.09-4.19-1,3.85-1.75,4.24-4.77,6.43-2.12,1.53-3.82,3.87-6,5.2-3.36,2.06-12,1-12.16-4.25-.22-6.47-2.72-12.71-2.4-19.14.27-5.52.65-5.55,4.64-8.93a35.2,35.2,0,0,1,7.21-4.25c3.11-1.53,5.81-2.53,8.18-5.19,2.14-2.41,4.29-4.66,6.64-6.88,5-4.72,7.23-10.6,10.9-16.53s8.25-10,12.69-15,8.25-10.22,14-12.85a156.45,156.45,0,0,1,19.53-7.15c2.56-.76,3.89-4.92,6.22-6.29a14.17,14.17,0,0,1,8.09-1.41c-3.15,3.48-4.55,5-5.73,9.72,2.91-.55,5.43-5.45,7.29-7.8.32,1.49.61,3,.87,4.43,1.34-1.75,2.66-3.53,3.95-5.27.57-.75,4,0,4.88.08-.83,1.36-1.62,2.7-2.43,4.07,3.48,2.64,1.46-3.82,4.31-2.69s6,2.34,9,3.52c2.53,1-2.16,3.39-3.11,3.6-2.15.46-5.13-.5-7.32-.7,1.12,2.05,3.45,1.31,4.43,3.69.27.59,3.27-.35,4.35-.28,2.57.23,5,1.35,6.7-.92.76-1.09,4,1.28,5.06,1.83-.63,2.37-2.88.85-4.57.44-.72,4.93,7.81,3,10.11,3.09,4.83.2,7,1.41,11.34,3.86a61.2,61.2,0,0,0,11.89,5.64c3.26,1,7.5,3.14,8.78,6.93s1.05,3.64-1,6.86c-1.31,2-1.72,3.21-3.79,3.91-4.74,1.56-6.27,1.78-10.95.68-8.75-2.07-15.87-4.07-24-8.16,2.36,2.39,9.14,6.88,9.14,10.45s-.61,10.86,2.64,12.25c3.7,1.61,8.45,5.85,12.07,4.34,2.13-.88,1-4.31-1.1-4.31-2.27,0-3-1.95-4.5-3.82,3.36-3.06,3.58-2.35,7.71-.91,3.36,1.19,6.73,2.32,10.09,3.5-.3-.87-2.95-7.44-2.59-7.66q3.81-2.58,7.59-5.1c1.32-.9,3.81-3.48,5.4-3l8,2.4c.34-1.52,1.62-4.36,1.06-5.82-.13-.44-2.77-4.65-2.92-4.11.61-2.48,1.21-4.91,1.78-7.37.22-.87-2.65-3.48-3.23-4.22,3.23.44,6.48.83,9.72,1.27,2.43.31,4,4,5.55,6-1.61.17-6.36-.3-7.21,1.21-1.41,2.41,1.21,4,2.74,6,1.69,2.16,4.21.8,6.68.42,3-.41.85-2.71,2.5-4.88.74-1,3.54-1.6,4.6-2.09l8.78-4c4.46-2,8.93-4,13.37-6.07,1.28,4.2,1.26,4.17,5.18,5.15,2.56.63,3.89-4.14,6.09-3.9,3.32.4,5.29.88,8.29-.57,3.45-1.65,4.4-1.52,8.15-.68-.57,1-1.16,2-1.73,2.95,4.12,1.23,3.94,1.43,6.67-2.21,2.53-3.4.88-3.69-1.63-7,5.78-2.53,14.1-1.61,20,.74,4,1.59,8,3.18,12,4.76,2.87,1.16,5.76,4.37,8.3,6.28.19-1.51,1.68-6.56.49-7.43l-8.83-6.6c-2-1.42,1.17-5.55,2-7.55.73-1.64-3.83-3.4-5.15-4.26,2.88-2.28,5.78-4.6,8.68-6.91,2-1.58,2.8-7.22,3.62-9.69,1.1-3.11,14.84.16,18.07.48-1.24,3.38-2.47,6.79-3.71,10.15-.66,1.77,2.34,5.86,3.14,7.51,1.45,3-3.34,16.27-1,17.87,2.84,1.9,6.07,2.24,4.56,5.86-.87,2-1.84,6.7-3.64,7.81l-9.33,5.72c-1.35.85-5.58-.61-7.21-.81,4,3.26,8.5,6.11,13.86,4.34,4.23-1.38,9-7.3,12.16-10.49,3.52-3.57-5.57-9,1.88-11.24,1.42-.42,5.46-2.62,6.57-1.32,1.87,2.2,3.78,4.39,5.67,6.56-.43-2.87-.09-5.63-2.39-7.28-3-2.17-3.37-2.19-7-1.65-.86.15-8.16,1.75-8.35,1.07-.54-2-2.36-5.53-1.48-7.47,1.15-2.4,3.89-5.57,2.28-7.93-1.25-1.88-5.19-5.65-3.82-7.77,1.77-2.78,4.4-3.23,7.29-4.43,2.13-.89.3-5.89-.26-7.18,1.58-.4,4.68,3.87,3.75,5.63-2.16,4.16-1.92,4.06.36,8.15,1.55,2.78,13,2.8,15.89,3a125.89,125.89,0,0,1-12.21-5c-4.65-2.19,3.41-5.65,5.24-6.23,5.59-1.78,7.91-.41,13.48,1.69a29.52,29.52,0,0,1,4.83,3c1.51,1,3.63.08,5.35-.18-.56-1.49-1.14-5-2.22-6.06s-5-.84-6.48-1.1c-1.89-.31-2.27-8.58-2.63-10.69q9.36-1,18.75-1.92c3.53-.35,7.08-.73,10.6-1.07,2.35-.25,1.42-2.72,1.48-5.09.14-4.64-.23-4.69,3.35-6.82,2.55-1.52,5.25-3.68,8-4.72,5.8-2.17,12.88-2.36,18.92-3.51,11.44-2.09,22.47-3.47,33.4-7.64,2.55-1,1.4-5.16,3.48-6.22,3.23-1.68,6.48-3.3,9.68-5,3.86-2,10.83-2,13.69,2.21-3,.94-6.11,1.86-9.14,2.79,4.82.67,9.65,1.39,14.47,2.07l-6,5.21c2.65.18,5.33.33,8,.52,0-1-.41-5,.58-5,2.09.06,4.17.16,6.23.23,3.14.09,6.62-.58,9.34,1.28s7.29,3.77,9.37,6.5c.52.71,3.21,3.43,2.84,4.22-.46,1-1.25,4.05-2.12,4.61L1301,275.67l26.93-7.61c-2.32-.37-4.63-.71-6.92-1.06,2.76-2.37,7-4.56,10.28-2.15,4.9,3.6,6,3.43,12,2.87,7.72-.73,15.55.89,23.24,1.72l-4.41,2.59c1.89.92,5.33,3.58,7.32,3.46l9.23-.47c1.83-.11,6.89.82,7.22-1.52.65-4.73.2-4.58,4.39-4.63,2.88,0,6,.3,8.81-.22,2.13-.42,6.62-2.34,8.66-1.65s4.83,5.44,6.33,7.15c.92,1-1.09,6.74-1.1,8.29,0,1.25.22,8.27,1.07,8.74,2.82,1.64,5.64,3.24,8.47,4.84,1.26.72,5-5.65,5.9-6.8,2.42-3.24,2-3.62,5.27-1.49s4,3.25,7.73,2.07c2.37-.75,5.2-2.52,7.56-1.36,1.68.87,5.43,3.86,7.25,3.14,2.87-1.21,5.74-2.38,8.69-3.59-.83-1.47-3.59-4.61-2.51-6.05.81-1.1,3.47-6,4.75-5.86l16.73,2.16c4.21.55,8.5,2.14,12.62,3.23,4.38,1.13,10.49,1.49,14.48,3.75,2.45,1.38,8,10.48,10.5,10l16.64-2.83c4.56-.79,8.94,1.38,13.38,2.67,2.68.78,4,.4,4.83,3.26.91,3,.77,3.72-.16,6.8,4.69,1.56,8.32,3.32,13.13,2.46,5.6-1,9.14-1.23,14.72-.27,2,.33,4.8,1.56,6.56.26,2.75-2.05,2.42-2.1,4.81.29,1.76,1.68,4.25,5.39,6.41,6.28,1.58.63,4.93-.5,6.62-.68-.51-3.71-1-7.41-1.56-11.11l23.83,1.87c6.23.47,12.2,4.82,17.85,7.56,6.52,3.19,12.8,6.54,19.12,10.17,3.9,2.24,4.45,2.45,6.12,6.89,1.86,5,1.32,6.62,6.25,6.62-.58-2-1.13-4-1.73-6.06a32.63,32.63,0,0,1,12.16,1.83c3.21,1.11,6.24,4.82,8.93,7-1.64,1.34-4,4.31-6,4.86-1.71.49-4.82-.77-6.6-1.05Zm-624,171.53h0c-.85-.77-.83-3.13-1.7-3.68-3.86-2.36-4.47,3.68-4.51,5.89-2.2-3.74-2.67-5.31-.84-9.35-1.6-.74-5.16-1.47-6.31-2.88-.89-1.14-.86-5.2-1.11-6.71,0-.12-5.37-2.22-3-2.79s2.92,2.21,5.27.47c-1.56-1.47-3.08-1.75-1.77-3.69a4.35,4.35,0,0,1,3.71-1.52c2.73.45,7,.31,9.29,1.39a5.36,5.36,0,0,0-3.25,5c1.69-2.42,2.35-3.92,5.26-4.28-1.45-4.57-2.48-1.56-6.31-2.77.6-2,1.92-4.26.89-6.14-.43-.82-2.13-4.84-3.51-3.21-1.47,1.78-3.68-.07-5.6-.82-1.42-.56-3.85,1.82-5.33,2.09-3.75.67-3.51-1.32-4.6,3.38-.33,1.31-4.58,2.29-5.69,2.79-2.63,1.1-2.43,1.22-3.06,4.3-.28,1.42-2.48,2.95-3.42,4,2.33.14,5,2,4.89,4.76-.07,4.09.5,5.67,2.13,9.36,1,2.26,3.58,3,4.79,5.12,2,3.46,2.66,4.57,6,6.2-2.77.84-3.32.53-4.06,3.59a42.1,42.1,0,0,1-1.92,5.5c-.87,2.24-.57,3.64-.37,6.07.24,2.65.95,2.15,3.35,2.73,2.08.5,2.18,2.07,3.84,2.57,2,.65,4.1,1.3,6.1,1.91,2.62.82,7.12-.85,9.86-1.19-.35-3.32-1.06-6.49-.41-9.73,1-5-1.28-2.69-3.25-6.25a14.57,14.57,0,0,0,1.87.14c-.22-.8-.42-2.47-1-3s-2.23.14-2.73-.45c-1.33-1.68-.5-3.33.24-4.91-.14.32,7.58,1.16,9,.5.51-2.19-1.43-3-2.8-4.31ZM272.93,235.89h0c2,.39,4.49,1.59,6.4.13a9.44,9.44,0,0,0-1.49-1.29c-1.72.07-3.62-.36-4.91,1.16ZM443.77,645.42h0a16.32,16.32,0,0,0,5.33,2.82c1,.3,2.39-1.49,4.37-.83a13.54,13.54,0,0,0-1.13-1.73c-2.4-.81-6.62-3.17-8.57-.26Zm-16.42-157.8h0c-.2.22-.42.44-.65.66l.45.31c.8-1,1.17-1.41.8-2.45-.17.23-.37.47-.53.72-.49-1.51-1.77-1.68-3-1.13-1.59.67-2.2-.87-3.82.34l1.31.3c1.54.68,3.89,2.22,5.42,1.25ZM418,483.93h0c-1-.69-1.16-.28-1.42-.07.31.35.65.66,1,1,.16-.33.28-.62.46-.95Zm2.23,2.22h0a6.12,6.12,0,0,1-.06-.63c-.44-.24-.82-.43-1.39-.75l-.94.83a5.27,5.27,0,0,0,2.39.55Zm128.63-33.82h0c.63-1.36,1.28-2.7,1.88-4.05-3.87-1.58-8.06,3.7-9.5,7.14-2.4,5.79-4.46,8.44-8.71,12.82-.75.79-1.11,5.05-.57,6,1,1.52,4.34,1.08,5.69.92,4.43-.51,9-.45,13.09,1.77-1.45.54-2.49,1.51-2.29,3.2,3.89-.8,4.71-3.5,8.77-3.78-.55,3-1,3,1.68,4.07,2.19.85,2.54.9,3.85-1.07,1.46-2.2-.2-7.32-.74-9.69-.36-1.56-3.08-2.22-2.94-3.12.37-2.62,0-2.68-1.68-4.66-1.31-1.51-6.81.5-8.41,1-.12-1,.15-3.19-.76-3.59-.71-.35-2.34-.63-2.36-1.57,0-3.06.87-3.33,3-5.3ZM496,646.44h0c1.09,2.72,5.8.54,6.89-1.16a8.37,8.37,0,0,0-.75-.8c-2.12-.17-7.71-1.94-6.14,2Zm-38.78-9.61h0c1.92-.49,3.81-1.09,5.72-1.67-1.55-1.25-2.63-2.35-4.51-2.69-1.35-.24-2.07-2.29-2.7-2.24a9.55,9.55,0,0,1-7.69-3.73c-.11.22-.24.45-.34.7-5.56-3.7-11.64-7.09-18-7.72-3.84-.38-6.78.46-10.55,1.39-3,.76-3.82,3.68-6.27,5.2,4.82,2.55,10.33-8.31,15.11-3.49a3.2,3.2,0,0,1-2.46.49,3.37,3.37,0,0,0,3.49,1.27c1.5-.47,1.64.7,3.25.75,2.63.09,5.1,2,7.92,2.36,2.62.36,2.7,3.45,5.58,4.8.76.34,3.6-.4,3.57,1.58,0,.64-2.41,2.46-2.87,2.94,3.55.64,7.16-.25,10.8.06Zm53-158.21h0c-2.27,4.21,1.66,4.9,4.5,6.22s3.6-.33,5.57-2.51c-2.93-.22-5.87-.45-8.79-.71-.43-1-.86-2-1.28-3ZM508.43,460h0c2.9,2.33,9.55,7.91,13.23,5-3.45-3.89-8.6-5.1-13.23-5ZM645.28,775.61h0c1.42,6.18,1.55,6.07-1.83,11q-6.21,9-12.47,18c-1.93,2.85-4.3,5-4.55,8.57q-1,13.26-1.9,26.54c-.41,5.85-6.5,11.87-9.51,16.52-1.33,2-2.43,5.37-4.8,5.5s-7.59-.66-9.53.68c-5.83,4-11.65,8-17.48,12-1.15.83-1.13,9.54-1.31,11.09-.2,1.84.1,5-1.07,6.5-4.83,6.22-9.67,12.46-14.51,18.66q-6.63,8.58-13.29,17.1c-1,1.29-15-4.73-17.11-5.4-1.26,4.78,6.71,5.3,7.53,9.43.42,2,2,5.91,1.61,7.92-.36,1.83-3,4.44-4,5.93-2.93,4.29-6.85,4.2-11.57,5.48-4.52,1.22-6.69,1.11-11.34.2.89,2.92,1.62,4.16.54,6.93-.64,1.74.16,4.55-.84,5.26-4.62,3.23-7.31,1.84-12.14-.58,0,2.42-.68,5.66-.16,8,.39,1.71,3.2,4.59,2.47,6.23-1.48,3.18-2.93,6.33-4.4,9.51s-1.95,2.82-5.18,3.6c-2.79.68-3.31,3.1-4.75,5.76-.9,1.67,2.54,4.85,3.54,6.29,1.29,1.82,5.54.24,4.66,3.2a13.87,13.87,0,0,1-3.24,6.22c-1.64,2-4,4-4.79,6.5-1.2,3.82-2.18,4-5.47,5.92s.37,11.92,1,15.56c.26,1.33.2,4.51,1.27,5.37,2.46,2.14,4.93,4.24,7.37,6.34,4.3,3.67,7.22,3,12.74,3.15-5,2.24-10,4.54-15,6.8-4,1.83-4.78.79-8.87-1.21-5.91-2.83-11.8-5.71-17.71-8.53-3.05-1.47-3.54-4.88-4.93-8.17-3.32-7.81-8.72-15.48-7.74-24.18q2.2-19.47,4.41-38.88c1.41-12.46,2-25.47,4.31-37.81q4.41-23.28,8.82-46.6,2.69-14.19,5.37-28.31c.76-4,2.21-8.52,2.39-12.62.13-3.46-.9-7.43-1.35-10.86-.27-2.25,0-7.69-1.18-9.61s-5.47-3.81-7.33-5.12q-5.48-3.78-10.91-7.6c-3.69-2.57-4.73-5.13-7-9.36q-6.71-12.57-13.45-25.16c-3.68-6.92-7.38-13.81-11.08-20.74-2.27-4.25,1.58-12.12,2.63-16.56.53-2.19.79-7.11,2.17-8.83,2.13-2.73,4.21-5.43,6.32-8.13,4.7-6,8.74-9.52,7.52-18-.29-1.92-1.45-3,0-4.38.2-.19-.5-2.93-.26-3.92.59-2.58-5.12-5-4.53-7.45.78-3.09.61-2.73-1.93-4.17-1.82-1.08-1.81-1-3.7.07a19.86,19.86,0,0,0-3.72,3c-.65.6,1.21,2.79,1.62,3.52-3.63,1.55-3.47,2-5.13-2-.74,2.17-4.38-1.5-6.4-1.89-1.05-.2-1.77,1-2.41.53-1.1-.84-2.2-1.71-3.32-2.54-2.27-1.71-6.76-3.83-8.33-6.33-1.33-2.09-.66-5.3-2.36-7.26-4.3-5-6.92-9.37-12.92-11.06-4.66-1.29-12.4-1.63-16.07-5.23-3.21-3.18-6.47-6.36-9.68-9.56-2.11-2.07-5.09.11-7.62.91-5.73,1.77-11.58-2.4-17-4.6-4.41-1.79-8.83-3.56-13.23-5.35-1.35-.55-4-1-5.11-2.1-2.87-2.91-5.72-5.83-8.6-8.75-2.65-2.68-1.08-4.3,0-8.06.71-2.44-3.85-7.25-5.12-9.2a27.09,27.09,0,0,0-4.54-5.49c-3.09-2.88-6.19-5.72-9.28-8.62-.7-.66.18-2.64.34-3.54s-1.51-2.44-2-3.1c-2.21-2.85-4-5.36-6.78-7.5-2.33-1.8-4.79-2.9-5.68-5.91-.5-1.68-1.8-9.74-3.2-10.39-2.88-1.3-5.73-2.63-8.59-3.93.95,3.25,1.61,9.56,3.65,12,3.12,3.72,5.79,6.63,7.64,11.22a10.61,10.61,0,0,0,3.82,5.17c1.55,1.35,2,3.49,2.71,5.51s1.75,4,1.85,6.32c.17,3.51,1.68,1,2.74,1.79s3.49,3,3.25,4.8c-.33,2.4-2.42,3-3.43,1.13-2.07-3.81-5.73-6.06-9-8.47-.94-.7-.6-5.05-.69-6.27-.14-1.9-2.88-3.17-4.17-4.25s-2.51-.55-3.89-1.78c-1.59-1.38-3.18-2.81-4.75-4.23,1.88-.22,6.35-.61,3.86-4.28-2.17-3.23-3.14-4.82-6.45-6.44-2.17-1.06-2.72-4.68-3.62-7-1.53-3.92-3.05-7.82-4.56-11.74-1.65-4.27-7.22-8-11.28-9.13-3.34-.91-4.48-.63-6-3.89-1.64-3.55-3.27-7.11-4.9-10.65-2.39-5.25-7.15-8.46-8.83-14.19-2.18-7.44-2-12.26-1.65-20.15.3-6.56.65-13.09,1-19.64.33-6.34-1.16-10.32-3.16-16.4a84.73,84.73,0,0,1,10.71,3.28c.14-5.34.37-6-3.07-9.69a47.62,47.62,0,0,0-8.08-6.87c-2.68-1.91-5.55-1.91-8.47-3.17-4.76-2.1-5.47-2.26-7.61-7.3-2.45-5.82-11.1-8.86-10.53-15.34.51-5.92.08-5.46-4.66-8.46-.67-.43-3.53,5.87-5.54,2.79-1.49-2.31-3.91-8.2-6.24-9.32-3.32-1.59-4-2.38-6.12-5.59s-4-7.35-6.57-9.92c-2.13-2.16-5.3-3.66-7.73-5.34-5.94-4.11-11.16-6.26-17.85-8.7-2.63-1-5.83,1.25-8.49.64s-6.05-3.71-8.51-5.23c-3.41-2.1-4.37-2.86-8.19-2.49-3.4.33-5.09,1.24-3.79,5.55,1.06,3.63-12.82,7.39-15.88,8.42-.67-1.58.07-2.69,1.59-3.13-2.34-.72-.57-7.5.92-8.32,3.46-1.86,5.18-2,9.07-1.92-.89-.79-1.79-1.62-2.68-2.43,1-.73,2-1.51,3.07-2.26-6.16,1.19-8.71,2.51-13.89,6.44-4.48,3.37-6.27,7.17-9.17,12.3,1.42.36,2.84.69,4.27,1.05-4.27,5.68-8.53,8.91-14.13,13-2.79,2-11.63,4.28-12,8.45-.33,3.75-11.81,5.87-15.08,6.82a24.21,24.21,0,0,1-4.08.62c-1.71.19-.85,1.1-2.13,2-2.78,1.84-4.71,2.38-7.7,1.64,2.73-2.66,5.58-3.34,8.69-5.28,2.36-1.46,9.27-8.09,11.37-4.44,1.48-2.65,7-8.76,10-6.65-1-2.84,4.15-4.66,4.73-7.82.48-2.64.52-3.28,2.26-5,1.14-1.14,2.25-1.73,1.09-3.47-3.73,2.06-7.77,5.39-11.61,2.57-1.32-1-3.85-3.83-5.43-3.15-1.95.86-3.91,1.7-5.84,2.57q-1.05-6-2.05-11.89c-1,.54-6,4.25-6.77,3.7-1.9-1.56-5.57-3.42-6.85-5.62-1.39-2.35-1.54-7-2.14-9.7-.51-2.29,1.32-4.06,2.46-6,2.21-3.78,1.94-4.77,6-4.38,3.36.33,3.86-2.4,6.82-3.61s5.35,1.12,6.78-2.53c1.14-2.9-.55-3.43-2.54-5.64.9-.52,1.8-1,2.68-1.54-1.27-3.82-4.3-.42-6.48.83-2.77,1.6-3.2-.31-6,0-5.52.73-11.73,1.85-14.77-4.17.7-.2,1.34-.92,2.05-1.06-2.73-.92-6.31-1.33-8.19-4,4-2.09,6.78-4,11.17-4-.29-.4-.62-.82-.93-1.22a17.59,17.59,0,0,1,9.12-2.6c-.17,4.4,3.19,3.73,6.57,4.63,2.95.75,3.9-.57,6.48-2.38-1.2-.53-2.4-1-3.59-1.55.45-.16.92-.36,1.4-.54-1.31-1.06-1.74-2.27-.31-3.28a36.51,36.51,0,0,1-8.84-1.78C43,328.07,43,324.17,40.64,323c-1.62-.77-8.61-2.68-9.29-4.34-.33-.74,1.22-4.07,1.48-4.92.18-.62,1.74-.41,2.26-.44,2.6-.18,6.59.65,8.28-1.77,1.93-2.72,3.67-5.67,6.1-7.89a30.61,30.61,0,0,1,15.21-7c3.5-.6,6.37-.6,9.21-2.86,3.92-3.14,3.68-3.21,8-.92,3.83,2,14.7-.76,16.38,3.93,1.22,3.45,12.55,3.14,16.3,3.63,5.66.73,11.33,1.39,17,2.41l25,4.4c5.48,1,10.64,4.14,15.76,6.45.9.39,6.72-6.68,7.66-7.59,1.53-1.6,4.53,3.08,6.32,2.28,3-1.3,16.2-9.38,18.15-6.23l-14.48,7.65c3.73,2.58,16-8.18,17.1-3.6,1.45-1.69,2.87-3.36,4.31-5.07,1.17-1.36-1.73-1.75.41-3.48a166.42,166.42,0,0,0,11.42,12.15c1.3-4.13,1.79-5.53,4.82-8.22,1.83,1.93-1.38,2.79,1.12,4.24.93.54-.58,2.52-1,3.41,1.6-.42,4.6-.47,5.89-1.51.48-.4-.59-2.35.31-2.46s1.81-.27,2.72-.41c3.22-.45,7.49,2.62,10.46,3.91,6.14,2.65,13.15,3.62,19.57,5.32-.14-.46-.3-.92-.43-1.4,4.11.16,6.24,2.09,9.8,4.49,2.64,1.83-5.43,4.62-6,4.88,2.72.85,5.6,2.31,8.43,2.09l14-1.11c2.17-.15,6-.81,7.48,1.5,2.14,3.18,4.28,6.35,6.41,9.55-.33-1.38-.66-2.78-1-4.17-.21-.85.66-1.63.54-2.42-.51-3.32-1.94-2.49-.15-5.7,1.26-2.18,10.78-2.44,8.65-5.75-4.62,1.87-8,3.37-12.9,3.25,1.1-4.22,2.81-3.77,6.6-5.05,4-1.3,4.48-1.69,8.11.37,1,.58,1.68,3,2.23,4.05.72,1.45,1.8,1.25,3.27,1.6a58.34,58.34,0,0,1,8.61,2.68c2.42.91,15.71,2.43,16.26.58,1.14-3.82,1.31-5.63,5.5-5.61,2.59,0,5.63,1.42,8.19,2.08-.36,1.26-2,5.07-1.6,6.22s4.11,2.77,5.15,3.47c-1.35-4.32-2.93-8.1,2.33-8.92,2.19-.36,3.46-2.33,5.06-3.91,1.14-1.11.34-2.59.07-4.17l-4.09,2c-.5-4.27,2.57-4.93,5.56-5.19-.14-3.34-3.28-1-5.32-1.74-1.6-.64-7.16-1.69-7.86-3.42-1.49-3.61-1.4-5.93-1.35-9.93s1.85-4.38,4.76-3.19c.51-1.85-.74-2.52-2.3-2.32,2.87-1.84,3.27-1.61,3.17-5.2-.12-3.24-.17-4.48-1.61-7.23-1.08-2.08-.29-5.1-.15-7.45.11-1.84,3.14-.85,4.56-.82-5.2-5.74,3.95-4.12,7.51-4.09A39.76,39.76,0,0,1,387.66,266c-2,2.9-4.71,9.18-7.55,10.9-2.53,1.51-8.74.26-11.43.21,8.57,1.27-1.29,6.85-.75,9.6,4.36-.78,6.84,3.07,7.63,7.19.51,2.66,4.8,5.86,6.54,8-2.15,1.43-4.27,2.86-6.38,4.28,2.11.82,3.81,2.23,5.75.87s3.7.31,5.77,1.33l-3,2.08c2,1.74,3.12,1.8,2.44,4.56s-1.11,3.34,1.32,4.91c1.43-2.13,2.29-3.17,2.53-5.77.08-1,.94-5,2.71-3.93,1.14.71,5.05,2.2,5.33,3.6.52,2.34,2,5.06-.91,6,0-.57-.31-1.19-.29-1.75-5.95,3.31,7.3,15.21,7.88,8.76.16-1.82-.08-2.9,1.21-4,.62-.59,2.63-1.78,2.63-2.76,0-4.81.07-4.56,4.11-6.35-1.62-2.54-3.13-3.77-2.53-6.76s2.27-2.27,4.93-1.81c1.75.3,6.54.11,7.76,1.53,2.3,2.6,3,3.08,6.3,3.8-1.38,2.52.82,4.14-.64,5.89-.94,1.11-4.09.69-5.44.82,1.21,2.61,2,5,4,6.81,2.15,2,3.14,3.61.8,6.59-1.54,2-5.31,3.25-7.36,4.51s-3.44-1.42-5.08-2.94c.83,1.87,1.64,3.73,2.48,5.6-1.3-.67-2.56-1.35-3.84-2,.14.52.31,1,.48,1.56-1.32-.29-2.6-.62-3.91-.92-.86-.2-.17-2.47-1-2.43-2,.07-4.73-.75-5.74,1.54,1.21.74,2.43,1.44,3.65,2.15-1.32,2-2.4,4.38-4.41,5.51-2.91,1.63-4,.27-6.93-1.32-4.66-2.43-8.76-2.23-13.95-2.45l10.75,5.42c2.62,1.32,7,.86,9.82,1.25-1.14,1.94-3.05,7.27-5,8.16-1.11.53-2.61,1.67-3.82,1.6-1.51-.16-3-.69-4.25.22-4,2.8-4.27,3-8.77,1.6-2.83-.85-5.7-1.54-8.54-2.32,1.89.87,3.78,1.72,5.67,2.6-.41.36-.67.88-1.11,1.23,3-.72,3.49-.67,6.21.83,1.42.8,3.64,2.91,1.25,4s-3.73,1.21-6.53,1.06c-.9-.07-2.36,3.17-2.84,3.89-2.27,3.58-5.88,7.42-6.79,11.77-1,4.9-2,9.84-3.09,14.75,2,.46,6.29.5,7.76,1.85,1.64,1.48,2.6,7.25,3.42,9.42,1.42,4,2.32,2.53,6.14,1.68,2-.45,4.28.95,6.17,1.62a55.6,55.6,0,0,1,14.93,7.62c1.6,1.14,4.68,4.46,6.62,4.64,2.85.32,5.72.63,8.55.92,1,.11,6.47,0,6.43,1.21-.16,4-.35,7.92-.5,11.88-.23,5.5,5.28,9.69,8.47,13.69s9.78-3.33,9.24-6.68c-.57-3.52-1.17-7-1.75-10.59-.31-1.87-2.77-4.37-3.81-6,3.47-2.27,10.18-4.78,12.59-8.24,2.2-3.1,2.74-11.58,0-14.27a41.49,41.49,0,0,1-5.36-5.71c-2.19-3.08-2.9-2.82-.16-5.35,3-2.72,3.27-2.35,2.15-6.39-.6-2.18-2-4.8-1.28-7,1.26-4,1.36-4.75.14-8.74-.77-2.51.81-3.36,3.38-3.69,4.71-.58,9,3.5,13.65,1.35,2.93-1.37,3.69.16,6.39,2.09,1.28.94,4.95,2.53,5.38,4.25.65,2.58,2.12,4.58,5,4.15,2.32-.33,3.88.78,6,1.82-1.24,2.1-2,2.69-1.57,5.06.39,2.21,1.08,4.33.19,6.51.62-.14,1.29.16,1.9,0-1.13,1.42-4.38,3.72-2.63,5.32,3-9,13.82,10.61,16.05-1.49.49.54,1.41.6,1.91,1.14,1.21-2.58,3.15-5.06,2.63-8-.38-2,2.57-6,4.6-5.56-.26,1.07-.5,2.15-.72,3.23,4.67.23,7.8,9.81,10,13.67,1.24,2.15,5,6.44,5.17,8.89.09,1.33-2.27,3.22-2,4.51.13.6,2.46,2,2.88,2.34,1.06.84,3.12,1.89,3.84,3.07.86,1.43-.53,3,1.37,3.08,3.59.2,5.1.26,8.1,2.28,2,1.42,6.1,3.35,1.65,4a49.28,49.28,0,0,0-7.41,2.16c1.5.56,3.47-.53,5.08-1-1.1,2-4.62,2.17-6.61,2.78s-1.3,4.44-.27,3.08c.88-1.17,1.54-1.32,2.88-1.84,1.18-.43.73-1.09,1.42-1.48a13.79,13.79,0,0,1,5.76-1.61,3,3,0,0,1-2.12-1.16c1.41-.06,4.21.13,4.81,1.81.81,2.18-1.65,2-.3,3.71,1.61-3,3.54-1.41,6.07-.59,2,.68.45,4.53,0,5.69-.82,2.25,1.74,3,0,5.59-.74,1.1-4.35,3.11-5.56,3.42-2,.51-3.86.09-6.08.8s-3.13,2.07-4.77,3.89c-3.38,3.71-6.16,4.26-11.15,3.75a88.42,88.42,0,0,0-14.73-.33c-4.43.27-9-1.24-10.2,4.7-.33,1.55-4.62,2-5.8,2.84-1.93,1.34-3.61,3.85-5.23,5.61-3,3.17-4.56,7-8.06,9.54,6-2.9,9.17-9.2,15.14-12.1,4.09-2,15.2-8.24,18.12-.91-.48-.26-1-.34-1.52-.58,3,2-1.08,3.55-2.59,4.87-1.93,1.68-3.51-1.26-5.74.28.91.24,3.08,2.64,3.2,2.61a6.72,6.72,0,0,1,4.09-.23,7.09,7.09,0,0,1-2.69,4.17c.68-.26,1.54.06,2.27-.08-1.13,3.13,2.18,5.65,4.57,6.23-.27.21-.53.42-.8.6,3.46,1.67,6.84,3.1,9.85.91.1.56.2,1.09.32,1.64a4.74,4.74,0,0,0,2-.61c-2.06-2.66,2.09-6.48,3.5-8.66,2.72,1,1.16,3.37.55,5.5,2-1.56,4.79,1.5,3.1,2.23-2.25,1-4.3,2.31-6.81,1.88.56.45.83,1.27,1.36,1.74-2.83,1.15-5.65,2.31-8.48,3.44a10.07,10.07,0,0,0-3.12,1.53c-1.21,1.08-1.54-1.39-2.56-.56-1.92,1.53-3.64,4.52-5.72,6.5-1.39,1.33-2.75-.57-3.61-.88-3-4.24,4.2-7.93,6.61-9.67,1.72-1.25.88.22,1.68.93,1.6,1.38,2.58-.53,4-1.85-1.89-.08-4.29-.77-5.92.39,0-1,.89-2,1.56-3-2.22-.55-5,2.32-6.84,3.51-1.18.79-1.16-1-2.54.66-.7.81-2.3.33-3.29.33,1.44,4.59-6.32,2.93-7.36,5-.31-.31-.62-.64-.94-.95-1.19,2.46-2.33,2.73-4.63,3.59-1.54.59-1.59,1.7-2.23,3.38-.94,2.41-5.35,10.53.69,9.89-.17-.38-.32-.79-.48-1.15a6.75,6.75,0,0,1,1.26,1.48c-1.79,1.26-3.92.17-5.81-.29-.94-.22-.62,2.57-2,2.66-4.44.35-6.43.59-10.25,3.14,2.72-.35,4.93-1.69,7.6-2.09-.3.22-.57.48-.87.68.76-.05,1.51.19,2.25.09-1.85,1-3.16,1.9-5.2,2-1.69.13-4.66-.49-5.66,1.3,4.13.47-1.82,8.33-3.34,9.63,1-1.72-2-2.85-2.66-4.85.14,2.42,3.19,5.7,2.09,7.91s-3.13,4.95-3.72,7.22l-.45-.13c0-1.7.8-3.05,1.43-4.59-1.08-.68-.56-2.86-2.72-2.27a20.63,20.63,0,0,1,1.07-4.81c.14-.26,1.51-3.39,0-2.33-3.52,2.55-2.47,4.23-1.51,8.55a9.26,9.26,0,0,0-3.38-1.75c.88,1.3,3,1.71,3.74,3,.52,1-.74,3.87-.46,4.81.5,1.74,2.92.84,2.26,3.72-.49,2.31-1.94,2.09-4,2.75,1.75,0,4.79-.58,4.35,2-.16,1.08-3.81,1.13-4.78,1.3.53.3.95.83,1.5,1.12-.81.27-1.21.8-2.21.79.85,2.12,2.12.2,3.56,1-1,.53-2,1.09-3,1.63-.78.39-1.86-.85-2.47-.5-1.19.7-2.4,3.5-3.24,4.73-.61.89-2.74.5-3.87,1.91s-1.91,2.93-3.28,3.74c-4.73,2.79-5.56,4.06-8.12,9.26-1.19,2.46-.42,6.81.72,9.27A87.46,87.46,0,0,1,435,595.87c.7,2.38,1.32,8.52-.41,10.23-1.3,1.32-2.41,3.06-3.93.91-.48-.67-3.27-3.18-3.32-3.4a30.85,30.85,0,0,0-2.09-5.11c-.82-1.85-1.76-2.93-1.2-5.12-.34.28-.68.58-1,.86-.83-2.82,1.76-6.86-1-8.8-2.48-1.71-3.83-5.09-6.75-4.15-1.58.51-3.24,1.67-4.71.7-1.31-.86-3-2.51-4.5-2.93-2.57-.7-6.9,2.73-7.65-1.64-.48,3.81-8.92,1.06-11.4,3,1.74.17,8.2,1,3.37,3.29.51.26,3.14,1.17,3.22,1.64.32,1.35-.85,1.91-1.77,1.73.68-1.76-1.92-2.42-3.17-3.2.27,1.24-.27,1.66-.3,2.6-1.18-2.45-2.22.11-3.81-1.1-2-1.52-2.9-2.95-5.23-2.13-1.32.46-3.19-.78-4.43-1.27-2.39-.89-6.16,1.82-8.45,2.79-3.75,1.54-12.72,8.19-12.76,13.58,0,1.66,2.19,3.36,2.29,5,.07,1.12-.84,3-1.14,4-.82,2.94-2.12,6-2.1,9.07,0,7.78,1.05,13.36,5.34,19.86,2.53,3.81,3.48,6.47,7.62,7.68.85.28,2.21,2.41,2.94,2.14,1.71-.67,3.41-1.31,5.12-1.92a15.11,15.11,0,0,1,4.57-1c1.23-.1,2.2,1.5,2.82,1.22a9.75,9.75,0,0,0,2.16-1c.4-.35-.6-1.38,0-1.92,1.48-1.33,2.2-1.8,2.77-3.77,1-3.29.68-7.15,4.17-8.53,1.45-.58,6.21-1.73,7.69-1.53,2,.24,7.58-.92,5.81,3.32-.71,1.67-3,6.65-4.21,6.75.63.35.27,1,1.68.93-.54.45-.94,1.08-1.48,1.46l.27.36c.26-.19.51-.36.78-.53a32.93,32.93,0,0,0-1.65,6.1,4,4,0,0,1-1-3.55,11.54,11.54,0,0,0-1.38,2.33c2.63.12-.38,5.17.5,7,.79,1.69-2,4.82-3.19,5.89,3.73,1.3,7.34.3,11.44.93,1.59.21,2.75-1.2,4.33-.93,1.75.22,4.13.11,5.77.83,3.48,1.52,5.71,4,5.09,8-.43,2.6-.83,5.17-1.23,7.76-.24,1.51-1.46,2.81-1.66,4.25-.87,7,7.63,18.48,14,15.87,4-1.61,6-3.22,10.1-2s5.56,3.38,8.53,6.66c-.21-5,6-11.73,8.34-15.76.73-1.24,5.34-2,6.57-2.45,3.34-1.18,6.7-2.41,10.07-3.61,3.06-1.12,8.62,1.56,11.65,2.27,8,1.86,15.88,3.68,23.84,5.55,4.3,1,8.65,1.06,12,4.24,6.2,6,12.39,11.9,18.59,17.86,3.92,3.74,12.48,3.83,17.45,5.06,4.67,1.16,8.33,8.91,11.27,12.76s6,7.81,9,11.71c.71,1,2.32,4.07,3.43,4.47l19.15,6.91,19.17,6.93c5.28,1.93,10.77,7.75,15.47,11.12.87.1,6.8.17,6.95.83.64,2.87,1.32,5.71,2,8.55Zm-205-272.18h0c0,2-6.48,3.57-8.4,3.49-2.85-.11-3.14,0-5.38,2-1.45,1.29-2.44,2.73-4.48,1.73a3.55,3.55,0,0,1,2.76-2.68c-.73-1.1-.87-.28-1.26-1.74a36.26,36.26,0,0,0-4,6.06c1.08.28,2.11.56,3.15.88-.23.29-.45.63-.7,1,4.28.4,6.08-1.7,9.75-3.05a33.76,33.76,0,0,0,9.22-5.38c0-1,.17-1.58-.71-2.26Zm5.57-1.36h0c3.29,3.15,10.28-2.92,6.71-4.36,1-.86,2-1.72,3-2.6-2,.82-6.3,4.06-7.76,3.44-2.57-1.15-5.86.4-8.53,1-5.66,7.38,4.28.34,6.59,2.54Zm-66.26-21.89h0c2,1,3.88-.27,5.81-.91-.17.41-.34.85-.52,1.27,4.63,2.49,11.29-7,14.78-4.23a6,6,0,0,0-3.55,3.87c1.62-.89,3.17-1,4.28.55s2.17.8,3.71,1.68c.64.34,7.34-2,8.48-2.16-.64,2.08,1.31,1.53,2.6,2.16,1,.45,1.44,2.17,2.33,3-1.62-.22-3.31-1.2-4,.74-2.32-2.71-7-1.22-8.62,1.55l-.45-.38c.24-.39.48-.73.74-1.11-.64.46-1.2.46-1.84,1.05-.08-.44-.14-.86-.19-1.29-1.63,1.67-4.41,6-4.82,8.21,1.9.4,2.8-3.24,4.33-4.24.27,1.74-1.48,4.38-2,6.22-.62,2.36-1.83,5.09-1.67,7.6.24,3.92,2.21,14,6.11,6.17,2-4.15,1.33-7,.56-11.19-.86-4.68,2.55-5.4,3.87-8.3-.09.83.07,1.82-.07,2.63,1.3-1.38.75-3.79,3.29-4-2.17-2.85,2.25-2.33,3.52-1,1.48,1.57,3.58.85,4.16,3.5a2.64,2.64,0,0,0-.79-.1c.86,1.48,1.28,4-.27,5-.31.2-2.3,2.32-2.08,3.12.39,1.44,3.95-1.83,4.79-1.79,1.92.1,2,5.11,2.29,6.63,1.08-1.24,2.16-2.43,3.24-3.62.67-.75.07-2.9.43-4,.76-2.29,3.17-4.9-.26-6.53,2.45-1.24,1.35,1.91,3.41,1.65-.31.62-.14.81-.71,1.36.57.39.56.29.77.87,1.15-1.09,3.25.46,4.49.12.19,0-.51-2.18,1.54-1-2.3-2.06-2.09-6.89-5.75-7.69-3-.67-6.77-.78-9.9-1.41-1.14-.23-7.56-2.11-7.07-3s-.11-1.47-.6-2.18.6-1.36.36-2.16c-.68-2.22-2.55-1-1.41-4.27-4.66.81-4.63-1.22-7-4.85-1.24-1.94-2.8.26-4.07-.3-1.58-.71-3.08-1.69-4.79-1.55,1.71,1.44.21,2.49-1.29,3.4a4.76,4.76,0,0,0,.86-2.42c-1.42.76-1.16,2.54-2.63,3.16a14.44,14.44,0,0,0,.64-1.67c-2.47.44-1.42,2.74-3.16,3.5l-6.29,2.79c-1.91,1.84-3.78,3.69-5.66,5.5Zm-119.12-145h0c-.62-.05-1.25-.6-1.88-.6.53-.4.91-1.11,1.49-1.46-2.17-.28-3.64,2.4-5.83,2.74-2.94.44-4.12.62-6.85-.58.76-2.31,4.26-3,6.16-3.9-4-1.47-4.95-1.84-8.88-.3-2.43.95-4.88,1.79-7.33,2.62-2.65.89-5.41,1.26-8,2.15-1.37.43-7.24.71-3,3.5l1.17-.85-.42-.83c1.73-.7,6.17-.7,8-.14a3.54,3.54,0,0,0-.47-.93,11.48,11.48,0,0,1,8.47,1.58c-1.35,2.22-5,.28-7.13.89a7.47,7.47,0,0,1,2.4,2.38,10,10,0,0,0-3.08,1.62c1.82,2.18-1.28,2.43-2.7,2.69,1.94,1.51,4.16.43,6.16,1.34,1.41.66,3.29-2.94,4.57-3.78,2.07-1.38,5.81-.29,2.84,1.64-1.18.76-1.38,1.81-1.94,2.28s-1.74.45-2.27.88c2.92,2.66,5.83-4.86,9.51-3.74a3.53,3.53,0,0,0-2.67-2.34c3-3.13,8.9,1.5,10.24-1.91a6.79,6.79,0,0,1-1.73.18c.12-2.07,1.52-1,2-2.15.41-1,.82-2,1.21-3Zm40.15,30.14h0c-3.13-1.34-8.1-2.32-11.09.1-1.15.95-1.92,2.6-2.8,3.51a6.09,6.09,0,0,1-4.54,2.37c-2,.23-5.32.08-6.3-2.49-.27-.7-3.74.12-4.71-1.66-.25-.5-3.5-1.87-3.91-1.49-.71.63,3.25,2.42,3.88,2.31-1.14,2.69,4.89,4.79,1.2,5.68-1.15.3-2.17-.66-3,.61s-.37,1.86-1.95,2.21a7.36,7.36,0,0,1,.74.62c-1.21,1-2.64,0-4.14,0,.06.26.12.54.16.8-1.55.05-2.76-.82-4.25-.69,2,2.67,7,3.26,10.05,3.75,1.93.3,9.45-.8,8.2-3.29,2.36-2.06,3.77-1.39,6.34-2.57,1.45-.66,3-2.69,4.26-3.82a10,10,0,0,1-1.1.08c1.6-1.46,2.54-2.4,4.42-2.89,1.63-.42,2.7.29,4.1-1.27-1.24.56-1.4.35-2.57,0,1.11-.28,2.26-.59,3.43-.85a4.2,4.2,0,0,1-3.07-.62c.82.07,1.69-.06,2.53.07-3.07-1.07-5.76,1.08-8.64,2.87,1-3.57,10.58-5.74,11.08-1.63a14.55,14.55,0,0,0,1.68-1.74Zm52.08,81h0c.28-1.94.08-1.05,1.25-1.71-.07.51-.19,1-.27,1.5a1.75,1.75,0,0,0,.5-.88c1.5.56,1.06,2.52.88,4,.42-.87,1.22-1.8,2.21-1.3.72.34-.59,2.32-.81,3.12a7.54,7.54,0,0,1,1.74-.91c-1.75,1.18-2.12,3.58-1.49,5.69s1.85-.34,1.74-1.45c.39.23.83.23,1.2.45-.83-1.81.7-3.82-.53-4.87s-2.09-3.93-2.58-5.25c-.94-2.43-5.61-12.62-3.54-13.81l-.5-.2c-.67.83-.83.69-1.8.87a2.85,2.85,0,0,1,1.94-2.17,11.62,11.62,0,0,0-1-.88c-1.49,2.69-1.46,3.5.69,5-1.66-.74-4.8-2.34-5.49.31-1.23,4.49-.5,3.61,2.78,4.46-3.81.83.85,5.35,1.81,7.24l1.32.75ZM35.18,385h0c-3.14-1.32-4.69,1-8,.63,1.39,2.16,3.52,2.53,5.69,3.3.36-1.18,1.67-.83,2.91-1,0-.27-.06-.53-.1-.8-.16-.93-1-.83-.46-2.17Zm189-100.42h0c2.89,1.44,5.22,2.36,7.39,4.86,3.5,4,3.05,4,7.51,1.42.68-.4,1.38-.82,2.08-1.22s.44,1,.89.93a29,29,0,0,0,4.38-2l1.29-6.37c2.06,1.36,4.25-.37,4.83-2.59.5-1.95,1.48-1.87,3.21-2.63,3.74-1.65,9.67-2.85,12.81-5.61,2-1.79,1.85-2.71-.44-4.32a27.22,27.22,0,0,0-5-3.29c-3.65-1.48-7.56-3-10.7.51.24-.55.18-1.27.38-1.83-4.23,1.21-8-3.76-11.91-3.2-4.67.69-9.37,1.33-14.05,2,.79,1.45,4.28,6.1,3.51,6.82-1.57,1.48-5.39,5.11-3,7.15-4.12.39-1.08,1.93-2.62,3.94-1.3,1.68-3.46,3.38-2.89,5.85a9.76,9.76,0,0,0,2.35-.44Zm18.15-39h0c2.39.33,1.11-1.6,1.81-2.3,1.35-1.27,3.18.51,2.81,2.95,1.23-.42,3.13-.6,4-1.65s-1.71-3.21,0-4c1-.47,1.8,3.26,3.61,1.21a1.67,1.67,0,0,0-.9-2.82c1.53-.95,3,.38,3-2.32,0-1.3,2.09-1.09,2.71-.46-3.52,2.29-.07,5.83,3.05,5,2.07-.56,7.52-4.59,3.69-6.54a4.77,4.77,0,0,1,2.51-.51c-5-.91-.53-3.18,1.59-4-3.23-1.75-4.42-3-7.81-1.72.56.32.69.77,1.49,1-1.49,1.41-2.91.38-4.53-.23-1.18-.43-3,.23-4.19.38-3.27.44-4.45,1.79-7.1,4-1.76,1.51-5.1,5.73-7.37,6-3.65.39-6.41,1.49-3.4,5.22,1.68.25,3.34.48,5,.71Zm36.39-21h0c-3.14-2.77-3.18-3.11-7-1.62,1.37,1,2.73,1.89,4.11,2.83l2.87-1.21ZM93.66,402h0c1.51,1.09,3.61-.56,4.26-1.55.25.23.49.48.74.7.26-.36.53-.7.77-1l-3-1.28A5.05,5.05,0,0,0,93.66,402ZM194,432.05h0c.25-2.69-6.33-1.72-6.39-1.14-.3,3.4,7.07,16,9.57,12.95-.72-.68-1.46-1.34-2.2-2-.74-3.55-1.37-6.18-1-9.8ZM90.25,405.48h0c-4.21-2.54-4.81,6.31-.43,6,1.25-.09,2.25-2.2,3.81-2.4s2.63-.91,2.54-2.69c1.11.53,1.88.18,2.37-1-.43-.1-.84-.2-1.26-.28,1-2.78-7.46-3.3-7,.44Zm140.8,59.61h0c-.58-1-2.43-1.32-3.41-1.65-1.48-.47-1.69-1.49-2.5-3-2.43-4.42-3.16-3.44-7.55-4.89-3.46-1.17-4.59-2.78-8.16-1.65C215.2,461,221.32,465,229,469.18c5,1.79,4.43,0,2-4.09ZM1043.2,808.21h0c-1.21-1.69-5.12-7.75-5.38-1.92-.18,4.63-1.46,4.66-4.33,7.93-2.3,2.64-3.36,5.16-6.37,6.69a31.81,31.81,0,0,1-9.37,3.44c-1.35.22-2.83,6.34-2.46,8,.66,2.87,2.68,7.55,2.34,10.48-.35,3.17-3.92,6.3-4.91,9.34-1.21,3.68-.38,6.36.6,9.87a81,81,0,0,1,1.86,10c.21,1.27,5.9,3.38,7.09,2.83.81-.4,6.82-2.19,6.93-2.52.75-2.56,1.53-5.14,2.3-7.69q4.17-14,8.37-28c1.9-6.32,2.33-9.22,1.8-15.92.79.8,1.61,1.61,2.41,2.39,2.09-5.06.35-9.24-.73-14.66l-.15-.24Zm327-152.81h0c-1.08,2,.16,5.08.57,7.3.29,1.75,2.66,1.94,4.08,2.49-3,1.55-.92,4.38,1.42,4.68,2.12.26,1.34-1.47,4,0a7.57,7.57,0,0,1,2.21,2.57c.21-1.26.43-2.49.63-3.73,2.56,1,3,.62,3.07,3.63,0,1.1,2.89,2.37,3.79,3,1.5-3.26-1.81-2.36-1.66-5.3,2.23,1.14,3.81-.09,1.86-2.12-.92-1-1,1.12-1.79.91a14.69,14.69,0,0,1-2.84-1.73,8.07,8.07,0,0,0-2.69-1c-1.19-.27-1.4,1.64-2.25,1.6-2.44-.12-1.51-2.49-2.4-4.25-1.74-3.47.52-2.3.36-5.45-.06-1.22,1.71,0,2.12-.61a11.67,11.67,0,0,0,.84-2.93c1.15-3.73-.16-2.13-.84-5.41-.37-1.72,1.66-2.55.55-4.93-3.51,1.74-2-.08-5-.7-1-.21-3,.51-3.2,1.61-.47,2.85-1,5.73-1.42,8.58-.25,1.57,1.34,2,.84,3.78-.74-.68-1.47-1.32-2.22-2Zm8.22-39.85h0c.57-2.6,3.14-9.32-1.73-7-2.74,1.28-5,4.84-5.69,8.18-.73,3.69,1.73,6.12,3.55,8.85a38.63,38.63,0,0,0,3.87-10ZM1367.57,681h0c-.83,3.86-1.21,5.92-4,8.52a28.36,28.36,0,0,0-6.2,8c3.64-2.24,7.14-3,7.91-7.63.18-1.24,3-2.65,4-3.38.26-.19-.64-3.26-.34-4.25a7.86,7.86,0,0,0-1.4-1.3Zm31.17,11.81h0a3.85,3.85,0,0,0-2.77-2.88c.21,1.37.44,2.7.65,4.06-1.58-.27-1.27-.49-2,.56-1.54-1-2.05.17-1.85,2-2.09-1.55-3,2-5,2.72,1.13-1.37,1-3.68-1-3.8-2.27-.14-1.46,2.93-2.66,3.28-2.2.66-6.17,3.23-3.88,6.46,1-.86,3.06-7.66,3.89-2.71.45-1.18.63-.86,1.3-1.61.14,1.48.14,1,1.25,1.77-.23-.66,0-1.49-.14-2.15,5.12-.69,1.73,4.15,2.71,6.71.63,1.64,4.74,4.68,5.48,2l.42,0c-1.09,3.54,2.48,2.16,1.84-.9-.49-2.28-1.91-3.8.75-5.74,1.32,1.8.51,3.66,1.65,5.49.07-1.08.12-2.16.17-3.24.26.18.52.32.79.49.34-1.46,2.15-6.89,0-7a4.34,4.34,0,0,0,.07-1.72c-.63,0-.89-.4-1.26-.44.32-.36.67-.71,1-1.05.2-1.24-.17-2.91-1.43-2.37Zm-25.13,98.69h0c-.87-2.05-7.91-4.63-7.69-1,2.34.93,9.69,5.66,7.69,1Zm-15.11-6.69h0c-.68-1-3.36-1.85-4.34-1.87-2.23-.06-2.07,1-3,3.13,4.61,1.5,7.67,1.14,12.33.36,6.81-1.15-.49-4.91-3.35-3.82.75,1.55-.16,2.17-1.62,2.2Zm19.76,2h0c.82-.09,1.06-1.11,2-1,2.1.37,3.08-1.68,4.39-1.71,2.84-.06,7.85,1.34,10.24-.84-3.43-1.29-5.48-.13-8.93-.39-2.07-.14-2.24.06-3.9,1.51-.91.8-2-.92-3.08-.33-2.15,1.27-6.65-2.62-8.77-.23-2.43,2.69,4,2,5,3.08,1.66-1.44,2,0,3.06-.14Zm2.89-18.8h0c.9.82,1.81,1.65,2.71,2.5,1.06-1.61,2.2-2.14,1-3.73-.82-1.16.12-2,1.15-1.78-.75-2.53-2.54-1.57-2.28.73-1.13-3.32-2.36,1.06-2.61,2.28Zm-62.24-30.68h0c-.14,1.12,1.24,2,1.48,3.07.14.6-1,.89-.74,1.69s.56,1.71.81,2.6c.36,1.23,1,.14.64,2.18,1.45-.7,1.23-.07,1.66-1.48,2.44,2.13,2,6.69,2.34,9.8.28,2.74,5.58.54,6.9-.09.2,1.23.4,2.48.61,3.7,4.12-2.32,4.55-3.26,8.55-.74.64.38,2.09-.26,3.07.1s1.14,2.7,1.42,3.78c2.16-1.08,4.33-2.18,6.51-3.23-.44,1.44-.4,2.72,1.12,2.54.07-3.12.13-6.18.17-9.28.06-2.88.81-3,2.94-4.84,2.9-2.55,2.88-2.52,2.59-6.62-.11-1.85,1.19-5.17,2.87-4.82,3.4.74,4.93.23,1.82-2.63-.75-.72-2.46-1.71-2.94-2.71-.29-.59.67-1.86.43-2.53-1.3-3.7-2.63-3.44-2.52-7.76.06-2.1,4.31-2.07,5.57-2.31-.67-.91-1.33-1.84-2-2.76,1.67-.46,3.3-1,4.93-1.38-.55-1.49-1.4-1.3-2.78-1.65-1.08-.25-1.93-2-2.62-2.91-1-1.24-4.49-4.66-5.81-4.48s-4.68,5.32-5.72,6.49c-1.88,2.15-.25,3.8-3,4.51-3.38.87-3.92.87-5.92,3.91-1.41,2.15-2.27,4.46-4.61,5.23-2.58.83-4.86.87-6.31,3.37-1.87,3.17-2.55,3.09,0,5.64-2.42-.62-7.23-.47-7.78-3.82-1,.59-2,1.23-3.06,1.85-.19,1.85-.45,3.71-.68,5.58Zm73.23,55h0c1.08-1.48,1.61-2.44,3.13-3.16,2.35-1.1,8.21-2.6,9-5.58a58.85,58.85,0,0,0-6.52.75,15,15,0,0,0-3,.63c-.54.27-.54,1.41-1.15,1.69-1.89.91-4,1.54-5.56,3-1.73,1.61,1,2.49-1.15,4.45,1.78-.37,4-.14,5.2-1.77ZM469.7,646h0c1.08.17,2.81-.45,3.78,0,.72.38.43,3.72,2.37,3,.88-.3.88-3.37,1.68-3.93,1.41-1,1.78.4,2.26.39,2.5-.08,4.25-.91,7.08-.91,2.1,0,1.68,1.85,3.14-.6.58-1-1.58-2.3-2.55-2.52-2.34-.49-2.47-.49-3.63-2.79-.89-1.7-1-.55-2.52-1.06-1.14-.36-3-1.58-4.14-1a10.55,10.55,0,0,1-3.06.82c-3.45-.06-4.4-1.13-7.7.41,3.44,1.63,3,2.72,5.19,5.9-2.07,1.54-10.73-2-9.7,1.12,2.94,2.09,4.14.53,7.8,1.09ZM738.08,353.18h0c2.57.72,4.18-1.32,4.08-4.18,2.08,1.14,3.2-.94,4.66-2.37-1.72-1.17-.41-3.61-1.29-4.15-1.75-1-3.14-2.33-5.22-1.56,2.54-4.26-9.79-9.28-7.63-3.71-3.68-.37-4.66,1.47-8.2-.13.2,1.35.37,2.67.58,4-1.39-2-1.83-3.68-4.15-3.74-1.86-.06-2.59,2.05-2,3.79-1.32-1.4-2.49-3.73-4.46-3.29,1.56,3.72-.47,1.86-1.48,3.51a38.39,38.39,0,0,0-1.85,4.3,46.75,46.75,0,0,1-2.75-4.46,1.6,1.6,0,0,0,2-1.69c-.09-1-2.16-1.4-2.68-1.84-2.69-2.32-2.52-2.88-6-2.83.46,1.76,1.71,1.4,3.26,1.67.48,4.58-4.17-.51-5.63,1.28-1.76,2.16,1.43,2.09.91,3.14s-2.06.23-2.93-.3c0,.49,0,1-.06,1.49-1.32-.21-1.06.2-2.12.76,3,1.3,3.87.68,7-.54,1.45-.57,4.48.88,6,1.23-1.27.61-2.52,1.24-3.77,1.86a3.77,3.77,0,0,0,3.61.29c0,.33.07.68.1,1-3.68-.1-7.33,1.39-10.63,1.34.54,2.73,6.52,1.38,8.56,1.38-1.09,1.19-.46,2.18,1.05,1.95-.09.4-.16.77-.23,1.16l1.15.12c-.91,2.64-5.36,1.82-4.23,4.84,2.91-.35,5.81-.74,8.71-1.12.77-.1,1.45,2,2.09,2.41.95.61,2.86.64,3.92.87,2.39.53,4.34.75,6.68-.42,1.14-.56.86-1.55,2.25-1.74l4-.57c1.55-1,5-4.27,6.75-3.79Zm-30.43-57.95h0c-.54-2.19-2.77-7.28-2-9.46,1.93-5.55,3.07-12.57,6.94-16.82,2.55-2.86,5.14-5.7,7.74-8.56.71-.79-1.09-7.34-1.26-8.45-.42-2.48-.15-6.43-2.22-7.85-2.59-1.76-5.18-3.54-7.78-5.29l11.33-11.1c-4-2.69-6.55-3.77-8.48-8.41-1.48-3.54,3.11-8.14,4.93-11.15,2-3.32,5.78-4.7,8.82-6.81a43.23,43.23,0,0,0,8.81-7.87c-1-.84-2-1.7-3-2.53,3.48-.7,7.46-.83,10.62-2.65,3.93-2.29,7.89-4.56,11.84-6.85-4.33-1.7-9.13-4.52-13.65-5.32-3.28-.59-10.06-1.31-12.32,1.51-1.43,1.81-2.44,4.45-4.72,4-2.73-.43-5.46-.9-8.19-1.35-3.11-.52-9.32,3.78-12.32,5.06.47-.9,6.27-10.06,2.12-10.19-3.63-.12-7.08.6-10.11-1.85,4.91-1.76,9.79-3.54,14.7-5.32-9.55-4.19-18-8.51-28.18-9.93-11.35-1.59-22.11-3.72-33.48-2.72l-12.2,1.07c-1.37.12-4.2-.24-5.47.49-1.94,1.12-2.21,5.6-4.76,5.15-3.25-.56-6.48-1.15-9.75-1.71-4-.69-8.69-2.72-12.43-1l-16.5,7.55c5.19,3.33,10.92,5.76,14.28,11.33a180.55,180.55,0,0,0-27.59-8.08c-2.94-.59-7.22.92-10.17,1.3-6.66.88-13.31,1.78-20,2.65-2.9.4-7.49,0-10.19,1.42-3.78,1.95-7.56,3.92-11.35,5.86l-27.94,14.41c3.43,3.78,7.59,3.18,12.37,3.71L503,207.35c-1.13,2.92-1.56,2.35-4.53,2.49a53.23,53.23,0,0,0-12,2.34q-8.14,2.37-16.31,4.71c-1.3.38-1.28,3.64-1.55,5-.21,1,2.28,3.48,2.84,4.23,1.62,2.23,3.68,6.64,6,8,3.18,1.87,6.35,3.76,9.54,5.62,1.59,1,6.07,4.83,7.9,4.59,3.6-.44,7.19-.92,10.78-1.38,6.47-.83,12.13.48,18.6,1.57,3.31.55,6.61,1.14,9.89,1.67,1.62.27,5,6.33,6.06,7.69,4.45,5.71,6.85,12.52,9.86,19.29,1.63,3.66,2.15,4,.88,7.77-1.19,3.53-3.17,5.67-.64,8.38s5.92,4.35,4.94,8.4-2.61,6.15.05,9.08c3.34,3.69,3.12,3.63,7.62,2.31,3.27-1,6.54-1.93,9.82-2.9-.31,2.47-.61,4.92-.92,7.38-.09.81-3.16,1.58-3.81,1.83-2.26,1-4.52,1.95-6.78,2.9-.51.21-.57,3.45-.63,4-.42,3.29-2.24,9-1.13,12.11q2.49,7,5,13.94c2.68,7.53,7.41,13.68,11.63,20.28,2.51,3.94,5,7.85,7.51,11.77,1.23,2,4.77,2.32,6.71,3,4,1.49,8,2.95,12,4.4,1,.36,6.49.49,6.68-.17q3.72-11.59,7.44-23.22c2-6.22,4.15-12.28,6.4-18.36,1.21-3.31,1.07-3.37,4.11-4.37l12-3.93c2.49-.82,6.18-1.26,8.43-2.77,2.52-1.72,4.77-6,6.75-8.41,1.76-2.19,2.43-3.58,4.9-4.22,3.76-1,7.53-2,11.27-3,5.41-1.43,12-2,16.93-5q9.19-5.61,18.35-11.23c2.91-3.54,3.13-3.4,2.08-7.87Zm615.11,349.38h0c1.14-.52,3.31-.57,3.56-2.3s.62-3.91,2.3-3.78c.34-1.6-.14-2.83-1.62-3.09-.07.36-.17.76-.24,1.12-4.27-2.4-6.35,1.53-9.33,3.44,0,3-.52,3.62,1.88,5a4.58,4.58,0,0,0,2.59.77c1.29.1.08-.83.86-1.16ZM1303.89,771h0c.75-3.87-.06-9,1.15-12.43,1.41-4.09-3.54-7.23-6.31-3.88,2.19-2.19.07-2.09-.27-3.92-.19-1-.33-4.26-1.17-4.63s-3.5-.81-3.66-2c-.32-1.92,1.4-2.5,1.11-3.95-.42-2.14-3.26-1.91-3.26-3.22,0-2.44-.91-1.33-2.5-2.55s.28-1.62-2.45-2.13c-1.66-.29-2.81-.13-3.85-1.55-1.92-2.65-4.83-3.51-7.19-5.77-2-1.86-5.13-3.94-6.78-6.17-2.18-3.11-1.54-4.67-5.62-5.13-1.26-.15-7.39-2.49-8-1.59-1,1.46,3.88,7.58,4.73,8.32,1.89,1.68,6,2.45,6.1,6,.16,3.91,4.69,3.14,5.64,6.71.56,2.1,1.14,4.22,1.7,6.35.39,1.46,1.79.94,2.69,1.9,2.21,2.3,3.54,7.78,4.91,10.75,1.22,2.7,3.34,4.56,5.28,6.72,3.95,4.33,7.92,8.58,12.4,12.71,0-.88.33-1.8.31-2.66,2.09,2.58,3.37-1.2,5.05,2.19Zm10.33-17.48h0c-2.51-2-1.56,3.15-1.38,4,3.3,1.08,3.46-2.34,1.38-4Zm26.67,26.71h0c-2.29.53-5.52-1.22-4.87-4.35-1.62.76-5.82.35-6.92-1.05-1.35-1.68-2.09-.8-2.64,1-.33,1.07-1.59.43-2.49.35-3.51-.37-6,.37-7.94-2.93-.29-.53-5.06-1.6-6.07-2.28-.57,1.67-2,.64-3.34.3s-1.45.25-2.44,1.43c-2.92,3.38,1,3.66,3.41,4.22-.09.47-.2,1-.29,1.4,2.93.57,5.64,2.26,8.37,2.79,1.43.28,3.09-.79,4.54-.66s3,1.11,4.36,1.58a17.44,17.44,0,0,0,3.71,1.25c1,.11,2,.27,3,.38.64.08.88-.81,1.37-.79,3,.27,4.15,1.26,7.19.68,1.82.78,3.65,1.6,5.46,2.41-2.18-2.78.62-6.89-4.42-5.76ZM1301.13,751h0a2.41,2.41,0,0,0,2.23.53c.54,0,.89,1.27,1.39,1.84.68.75.29,1.29,1.17,2a4,4,0,0,0,2.69,1.17c-.78-.92-.63-1.81.44-2.67-4,.14-2-5.81-5.19-5.52.06.47.13.9.22,1.33-1.37-2.09-2,0-2.95,1.29Z"/><path class="cls-4" d="M976.46,587c56.28-18.2,100-52.52,132.19-153.23,21.2-66.29,8.4-122,8.4-122"/><polyline class="cls-5" points="985.42 567.73 974.38 589.78 1000.05 591.11"/><path class="cls-6" d="M929.44,431.46c8.39-44.85.2-86-15.28-120.68s-75.23-79.94-75.23-79.94"/><polyline class="cls-5" points="921.29 410.23 928.77 433.73 948.09 416.77"/><path class="cls-4" d="M799.74,428.33c-26-31.83-75.23-55.64-111-64.68-67.48-17-122-8.4-122-8.4"/><polyline class="cls-5" points="777.91 421.66 800.98 430.38 799.66 404.7"/><path class="cls-4" d="M764.06,543c-50.94-18.8-118.86-24.72-197.53,15.82-61.86,31.88-92.18,80.3-92.18,80.3"/><polyline class="cls-5" points="740.72 547 765.13 543.5 751.59 521.65"/><path class="cls-4" d="M756.93,629.34C702.39,649,649.19,687.81,618.55,783.61c-21.2,66.29-8.4,122-8.4,122"/><polyline class="cls-5" points="743.44 647.79 758.83 628.52 734 621.88"/><path class="cls-4" d="M887.33,728.12c24.26,45.2,67.48,90.74,144.3,115.31,66.29,21.2,122,8.4,122,8.4"/><polyline class="cls-5" points="906.72 739.61 886.53 725.44 881.44 750.63"/><path class="cls-4" d="M981.75,681.65c50,16.62,125.51,22.89,200.36-15.68,61.86-31.88,92.18-80.3,92.18-80.3"/><polyline class="cls-5" points="1004.09 676.36 979.01 680.67 994.09 696.93"/><path class="cls-7" d="M869,701.45c-23.77,0-47.55-5.23-65.66-15.68-17.51-10.11-27.16-23.55-27.16-37.84s9.65-27.72,27.16-37.83,40.84-15.69,65.66-15.69S917.1,600,934.63,610.1s27.16,23.55,27.16,37.83-9.64,27.73-27.16,37.84C916.53,696.22,892.75,701.45,869,701.45Z"/><path class="cls-8" d="M946,635.4V618.31h-5.91c-3.76-5.23-9.3-10.12-16.65-14.37-30.1-17.37-78.88-17.37-109,0-7.35,4.25-12.9,9.14-16.65,14.37h-5.91V635.4h0c0,11.39,7.52,22.77,22.57,31.46,30.09,17.37,78.88,17.37,109,0C938.5,658.17,946,646.79,946,635.4Z"/><ellipse class="cls-9" cx="868.97" cy="618.31" rx="77.05" ry="44.49"/><path class="cls-7" d="M940.13,617.65V594.32h-5.46c-3.47-4.83-8.59-9.34-15.38-13.27-27.79-16-72.85-16-100.64,0a48.43,48.43,0,0,0-15.38,13.27h-5.46v23.33h0c0,10.52,7,21,20.84,29.05,27.79,16,72.85,16,100.64,0C933.19,638.68,940.13,628.17,940.13,617.65Z"/><path class="cls-10" d="M940.13,612V588.7h-5.46a48.53,48.53,0,0,0-15.38-13.26c-27.79-16.05-72.85-16.05-100.64,0a48.53,48.53,0,0,0-15.38,13.26h-5.46V612h0c0,10.52,7,21,20.84,29.06,27.79,16,72.85,16,100.64,0C933.19,633.06,940.13,622.55,940.13,612Z"/><ellipse class="cls-11" cx="868.97" cy="594.32" rx="71.16" ry="41.08"/><path class="cls-12" d="M946,593.94V576.85h-5.91c-3.76-5.22-9.3-10.12-16.65-14.36-30.1-17.38-78.88-17.38-109,0-7.35,4.24-12.9,9.14-16.65,14.36h-5.91v17.09h0c0,11.39,7.52,22.77,22.57,31.46,30.09,17.37,78.88,17.37,109,0C938.5,616.71,946,605.33,946,593.94Z"/><ellipse class="cls-9" cx="868.97" cy="576.85" rx="77.05" ry="44.49"/><path class="cls-7" d="M940.13,575.33V552h-5.46a48.53,48.53,0,0,0-15.38-13.26c-27.79-16-72.85-16-100.64,0A48.68,48.68,0,0,0,803.27,552h-5.46v23.33h0c0,10.52,7,21,20.84,29,27.79,16,72.85,16,100.64,0C933.19,596.36,940.13,585.85,940.13,575.33Z"/><path class="cls-10" d="M940.13,570V546.66h-5.46a48.53,48.53,0,0,0-15.38-13.26c-27.79-16-72.85-16-100.64,0a48.53,48.53,0,0,0-15.38,13.26h-5.46V570h0c0,10.51,7,21,20.84,29,27.79,16,72.85,16,100.64,0C933.19,591,940.13,580.51,940.13,570Z"/><ellipse class="cls-9" cx="868.97" cy="552" rx="71.16" ry="41.08"/><path class="cls-13" d="M946,551.63v-17.1h-5.91c-3.76-5.22-9.3-10.11-16.65-14.36-30.1-17.37-78.88-17.37-109,0-7.35,4.25-12.9,9.14-16.65,14.36h-5.91v17.1h0c0,11.38,7.52,22.77,22.57,31.45,30.09,17.38,78.88,17.38,109,0C938.5,574.4,946,563,946,551.63Z"/><ellipse class="cls-9" cx="868.97" cy="534.53" rx="77.05" ry="44.49"/><path class="cls-7" d="M940.13,533V509.68h-5.46a48.53,48.53,0,0,0-15.38-13.26c-27.79-16.05-72.85-16.05-100.64,0a48.53,48.53,0,0,0-15.38,13.26h-5.46V533h0c0,10.51,7,21,20.84,29.05,27.79,16,72.85,16,100.64,0C933.19,554.05,940.13,543.53,940.13,533Z"/><g class="cls-14"><path class="cls-10" d="M940.13,526.49V503.15h-5.46a48.53,48.53,0,0,0-15.38-13.26c-27.79-16.05-72.85-16.05-100.64,0a48.53,48.53,0,0,0-15.38,13.26h-5.46v23.34h0c0,10.51,7,21,20.84,29,27.79,16,72.85,16,100.64,0C933.19,547.52,940.13,537,940.13,526.49Z"/></g><ellipse class="cls-11" cx="868.97" cy="509.68" rx="71.16" ry="41.08"/><path class="cls-15" d="M946,509.31v-17.1h-5.91c-3.76-5.22-9.3-10.11-16.65-14.36-30.1-17.37-78.88-17.37-109,0-7.35,4.25-12.9,9.14-16.65,14.36h-5.91v17.1h0c0,11.38,7.52,22.77,22.57,31.46,30.09,17.37,78.88,17.37,109,0C938.5,532.08,946,520.69,946,509.31Z"/><ellipse class="cls-11" cx="868.97" cy="492.21" rx="77.05" ry="44.49"/><ellipse class="cls-11" cx="868.97" cy="492.21" rx="77.05" ry="44.49"/><path class="cls-16" d="M946,509.31v-17.1h-5.91c-3.76-5.22-9.3-10.11-16.65-14.36-30.1-17.37-78.88-17.37-109,0-7.35,4.25-12.9,9.14-16.65,14.36h-5.91v17.1h0c0,11.38,7.52,22.77,22.57,31.46,30.09,17.37,78.88,17.37,109,0C938.5,532.08,946,520.69,946,509.31Z"/><ellipse class="cls-11" cx="868.97" cy="492.21" rx="77.05" ry="44.49"/><ellipse class="cls-9" cx="868.97" cy="492.21" rx="77.05" ry="44.49"/><path class="cls-17" d="M923.46,522.29c-30.09,17.37-78.88,17.37-109,0-14.75-8.51-22.25-19.61-22.54-30.77-.31,11.62,7.19,23.29,22.54,32.15,30.09,17.37,78.88,17.37,109,0,15.35-8.86,22.85-20.53,22.54-32.14C945.7,502.68,938.2,513.78,923.46,522.29Z"/><g class="cls-18"><g id="icons"><g id="Layer_3-2" data-name="Layer 3"><path class="cls-19" d="M458.53,723.94c-16.84-3.11-28.22-11.29-28.22-18.49s.42-27.75.42-27.75l-20.59-.38h-.21l-20.6.38a259.53,259.53,0,0,1,4.21,28.3c0,7.2-7.45,16-23.54,17.94-16,3.29-21.06,18.92-21.53,28.69l61.84-3.37h67.47C477.15,739.49,471.34,730.6,458.53,723.94Z"/><path class="cls-20" d="M410.56,716.53a30.3,30.3,0,0,0,19.88-9.69,8.07,8.07,0,0,1,0-1.39c0-7.16.42-27.75.42-27.75l-20.6-.38h-.21l-20.59.38a259.53,259.53,0,0,1,4.21,28.3,10.52,10.52,0,0,1-.42,3A29.46,29.46,0,0,0,410.56,716.53Z"/><path class="cls-19" d="M448.05,665.35a12.84,12.84,0,0,0-4.22-10.48c.43-7.5.51-17.23-4.21-21.06-5-16-21.65-16.22-35.34-16.22s-23.12,6.07-28.43,21.06a39.13,39.13,0,0,0,.47,15.8,12.62,12.62,0,0,0-4.22,10.61c0,6.23,2.91,11.29,6.45,11.29h0c5.05,24,22.2,34.33,32.05,34.33s26.71-10.16,31.55-34.42C445.43,676,448.05,671.25,448.05,665.35Z"/><path class="cls-21" d="M404.28,617.59c-13.26,0-23.08,6.07-28.43,21.06a39.13,39.13,0,0,0,.47,15.8c1.93,1,1.89,4.21,2.56,9,.76,1.48,3.12.59,3.12.59a66.76,66.76,0,0,1,1.14-9.77c-1.85-6.49-1.31-8.43,3.37-10.32a82.65,82.65,0,0,0,45.28-2.11,8.44,8.44,0,0,1,3.54,9.9,48.79,48.79,0,0,0,.88,15.8c.29,1.3,1.64,1,2.36.59a23.16,23.16,0,0,1,5.35-13.69c.42-7.5.46-17.15-4.21-21.06C434.61,617.84,418,617.59,404.28,617.59Z"/><path class="cls-22" d="M434.06,763.2c20.85-1,37.32-3.45,44-6.57-1.44-9.18-4.72-25.27-10.49-29.23a305.36,305.36,0,0,0-29.95-11.33l-5.05,10.32-13.82,6.1L413,734.77l-9-1.27s-13.14-17.22-15.25-17.6c-5,4.93-28.18,11.2-28.18,11.2-5.68,4.21-11.33,13-12.63,29.49,6.7,3.07,23.12,5.51,43.93,6.52Z"/><path class="cls-23" d="M435.33,715.52a37.19,37.19,0,0,1-20.39,21.06,32.75,32.75,0,0,1,14.36,16.47s9-23.21,9-34.37A8.42,8.42,0,0,0,435.33,715.52Z"/><path class="cls-23" d="M391.35,715.52a37.17,37.17,0,0,0,20.43,21.06,32.7,32.7,0,0,0-14.4,16.47s-9.06-23.21-8.81-34.37A8.47,8.47,0,0,1,391.35,715.52Z"/><path class="cls-24" d="M420.79,763.62l-3.58-22.7-9,.46-3.58,22.24h16.21Z"/><path class="cls-23" d="M407.86,742.48a3.8,3.8,0,0,0,1.94.59h5.06a4.26,4.26,0,0,0,2.48-.93l-.13-1.22-9,.46Z"/><rect class="cls-25" x="405.72" y="733.76" width="13.18" height="8.38" rx="4.04"/><path class="cls-26" d="M391.1,712.7a37.16,37.16,0,0,0,20.39,21.06,32.72,32.72,0,0,0-14.37,16.47s-9.05-23.13-8.8-34.58A8.36,8.36,0,0,1,391.1,712.7Z"/><path class="cls-27" d="M435.58,712.7a37.17,37.17,0,0,1-20.43,21.06,32.71,32.71,0,0,1,14.41,16.47s9-23.13,8.71-34.58A8.37,8.37,0,0,0,435.58,712.7Z"/><path class="cls-28" d="M481.19,753.55a.53.53,0,0,0,0-.25c-3.24-9.35-8.42-22.36-13.64-25.9A162.63,162.63,0,0,0,443,717.88v44.77C465.57,761,481.19,757.55,481.19,753.55Z"/><path class="cls-29" d="M382.34,762.61v-43a140.53,140.53,0,0,0-24.52,7.75c-5.26,3.66-10.19,17.39-13,26.74C346.24,757.85,361.11,761.05,382.34,762.61Z"/></g></g></g><g class="cls-30"><g id="icons-2" data-name="icons"><g id="Layer_3-3" data-name="Layer 3"><path class="cls-21" d="M815.83,107.61c-7.41-20.17-17.52-26.95-35.89-25.94s-33.69,9.6-40.22,34.33c-6.62,25.86,5.52,52.52-12.34,79.81-2.78,4.21,101.08,0,101.08,0C816.46,169.23,832.72,153,815.83,107.61Z"/><path class="cls-19" d="M828.09,190.08c-16.85-3.11-28.27-11.28-28.27-18.49s.47-27.75.47-27.75l-20.64-.38h0l-20.6.38a257.47,257.47,0,0,1,4.21,28.3c0,7.2-7.45,16-23.58,17.94-16,3.29-20.85,18.92-21.49,28.69L780,215.4h67.35C846.66,205.63,840.85,196.74,828.09,190.08Z"/><path class="cls-20" d="M780.11,182.67A30.21,30.21,0,0,0,800,173a8.07,8.07,0,0,1,0-1.39c0-7.16.46-27.75.46-27.75l-20.64-.38h0l-20.59.38a259.89,259.89,0,0,1,4.21,28.3,12.21,12.21,0,0,1-.42,3A29.47,29.47,0,0,0,780.11,182.67Z"/><path class="cls-31" d="M836.93,193.54a289.61,289.61,0,0,0-28.22-10.78h0s-7.92,24.05-26,24.05S758.21,182,758.21,182c-4.93,4.93-28.14,11.12-28.14,11.12-5.68,4.21-11.33,13-12.63,29.48,6.61,3.25,22.91,5.69,44,6.7h42.12c20.85-1,37.32-3.45,44-6.57C846,213.59,842.7,197.54,836.93,193.54Z"/><path class="cls-32" d="M850.66,219.69a.53.53,0,0,0,0-.25c-3.24-9.35-8.42-22.36-13.64-25.9A163.7,163.7,0,0,0,812.46,184v44.77C835,227.15,850.66,223.7,850.66,219.69Z"/><path class="cls-33" d="M751.85,228.75v-43a143.82,143.82,0,0,0-24.56,7.75c-5.26,3.66-10.19,17.39-13,26.74C715.71,224,730.58,227.19,751.85,228.75Z"/><path class="cls-19" d="M813.43,121v-.38c-1.18.63-3.08,2.61-3.58,9-1.81-9.27-6.57-22.2-8.89-23.42-6.57,12.26-35.09,31.51-52.61,37.91,5.35,23.08,22,33.15,31.72,33.15s26.7-10.15,31.59-34.41c3.28-.51,5.9-5.27,5.9-11.17A13,13,0,0,0,813.43,121Z"/></g></g></g><g class="cls-34"><g id="Icons-3" data-name="Icons"><path class="cls-35" d="M597.08,1032.68l-.14,5.22-23.24,6.71c-12.4,3.64-22.24,12.34-26.46,23.49l-6.14,16.24s68.38,28.18,142.69.11l-6.14-16.25c-4.22-11.14-14-19.84-26.46-23.49l-23.54-6.84.16-5.5"/><path class="cls-36" d="M628.09,1037.83c0,17.23-31.29,17.06-31.29-.15v-7.14h31.29Z"/><path class="cls-37" d="M628.09,1029.83c0,17.23-31.29,17.06-31.29-.15v-7.14h31.29Z"/><path class="cls-38" d="M621,973.29c11.31,22.18,7.19,14,12.6,23.41s1.79,27.38,1.79,27.38c15.33-10,14.28-31.66,14.28-31.66a48.11,48.11,0,0,0-11-30.12A34.86,34.86,0,0,0,622,950.77a34.11,34.11,0,0,0-19.53-.55c-15.23,3.86-28.36,18-28.36,42.14h0s-1.32,21.76,15.24,31.72c0,0-8.24-15.37-2.42-24.72s22-3.92,34.18-26.05"/><path class="cls-38" d="M626.31,940.56a13.59,13.59,0,0,1-4.35,10,34.11,34.11,0,0,0-19.53-.56,13.51,13.51,0,0,1-3.81-9.48,13.85,13.85,0,1,1,27.69,0Z"/><path class="cls-36" d="M621,972.19a38.91,38.91,0,0,1-21.86,18c-15.5,5-17.49,5.29-17,15.81s11.3,29.65,27.57,31,26.81-9.07,30.52-23.87.6-17.45-4.77-21.49S622.38,976.58,621,972.19Z"/></g></g><g class="cls-39"><g id="icons-4" data-name="icons"><g id="Icons-5" data-name="Icons"><path class="cls-40" d="M1145.55,259l-6.6-67.86c-1.81-18.6-16.53-32.65-35.26-32.83h-.89c-18.78.17-34.65,14.3-36.39,33l-6.36,66.89"/><path class="cls-41" d="M1088.33,240.3l-.39,4.84-21.43,6.26c-11.56,3.39-20.75,11.49-24.68,21.86l-5.74,15.13s63.8,26.23,133.14.1l-5.74-15.13c-3.93-10.38-13.07-18.47-24.68-21.87l-21.43-6.25L1117,240"/><path class="cls-42" d="M1117.75,244.92c0,15.11-29.9,15-29.9-.13v-6.27h29.9Z"/><path class="cls-43" d="M1128.74,222.33c3.56.67,4.46-4.06,5.5-8.57a23.25,23.25,0,0,0,.88-6.1,3.21,3.21,0,0,0-4.31-2.61l-2.89,1v-8.11h-50.66V206c0-.25-3-1.28-3.32-1.38a3.24,3.24,0,0,0-3.45.43c-2,2-.66,6.29-.11,8.67,1,4.51,1.94,9.24,5.5,8.57,3.5,12.56,13.95,22.47,26.33,22.47,12.6,0,23.23-9.46,26.53-22.38"/></g></g></g><g class="cls-44"><g id="icons-6" data-name="icons"><g id="Layer_3-4" data-name="Layer 3"><path class="cls-19" d="M1271.77,900.44c-16.85-3.12-28.26-11.29-28.26-18.49s.42-27.76.42-27.76l-20.6-.42h-.21l-20.6.42a257.32,257.32,0,0,1,4.22,28.31c0,7.16-7.5,16-23.59,17.94-15.92,3.24-21,19-21.65,28.69l61.83-3.37H1291C1290.34,916,1284.53,907.05,1271.77,900.44Z"/><path class="cls-20" d="M1223.75,893a30.46,30.46,0,0,0,19.88-9.69,8.07,8.07,0,0,1,0-1.39c0-7.16.42-27.76.42-27.76l-20.59-.42h-.21l-20.6.42a254.92,254.92,0,0,1,4.21,28.31,11.35,11.35,0,0,1-.42,2.9A29.25,29.25,0,0,0,1223.75,893Z"/><path class="cls-19" d="M1261.24,841.85a13,13,0,0,0-4.21-10.49c.38-7.49.46-17.22-4.22-21.06-5.09-16-21.73-16.09-35.42-16.09s-23.08,6.07-28.43,21.06a39.32,39.32,0,0,0,.46,15.84,12.68,12.68,0,0,0-4.21,10.62c0,6.23,2.91,11.24,6.49,11.24h0c5,24,22.2,34.33,32,34.33s26.71-10.15,31.55-34.41C1258.63,852.51,1261.24,847.83,1261.24,841.85Z"/><path class="cls-45" d="M1294.39,930.05a.71.71,0,0,0,0-.29c-3-8.43-7.63-20-12.3-24.64a6.78,6.78,0,0,0-1.35-1.22c-7.71-3.71-26.49-10.2-27.29-10.49-5.94,25.27-47.3,25.56-54.42,1.05-1,.55-20.22,5.73-27.93,9.44-5.26,3.66-10.19,17.39-13,26.74a5.63,5.63,0,0,0,3.07,2.44h0c10.28,4.68,23.38,5.19,34.46,6h0l9.47.59h42.16l8.93-.55h0a141,141,0,0,0,32-4.85h0c1-.33,2-.71,2.91-1.13h0C1293.25,932.07,1294.39,931.1,1294.39,930.05Z"/><path class="cls-21" d="M1217.48,794.21c-13.27,0-23.09,6.07-28.44,21.06a39.32,39.32,0,0,0,.47,15.84c1.94,1,1.89,4.21,2.57,9,.76,1.51,3.11.63,3.11.63a69.61,69.61,0,0,1,1.14-9.77c-1.85-6.49-1.3-8.22,3.37-10.28a82.93,82.93,0,0,0,45.28-2.15,8.43,8.43,0,0,1,3.54,9.9,48.71,48.71,0,0,0,.88,15.79c.3,1.35,1.65,1.06,2.36.59a23.26,23.26,0,0,1,5.35-13.64c.42-7.5.46-17.19-4.21-21.06C1247.8,794.34,1231.16,794.21,1217.48,794.21Z"/></g></g><g id="Icons-7" data-name="Icons"><path class="cls-46" d="M1210.4,877l-.48,5.53-21.31,5.71c-11.56,3.1-20.67,10.51-24.59,20l-5.71,13.83s65,42.71,132.55.11l-5.71-13.83c-3.92-9.5-13-16.91-24.59-20l-21.31-5.71-.43-5.35"/><path class="cls-40" d="M1210,881.84a1.77,1.77,0,0,1-.51,0,6.5,6.5,0,0,1-2-.35,5.47,5.47,0,0,1-3.52-4.38c-.42-.22-.9-.43-1.33-.65a5,5,0,0,1-2.4.69,5.65,5.65,0,0,1-3.13-1,5.45,5.45,0,0,1-2.45-5.07,12.21,12.21,0,0,1-1.07-1,3.7,3.7,0,0,1-1.37.26,5.62,5.62,0,0,1-5.24-7.33c-.25-.39-.55-.73-.81-1.12-.09,0-.17.08-.26.08a5.48,5.48,0,0,1-4.68-2.86,5.59,5.59,0,0,1-.64-3.94,4.92,4.92,0,0,1,.73-1.74c-.17-.43-.39-.87-.56-1.3a5.39,5.39,0,0,1-4.12-3.82,5.31,5.31,0,0,1,1.42-5.37c-.13-.52-.17-1-.26-1.56a4.83,4.83,0,0,1-2.27-1.78,6.09,6.09,0,0,1-.3-5.81,4.94,4.94,0,0,1,2.06-2c0-.52,0-1,0-1.52a5.34,5.34,0,0,1-2-5.24,5.39,5.39,0,0,1,3.69-4.25c.13-.48.26-.91.39-1.35a5.51,5.51,0,0,1-.77-5.63,5.4,5.4,0,0,1,4.63-3.3c.22-.43.47-.78.69-1.17a5.47,5.47,0,0,1,.51-5.72,5.31,5.31,0,0,1,5.28-2.13c.3-.35.6-.69.9-1a5.42,5.42,0,0,1,1.8-5.42,5.84,5.84,0,0,1,3.74-1.34,4.73,4.73,0,0,1,1.88.43l1.08-.65a4.94,4.94,0,0,1,.81-2.9,5.77,5.77,0,0,1,5.11-2.6,4.56,4.56,0,0,1,2.79,1.08c.42-.17.85-.3,1.28-.48a5.07,5.07,0,0,1,1.33-2.6,5.66,5.66,0,0,1,5.58-1.34,4.84,4.84,0,0,1,2.4,1.73c.48,0,.9-.17,1.38-.22a5.53,5.53,0,0,1,9.65,0c.47.05.9.18,1.37.22a5.1,5.1,0,0,1,2.41-1.73,5.71,5.71,0,0,1,5.57,1.34,5,5,0,0,1,1.33,2.6c.48.18.9.35,1.33.48a5.29,5.29,0,0,1,5.67-.48,5.79,5.79,0,0,1,2.7,2.95,5.1,5.1,0,0,1,.26,1.91c.38.26.77.48,1.11.69a5,5,0,0,1,1.89-.43,5.34,5.34,0,0,1,3.73,1.34,5.41,5.41,0,0,1,1.81,5.42c.3.31.6.65.9,1a5,5,0,0,1,3,.3,5.94,5.94,0,0,1,3.43,4.64,5,5,0,0,1-.56,2.95c.22.39.43.78.69,1.17a5.41,5.41,0,0,1,4.59,3.3,5.51,5.51,0,0,1-.77,5.63c.13.44.25.87.38,1.35a5.1,5.1,0,0,1,1.72.82,5.42,5.42,0,0,1,2,3.47,5.28,5.28,0,0,1-2,5.2c0,.52,0,1,0,1.52a4.94,4.94,0,0,1,2.06,2,5.88,5.88,0,0,1-.3,5.81,4.81,4.81,0,0,1-2.28,1.78c-.08.52-.12,1-.25,1.56a5.28,5.28,0,0,1,1.41,5.37,5.38,5.38,0,0,1-4.12,3.82c-.17.43-.38.91-.55,1.34a5.54,5.54,0,0,1,.08,5.64,5.48,5.48,0,0,1-3,2.56,4.72,4.72,0,0,1-1.63.26c-.09,0-.18,0-.26,0-.26.39-.56.73-.82,1.12a5.52,5.52,0,0,1-1.2,5.55,5.6,5.6,0,0,1-4,1.78,3.85,3.85,0,0,1-1.37-.26,12.34,12.34,0,0,1-1.08,1,5.39,5.39,0,0,1-2.44,5.07,5.66,5.66,0,0,1-3.14,1,5,5,0,0,1-2.4-.69l-1.33.65a6.3,6.3,0,0,1-.47,1.78,5.86,5.86,0,0,1-3,2.6,6.25,6.25,0,0,1-2,.35,2.12,2.12,0,0,1-.56,0"/><path class="cls-19" d="M1239.25,882.68c0,16.73-29.28,16.57-29.28-.14V875.6h29.28Z"/><path class="cls-19" d="M1247.69,861.79c3.4.6,7.11-2.33,8.1-6.45s-.87-9.36-4.27-10l-5.89,8.91-.48-14h0a6.15,6.15,0,0,0-6.78-7.09l-13.79,1.69-13.79-1.69a6.15,6.15,0,0,0-6.78,7.09h0l-.73,14.42-5.87-9.5c-3.16.61-5,6-4.05,10.14s4.23,7,7.4,6.36c3.1,11.49,12.38,20.55,23.37,20.55C1235.33,882.25,1244.77,873.6,1247.69,861.79Z"/><path class="cls-47" d="M1247.69,861.79c3.4.6,7.11-2.33,8.1-6.45s-.87-9.36-4.27-10l-5.89,8.91-.48-14h0c0-4.71-2.75-7.59-6.78-7.09l-13.79,1.69-13.79-1.69c-4-.5-6.61,2.32-6.78,7.09h0l-.73,14.42-5.87-9.5c-3.16.61-5,6-4.05,10.14s4.23,7,7.4,6.36c3.1,11.49,12.38,20.55,23.37,20.55C1235.33,882.25,1244.77,873.6,1247.69,861.79Z"/><path class="cls-47" d="M1210,881.84a1.77,1.77,0,0,1-.51,0,6.5,6.5,0,0,1-2-.35,5.47,5.47,0,0,1-3.52-4.38c-.42-.22-.9-.43-1.33-.65a5,5,0,0,1-2.4.69,5.65,5.65,0,0,1-3.13-1,5.45,5.45,0,0,1-2.45-5.07,12.21,12.21,0,0,1-1.07-1,3.7,3.7,0,0,1-1.37.26,5.62,5.62,0,0,1-5.24-7.33c-.25-.39-.55-.73-.81-1.12-.09,0-.17.08-.26.08a5.48,5.48,0,0,1-4.68-2.86,5.59,5.59,0,0,1-.64-3.94,4.92,4.92,0,0,1,.73-1.74c-.17-.43-.39-.87-.56-1.3a5.39,5.39,0,0,1-4.12-3.82,5.31,5.31,0,0,1,1.42-5.37c-.13-.52-.17-1-.26-1.56a4.83,4.83,0,0,1-2.27-1.78,6.09,6.09,0,0,1-.3-5.81,4.94,4.94,0,0,1,2.06-2c0-.52,0-1,0-1.52a5.34,5.34,0,0,1-2-5.24,5.39,5.39,0,0,1,3.69-4.25c.13-.48.26-.91.39-1.35a5.51,5.51,0,0,1-.77-5.63,5.4,5.4,0,0,1,4.63-3.3c.22-.43.47-.78.69-1.17a5.47,5.47,0,0,1,.51-5.72,5.31,5.31,0,0,1,5.28-2.13c.3-.35.6-.69.9-1a5.42,5.42,0,0,1,1.8-5.42,5.84,5.84,0,0,1,3.74-1.34,4.73,4.73,0,0,1,1.88.43l1.08-.65a4.94,4.94,0,0,1,.81-2.9,5.77,5.77,0,0,1,5.11-2.6,4.56,4.56,0,0,1,2.79,1.08c.42-.17.85-.3,1.28-.48a5.07,5.07,0,0,1,1.33-2.6,5.66,5.66,0,0,1,5.58-1.34,4.84,4.84,0,0,1,2.4,1.73c.48,0,.9-.17,1.38-.22a5.53,5.53,0,0,1,9.65,0c.47.05.9.18,1.37.22a5.1,5.1,0,0,1,2.41-1.73,5.71,5.71,0,0,1,5.57,1.34,5,5,0,0,1,1.33,2.6c.48.18.9.35,1.33.48a5.29,5.29,0,0,1,5.67-.48,5.79,5.79,0,0,1,2.7,2.95,5.1,5.1,0,0,1,.26,1.91c.38.26.77.48,1.11.69a5,5,0,0,1,1.89-.43,5.34,5.34,0,0,1,3.73,1.34,5.41,5.41,0,0,1,1.81,5.42c.3.31.6.65.9,1a5,5,0,0,1,3,.3,5.94,5.94,0,0,1,3.43,4.64,5,5,0,0,1-.56,2.95c.22.39.43.78.69,1.17a5.41,5.41,0,0,1,4.59,3.3,5.51,5.51,0,0,1-.77,5.63c.13.44.25.87.38,1.35a5.1,5.1,0,0,1,1.72.82,5.42,5.42,0,0,1,2,3.47,5.28,5.28,0,0,1-2,5.2c0,.52,0,1,0,1.52a4.94,4.94,0,0,1,2.06,2,5.88,5.88,0,0,1-.3,5.81,4.81,4.81,0,0,1-2.28,1.78c-.08.52-.12,1-.25,1.56a5.28,5.28,0,0,1,1.41,5.37,5.38,5.38,0,0,1-4.12,3.82c-.17.43-.38.91-.55,1.34a5.54,5.54,0,0,1,.08,5.64,5.48,5.48,0,0,1-3,2.56,4.72,4.72,0,0,1-1.63.26c-.09,0-.18,0-.26,0-.26.39-.56.73-.82,1.12a5.52,5.52,0,0,1-1.2,5.55,5.6,5.6,0,0,1-4,1.78,3.85,3.85,0,0,1-1.37-.26,12.34,12.34,0,0,1-1.08,1,5.39,5.39,0,0,1-2.44,5.07,5.66,5.66,0,0,1-3.14,1,5,5,0,0,1-2.4-.69l-1.33.65a6.3,6.3,0,0,1-.47,1.78,5.86,5.86,0,0,1-3,2.6,6.25,6.25,0,0,1-2,.35,2.12,2.12,0,0,1-.56,0"/></g></g><g class="cls-48"><g id="icons-8" data-name="icons"><g id="Layer_3-5" data-name="Layer 3"><path class="cls-19" d="M1000.75,1094.37c-16.85-3.12-28.26-11.29-28.26-18.49s.42-27.76.42-27.76l-20.6-.42h-.21l-20.6.42a255.09,255.09,0,0,1,4.21,28.3c0,7.17-7.49,16-23.58,17.95-15.92,3.24-21,19-21.65,28.68l61.83-3.37H1020C1019.32,1109.91,1013.51,1101,1000.75,1094.37Z"/><path class="cls-20" d="M952.73,1087a30.45,30.45,0,0,0,19.88-9.68,8.07,8.07,0,0,1,0-1.39c0-7.16.42-27.76.42-27.76l-20.59-.42h-.21l-20.6.42a255.09,255.09,0,0,1,4.21,28.3,11.43,11.43,0,0,1-.42,2.91A29.23,29.23,0,0,0,952.73,1087Z"/><path class="cls-19" d="M990.22,1035.78a13,13,0,0,0-4.21-10.49c.38-7.5.46-17.23-4.22-21.06-5.09-16-21.73-16.09-35.42-16.09s-23.08,6.07-28.43,21.06a39.32,39.32,0,0,0,.46,15.84,12.66,12.66,0,0,0-4.21,10.61c0,6.24,2.91,11.25,6.49,11.25h0c5.05,24,22.2,34.33,32.05,34.33s26.71-10.15,31.55-34.42C987.61,1046.44,990.22,1041.76,990.22,1035.78Z"/><path class="cls-49" d="M1023.37,1124a1.5,1.5,0,0,0,0-.3c-3-8.42-7.63-20-12.3-24.64a7.45,7.45,0,0,0-1.35-1.22c-7.71-3.7-26.49-10.19-27.29-10.49-5.94,25.28-47.3,25.57-54.42,1.06-1,.54-20.22,5.73-27.93,9.43-5.26,3.67-10.19,17.4-13,26.75a5.67,5.67,0,0,0,3.07,2.44h0c10.28,4.68,23.38,5.18,34.46,6h0l9.47.59h42.16l8.93-.55h0a141,141,0,0,0,32-4.84h0c1-.34,2-.72,2.91-1.14h0C1022.23,1126,1023.37,1125,1023.37,1124Z"/><path class="cls-21" d="M946.46,988.14c-13.27,0-23.09,6.07-28.44,21.06a39.32,39.32,0,0,0,.47,15.84c1.94,1,1.89,4.21,2.57,9,.76,1.52,3.11.63,3.11.63a69.79,69.79,0,0,1,1.14-9.77c-1.85-6.48-1.3-8.21,3.37-10.28a82.93,82.93,0,0,0,45.28-2.14,8.42,8.42,0,0,1,3.54,9.89,48.77,48.77,0,0,0,.88,15.8c.3,1.35,1.65,1,2.36.59a23.29,23.29,0,0,1,5.35-13.65c.42-7.49.46-17.18-4.21-21.06C976.78,988.27,960.14,988.14,946.46,988.14Z"/></g></g></g><g class="cls-50"><g id="Icons-9" data-name="Icons"><path class="cls-51" d="M499.83,373.69l-.54,6.3L475,387.16c-1.21.32-2.64.23-3.77.57-.13,0-.16-.42-.3-.37-11.4,4.05-20.45,12.2-24.5,21.91L439.88,425a185.35,185.35,0,0,0,24.45,6.63c6.4,1.35,14-2.59,22.34-1.58,6.29.76,12.95,6.6,20.13,6.91,5.6.24,11.44.31,17.48.15,7.84-.2,15.88-7.2,24.3-8.28,6-.77,12.23,4.63,18.43,3.31a215.7,215.7,0,0,0,25.43-7l-6.57-15.75c-4.14-9.93-13.67-18.07-25.43-22-1.06-.35-2.05.54-3.15.25l-24.75-6.8V374"/><path class="cls-36" d="M499.83,372.72l-.54,7.27L502,388.7l14.21-.51,11.55.51,5.42-8.17-.69-7.81S518.06,386.47,499.83,372.72Z"/><path class="cls-52" d="M550.87,350.27c-2.66,8.26-7.87,6-7.87,6-1.56,11.13-11.8,18.11-11.8,18.11a20.88,20.88,0,0,1-13.33,5.71,17.3,17.3,0,0,1-3.39-.08,28.75,28.75,0,0,1-13.16-5.16c-9.43-6.56-12.94-18.49-12.94-18.49-7.28-.6-8.21-7.83-8.21-7.83a10.78,10.78,0,0,1,4.9-12.1,88.63,88.63,0,0,1,1.61-15.58c.13-5.92,4.32-12.22,4.32-12.22,1.44-2.37,6,.59,11.3,1.56s17.05-1.69,26.57-3.26,13,2,14.43,5.55,0,5.12,3.22,10.83.59,13.67.59,13.67A12.52,12.52,0,0,1,550.87,350.27Z"/><path class="cls-51" d="M516.38,293.23H516c-3.46,0-29.32.47-32,22.85,0,0-1.91,12.57,1.23,20.86,0,0-.67-10,3-12s-1.53-15.91,8.72-14.75c4.19.48,7.94.88,11,1.2,4.72.49,15.32.1,15.32.1,3.26-.28,7.4-.76,12.11-1.3,10.24-1.16,5.05,12.81,8.71,14.75s3,12,3,12c3.15-8.29,1.24-20.86,1.24-20.86-2.65-22.38-28.51-22.89-32-22.85H516"/></g></g><g class="cls-53"><path class="cls-54" d="M1299.35,528.21c8.31,3.48,20.23,5.67,33.67,5.67s25.36-2.19,33.66-5.67Z"/><path class="cls-54" d="M1304.67,477.18h56.7l5.67,51h-68Z"/><path class="cls-55" d="M1310.34,539.55c-13,6.23-25.93,12.47-38.88,19.28-5.07,2.83-7,9.07-6.48,14.74.23,3.4-1,7.94,2.5,10.2,3.35,1.7,7.27.57,10.91,1.14H1396c4.36-.57,5.51-5.11,5.09-8.51.08-5.67.38-11.34-3.73-15.31-3.35-3.4-8.14-5.1-12.23-7.37-9.8-4.53-19.61-9.64-29.4-14.17Z"/><rect class="cls-20" x="1316.01" y="522.54" width="34.02" height="28.35"/><path class="cls-19" d="M1333,448.83c-16.8,0-30.72,15.31-33.49,35.15-.65,0-1.36-.57-2-.57-3,1.14-3.71,6.81-1.77,13,1.14,3.4,3,6.23,5,7.37,4.4,17.57,17.09,30.05,32.25,30.05s27.84-12.48,32.25-30.05c1.93-1.14,3.82-4,5-7.37,1.94-6.24,1.21-11.91-1.77-13-.59,0-1.3.57-2,.57C1363.74,464.14,1349.82,448.83,1333,448.83Z"/><path class="cls-56" d="M1310.34,539.55c0,11.9,10.15,51,22.68,51s22.68-39.13,22.68-51Z"/><path class="cls-57" d="M1333,448.83c-20.34,0-40.41,20.41-39.69,39.69-.3,12.47,5.66,26.08,5.88,38.55,5.94-7.37,5.73-16.44,5.49-25.51,1.2-6.24.06-15.31,5.64-18.71,13.46-6.81,21.65-19.85,26-34Z"/><path class="cls-19" d="M1310.34,539.55c0,7.94,10.15,34,22.68,34s22.68-26.08,22.68-34Z"/><path class="cls-58" d="M1333,448.83c20.33,0,40.41,20.41,39.69,39.69.29,12.47-5.67,26.08-5.89,38.55-5.94-7.37-5.73-16.44-5.49-25.51-1.2-6.24,0-15.31-5.63-18.71-13.46-6.81-21.66-19.85-26-34Z"/></g><path class="cls-4" d="M810.71,715.74c-12.6,47.86-35.19,123.79-.22,191.63,31.88,61.86,80.3,92.18,80.3,92.18"/><polyline class="cls-5" points="817.92 737.3 811.81 713.41 791.55 729.23"/></g></svg>
\ No newline at end of file
+<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 1712 1208"><defs><style>.cls-1,.cls-4,.cls-47,.cls-5,.cls-6{fill:none;}.cls-2{fill:none;}.cls-17,.cls-3{fill:#fff;}.cls-3{opacity:0.15;}.cls-4,.cls-5,.cls-6{stroke:#fff;stroke-width:2.67px;}.cls-4,.cls-47,.cls-5,.cls-6{stroke-linecap:round;stroke-linejoin:round;}.cls-4{stroke-dasharray:9.34;}.cls-6{stroke-dasharray:8.01;}.cls-7{fill:#354757;}.cls-8{fill:url(#linear-gradient);}.cls-9{fill:#c2cfda;}.cls-10{fill:#445c70;}.cls-11{fill:#bdbbdd;}.cls-12{fill:url(#linear-gradient-2);}.cls-13{fill:url(#linear-gradient-3);}.cls-14{opacity:0.51;}.cls-15{fill:url(#_ÂÁ_Ï_ÌÌ_È_ËÂÌÚ_24);}.cls-16{fill:url(#linear-gradient-4);}.cls-18{clip-path:url(#clip-path);}.cls-19{fill:#fcce85;}.cls-20{fill:#ebbb76;}.cls-21{fill:#99553b;}.cls-22{fill:url(#linear-gradient-5);}.cls-23{fill:#221f1f;opacity:0.2;isolation:isolate;}.cls-24{fill:url(#linear-gradient-6);}.cls-25{fill:url(#linear-gradient-7);}.cls-26{fill:url(#linear-gradient-8);}.cls-27{fill:url(#linear-gradient-9);}.cls-28{fill:url(#linear-gradient-10);}.cls-29{fill:url(#linear-gradient-11);}.cls-30{clip-path:url(#clip-path-2);}.cls-31{fill:url(#linear-gradient-12);}.cls-32{fill:url(#linear-gradient-13);}.cls-33{fill:url(#linear-gradient-14);}.cls-34{clip-path:url(#clip-path-3);}.cls-35{fill:#f43735;}.cls-36,.cls-52{fill:#b17553;}.cls-37{fill:#965d44;}.cls-38{fill:#2c2d2d;}.cls-39{clip-path:url(#clip-path-4);}.cls-40{fill:#464747;}.cls-41{fill:#efefef;}.cls-42{fill:#ddbea8;}.cls-43{fill:#f9d9c0;}.cls-44{clip-path:url(#clip-path-5);}.cls-45{fill:url(#linear-gradient-15);}.cls-46{fill:#1d97ff;}.cls-47{stroke:#303030;stroke-width:4.35px;}.cls-48{clip-path:url(#clip-path-6);}.cls-49{fill:url(#linear-gradient-16);}.cls-50{clip-path:url(#clip-path-7);}.cls-51{fill:#333;}.cls-52{stroke:#333;stroke-miterlimit:10;stroke-width:4px;}.cls-53{clip-path:url(#clip-path-8);}.cls-54{fill:#d05627;}.cls-55{fill:#e54c3c;}.cls-56{fill:#eceff0;}.cls-57{fill:#f19b1f;}.cls-58{fill:#e47d25;}</style><linearGradient id="linear-gradient" x1="791.92" y1="635.4" x2="946.02" y2="635.4" gradientUnits="userSpaceOnUse"><stop offset="0" stop-color="#6586a2"/><stop offset="0.19" stop-color="#6a8aa5"/><stop offset="0.41" stop-color="#7895ae"/><stop offset="0.65" stop-color="#90a8bc"/><stop offset="0.9" stop-color="#b1c1cf"/><stop offset="1" stop-color="#c1ced9"/></linearGradient><linearGradient id="linear-gradient-2" x1="791.92" y1="593.94" x2="946.02" y2="593.94" xlink:href="#linear-gradient"/><linearGradient id="linear-gradient-3" x1="791.92" y1="551.63" x2="946.02" y2="551.63" xlink:href="#linear-gradient"/><linearGradient id="_ÂÁ_Ï_ÌÌ_È_ËÂÌÚ_24" x1="791.92" y1="509.31" x2="946.02" y2="509.31" gradientUnits="userSpaceOnUse"><stop offset="0" stop-color="#5963ac"/><stop offset="0.18" stop-color="#5e67ae"/><stop offset="0.39" stop-color="#6c74b5"/><stop offset="0.62" stop-color="#8489c1"/><stop offset="0.85" stop-color="#a5a6d1"/><stop offset="1" stop-color="#bdbbdd"/></linearGradient><linearGradient id="linear-gradient-4" x1="791.92" y1="509.31" x2="946.02" y2="509.31" xlink:href="#linear-gradient"/><clipPath id="clip-path"><circle class="cls-1" cx="413.01" cy="679.81" r="82.31" transform="translate(-324.99 976.56) rotate(-80.63)"/></clipPath><linearGradient id="linear-gradient-5" x1="413" y1="517.1" x2="413" y2="461.21" gradientTransform="matrix(1, 0, 0, -1, 0, 1221.76)" gradientUnits="userSpaceOnUse"><stop offset="0" stop-color="#fff"/><stop offset="0.3" stop-color="#fafbfb"/><stop offset="1" stop-color="#f4f5f5"/></linearGradient><linearGradient id="linear-gradient-6" x1="404.37" y1="469.49" x2="420.79" y2="469.49" gradientTransform="matrix(1, 0, 0, -1, 0, 1221.76)" gradientUnits="userSpaceOnUse"><stop offset="0" stop-color="#c43535"/><stop offset="1" stop-color="#9c2b2b"/></linearGradient><linearGradient id="linear-gradient-7" x1="405.72" y1="483.81" x2="418.94" y2="483.81" xlink:href="#linear-gradient-6"/><linearGradient id="linear-gradient-8" x1="399.9" y1="507.92" x2="399.9" y2="467.82" xlink:href="#linear-gradient-5"/><linearGradient id="linear-gradient-9" x1="1537.27" y1="507.92" x2="1537.27" y2="467.82" gradientTransform="translate(1963.99 1221.76) rotate(180)" xlink:href="#linear-gradient-5"/><linearGradient id="linear-gradient-10" x1="462.1" y1="500.68" x2="462.1" y2="455.48" gradientTransform="matrix(1, 0, 0, -1, 0, 1221.76)" gradientUnits="userSpaceOnUse"><stop offset="0" stop-color="#73aede"/><stop offset="1" stop-color="#4890cc"/></linearGradient><linearGradient id="linear-gradient-11" x1="363.57" y1="498.99" x2="363.57" y2="455.61" xlink:href="#linear-gradient-10"/><clipPath id="clip-path-2"><circle class="cls-1" cx="782.48" cy="145.74" r="82.31" transform="translate(511.23 894.02) rotate(-80.63)"/></clipPath><linearGradient id="linear-gradient-12" x1="782.47" y1="1050.96" x2="782.47" y2="995.07" xlink:href="#linear-gradient-5"/><linearGradient id="linear-gradient-13" x1="831.57" y1="1034.53" x2="831.57" y2="989.34" gradientTransform="matrix(1, 0, 0, -1, 0, 1221.76)" gradientUnits="userSpaceOnUse"><stop offset="0" stop-color="#aacf40"/><stop offset="1" stop-color="#91b93e"/></linearGradient><linearGradient id="linear-gradient-14" x1="733.06" y1="1032.85" x2="733.06" y2="989.47" xlink:href="#linear-gradient-13"/><clipPath id="clip-path-3"><circle class="cls-1" cx="613.92" cy="1008.28" r="82.31" transform="translate(-480.9 1449.76) rotate(-80.63)"/></clipPath><clipPath id="clip-path-4"><circle class="cls-1" cx="1103.97" cy="216.49" r="82.31" transform="translate(710.54 1270.46) rotate(-80.63)"/></clipPath><clipPath id="clip-path-5"><circle class="cls-1" cx="1226.24" cy="856.13" r="82.31" transform="translate(181.8 1926.54) rotate(-80.63)"/></clipPath><linearGradient id="linear-gradient-15" x1="1226.24" y1="324.18" x2="1226.24" y2="278.94" xlink:href="#linear-gradient-10"/><clipPath id="clip-path-6"><circle class="cls-1" cx="955.22" cy="1050.06" r="82.31" transform="translate(-236.41 1821.48) rotate(-80.63)"/></clipPath><linearGradient id="linear-gradient-16" x1="887.07" y1="1110.46" x2="1023.38" y2="1110.46" gradientTransform="matrix(1, 0, 0, 1, 0, 0)" xlink:href="#linear-gradient-13"/><clipPath id="clip-path-7"><circle class="cls-1" cx="519.33" cy="351.24" r="82.31" transform="translate(88.19 806.41) rotate(-80.63)"/></clipPath><clipPath id="clip-path-8"><circle class="cls-1" cx="1333.02" cy="506.42" r="82.31" transform="translate(616.22 1739.15) rotate(-80.63)"/></clipPath></defs><title>login_graphic</title><g id="Layer_4" data-name="Layer 4"><rect class="cls-2" width="1712" height="1208"/><path class="cls-3" d="M781.08,405.92c-.34,1.57.63,2.29,2.22,2.08-1.38,2.89-4-.38-5.25-1.82.16-.28.3-.59.54-1,.39.3.77.62,1.17.94,0-.44.07-.86.11-1.3.74,0,.87.44,1.21,1.07ZM358.23,277.23h0c-.52.57-1.5.6-2.05,1.15-1.78-4.05-2.71-3.25-6.83-3.33l6.27-4.18c-.74-.27-1.3-1.09-2-1.37l3.1-1.92c-2.35-1.24-3.37-2.27-5.85-1.41-2.68.9-3.58,1.57-6.11.33s-3.72-.29-6.31-.17c-1.09.06-2.64,2.65-3.52,3.5,1.05.46,5.83,1.73,5.83,2.87,0,2.43.08,5.5-3.32,4.89-1.53-.28-3.39-3.94-5-3.4s-4.21,2.1-2.09,3.8c3.92,3.14,8.5,4.2,11.74,8.27,1.48,1.86,2.64,4.3,4.86,4.81,1.82.38,4.82-1.1,4.05-3.43,3.07,1.36,11.54-4.33,6-6.29a15.94,15.94,0,0,1,2.52-.93c-.44-1.06-.87-2.11-1.31-3.19Zm417,128.6h0c.15.66-.81,2.29.66,3.43,0-1.57-.23-2.7.76-4a5.79,5.79,0,0,0-1.92-.24c-.13.63.18.46.5.78ZM449.5,326.08h0c1.58,1.41,6.15,4.06,7.92,1.23s.37-4.32,1.47-7.23c-3.71-5.18-13.57,2.23-9.39,6Zm27.56-34.43h0c-1.29-4.27-6.72-3.62-9.7-2.56-1.78.64-6.12-6.21-7.9-7.92-2.07-2-7-4.19-9.72-3.81-1.42.2-4.56-.08-5.63.95-.75.72-3.21,3.83-4.06,3.33-3-1.83-2.79-2-5.34.58-1.43,1.42-3.46,1.44-2.12-1,1.54-2.88,1.91-3,.48-5.9-1-2.11-1.79-1.84-3-3.47s-.63-4.11-2.62-4.22c-1.45-.11-3.87-.77-5.25-.24-3.55,1.4-7,3-10.71,3.67.35-1.34.68-2.7,1-4.08-5.66-.66-8-.65-13.25,1.61-3.92,1.69-6.24,4.1-8,8.64-.64,1.65-2.85,5.27-2.59,7,.17.82.69,6.27,1.23,6.33,5.07.51,8.39,0,12,3.89-3.66-.33-7.33-.63-11-1,1.4,2.92,4.32,5,6.93,6.49,2.07,1.21,3.05-.41,4.74-.58,3.85-.36,1.07.69,3.15,2.61.87.8,4,1.34,5.23,1.39,3.55.16,8.27-.63,11.57.65,1.13.44,2.25.89,3.43,1.33.72.28,1.2-1.54,1.8-1.48,1.71.19,2.19,2.63,4.09,1.92-1.42-1.33-2.85-2.66-4.25-4,5.64,1.6,9.14,2.93,14.81,1.57-1.07-2.32-1.38-3.51-3.78-4.18,3-2.81,2.71,1.59,4.86,2.61.75.35,2.71-.87,2.91.23s.5,2.38.71,3.58c2.58-2.7,7.17,3.3,9.29,5-3.93,1.15-4.71.51-4.71,5,1.79-.7,3.58-1.36,5.39-2.05,2.37-.93,2.17-1.15,3.54,1.24,1.76,3.08,5.64,2.15,7.52,5.57,1.21,2.26,2.43,4.53,3.68,6.78.58,1.08-.71,1.65-1.49,2.41l-8.73,8.79c.89.68,4.61,2.52,3.94,4.33-.33.8-5.59,1.59-6.44,1.84-3.4,1-7.41-.37-10.89-.8.43,2.37-2.69,3-3.79,5-.82,1.47,1.66,4.47,3.24,4.39,2.37-.13,5.24.44,7.07-1.28s4.08-.26,6.23.25c-.07-.72.41-1.54.31-2.25,1.48-.21,2.39.62,2.38,2.25,3.76-2.46,3.69-.18,6.12,3.57,1.34,2.05,3.84,1.82,6,3-1.25.64-2.55,1.27-3.78,1.92,2.12,1.26,3.52,2.31,6,2.24-.26.44-.52.84-.79,1.24q3.6.9,7.18,1.84c1,.28.92,2.43,2.64,2.85,4.69,1.22,9.39,2.41,14.11,3.64.29-2.26,1-3.12-.75-4.33s-3.48-2.5-5.23-3.73c-1.09-.75-3.71-.53-4.4-1.72-.95-1.65-1.88-3.33-2.85-5,1.69.74,3.36,1.51,5.05,2.26-.39-.74-.42-1.69-.8-2.45q4.33,2.7,8.63,5.41c1.56,1,4.22,4.48,5.23,4.15q-.55-1.49-1.11-2.94c.5.32,1.21.25,1.74.52,1.09-2.57-2.54-3.25-1.12-5.74.8,1.05,1.58,2.09,2.38,3.13-.23-1.61,0-4.93-.8-6.26-1-1.63-2.92-.89-3.39-3.11-.53-2.66-.28-3.27-2.51-4.28-1.79-.81-3.25-2.16-3.85.82-.62-1.93-1.25-3.82-1.85-5.71-.75-2.26-1.2-1.3-3.18-.55-.44-1.32-.85-2.65-1.28-4l3.94.51c-.13-2.57-2.9-2.39-1.34-4.77,1.07-1.58,2.29-1.37,4-.4,1.49.82,2.93,3.77,4.56,4.16,1.17.25,3.71-1.33,4.87-1.75.83,2.87-1.95,3.13-3.77,4,3.13,3.72,4.9,5.33,9.13,7.3.85-2.61.12-5.5-.15-8.16,3.45,2.4,4.86.52,8.48-1.37-1.21-.58-2.4-1.18-3.62-1.75,1-1.34,3.51-.25,5,0,.39-3.38,1.61-5.39-1.56-6.77-1.94-.83-5.63.14-7.72.17l2-3.12c-3.11-.45-4.53-.32-6.72-2.72-1.88-2.08-2.67-2.88-5.15-3.79-5.13-1.95-10.19-3.88-15.19-6.15l4.25-.52c-.21-1.33-.43-2.65-.63-4l6,1.22c-1.17-3.26-.93-3.15-4-2.6-1.69.29-3.21-.62-4.8-1.23,2.8-1.75,3.69-2,6.91-1.81,0-2.54-2.65-3.74-4.33-4.86-.42,2.54-3,3.05-4.8,4,.67-2.63-1.31-2.2-3.06-2.49,2.22-.7,6-.73,6.82-3.49-2-1-11.85-7.48-13.06-4.72-1,2.21-4.33,4.49-5.37,1.65-.42-1.24,4.17-3.22,5.23-3.85ZM329.55,244.89h0a4.29,4.29,0,0,0-3.07,1.44h4c-4.24,2.93,1.7,3.13,3.74,2.69,3.12-.67,6.31-.94,9.49-1.32a2.36,2.36,0,0,1-2.6,1.55c.27.19.51.4.8.63a3.27,3.27,0,0,0-3.24,1.42,8.36,8.36,0,0,1,3.74.92,15.29,15.29,0,0,0-2.41.31c.26,2.1,1.91,1.93,3.57,2.47.91.3,1.36-1.23,2.24-1.15,2.53.16,5.92,1.31,8-.8-.81-.39-1.42-1.27-2.22-1.66a2.81,2.81,0,0,0,1.19-2.68c.43.45,1.16.63,1.62,1.08.39-1.82-.77-2.36-.89-3.86-.07-1.33.66-2.72.57-4-.06-.68-1.46-3.31-2.09-3.55-1-.38-3-1.73-4-1.14-2.89,1.75-5.14-.71-8.7.62-3.88,1.44,2.57,1.76,3,3.52-.71-.17-1.47.17-2.16,0,1,1.36,2,2.7,3,4.06-1.35-.76-11.2-10.18-10.75-3.68.94,0,1.89.05,2.83.1-2.14.86-1.69,3.11.6,2.41-.63,2.08-4.35.24-6.3.57Zm.2,62.71h0c.64-3.93,2.7-2.88,4.72-1.16.18-.58.77-1,.95-1.63,2.91,4.48,2.49-1.42,2.32-3.46-3.2.65-7-1.63-10.28-3.66-1.24-.74-5.94-2.53-6.54-4s1.08-3.61.3-5.55c-1.87-4.59-3.07-11.47-7.29-13.81-1.78-1-3.35-3.57-4.69-1.52-.61.94-3.85-1.41-4.79-1.88,1.12,1.8-1,2.33-.57,3.48s.88,2.48,1.32,3.71q1.46,4.16,2.95,8.29c-1.95.77-3,2.12-3.76-.17-.88-2.53-1.75-5.07-2.58-7.63-1.21-3.52-7.17-3.69-9.73-3.29l4.41,4.62c-1-.26-4.31-1.69-4.85-.76-1.36,2.34-1.52,2.15-4.08,2.15.67-.89,1.34-1.77,2-2.67-1.73-.83-6.64-4.38-8.37-3.92-1.17.29-1.55,3.15-2.87,3.24s-2.79.24-4.16.35c2.26-1.86,4.6-4.35,1.33-6.25-2.41-1.41-3.48-.42-6.14.59-5.63,2.1-9.31,3.78-14.1,7.62.74.14,1.38.89,2.12,1-1.88,1.74-4.93,3.33-4.42,6.49h4.72c-.34.51-.4,1.3-.74,1.83l10-.34c-3.45,1.56-6.91,3.08-10.37,4.62,2.07,2.07,2.67,3.26,5.37,3.22,3.51-.06,7-.1,10.52-.14,5.14-.06,9.42,1.12,14.48,2.42,3.51.9-2.19,1.91-3.41,1.9-2.68,0-5.49-.73-8.14-1.07-4.25-.56-9.69,1.81-13.88,2.69,2.46,8.44,10.55,7.06,17.3,7.41-.4,4.22.54,6.45,4.42,6.16,4.76-.39,9.5-.73,14.26-1.13,3.24-.22,4.42-2.51,7.66-3.06a7.59,7.59,0,0,0,4.41-1.83c1.36-1.1,1.42-2.86,3.35-2.22-.3.55-.21,1.4-.53,2l6.82,1.39c-.43.3-.79.75-1.26,1,3.82,0,7.42,2.14,11.25,1.75,1-.12,4.82-1.33,4.82-2.37,0-1.72-2.39-1.32-.83-3.54-2.58-.71-4.21.77-6,2.55.06-1.84.44-3.37-.95-4.75a9.15,9.15,0,0,1,1.89.25,9.09,9.09,0,0,0,1.69,1Zm14.6,4.73h0a7.29,7.29,0,0,0,1.92,1.68c.35-.88.69-.62,1.08-1.11a2.11,2.11,0,0,0,2,1.9c.14-.35.25-.72.39-1.09,1,2.84,5.42,3.14,7.79,3.57,2.53.46,4.94-2.08,7.08-3.48a71.31,71.31,0,0,0-8.85-7c-1.79-1.2-3.23-3.24-4.87-1.55-1.23,1.22-3.28,2.76-1.15,4.31-.38.1-.72.18-1.1.26-1.1,2.19-3.13.25-4.28,2.48Zm433,90.66h0l-.89.4c.17.3.34.62.49.94,1.16-1.05,1.65-1.71,3-2l-.68-.89c2-.22,1.73-2.93.82-2.5-1.43.72-5.53,2-2.73,4.08Zm-342.6-45.67h0c-3.13-2.31-3.73-2.5-7.45-2,3.32-3.31-5.31-7.59-6.94-8.72-1.27-.87-3.28-.46-4.32-1.59-1.6-1.76-2.13-2.46-3.85-.1a5.93,5.93,0,0,1-1-2c3.45-.6,2.35-5.31-.56-4s-2.86,3.91-3.77,7.27c-.37,1.38-.57,2.8-.84,4.19-.18,1,.83,2.57.46,3.44-.43,1-3.87,3.55-4.72,4.84.89-.09,6.48-1.54,6.92-1.25.67.42,1.09,6.13,2.36,5.26,1.82-1.31,3.31-4,4.95-4.56,2.72-1,2.41-3.22,5.17-4.29-.61,4.42,6.87,5.3,9.55,6.13,1.34-.9,2.66-1.79,4-2.67ZM379.53,256.56h0c1.08,2.4,4.19.21,5.63-.78,1.13,2.37,1,2.74,3.42,3,2,.2,3.77,1,4.22-1.9.34.62,1.06,1.08,1.38,1.72,0-1,.48-2,.51-3,2.56,1.05-.17,4.2,2.72,4.34s5.75.27,8.63.39a20.55,20.55,0,0,0-.12-2.08c1.55,2.08,5.46,2.91,6.3-.24.78,3.15,5.17,1.13,7.35.8-.23-1.19-.41-2.37-.63-3.55,3,0,1.36,3.25,3.52,4,1.93.67,3.28,1.36,5.22,1,1.17-.2,6.55-.29,6.88-1.54.8-2.71,1.68-2.47,4.2-3.29-1.13-1.19-2.61-1.28-4.1-1.61,1.17-.86,2.32-1.73,3.47-2.56-4.51-3.82-10.11-6.79-15.88-4.88-2.44.81-4.53-.45-7.16.48A54.35,54.35,0,0,1,407.5,249a17.93,17.93,0,0,0,1.56,1.26c-2.63-.58-6.37-2.27-9-1.95-.8.09-2.39,1.63-3.12,1.16-1.26-.81-2.53-1.64-3.83-2.44-.69-.45-6-3.44-6.06-3.58-.48-1.71,4.79.35,5.35-2.09-1.51-.42-3-.85-4.5-1.29-2.06-.58-1.09-1.65-2.63-2.65-2.68-1.71-5.51.67-8.31.11s-4.22-3-6.81-3.42c-2.86-.45-6.41-1.81-9.22-1-4.64,1.31-3.23,3.2-.23,6.18s4.65,2.38,8.3,1.86c3.13-.43,4.6-1.58,6.85,1.06,1.36,1.59,5.06,4.63,2.71,6.89-1.39,3.5-.59,4.09,1,7.49Zm81.26,64.92h0c-1.76,2,5.46,1.95,6.09,2-.78-3.47-4.2-4-6.09-2Zm-66.2-140.85h0l-6.76,5.71c3.81,2.74,7.83.53,12.32.36,4.09-.14,8.44-1.76,12.38-2.78-3.7,1.93-6.44,3.29-10.55,3.64-3.91.37-6.29.19-9.91,1.91,3.89,1.07,7.84,3.58,11.37,1.2,4.43-3,6.53-3.41,11.76-3.8-4.62,1.41-6.86,2.42-10.54,5.74a77.92,77.92,0,0,0,9.86,1c2.69,0,3,.6,3.31-2.35.13-1,3.09-1.38,4-1.64-.52.5-.89,1.24-1.42,1.74,2.1-.66,4.21-1.29,6.31-1.92l-4.73,4c2.6-.51,5.21-1,7.81-1.49,1.61-.32,5.58-.22,6.86-1.46,3.95-3.83,7.49-5.42,12.41-7.64-2.09,1.93-4.2,3.83-6.3,5.73l3.93,1.75c-8.38,2.2-16.69,4-25.17,5.53,2.82,2.6,5.66,5.2,8.48,7.81-3.59-2.18-8-6.24-12-7.27-.67-.18-12.14-.18-12-.5-3.49,6.72,3.28,6.26,7,8.81a29.44,29.44,0,0,1,8.36,10.07c-5.36-2.84-14-3.7-18.81,1.14-4.41,4.46-.37,4.72,3.81,5.63,2.92.65,5.18-3.07,7.32-5.1-1.56,4.72-5.71,7.46-.7,11.06,4,2.85,8.69-3,11-5.5-3.81,5.41-6.31,9.19-13,7.44-2.73-.72-3-4.47-5.35-4.8-3.3-.46-5-.66-8.09.5,2,3.64,2,4,5.88,4.38-2.68,2.76-4.28,1.95-7.52,3.33-1.11.49-3.78,1-4.55,2s1.29,1.9-.3,2.9c2.09,2.75,2.8.78,4.6-1.3.12,3.21,4.4,5.45,5.56,1.86.54,3.12,2.49,1.45,4.55,1.65a62.88,62.88,0,0,0,6.27.54c2.43,0,3.07-2.28,4.83-1.67,1.51.52,4.14,1.65,3.54-1.33,1,2.28,5.47,4.39,5.69.58,2,2.12,3-.56,4.35.51,1.94,1.53,1.12,2.34.52,4.81,2.77-.85,5.54-1.71,8.34-2.54.84-.3,1.24-1.84,2-2.14.28-.11,1.11,1.21,2.13.85.67-.24,3-.56,2.86-1.46s.07-3.26-.84-3.79c-1.52-.91-1.88-1.56-3.37-.67-1.75,1.06-1.78,1.64-3-.16-1-1.57,4.05-5.23,5-6.06,2.79-2.42-1.63-3.71-.27-4.84,1-.83,4.81,1.63,6.48,1,3.33-1.18,4.12-1.68,6.3-4.69-1.59-.88-3.15-1.75-4.74-2.59l8.34-1.06c.32-3.45-7-3.71-9.3-4.31h9.61c.77-3.85-8.44-2.76-10.84-3,5.82-.67,11.67-1.24,17.46-2.41-.32-1.05-.62-2.1-.95-3.11,2.08.54,4.82,2.07,6.8,1a19,19,0,0,0,6.42-5.05c-2.12-.09-4.19-.21-6.29-.34,3.35-.67,6.7-1.35,10.08-2.06,2.89-.59,6.43-3.94,9-5.51,3.47-2.15,14.82-5.08,15.08-9.26q-12.9,2.61-25.81,5.2,7.86-2.32,15.73-4.68l-9.14-1.55q10.13-.76,20.23-1.51c4.83-.35,10.87-5.44,15.25-7.75A107.4,107.4,0,0,0,506,166.36c-5.33-1-10.14.75-15.42,1.89,2.87-1.64,5.73-3.24,8.6-4.85-5.31-.76-11-2.33-16.37-2.33-5,0-10.66,1.68-15.73,2.33.69,1.38,1.4,2.77,2.1,4.16-2.44-1.66-5.68-5-8.56-5.12-4.22-.07-8.44-.12-12.64-.2,2.52,2.09,5.05,4.16,7.56,6.25l-8.88-3.65c-1.6-.65-6.55-2-8.11-1.44-1.21.43-1.48,2-2.88,2.13-1.93.11-3.85.25-5.81.35-2.16.15-4.53,3.25-6.22,4.7q7.46,4,14.91,8.06l-16.49-4.1c-2.39-.63-5.18-3.37-7.28-4.75-1.64-1.07-4.38-.54-6.23-.61.42,1.1.86,2.2,1.3,3.28-2.11,0-4.2.12-6.3.18l4.41,2.1c-5.56.35-13-2.81-15.9,3.64-3.82-3.32-8.58-.75-12.6,1.56,2.59,1.22,5.17,2.42,7.73,3.64l7.39-3ZM338,225.47h0c-1.63-2.1-3.69-1.76-5.88-1.33-2.53.51-.95,2.28.85,2.23,1.79-.27,3.19-1.43,5-.9Zm98.56,149.79h0c1.34-1.28,5.53-5.51,1.48-6.83-1.69-.54-3.37,1.49-3.53,2.94-.19,2.1.69,2.43,2.05,3.89ZM764.2,446.79h0c-.52.29-.87,1-1.4,1.31,4.28,3.62,10.12-3.11,14.24-4.24,1.4-.39,2.43.88,3-.85.47-1.56,1-3.14,1.45-4.71.61-2.05-.58-4.66-1.83-6.08,2.9-2,3.81-2.07,4.11-5.8-1.48.49-1.88-2.24-3-3.57-.71-.83-3.37.38-4.38.62.26-.4.49-.81.71-1.21-3.28-1.95-6.52,1.73-8.11,4.41,1.05.4,2.13.76,3.17,1.13-1.34,1.05-2,2.12-3.63,1.72-1.05-.29-2.56-1.15-3.57-.56-1.8,1-1.28,1.21-.67,3.31.29,1-1.35,2.07-2,2.73a14.3,14.3,0,0,0,5.42,1.66,31.67,31.67,0,0,0-4.42,4.67c1.85-.4,3.77-1.25,5.63-.6-1.26.27-3.85.24-4.63,1.36a4.51,4.51,0,0,1-3.1,2c.77.12,1.49.59,2.29.69a22.1,22.1,0,0,1-2.37,1.21c1,.28,2.1.53,3.13.78ZM417.28,368.43h0c.2.53.48,2.34,1.11,2.28,3.88-.35,8.33-2,8.94-6.92l-2.93-.1c-2.43.39-3.95.48-5.9,2.09-1.32,1.1-1.81.94-1.22,2.65ZM372.62,253.67h0c-.48-2.57-3.4-6.5-6.18-5.59-1.62.49-9.73,1.91-8.38,6,.57,1.62,6.88,3.87,8.42,4.71,3.61-.5,7.06.05,6.14-5.11Zm-53.9-40.2h0c2.42.28,3.18-3.35,5.36-1.17-.47.31-.78.89-1.28,1.17,1.25.23,2.46.48,3.68.69.4,4.12-5.26.92-7.76,2.55.78,7.08,8.76.17,10.16,1.86,1.59,1.89,4.54,1.48,6.78,1.77s2.41,1.55,3.58,3.7c1,1.84,10.84,1.63,6-3.89-.72-.78-2.41-1.93-2.08-3.09.46-1.57.64-1.48-.53-2.44-2.1-1.72-2.69-1.36-5.3-.92.87-5.19-5.6-2.57-7.35-1.61-1.34-3.09-2.93-5.5-6.52-5-4,.57-6.17-.3-7.64,4l4.09-.14a22.92,22.92,0,0,0-1.16,2.56Zm1.11,18.65h0c1.12,1.31,2.53-.73,1.33-2.15a16.91,16.91,0,0,0-2.65-2.6c-1.47-1.1-2.66-2.68-4.55-1.82.34,1.33.69,2.65,1,4,1.32,1.12,4,1.6,4.83,2.57Zm28.11-32.64h0c-1.12-2.79-8-2-5.91,1.85,3,1.17,8.29,4.16,5.91-1.85Zm9,21.79h0c-1.33.64-2.79.37-4.15,1,1.15.51,3.26,2.75,3.72,2.76a16.19,16.19,0,0,0,4.21-.92c1.47-.4,4.23-.44,5.1-1.91s-1.24-2,.67-3.92c-1.69-.61-4-.59-5.4-1.16-1.2-.47-2.57-2-4.1-2.65-2.16-.92-10-2.34-5.61,2.2l-1.48.23c1.05,4.21,4.71,2.11,7,4.39ZM286,222.82h0c-4.3.69-6.23-.13-5.34,5.05,1.94,0,3.6,2.76,5.23,2.31l7.84-2c1.84-.49.89-1.16,1.35-2.5.35-1.12-2.91-.19-3.57-1.42,2.2-.49,4.32-.54,5.87-2.54-3.24-1.42-8.14.55-11.38,1.08Zm7.9,18h0L299,244l-3.45,1.39c1.07.48,5.52,1.58,5.34,2.87-.4,2.71-3,1.42-5.26,1.3-1.15-.07-5.93.44-6.24-.93-.71-3-1.07-2.74-3.88-2.47.44-.24.91-.49,1.37-.77-1.84-1.46-4.14-4.49-6.47-4.09-4.28.75-2.72-.92-6.2-2.29-.67-.25-6,.21-6.07,1.51s4.32,1.81,5.37,2.1c-3.53-.27-6.07-.72-9.32.72l0,1.74c2.21,1.31,6.14.29,8.64.21-1.14.77-11.26.19-11,2.69s8.79-.26,9.88-.54c-3.27,2.73-10.05.74-12.11,4.67,2.82.89,4,1.23,6.88.53-.1.46-.22.92-.34,1.36a27.73,27.73,0,0,0,3.5.93c-.86-2.44,1.87-2,2.29.34,3-1.82,3.49-2.06,4.44-5.63,2.21.73,1.3,2.36.92,4.25,1.7-.13,5.65.65,5.88-1.76,1,2.48,5.17,1.23,7,0-3.44,3.65-10.5,4.27-15.35,5.94,5.86,3.78,8.27,2.55,14.54.28,3.5-1.24,7-2.53,10.49-3.79,2-.72,3.14,1.18,5.07,1,1-.07,1.1-1.8,2.69-1.8h5c2.18,0,3.15-2.62,3.67-4.94.67-2.9.38-5.62-3.45-5.1-4.62.65-.77,2-2.59,4.34-.69-2.41-1.49-2.78-3.52-3.4-1.3-.4-1.58-2.86-2.69-3.76-2.3-1.81-.51-7.22-5.17-5.3a21.8,21.8,0,0,1-4.92,5.25Zm63.63-42h0c.68,5.45,6.64,5.45,10.24,4-1.23,1.9-3,1.74-4.88,2-1.55.23-1,2.16.4,2s1.26,2.49,2.93,1.19c1.18-.92,1.92-1.84,3.42-1.27-.07.37-.14.8-.22,1.19,1.66.88,2.23-.51,3.63-1.19.4-.22,2,1.78,1.55-.88,2.66,1.08,7.13-.28,9,1.39l-6.61.85c3.25,1.34,6.56.62,10,.45-6.27,1.18-12,.7-17.95,3.12,1.67,1.26,3.72,1.59,5.68,2.16l-3.15.24c1.73,2.63,6.55,1.71,9.51,2.36-2,.23-4,.48-6,.7,2.63,4.18,8.53,3.42,12.52,3.63a2.94,2.94,0,0,0-2-2.16c2.65-.11,3.78,1,5.9,2.7-1-2-1.93-3.92-2.9-5.93,2,2,3.93,3.85,5.89,5.76.87-2.28,1.55-3.39.08-5.56,8.27,4.44-.74-3.48,4.8-5.11-.54,1.77.31,3.22.94,4.84,1.51-1.3,3.83-2.12,2.76-4.5,1.44,1.25,7.28-1.89,9.68-2.62a17.11,17.11,0,0,0-3.94-4.24c-.23.77-.93,1.4-1.1,2.17-.31-4.11-4.76-1.63-6.68-.87,2.15-4.13,3.22-6-1.9-6.58,3.18-2.73-1.29-6.19-4.17-3.73.63,1.1,1.27,2.19,1.89,3.29a4.31,4.31,0,0,1-4.17-2c-.55-.91.93-3.72-1.47-3-2.62.79-4.9-.39-6.69-2.45-2.86-3.23-4.43-5.86-8.38-6.88-2.37-.63-6.23-2-8,.61,2.19.79,4.61,0,6.52,1.12-2,3.54-9.13-1.56-11.31,4.08,1.76.59,4.41.26,5.8,1.47-1.69.36-9.79.67-7.29,3.31-1.25.44-2.55.91-3.78,1.37,2.17,1,3.45.55,5.57,1.07-.34.18-.69.38-1,.59,2.05,1,4.22-1.29,6.05,0-.71.15-1.29.86-2,1,.48.38.85,1,1.33,1.31a23.08,23.08,0,0,1-2.27-.61q-4.11-.24-8.19-.43Zm-36,43.7h0c1.63,1.91,9.21,2.52,8.5-1.46-2.06-.35-7-.22-8.5,1.46ZM260,243h0c-1.39.38-8.88,3.32-8.07,5.44.6,1.54,4.22.9,5-.14,1-1.37,3.57-3.4,3.07-5.3ZM780.24,409.43h0c-.2.12-.4.27-.61.38l.53.6c0-.33.4-.46.08-1ZM309.53,270.21h0c2.41.74,2.65,1.2,4.49,2.82,1.56,1.43,2.44,3.1,4.43,2.23,1.38-.63,2.69-3.12,2.66-4.65-.09-2.23-1.45-2.43-3.24-3.61-3.16.64-7-.53-8.34,3.21Zm16-17.13h0c-1.2-3.31-2.8-2.88-5.42-2-3.08,4.31,3.84,2.64,5.42,2Zm-5.15-15.21h0c.75,1.52,1.14,1.42,1.33,2.85,2.16.17,4.84.76,6.56-1l-3.1-2a5.59,5.59,0,0,0-4.79.17Zm51.62-9h0c.74-1,1.45-2.06,2.21-3.1-4.93-1.45-10.15-1.8-14.58.79,1,3.61,9.59,2.2,12.37,2.31Zm62.84,46.62h0c.63.84,2.35,1.42,3.22,1.93,1.59.95,6.65-1.25,8.48-1.67,2.28-.5,5.19.22,7.51.32-3.1-4.07-5.32-5.44-9.67-7.76-1.41-.75-3.45.37-5-.2l-5.41-2a3.15,3.15,0,0,0-.77,5.94c2.19,1.08.38,1.75,1.6,3.42Zm-51.22-47.87h0c-1.74,1.59,1.8,2.95,2.64,3.39,1.58.84,3.09-.12,4.74-.62-.22-3.61-5.25-4.73-7.38-2.77Zm3.17,8.12h0c-1.69,1.3,2.28,3.86,3.69,3.27-.35-.49-.44-1.36-.71-1.73,2.05-1.42-1.76-2.48-3-1.54ZM1499.88,258h0a38.06,38.06,0,0,0,14.49-1.67c.34-.1.71-3,.49-3.41-.28-.56-3.17-1-3.72-1.12-2.8-.88-3.91-.47-6.75.43.17-.62-.07-1.36.08-2-2.46-.11-4.93-.8-7,1.05-.18-4.95-5.89-1.84-5.25,1.16.31,1.57,6.29,4.57,7.66,5.54ZM1053.72,291.2h0c2.92,3.12,6.52,5.24,10.47,5.51,3.59.24,11.13,2.54,14.3-.11-5-3.46-9.14-6.42-9.31-13.48-.13-5.54,5.16-10.24,8.26-13.89,1.87-2.22,3.57-4.61,5.33-6.93,1.59-2,5.3-3.39,7.42-4.75,4.1-2.61,6.86-5.93,11.46-7.35,5.53-1.7,11.13-3.28,16.62-5.18,2.76-.93,13.82-2.9,14.27-7.85.53-6-10.83-3.4-12.88-1.75-4.54,3.71-9.66,4.47-15.15,6-5.06.06-8.37.4-13.12,2.29-3.62,1.49-9.51,2.56-12.49,5.22a121,121,0,0,0-9.89,9.33q-3.23,3.6-6.49,7.21c-1.67,1.87-.72,3.08-.15,5.65.21,1-4.49,3.63-5.3,4.22-3,2.14-.23,2.32-1.68,5.14-1,2.08-4.18,1.13-4.36,3.94-.26,3.9.15,4,2.69,6.74Zm10-95.43h0c-5.19-1.89-5.34-1.6-9.76,2,2.11.28,4.22.53,6.31.81,1.16-.92,2.3-1.86,3.45-2.78Zm19.63-12.26h0l-3.68-3.23c2.5-.62,5-1.24,7.48-1.85-4.14-.74-5.76-1.63-9.23.83-2.74,2-5.49,3.86-8.31,5.64,2.54.34,5.1.71,7.65,1.06,2-.82,4.07-1.62,6.09-2.45Zm-.11,117.26h0c.73,1.9,6.63,6.79,8.74,5s-5.13-5.87-6.1-6.63c-.88.57-1.76,1.08-2.64,1.63Zm6.61-101.17h0c-1-2.17-3.16-.76-4.83-.35a21.62,21.62,0,0,0,2.21,1.72c.88-.44,1.75-.92,2.62-1.37Zm-9-10.42h0c-3.19-1-6.08-2.23-9.41-2.12-4.62.19-6.25-.41-9.35,3.29,3,.79,6.08,1.62,9.11,2.42,3.86-.77,6.52-1.05,9.65-3.59ZM1034.85,192h0c-2.26,1.49-4.49,3-6.72,4.49a29.72,29.72,0,0,0,11,1.73c-.34-1.22-.68-2.45-1.05-3.68,4.41-1,8.82-2.1,13.22-3.12-2.4-1.63-4-3-6.92-2.26s-5.42,1.94-8.22,1.25c-5.94-1.45-9.91.35-15.82,2.17l6.1,1.6,8.4-2.18Zm2.4,122.36h0c1.51,1.49,6.1-2.55,7.25-3.39-2.06-1.93-3.21-2.31-5.88-3-3.47,1.41-4.46,3.33-1.37,6.39ZM910.59,302.06h0c4.58-.7,7.41-2,10.51-5.62-2.08,0-2.13,1.86-3.77,2.7-1.35.75-3.9.39-5.38.54.85,1.31,0,2.08-1.36,2.38ZM286.38,218.83h0c2.25,1.26,2-.51,3.8-.75,1.42-.16,9.75,3,8.71-1.33-.62-2.61-7.21-2.47-8.91-1.93-2.81.89-8,1.27-9.91,4,.36.27.73.5,1.11.75,1.5-.35,3.78-1.58,5.2-.75Zm796.83-25h0c-1.17.08-13.28.51-12.08,3.88s9.36.81,12.29.28c-.47-.41-.67-1.19-1.15-1.62,1.49-.23,2.94-.47,4.4-.68-1.13-.64-2.31-1.24-3.46-1.86Zm370.08,61.88h0c1.65,1.08,3.31,2.82,5.25,2.68,3.25-.28,3.12-.45,4.5-3.73,2.49,3.91,6.13.63,9.71-.75,1-.38,2.23,3.12,3.33,2.9,1.78-.38,3.54-.74,5.32-1.1-.62-1.05-1.25-2.09-1.87-3.12,2.27,1,3.06,1.79,5.16.48a13.22,13.22,0,0,0,4.29-3.51l-14.31-5.45c-1.25-.49-3.4-1.94-4.73-1.36-2.36,1.07-1.23,2.7-.82,5.32-3.35-1.46-10.19-7.91-13.5-5.22-3,2.46-4.68,3.24-5.71,7.19-.57,2.16,2.1,4.07,3.38,5.67Zm-673,164.54h0c1.2-.39,1.38-1.33.73-2.57a4.75,4.75,0,0,0-1.58,1.1c1.24.27.44.84.85,1.47ZM1471.75,271h0c3.09,2.6,5.22,1.95,9.13,1.83-.87-3.57-1.15-3.68-4.07-5.46-.7-.38-5.73-2.66-5.75-2.82-.3-2.48-2.23-4.86-5.08-2.95-3.31,2.21.68,4.45,2.12,5.54l-5.69,3.94c2.58-.26,7.25-1.87,9.34-.08Zm-358-81.34h0c2.86-.65,1.93-1.85,1.78-5-1.1.11-3.61-.28-4.52.35s-.9,2.85-1.78,3.34c-2.4,1.37-4.89-2.2-6.71,1.4a14.16,14.16,0,0,0,2,2c3.08-.7,6.17-1.4,9.24-2.08Zm-25.4,4.49h0c1.68,0,2.63-.49,3.72.9,1.89,2.37,6.63-1.06,8.33-2.94,2-2.21-2.4-5.45-4.59-4.9a45,45,0,0,0-9.76,3.61c.61,1.61.61,3.37,2.3,3.33Zm185.73,27.55h0c2.56,3.5,9-.91,12.11-2,1-.32,2.63,1.61,4.07,1.38,2.71-.49,5.43-1,8.16-1.44,2-.33,2.81-1,4.54-2.3,1-.84-1.15-4.05-2.37-4.16-2.66-.27-3.14-1.38-5-3.55-.78-.92-4.32,0-5.47.08l2.3-2.07c-3.74-1.38-6.41-1.27-9.17,1.7a55.1,55.1,0,0,0-6.77,9.85c-.8.85-1.63,1.69-2.41,2.55Zm-35.36-17.82h0c2.7-.17,8-1.91,9.82.51,2.36,3.06,3.78,7,7.53,6.67,4.52-.49,6.7-.59,10.93,1,3.85,1.46,5.59.64,9.58-.55-.38-1.26-1.79-4-1.33-5.22.62-1.66,2.31-3.84.62-4.78-3.61-2-5.65-.27-9.43,1.2,1.23-1.34,2.5-2.7,3.75-4-1.79-.4-6.09-.28-6.48-2.39-.84-4.56-.83-4.06,3.22-5.24-2.6-1.86-7.42-7.08-10.47-7.2-3.54-.13-1.24,2-3.31,2.61-2.38.74-4.71,1.48-7.08,2.18-2.7.84-2.38,1.69-3.17,4.75-.29,1.05-4.42,1.48-5.42,1.76s-2.16,4.39-2.64,5.47c-.26.61,3.25,2.8,3.88,3.25Zm412.06,91.49h0c1.24-.37,2.31.54,3.52.29,4-.8,7.21-.71,10.09-3.88-1.66-1.49-3-3.32-5.13-3.43l-8.54-.38c-2-.09-4.94,2-6.81,2.8-.5.21,1,5.37,1.17,6.22l5.7-1.62ZM885.48,310h0c-1.59.71-3.82.84-3.17,3.29.91-.71,1.82-1.44,2.7-2.17.17-.38.33-.75.47-1.12ZM873.3,320.42h0A2.18,2.18,0,0,0,876,319c-.76-.83-1.61-.68-2.51.18-.05.4-.08.87-.14,1.27Zm6.76-8.22h0c-1,1.12-2,2.25-3,3.38,1,.21,2,.4,3,.61,2-1.25,1.64-2.61,0-4Zm-85.28,83.55h0c1.12.32,1.32.12,2.34-.46-.78-.07-1.23-.42-2.08-.24.27-.18.51-.32.77-.47-1.61-1.26-1.9.46-2,1.09.24.34.47.68.7,1,.08-.28.14-.6.25-.91ZM917,298.7h0c1.06-1,2.17-1.55,2.27-3.06-1.52.84-1.24,1.76-3.13,1.22a7.53,7.53,0,0,0-3.86-.19c.61,2.93,2.63,2.14,4.72,2ZM781.8,418.61h0a16,16,0,0,0,1.17-2.14c-1-.26-1.93.54-1.17,2.14Zm98.8-101.55h0c-2,.06-3.93-.53-3.85,2.49,1.27-.81,2.57-1.64,3.85-2.49Zm-95.86,102.2h0a3.07,3.07,0,0,0,.84,2.09c.62-1.05.29-1.87-.84-2.09Zm-1.09-12.18h0c-.25.12-.5.26-.75.37.37.12.72.22,1.06.35a6.06,6.06,0,0,0-1.64,3.23c-.14.61-1.65,1.13-2.27,2,2,.41,2.05,1.24.09,1.66,1.21,1.19,4.39-.09,1.69-1.73,1.68,1,2.49-.53,3.75-1.71.18.22.32.45.47.67-1.88,1-2.21,3.19-2.7,5.24-.31,1.39.49,1.41-.21,3.17-.35.89-1.07,1.34-.33,2.05,1.54,1.37,1.2-1.85,1.36-2.92.22-1.62.14-3.38,2.08-4.11-2.24,1.84-.35,3.69,1.15.43a7.71,7.71,0,0,1,.56,1.7c-1.31.1-1.05.57-.77,1.88.43,1.79.72,1.13,0,3.3s-2.74,2.4-.3,4.29c0-.51,0-1-.08-1.56,1.15.43,3,1.91,2.3-.11,1.78,1.2,4-1.16,6.51-.79-4.32,1-2,7.74.62,5.72-1.19,1.66-1.06,5.16.4,6.15l-.51.16c-.71-1-.48-.39-1.31-.85.1.38.19.75.29,1.14-1.59-.3-3-1-4.37.17a1.82,1.82,0,0,0-2.57-1.19c1.82,1.49.92,2.89-.71,4,1.07-.21,2.13-.42,3.18-.61-.31,2.13.93,2.68-.51,4.69-.76,1.06-3.92,1.64-5.11,2.15.19.53.28,1.42.21,1.18,1.38,2.4,3.2-.73,5.27.44-.25.21-.52.41-.78.6.85,0,3,1.32,3.37,1.21,1.53-.54,3.07-1.05,4.6-1.59-.92,1.11-1.88,1.93-2.11,3.39-2.92-.4-6-1.7-7,2.08-.5,2-3.81,3.63-5.2,5.26,2.57,1.81,5.37-3.51,9-.86,2.05-5.1,2.83-1,6.53-2.75,1.09-.56,3.36-2.34,4.56-2.28,1.58.1,1.95,1.82,3.72,1.4,3-.77,5.09-.66,8.29-2,4.09-1.68-2.19-3-3.42-3.14,3.09-2.33,5.21-3.5,5.68-7.69s-6.8-1.4-7.51-2.2c2.82-2-1.4-5.63-3.53-5.63a2.46,2.46,0,0,1,3.29,1c-.89-5.5-5.5-6-6.89-10.46-1.76-5.76-4.19-6.24-9.4-7a3.22,3.22,0,0,1,3.39-1.39c-1.58-3.31,5.82-7.32,3.86-10.31-1.25-1.9-9.79-.92-10.74,1l-.46-.37c.63-.55,1-1.55,1.68-2a12.69,12.69,0,0,0-2.23-.67c.52.06,1.07,0,1.57,0,.42-2.06,4.31-2.56,4.85-5.67a10.4,10.4,0,0,0-6.66,1.23c-1-.51.1-.69-1.38,0-.4-2.13-2.19-.35-1.45,1.38-.47.1-.94.17-1.41.26-.21.55-.31.91-.42,1.2.6.57,1.09,1.39,1.73,1.89a3.34,3.34,0,0,0-3.29-.28c.44.75.49,1.8.94,2.55-.42-.09-.88-.19-1.29-.26-.21,1.15.37,1.06,1.25,1.38Zm5.63,21.44h0a3,3,0,0,0-1.8,2.52c.3,0,.59,0,.88,0a1.9,1.9,0,0,0,.92-2.55Zm98.77-113h0c1.78-1.91,3.55-3.82,5.36-5.74-1.25,1-2.5,2.09-3.72,3.13-1.58,0-2.16,1-1.64,2.61Zm9.33-11.25h0c-.89,1.21-1.82,1.62-3.06,2.86,1.08,0,2.14.11,3.21.16.84-1.46,2.16-2.19-.15-3Zm-6.27,3.28h0c-2.19.71-2.16.48-2.32,2.95-.25,3.69,4.7-1.27,5.8-2.15-.92-1.94-2-1.29-3.48-.8Zm10.71-4.29h0c-1.43-.89-3.28-1.06-3.87.89a10.18,10.18,0,0,0,1.59.71,2.32,2.32,0,0,0,2.28-1.6Zm-16,10.06h0c-1,.65-.37,2.2-2,3,.2-1.18.4-2.31.63-3.48-1.53,0-2.24,1.29-1.74,2.88-.42,0-.85.06-1.27.07-.21,1.57.06,1-1.08,2.25,1.9.34,2.58,1,3.82-.68.85-1.18,1.64-1.7,3.17-1.23.38-1.27.08-3.78-1.49-2.82ZM881.58,320h0c0,2.24-1.2,2.7-2.91,2.94.68.49.42.73,1.28,1.1a8.82,8.82,0,0,1-1,1.69c1.9-2,3-2.68,2.62-5.73Zm2.12-.73h0a6.75,6.75,0,0,0-1.68-.24,6.9,6.9,0,0,0,.26,2.41c1.48-1.49,3-3,4.42-4.55-1.45-.12-2.42.87-3,2.38ZM905.25,304h0c-2-1.28-5.49,1-6.91,2.84.95-.31,1.92-.63,2.87-.92,1.37-.63,2.7-1.3,4-1.92Zm1.85-2.65h0a5.38,5.38,0,0,0-2.15.1c.16.48.3,1,.47,1.39,1.24.93,1.86.24,1.68-1.49ZM1139,269.89h0c-3,.34-2.22,1.63-2.52,4.75,2.62-.45,5.25-.93,7.88-1.39a4.64,4.64,0,0,0-5.36-3.36Zm276.37,292.78h0c.17,1.23.33,2.42.48,3.67,3,.31.7-3.05,2.82-2.82,2.59.32,1.21,3.67.55,4.72-1.38,2.16-1.66,9.19,2.08,6.5,3-2.19,4.08-6.19,5.7-9.67.39-.87-1.25-3.14-1.61-3.77-1-1.77-2,.26-3.41-1.82,2.35-2.18,5,1.17,6.2-3.13,1.22,2,2.14,1.2,3.68.28.76-.47,3.4-1,3.72-1.45,1.58-2,5-.7,7.29-.51-3.47,3-1.35,5,1.26,7.33,1.39-2,2.67-5.49,5.41-5-1.61-1.4-2.12-3-.17-4.3,2.2,3.58,6.67,2,8.83-1.09l1.47,3a23.65,23.65,0,0,1,3.86-4.94c-.25,1.08-.47,2.2-.71,3.29,2.31-.8,2.71-2.75,4.66-3.83.25-.14-.41-4.8-.13-6.1.55-2.58,1.54-2.66,1.51-5.79-.05-2-.46-5.25,2.4-3.79,0-2-.56-3.47,1-4.52,1.78-1.14,1.17-3.27,1.23-5.43,0-1.52-1.65-3.67-2.31-5s0-2.79.34-4.31c-2.44-1.3-3.89.6-3.21,3.21-1.48-5.57-4.85,1.73-5.42,3.86-.45,1.71,1.63,2.49,1.34,3.37-.74,2.27-1.48,4.57-2.2,6.87-1,3-3,6.16-5.75,7.52-1.71.86-3.15,1.76-5,1.88-1.73.05.3-3.07.84-3.55-2.46.94-3.37.62-3.44,3.49-.06,1.49-2.35,3.49-3.22,4.59-1.08,1.39.51,2.65-1.37,3.49-2.69,1.18-1.52-1.06-3.21-.89-3.08.34-8.87-.42-10.8,2.4-2.19,3.22-5.06,5.32-8.56,5.21,1.41,3.84-3.8,5.44-6.14,7Zm-4.68,164.13h0c-1.35,1.24-3.55,2.73-4.53,4.35-1.48,2.51-.5,3-.1,5a18.6,18.6,0,0,1,.28,5.6c-.15,1.15,2.68,2.74,3.47,3.47-.34-2.31-1.28-7.36,2.62-5.78-.59-.49-4.5-3.11-2.53-3.62,2.21-.57,2.51-3.29,0-3.94a17.05,17.05,0,0,1,1.31-2.11,28.62,28.62,0,0,0-.5-3Zm104.51,138.09h0c-2.73-2.49,1-5.83-3.29-7.29-.47-.17-2.7,2.81-3.2,1.13-.61-2.07-1.23-4.08-1.86-6.1-1.11-3.72-1.07-5.8-4.14-7.57-1.22-.71-9.69-4.51-9.69-5.84,0-3.52.94-7.49-1.34-10.13-3.18-3.7-3-5.18-3.22-10.33-.19-3.26-4.18-5-6.37-3.16-1.15-7.4-3.24-13-6.09-19.88-3.49.84-3.76,7.22-4.64,10.36-.91,3.41-.16,7.5,0,11,.16,4.26-2.29,17.75-8.11,15.62-2.06-.74-3.85-4.39-6-5.7-3.9-2.31-7.79-4.61-11.67-6.94-3.59-2.13-2.06-3.39-1-7.79.82-3.54,2.78-5.34,5.06-8-3.66-3.57-4.57-3.77-9.42-4.24-3.74-.37-7.57-1-11.37-.86.13,1.77.27,3.53.43,5.32-4.22-.63-8-2.88-10.69,1s-3.3,7.43-4.43,12.16c-3.65-1.93-7.25-3.87-10.89-5.78-1.32-.7-5.82,4.37-6.85,5.25-5.9,5-13.83,9.38-16.78,17.09-1.48,4-1.5,7.17-5.3,8.08-5,1.17-10,2.35-15.06,3.49-3.44.82-5.31,2.29-8.33,4.47-3.74,2.72-4.45,3.73-6.26,8.35-.63-1.56-1.25-3.09-1.87-4.64-2.52,6.17-4.09,11.39-1.58,17.64,1.47,3.73,1.08,4.29-.2,8.2-.87,2.74.88,4.74,2,7.28a66.93,66.93,0,0,1,5.85,19.08c.37,2.6,2.56,9.32,1.65,11.62-.33.83-5.93,4-3.2,6.13,2.26,1.78,4.83,5,7.7,5s6.26,1,8.47-1.19c3.2-3.16,4-4.31,8.16-4.72,3-.3,5.9-.73,8.85-.83,2.25-.07,4.49-.12,6.73-.2.69,0,1.74-3.19,2.09-3.9,1.15-2.46,5.63-3.47,7.88-4.56,2.5-1.21,6,.69,8.24-.64,1.75-1,5.23-4.28,7.2-4,7,.93,13.24,1.66,19.88,4.18,4.2,1.61,4.49,2.39,6.86,6.65a65.3,65.3,0,0,0,4.93,7.86c3.74-4.26,6.88-7.92,9.66-12.95,1.71,5.29-1.71,9.46-4.39,13.88,4.41,1,4.2-1.54,6.28-5.78.25,2.68-.49,9.26,2.24,9.26,2.43,0,4.19,5.07,4.66,7.26,1.6,7.55,7,9.59,13.39,10.61,4.12.67,4.71,1.19,8-1.6,3.68-3.15,3.39-1.71,6.48,2,1.48,1.78,5.39.37,6.82-1.07,3.28-3.31,3.77-3.62,8.19-3.75,7.4-.25,6.74-10.35,7.9-16.7,1-5.5,7-9.54,8.36-15,1.58-6.44,4.93-14.24,5.13-20.9.21-6.34-2-13.63-2.93-19.9-2.94-2.69-5.9-5.37-8.86-8.08ZM1398.41,757.28h0c-1.46,4.17,5.42,2.34,6.3,2,.17-2.52-5.33-4.78-6.3-2Zm24.32,41.49h0c-2.33,1.58-5-1.71-5.29,2.73,2,0,4,1,5.58,0s2.13-3.34-.29-2.68Zm101.76-33.22h0c1.09-2.53,1.49-2.64.1-4.94-.23-.35-1.1.27-1.5-.31a7.72,7.72,0,0,0-1.18-1.87c-2.23-1.85-5-3.22-7.39-4.79-.89,2.91,10,4.34,8.86,9.68a14.48,14.48,0,0,0,1.11,2.23Zm-23.67,196.94h0c-1.44.56-5.74,3.3-7.11,2.67-2.53-1.12-5.07-2.25-7.57-3.38a25.76,25.76,0,0,0,1.45,12.27c2,4.6,4.19,5.62,8.34,6.39,5.06,1,10-16.31,4.89-18Zm7.51-193.42h0c-1.88.06-3.77-.48-5.58.17,1.21,3,7,4.48,9.71,3.82,2.08-.49,4.72-1.42,5.66-3.52.34-.71,4.44-.41,1.89-3,3.47-.76,1.88-3.54,0-4.82-2.55-1.66-2,3-1.94,4.26-.28-.05-8.58,6-6.51,1-.31-.7-1.46,2-3.19,2.08Zm-17.28-.52h0c-1.52-1.66-.53-4.28-2.65-5.59s-4.17-2.64-6.2-3.92c-3.07-1.93-7.21-2.77-10.52-4-5.37-2-10.72-4.09-16.07-6.13-2.59-1-6.8,1-8.55,3.32-.62.84-3.45,5.49-4.23,5.15-2.26-1.1-3.4-1.21-4.32-3.65a29.3,29.3,0,0,1-2-7.62c-.39-3.06-1.2-2.47-4-3.15-4.22-1-8.59-.08-10.92,4.43,1.49.27,3,.46,4.48.68.78.14,0,2.57,1,3.1,2.53,1.39,5.71.55,8.51.41a5.66,5.66,0,0,1-.21,2.2c-3.4-1.15-5.39-.48-8.92.35,1.47,2.53,2.93,5,4.41,7.52,1.28-1.6,2.57-3.15,3.89-4.76.66,3.76.62,3.62,3.76,4.95,3.7,1.57,7.36,3.15,11.06,4.7,1.52.64,5.37,1.38,6.09,3.1,1.27,3,2.49,5.94,3.73,8.9-4.34,1.23-4.75.76-5.34,5.64,3.32-.32,6.62-.65,9.93-1,1.72-.17,3,5,5.07,5.11,3.49.17,6.7,1.1,9.73-.86,1.7-1.08,2.45-6.37,4-6.13,1.89.25,7.49,0,8.84,1.38,2.63,2.79,5.27,5.57,7.93,8.37,2.11,2.19,4.86,2,7.7,2.46,2,.33,5,2.69,6.62,2.14-1.19-1.28-5-3.88-3.16-5.43-1.79-.42-4.36-.13-3.14-2.89-4.32-.15-4.11-1.25-6.17-5.41-.5-1-2.41-1.79-3.33-2.4s-1.24-2.83-1.62-3.87c1.4-.17,2.8-.31,4.2-.49.55-6-7.25-4.07-9.56-6.56ZM1474.17,453h0c0,3.3.35,6.33-1.07,9.24-1.8,3.77-.38,3.85.39,7.67.45,2.37.38,2.53-.87,4.55-.63,1,.29,2.69.3,3.87,0,3.71-.62,4.49.82,8.08.47-2,.46-5.15,2.83-5.53s3.58,2.58,3.47,4.62c2.29-2.39-.5-6.14-1.8-8.35-1.67-2.85-2.72-3.43-1.71-6.63,1.39-4.43,1-5.67,5.13-6.46,2.74-.51,2.46,4.16,5.1,4.21a44.45,44.45,0,0,1-4.25-11.79c-.54-2.07-1.06-4.14-1.59-6.23-.35-1.41-2-2.53-2.25-3.95-.75-4.55,2.81-6.78.5-11.31-1.23-2.38.24-9-4.05-5.69,1.64,1.63,2.66,4.24.9,5.89-.73.66-1-.78-2.32.31s-1,1.33-.48,3.2c.56,2.17-.76,5.84-1.13,8.07-.36,2.4,4.4,3.68,2.08,6.23Zm-84.64,238.25h0c2.16.44,3.59-2.91.79-3.21-.81.73-3.45,2.66-.79,3.21Zm-3.31.75h0a8.64,8.64,0,0,1,3-5.15c.89-.83.36-3.55.71-4.91l-.75.4c-.93,2.93-3.43,6.55-3,9.66Zm7.69-10.35h0a2.48,2.48,0,0,1-3.22-.82c.13,1.38,0,2.61.8,3.59,2-1.72.58,3.34,2.57,4.47-.11-.76,0-1.57-.15-2.29.31.64.66,1.28.93,2,1.21-1.82-1.1-4.45-.93-6.94Zm-6.93-4.28h0a6.44,6.44,0,0,0,2.53,2.73,10,10,0,0,0,.13-2.89c-1.89.14-1.45-2.1-4-1.92A3,3,0,0,1,1385,679a11.72,11.72,0,0,1,1.94-1.63Zm3.51-1.71h0c.06,1.84,1.48,2.43,2.75,3.5s-.13,1.36.76,2.54c3.16,4.19,2.79-1.43,2.3-4-.8-3.05-3.56-2.1-5.81-2Zm-11.21,4h0c.43,5.26-.26,9,5.2,6.41-1.39,1.83-4.56,4.92-1.58,6.28,1.17.54.76,2.15,2.18,1.89s.71-2.25.68-3.55c0-1.88,2.3-5.53,1.59-6.8-1.73-2.93-2.6-3.24-5.62-4.42a8.88,8.88,0,0,0-2.45.19Zm-12,67.55h0c-.64,2-.17,3.26-1.15,5.41-1.36,2.92-2.15,3.22-.37,5.84,1,1.44,3.49-.5,3,2.93-.21,1.41-1.8,6.88-1.14,7.94s4.36,1.58,5,.33c.33-.56-.71-2.38-.68-3.1s.93-1.67,1-2.53c.21-1.73-.2-4,0-6s-2.44-3.29,1.37-3.76c2.09-.23.45,3.72.72,4.64.73,2.24,3.35,1.85,2.72,4.15s.94,2.83,2.71,2.41c-.85.22,3.84-3.67,3.29-2.41,1.36-3.15-1.85-1.57-2.82-3.9-.25-.59,1.37-1.76,1-2.49-.57-1.11-1.17-2.19-1.75-3.3-1-1.81-1.9-1.7-3.14-3,4.25,1.59,5.8-7,9.58-4.52,1-3.74-2.23-1.48-3.6-1.44-1.79,0-1.86.8-3.24,1.18-1.65.43-.81-1.55-2.43.26-4.08,4.45-8.36-3.38-5.22-7.2,1.51-1.84,3.44.28,5.51.09,2.33-.17,5.4-1.17,7.54,0,5.23,3.07,8.19-2.74,9.8-7.31-2.19,0-4,3.44-5.86,4.71-1.07.68-2.9-.58-4.06-.64-1.43-.09-1.18.94-2.88.36-2.14-.74-6.07-3.06-8.17-1.69-2.76,1.79-3.38,3.34-4.93,6.43,1.93,2.86-1,4.12-1.82,6.6Zm5-76.32h0q2,3.45,4,6.93c2.72-3.23,2.32-4.91-.79-7l-3.23.09ZM1346,782.49h0c0,2.68,1.86,4.9,3.8,2.38s-2.11-3.07-3.8-2.38Zm120.24-281h0c-.19,1-.18,3.22-1,3.66-1.6.86-1.87.86-2.37,2.74-.14.5,1.61,6,2.11,6.16s1.51-2.18,2.52-1.91c.7.2,2.34.34,1.52-1-.93-1.67-4-.56-3.53-3.53,1.49-.51,3.08,1,3.88.62s2.89-1.71,3.68-.92c1.19,1.14,4.92,4.34,6.45,3.6a23.62,23.62,0,0,1,1.26-4,6.48,6.48,0,0,1,3.5-2c2.75.11,4.94-.36,6.87-2.68-5.14.16-1.27-4.18-2-6.36-3.55,3.7-3.69,2.7-8.15.44-3.15-1.61-4.69-4.48-6.88-7.47-2.76-3.74-1.59,4.59-1.22,5.83s-2,2.74-1.81,4.24.29,2.4-.51,3.73c-1.43-.39-2.87-.77-4.3-1.17ZM855.53,420.81h0c.17,1.19,2.15,3.87,3.35,3.58,1.79-.4,1.38-2.78-.09-3.11-.42-1.7-1.85-1.26-3.26-.47ZM971.41,548.54h0c-1.51.68-3.78,2.36-5.4,2.21-1-.09-4.56-.86-5.29.57-2.4,4.75,7.38,2,8.34,1.74-1.25-2.27,1-3.26,2.35-4.52Zm-38.73,3.83h0c.1-1.77-3.4-2.4-4.94-2.18-3.16.46-4-.14-6.84-1.82a7,7,0,0,0-1.1,2.42,36,36,0,0,0,12.88,1.58ZM861.83,419.89h0c-.41,1.31,0,3.66,1.59,3.56,2-.15,1.58,1.53,2,3.48.35-2.25.11-4.6,2.69-4.84-.55-.36-.88-1.15-1.44-1.51,6.42-1.32-4-7.13-1-1-1.36-.11-1.84-.75-1.15-2.09a4.2,4.2,0,0,0-1.58,0,2,2,0,0,1-1.13,2.43Zm57.29-21.15h0c-3.19-1-4.45-.74-7.66.22,1.1,1.2,1.94,2.37,1.17,4.27,1.38-2.44,4.28-3.07,6.49-4.49Zm-69.19,122h0c.13.68-1.12,2-1.28,2.77-.07.37,1.17,1,1.11,1.39-.34,2.18-2.19,2.37-.4,4.08,1.41,1.3,2.84,1.48,3-.74.1-1.28,2-.08,2.29-2.39s.6-4.77.88-7.16c.59-4.89-4.95-2-6.27-1.07-.48-.19-.95-.34-1.44-.53-.88,2.61,1.69,1.84,2.08,3.65Zm844.89-163h0c-1-.05-5.16-1-5.87-.3-1,1,0,3.15.74,3.76,2.59,2.06,6.13-1,7.79,1.14,2,2.48,5,3.46,6.37-.63-2.71-1.31-6-3.82-9-4ZM894.33,410.41h0a9.26,9.26,0,0,1,3.91-3.13c-1.53-1.73-.13-2.72.94-4.16-4.65-1.14-5.1,3.58-4.85,7.29Zm9.68-23.1h0c-.08-.52-.14-1.05-.24-1.56h.75c-.38-3.11-4.46-.82-.51,1.56Zm-54.32,122h0c-1.71,1.44,1.39,4.45,2.91,4.37a18.29,18.29,0,0,0,1.08-9.35c-1.35.28-.17,1.39-.95,2.43a17.65,17.65,0,0,1-3,2.55Zm685.8,261.84h0c-1.29-.65-1-2.61-3-3.22a4.61,4.61,0,0,0,1,3.73c.74.89.38,2.22.88,2.78,1.05,1.26,5.3,2.51,3.92-.64a8,8,0,0,0-2.8-2.65ZM1434.91,561.46h0c.63-.27,1.65,1.94,2.25,1.15s2.28-2.35,2.31-3.13c.3-5.69-7.3-.75-8.48-1.66-1.74,3.73-3.07,2.87-1.72,7.36,3,2,3.45-2.76,5.64-3.72Zm-27.56,195.4h0c-2.2,2.87,2.12,2.87,3.32,2.7.89-.11.52-2.07,1.35-1.74s2.21,1.16,3.19.9c2.81-.76,3.64.35,6.1,2,1.08-4.94-4.32-5.41-7.3-6.2-2.45.44-5,.21-6.66,2.3Zm211.81,209.76h0c.1-2-.68-3.52-1.46-5.31-2.2,1.21-3,1.22-3.61,3.82-.63,2.76-1.38,1.52-2.8,3.48-1,1.4-.82,3.84-1.76,5.31s-3,2.66-4.26,3.76c-1.39,1.18-2.67,2.62-4.28,3.34-1.18.54-3.94,1.17-4.78,2.26q-3.95,5.31-7.86,10.6c-2.72,3.62,5.2,2.65,6.28,3.9,1.58,1.82,7.28,3.77,8.89,1.08,1.8-2.94,5.08-6.58,6-10,1.24-4.75,2.94-5.47,6.71-8.26a2.43,2.43,0,0,0,2.12,2c-1.44-2.93-1.65-3.22.28-5.74s3.86-5,5.8-7.54c-.55-1.86-1.12-3.71-1.67-5.58-1.2,1-2.39,1.95-3.59,2.89Zm-24.71,33.25h0c-1.47.53-.52,2.42-1.71,3.93,1.56-1.48,5.87-.7,1.71-3.93Zm47.84-56.26h0c-3.75,2.41-4.45,2.12-8.74,1-2.6-.67-.87-5.56-3.57-6.86.28,2.73-1.5,4.9-3.2,1.52-.48-1,.4-2.54-.25-3.52a10.11,10.11,0,0,1-1.85-2.64c-1.14-3.6.89-3.14-3.06-4.66-2-.76-2.95-2.71-4.8-3.22,1,2.06,2,4.13,3,6.23l1.11-.88c1,2.24,3.3,10.37,5.75,9.55-.88,2.57.87,5.1,0,7.55-1.26,3.45-1.76,4.32-4.56,6.44a27.83,27.83,0,0,0,3.31,3c.74.45,3.17.56,3.58,1.32,1.35,2.54-1.82,5.92-3.11,7.36,2.43,1.53,5.12,2.79,6.91-.84,1.49-3,4.33-6.74,4.22-10.23-.08-2.14,2.49-2.34,3.71-1.74,1.46.7.3-1.27.78-1.77,1.64-1.6,4.55-7.12.84-7.6ZM821.11,525h0c.93.74,1.88,1.52,2.84,2.26.84-.7,1.69-1.38,2.51-2.08-1.73-3.23-2.83-1.63-5.35-.18Zm865.64-182.84h0c-.11,3.06.48,4-2.1,5.23-1.91.9-.27,3.76.2,5.71a12.25,12.25,0,0,1-7.52-3c-1.71-1.29-5.55,1-6.07-1.15-.77-3.09-.34-6-3.39-6.22l-9.95-.7c-2-.17,1.38-6.12-3-5.41-2.25.39-1.41,6-1.51,8.23-.17,3.5-11.24,4.5-14.24,5.32,2.58,1.83,5.58,2.65,5.78,6.18.25,4.11,1.84,5.75,4.14,9.06.24.32-1.62,2.79-2.07,3-.86.35-3.25-.65-4.14-.82-1.59-.32-5.3-1.93-6.78-1q-9.17,5.55-18.29,11.13c-4.77,2.89-9.9,4.46-12.17,10-4.23-4.2-4.48-4.72-10.06-4-5.29.69-5.59,1-8.83,5.73,0-1.69-.1-3.37-.16-5-1.62.8-4.66,3.15-6.42,2.92-2.26-.33-4.35-1.56-5.7.62-3.06,4.88-6.07,9.79-9.11,14.67,1.62.53,7.33,1.22,6.82,3.22-1.22,4.74-1.46,4.92,1.36,8.75-4.76,2.08-9,4.17-6.45,10.39.43,1-3.67,2.63-4.7,3-2.31.79-4.35.53-4.58,3.28-.24,3.24.64,5.95-2.39,6.75-3.81,1-4,.52-4.66,4.79s-5.88,8.42-8.39,11.53c-3.12-14.6-13.71-42.46,3.8-51,5-2.44,7.94-3.2,10.85-8.22,2.71-4.7,5.92-6.75,10.17-9.93,2.93-2.19,6.88-3.37,7.82-7.26.7-2.93,1.41-5.84,2.1-8.75.17-.68,4.18-1,4.94-1.2a18.58,18.58,0,0,0-7.43-.64c-2.17.26-3.34,3.68-4.53,5.57-2.42,3.87-7.49,6.65-10.88,9.46-1.64-4.36-1.21-6.06-.31-10.75-3.21,1.91-4.5,2.61-8.1,2.54s-4.59-.29-7.48,2.06c-4.61,3.72-8.31,8-12.29,12.57,1.21,1.07,4.24,2.52,3.31,4.17-.35.67-4.48,1-5.31,1.07-4.27.5-8.53,1-12.77,1.53,1.51-1.12,3-2.2,4.54-3.28-4-.83-8.09-1.62-12.14-2.41-1.11-.24-3.91,2.25-4.93,2.85-1.3.77-2.9,0-4.31-.19a50.94,50.94,0,0,0-10.83-.54c-2.33.11-9.08-1-10.9.75-6.28,5.86-12.47,11.68-18.46,17.92-5.57,5.76-11.79,9.94-18.23,14.57.88,2.2,2.33,2,4.18,2.16,2.37.23,2.6-.17,3.51,2.23.27.74,1.1,4.24,1.86,4.32,4.85.4,5.23,1.16,7.59-3.55,2-4,13.52,5.4,13,8.59-1.33,7.58-3,15.06-4.75,22.56-1.6,7.1-4.13,11-8,17.1-3.6,5.69-6.61,11.21-11.3,15.83-3.17,3.13-6.36,6.3-9.54,9.45-1.76,1.74-5.38,1.72-7.63,2.25-1.12.27-2.15-3-3.2-3.24-.83-.16-3.47,2-4.2,2.48-3.56,2.09-3.6,3.08-5,7.37-2.26,6.71-7.5,10.26-12.32,14.95,5.33,4.62,10,9.66,9,17.54-.72,5.3-.09,6.48-4.41,8.76-3.56,1.86-5.59,1.75-9.61,1.63.43-3,.83-6,1.24-9,.48-3.46-2.65-3.22,0-6.34,1.66-2,.78-4.68-1.61-4.45-2.23.24-5.8,1.74-6.54-1.74-.38-1.78,1.91-6.17,2.46-8,.07-.28-4.9-3.52-5.6-3.49-1.84.06-5.19,3.13-6.78,4.09l-6.78,4.07c-1.79-4.51,2.43-7.82,5-10.57-2.79-2.21-2.87-2.84-6-1.35a26.43,26.43,0,0,0-5.45,3.93c-2.3,2-3.72,3.15-6.45,4.07-.48.18-5.36,1.9-4,3.42a46.49,46.49,0,0,1,5.12,6.16c2.08,3.27,1.82,2.83,5.1,1.19,4.71-2.34,8.39-.33,13.38,1q-8.19,6.91-16.37,13.88c2.34,2,5.21,3.68,6.59,6.66,1.75,3.8,3.48,7.58,5.19,11.37-2.8-.53-5.63-1-8.47-1.57,3,2.21,6,4.39,9,6.6-2.17,1.55-4.39,3.1-6.61,4.7,2.73.78,5.48,1.6,8.2,2.41-3.38,6.27-6.28,14.21-10.61,19.69-4.65,5.88-8.19,12.41-14.85,15.2-7.18,3-14.32,6-21.6,8.63-2.24.8-4.49,1.63-6.72,2.44-1.85.66-1.42.68-1,2.87.29,1.41.32,4.34-2.19,3-.68-.34-1.42-3.67-1.74-4.51.82-.19,1.53-.84,2.35-1-2.52-2-7.06-3.44-9.86-1.19-2.39,1.92-8.14,4.77-9.13,7.91-.28,1-2.18,5.09-1.67,5.92,1.42,2.29,2.86,4.56,4.28,6.85a114.92,114.92,0,0,0,6.89,9.21c3,3.8,4.59,5.06,4.79,9.9.13,3,1.78,9.95-.42,12a237.73,237.73,0,0,1-19.11,16.19c-2.2-2.29.88-5.69-.72-7.38-2.13-2.34-4.29-4.64-6.43-7-3.85-4.12-6.82-6.45-12-6.67.16-1.28.33-2.56.48-3.81-5.09.22-4.15.91-4.57,6.44-.26,3.31-1.89,6.39-3.05,9.48-.48,1.31-.08,2.8,0,4.21.24,2.68.24,2.24,2.7,2.1,1.27-.06,2.84,8.08,3.27,9.56.74,2.46,5.55,4.72,7.44,6.17,1.64,1.28,4.74,4.26,5.51,6.26,1.12,2.89-.07,7,.63,10.08.7,2.91,2.37,5.88,3.47,8.68-4.3-.73-6.91-3.47-10.47-6.23-3.28-2.58-3.49-4.05-4.89-8.35-1-2.94-1.86-9.69-3.93-11.89l-9.2-9.8c-1.38-1.5.56-9.54.79-11.8.38-4.13-.56-8.88-.84-13-.55-8.26-3.15-15.24-5.62-23.06-1.63,2-3.27,4-4.9,6-2.09,2.55-1.89,2.49-5,1.77-3.3-.77-3-.46-2.52-4.06.2-1.55,1.5-5.61.88-7-2.19-5.09-3.38-9.56-7.52-12.86-3.62-2.9-4.83-7.91-6.73-12.29-1.82,1.27-4.41,4.07-6.57,4.36-3.78.54-7.6,1.07-11.41,1.59-.5.06-2.91,0-3.27.45-.63.74.48,3.32-.2,4.05l-5.6,5.76q-7.94,8.14-15.91,16.36c-1.77,1.84-5.43,2.72-7.61,3.81-2.83,1.38-1.78,3.48-1.74,6.86.07,2.86.91,7.1.16,9.86-.7,2.57-2.77,6.67-2.08,9.31,1.07,4.22,1.58,6,4.25,9.14,2.3,2.73,3.36,5.6,4.79,9,2.6,6.05-7.69,11.35-8.43,3.17a71.68,71.68,0,0,1-.32-10.56c.15-3.54-1.14-4.06-3.5-6.58-.3,2.48.16,5.05-1.85,6.37-2.16,1.38-4.32,2.83-6.48,4.24-6-11.34-11.06-23-16.26-34.81-1.36-3.08-3.64-6.63-4.36-10-.53-2.39-.19-5.48-.26-7.92q-.35-11.31-.7-22.59c-1.59,2.17-3.16,4.36-4.76,6.54s-1.77,1.91-4.42,1.81c-3-.12-6.36-5.78-8.44-8,2.12-.47,6.57-.19,6.92-3.12-1.11.1-2.7.58-3.78.33-3.06-.74-6.48-3.69-9.28-5.29-1.91-1.1-3.16-6.07-4.12-8.12-1-2.27-17,1.27-19.71,1.6-5.92.69-11.9-1.65-17.7-3-2.55-.58-5.48-.31-6.8-2.9-2.34-4.64-1.77-6-6.38-4.28-3.85,1.43-6.2.88-10.29.22-2.52-.4-4.12-3.5-6.43-4.59-4.14-2-4.59-2.45-6.6-6.86-1.37-2.91-1.92-6.7-5-7.17-5.33-.77-5.3-.55-9,3.77-1.25,1.52,3.17,6.88,4.13,8.45,3.33,5.56,6.16,11.44,9.18,17.2.44-2.61.83-5.2,1.26-7.81,2.19,3.89,1.74,7.77,1.88,12.32,3.81-.24,10.19.42,13.7-1.73s6.65-7.58,9.44-10.76c.25,3.27-.54,8.64,2.15,10.47,1.56,1.06,3.22,2.65,4.94,3.4,1.54.67,3.36.08,4.24,1.75.66,1.21,1.72,4.54,3,4.77,2.35.39,1.38,2,1.21,4.43s-5.1,6.5-6.62,8.3c-.11-.77-.69-1.47-.79-2.24-1.31,3-2,4.43-2,7.68,0,2.83-1,2.53-3.43,3.68s-4.89,2.35-7.3,3.49c-1.45.67-1.41,4.76-2.8,5.44-1.12.54-2.94-.94-4.14-.43l-5.34,2.34c-2.45,1.1-2.11,4.39-4.37,5.2-4.05,1.44-8.08,2.88-12.12,4.35-1.21.42-1.41,1.06-2.17,2.24-1,1.55-2.22,1.35-3.9,1.66-3.5.68-7,1.81-10.39,2.73-2.56.66-3.08,3.59-5.87,3.59-4.35,0-4.72,1-5.56-3.53s-1.7-9.11-2.54-13.66c-1.34-7.1-4.75-11.77-8.4-17.87-2.15-3.62-2.49-4.29-6.23-5.69-2.16-.81-2.13-7.36-2.54-9.65-.59-3.46-2.82-6.59-4.32-9.66-.93-1.84-3.06-2.74-4.2-4.77-2.4-4.32-4.8-8.61-7.22-13-1.21-2.13-2.12-5.84-5-5.1.34-2.65.73-5.32,1.08-8-1,3.18-2.09,6.35-3.14,9.54-3.59-3.81-5.47-7.12-7.87-12-2.56,3.25,2,8.67,3.42,11.61,2.93,6,5.9,12.06,8.86,18.09,1.76,3.61,1.13,7.65,3.75,10.49,1.12,1.19,3.92,3.18,4.21,4.93.45,3.07.93,6.09,1.42,9.17.26,1.78.1,5.18,1.44,6.47,1.66,1.59,4.17,3.27,5.42,5.24,2.49,3.87,3.6,9.86,5.23,14.24.54,1.52,4.82,1.27,5.89,2.53,1.63,1.91,3.3,3.83,4.93,5.76,2.75,3.18,8.3,6.69,4,10.82,2.9.88,6,6.83,8.34,6.24q11.85-3.18,23.7-6.34c1.46-.38,5.67-2.17,6.89,0,.75,1.32-2,8.9-2.39,10.53-1.43,6.32-6,12.29-9,17.83-2.56,4.73-4.67,9.86-8.29,13.66-9.55,10.05-20.71,19.31-27.86,31.61-1.61,2.69-11.81,16.63-10.16,19.11,2.85,4.28,2.88,5.07,2.56,10.39-.27,4.79,0,5.15,2.77,8.9,4.28,5.8,2.83,14.81,3.17,22.12.24,5.4-4.1,11.68-8.46,13.78-2.41,1.17-7.31,2.3-9.15,4.43-2.36,2.78-4.74,5.53-7.13,8.32-2.1,2.43-4.64,3.58-3.31,6.75.9,2.12,4.14,7,3.88,9.32-.3,2.76.17,9.05-1.25,11.27-1.22,2-7.2,3.44-9.22,4.41-3.36,1.6-2.62,3.14-3,7.26-.19,2.18.22,8.15-1,9.93-4,5.62-7.63,12.28-12.22,17.27-2.43,2.61-5.49,4.72-8.15,7-1.52,1.32-4.44,5.08-6.4,5.47q-10.59,2.24-21.19,4.45c-3.23.68-6.52,1.36-9.76,2.06-1.58.31-4.73-3.81-5.87-4.88-3.84-3.46-3.71-3.4-3.13-8.93.23-2.1-2.17-5.89-2.91-7.76-1.65-4.11-3.31-8.23-5-12.33-1-2.45-4-4.34-5.8-6.12-1.22-1.2-1.19-6.89-1.45-8.59-.72-4.72-1.43-9.39-2.16-14.09-1-6.3-4.12-11.28-6.89-16.88-1.82-3.69-3.64-7.35-5.42-11-.79-1.63.3-4.66.54-6.33,1.2-8.06,1.39-15.63,5.28-22.58,3.78-6.69,1.47-12-.15-18.94-1.76-7.5-3.49-15-5.24-22.47-.54-2.28-3.55-5-4.88-6.74-2.57-3.43-5.08-6.84-7.64-10.26-1.38-1.82-.4-4.22-.12-6.52.53-4.66,1.09-9.33,1.64-14,.48-4,.68-4.24-1.64-7.43-2.65-3.68-2.51-4-6.65-3.72-2.4.1-7.22,1.64-8.94-.47l-7.33-9c-1-1.29-16,1.06-17.84,2l-10.58,5.39c-2.76,1.42-4,.69-7-.11s-5.17-1.79-8.2-.72c-3.87,1.34-7.73,2.72-11.59,4.09-1.83.65-3.9-1.84-5.38-2.92q-5.56-4-11.12-8c-4.69-3.37-7-5-9.9-10-4.71-8.24-9.43-16.42-14.15-24.63q-2.25-3.94-4.53-7.89c-.7-1.24,1.81-5.83,2.26-7.09.8-2.17,3.25-6.17,2.73-8.57-.87-3.94-1.75-7.83-2.64-11.76-.59-2.63-2.58-7.35-2.24-10.06.23-1.64,2.24-4,3-5.43,4.55-8.19,9.07-16.42,13.63-24.64,3.2-5.78,7-7.46,12.48-10.94,2.83-1.8,4.1-1.83,4.63-5.32.65-4.33,1.32-8.68,2-13,.78-5.12,11-6.07,13-11.06,1.4-3.48,2-8.32,5.52-9.32.91-.25,3.44,4.48,6.27,3.87,1.25-.27,4.15-1.54,5.36-.91.65.36,3.24,2.28,3.85,1.92a97.22,97.22,0,0,1,8.37-4.95c5.27-2.39,11.83-4.73,17.51-5.43,1.54-.17,3.92-1,5.4-.58,1.22.44,3,1.49,4.31,1.42,1.45-.06,2.83-1.74,4.25-2a19.54,19.54,0,0,1,4,.22c3.84.22,6.49.87,9.83-1.13,2.7-1.64,5.21.52,8,1.7-2.06,4.55-2.48,4.72-.15,9.08,1.09,2-3.12,5-4.51,6.53,2.25,2,5,5.7,7.82,6.44l14.48,3.84c3.74,1,2.69,5.11,6.38,6.7,3.23,1.38,6.29.85,9.27,3,4.22,3,6.44,3.72,9.17-1.63.63-1.27-1.42-3.18-.78-4.34.54-.94,1.65-4,2.61-4.22,4.69-1.34,7-2.06,11.7-.8,1,.28.1,2.44,1.45,2.7,2.19.46,4.36.88,6.55,1.35,1.75.36,1.84,1.21,2.73,3,.47.92,2.16-1.11,2.94-.86l10.48,3.08c3.85,1.13,4.34,1.13,8-.65,4-2,4.42-2.59,8.38-.66,4.73,2.32,12.1,1.57,14.29-4.45,1.32-3.76,7.94-15.38,5.36-19.19-1.65-2.42,1.94-7.61,1.11-8.54s-2.34.63-3.1,1.27c-1,.82-2.3-1.25-3.32-1-1.35.25-2.45,3.07-3.72,3.68s-3.54.16-4.85.23c-3,.11-4.33-3.14-7.09-3.63-1.83-.33-3.37-1.43-4.08.62-.81,2.45-.79,2.32-3.18,2.76s-6.12-2.76-8-3.85c-3.45-2-9.42-12-5.7-16.17-1.22.16-2.47.28-3.71.44-.53-4.12,4.81-5.25,7-5.31,4.3-.14,6.49-.19,10.28-2.32-1.16-.6-2.35-1.17-3.53-1.8.73-2,5-1.15,7-.88,3.59.52,3.79-.48,6.65-2.4,1.82-1.19,4.46-3.09,6.68-2.94,2.91.24,5.58.72,8.37-.25-.67,1.17.5,2.22,1.76,2.84,2,1,1.24-1.67,3.24,1.15.74,1,6.2,1.85,7.95,2.59,3,1.17,4.82-.6,7.8-.22,3.35.39,5.73-.86,8.6-2.7,2.4-1.5,1-5.7-.44-7.39-2.13-2.4-4.76-2.85-7-5s-4.44-5.26-7.7-5.67a31,31,0,0,1-3.33-2c-1.32-.89-2.56-1.94-3.84-2.89.14-.27,1.06-1.49,1.06-1.51l3.66.74c-1.12-3.92,1.39-5.13,4.27-5.06-1.37-1.13-3.22-2.16-4-3.78l3.68-.11c-.88-2.8,2.76-.75,3.3-2.46.63-2-2.33-1.13-3.17-1-3,.5-6.32.58-8.47,3.41v-1c-3.38.82-4.7,1.38-7.32,3.86.2-.44.4-.88.61-1.3-3.47-.44-1.89,3.91-.48,5.57,1.76,2.12,4.52,1,7.37,1-2,3.65-4.36.94-6.57,2.13s-6.87,5.34-9.43,3.29c1.54-4.28-.44-3.75-4-5.44,1.75-.92,8.51-3.38,3.92-4.95-1.42-.48-3.1-.11-4.58-.05-1.06.07-2.54-1.58-3.45-2.22,1.88.13,4.25,1.13,5.24-1-2,1-7.2-1.33-8.41.05s-5.26,4.53-5.57,6.61c-.2,1.25-.14,4-.78,5s-3.3.84-3.54,2c-.77,3.69-.58,6.42-3.58,8.38s-2.25,5.36-.86,8.08c.9,1.75,5.63,3.95,5.37,4.77-.78,2.37-5.1-.65-6.65.84-2.33,2.14-4.63,4.31-6.95,6.47-.25-2.52,1.18-3,2.9-4.06-1.33-.56-2.9-.58-4.45-1.19-2.43-.92-3.81-.33-6-.92-1.09-.28-2.45.61-3.46,1s.37,2.14-.16,2.55c-1.9,1.59-3.24.16-4.88-1-1.78,2,.19,3.87,1.22,5.7,1.58,2.82,1.66,2.51-.57,4.8,2.91,2,6.13,2.76,5.48,7-1.74-1.35-2.95-3-4.79-.71,2.28.44,2.48,1.87.86,3.15s-.86,2.12-.17,4.23c-2-.37-3.44,0-4.29-2-.79-1.7-1.63-1.2-3.08,0-1.52-5.15-2.57-5.62,1.41-8.85-3.69,0-3.69-.45-5.93-3.81-1.26-1.88-2.17-5.07-3.82-6.42-2.93-2.41-1.86-4.23-1.49-8.19.32-3.67-.88-3.67-3.64-5.86-3.63-2.88-7.82-6.9-12.3-7.49-1.15-.17-3.77-3.63-4.17-4.87-1.07-3.58-1.37-4.51-4.13-6.66-1.23,3.76-2.73,1.88-3.22-.81s0-2-2.84-1.23-4.56,1.07-2.76,4.33c.62,1.14-1.61,3.82.41,5.37,1.67,1.25,4.43,2.55,5.68,4.26s1.08,4.62,2.76,6.11c2,1.76,3.07,3.18,5.63,3.31,1.66.09,4.58,0,2,2.1C886.52,515,898.43,520,895.4,524c-1.21-.63-4.65-5.34-6-4a5.34,5.34,0,0,0-2.09,3.67c-.38,1.72.71,1.59,1.93,2.54,3.46,2.69-2.36,3.44-2.14,5.07.3,2.32-4.36,6.39-4.25,2.62a4.85,4.85,0,0,0-1.65,6.53c1.16,2.32-3.57,3.08-4.11,1.22-1-3.4-12.38-3-7.93-7.93.63.74,6.78,1.29,8.2,1,1.64-.38,4.48-.41,5.9-1.37s.16-2,1.75-2.86c1.09-.55-1.58-7.62-2.36-7.72-.93-.11-3.21-.18-3-1.63.28-1.85-1.5-2.54-2.82-1.84.27-1.55-3.11-4.08-4.47-3.91-2.43.34-3.81-2.09-5.56-3.83-3.13-3-7.38-4.57-8.35-8.77-.92-3.93-.92-4.18-4.23-5.91-1.72-.92-3.85-1.59-5.1,0-.9,1.1-9.87,7.69-11,7.31-3-.95-5.92-1.95-8.89-2.93-1.52-.47-3.88,2.75-5,3.8-.6.53,1.18,5.07.06,6.67s-5.14,2.62-6.78,3.45c-4.82,2.52-6.3,6.39-9.2,11.37-.86,1.46,2.89,2.82,1.08,5.22-1.09,1.51-4,3.91-3.14,5.73-1.05.27-3.52.36-4.12,1.35s-1.69,3.62-2.66,3.71a66,66,0,0,1-9.22,0c-2.74-.12-4.35,3.24-6.51,3.93-2,.64-5.45-3.7-3-5.42-2.38,1.13-3.51-2.9-6.53-1.17-2.4,1.37-4.16-.69-6.32.94a19.59,19.59,0,0,0,.68-5.33c-.09-1-.16-2-.24-3s-1.11.25-1.51-.36c-1.83-2.79-.48-3.45.26-6.58s3-7.74,1.72-10.65c-1.17-2.73-.6-5.82-.07-8.61-1.68,1.34-2.79-1.22-2.11-2.83s3.77-1.49,4.86-1.66a6.64,6.64,0,0,0-.52-1c2.9-2.61,4.26.94,6.79.3,3.6-.89,4.89-1.09,8.39,0,2.72.88,5-.52,7.47.39a15.37,15.37,0,0,0,6.74.72c4.8-1,4.18-10.38,4.15-14.22,0-3.63.6-4.8-2.81-5.86-2-.61-2.25-4.17-1.82-5.25-1.83.44-1.12-.69-1.88-1s-2.93-.49-3.27-.75c-1.47-1.15-2-1.89-3.82-1.79a2.64,2.64,0,0,1-3-1.46c.52-.06,1-.42,1.53-.47a3.06,3.06,0,0,1-2-2.9c2.08-.15,4.27.18,6-1.07,3.66-2.58,1.57,2.06,4,1.45.85-.18,5.4-.94,5.2-2.2a21.07,21.07,0,0,0-1.86-5.67c1,.09,2.75-.25,3.11.83.48,1.49.3,1.59,1.66,1.76a10.23,10.23,0,0,0,6.43-.88c-.63,0-1.21-.49-1.82-.57,1.34-1.9,3.88-2.54,5.85-3.48,2.82-1.38-.14-3.22,1.24-5.47.61-1,5-2,6.23-2.58,2.23-1.05,3.54-.92,6-.74-.83-.27-3.16-.56-3.22-1.56,0-.21,2.19-.43,2.39-.64.38-.42,0-1.47.45-2a12,12,0,0,0,2.38-5.68c.25-1.18,2.24-.94,3-1.83,2.53-3,5-1.29,8-2.23.44-.15,0-1.58.75-1.71s1.65-.24,2.47-.37a14.41,14.41,0,0,1,3.9.43c-.45-2.38,1.55-1.76,3.21-2-.9-.34-3.41-2.45-2.18-3.43,2.05-1.59.26-1.47-.4-3.56s.63-3.42-1.23-4.95c-1.48-1.24-1.13-2.06-1.24-4.14-.14-3.43.53-7.29,4.13-7.44,2.75-.07,5-3,7.66-4.37-1.85,2.69-2.8,8.42,1.19,9.4-2.33,3.72-6.74,4.95-5.94,9.92.61,3.62,4,6.72,7.36,5.12-.45,1-.91,2-1.36,2.94,3.31,1.93,6.14-2.77,9-3.12,1-.13,3.75,1.6,4.12,2.7.57,1.93,2.28,2.35,3.9,3.26a5.46,5.46,0,0,0,.31-1.81c-.93-.08-1.85-.19-2.77-.27,2-1.29,9.18-1.43,10.59-3.29,2.27-3,8.94-4.89,12-2.27-.28-.2-1.42-.55-2-.88.07,3.12,4.31,3.55,5.9,1.65.62-.73.87-2.54,1.28-2.95s1.24-.06,1.63-.41c1.07-1,2.48-1.46,3.24-2.7a8.24,8.24,0,0,1-2,2.95c5.24,2.55,2.1-7.11,2-9.48a6.54,6.54,0,0,1,1.58-4.87c1.1-1.34.21-3.47,2-4.83,4.68-3.49,5.8,4.22,9.26,4.46,1.9.15,3.27-2.61,3-4.3-.2-1.11.72-5.49.44-5.71-.52-.42-1.51.82-1.88.54a22.26,22.26,0,0,1-2.08-2.23c-.51-.58-1.48-4.49-1-4.71,3.26-1.43,7.29-3.51,10.89-3l8,1c3.68.46.54-.88,2.74-2.29,1.41-.88,3.47-.33,5.12-1.36,1.13-.73,3.76.32,5.06.51-.77-2.48-5.7-3.36-7.84-4.27.38-.57.38-1.52.79-2-7.48,1.45-15.16,3.27-22.8,4.74-.78.16-3.94,1.31-4.42.5-1.51-2.4-1.91-2.82-4.36-3.82-3-1.2-2.72-.95-2.2-4.42a11.48,11.48,0,0,0-.1-5.74c-.39-1.58-2.07-5.24-1.73-6.88.3-1.47,3.36-3.81,4.32-4.94,2.43-2.78,5.7-4.53,8-7.45,1.2-1.46,3-4.94,4.63-5.73s3.84.77,3-2.27c-1-3.77-3.9-5.56-7.61-5.68-5.19-.19-5.65-.38-9.27,3.67-2.31,2.58-3.5,4.66-1.64,7.93,1.65,3-12.42,10.25-13.61,11.79-3.54,4.44-9.5,11.54-5.69,18.12,1.63,2.83,6.32,2.74,7.8,6,1,2.31-2.87,4.28-4.56,5.75-2.91,2.54-5.19,3.53-5.77,7.54-.48,3.22-.35,7.95-1.63,10.92-1.74,4-4.75,4-8.25,4.79-1.38.26-1.31,2-1.68,3.36-.47,1.72-1.49,1.19-3.08,1.29-2.47.18-2.71.78-3.11-1.94-.2-1.43-1-3.67-.46-5,1-2.84-3-6.25-4.7-8.46-.71-.93-.3-2.7-.8-3.81-.67-1.38-1.82-3-2.16-4.51s.95-4-.67-4.32c-1.4-.34-1.62-2.77-2.09-4.19-1,3.85-1.75,4.24-4.77,6.43-2.12,1.53-3.82,3.87-6,5.2-3.36,2.06-12,1-12.16-4.25-.22-6.47-2.72-12.71-2.4-19.14.27-5.52.65-5.55,4.64-8.93a35.2,35.2,0,0,1,7.21-4.25c3.11-1.53,5.81-2.53,8.18-5.19,2.14-2.41,4.29-4.66,6.64-6.88,5-4.72,7.23-10.6,10.9-16.53s8.25-10,12.69-15,8.25-10.22,14-12.85a156.45,156.45,0,0,1,19.53-7.15c2.56-.76,3.89-4.92,6.22-6.29a14.17,14.17,0,0,1,8.09-1.41c-3.15,3.48-4.55,5-5.73,9.72,2.91-.55,5.43-5.45,7.29-7.8.32,1.49.61,3,.87,4.43,1.34-1.75,2.66-3.53,3.95-5.27.57-.75,4,0,4.88.08-.83,1.36-1.62,2.7-2.43,4.07,3.48,2.64,1.46-3.82,4.31-2.69s6,2.34,9,3.52c2.53,1-2.16,3.39-3.11,3.6-2.15.46-5.13-.5-7.32-.7,1.12,2.05,3.45,1.31,4.43,3.69.27.59,3.27-.35,4.35-.28,2.57.23,5,1.35,6.7-.92.76-1.09,4,1.28,5.06,1.83-.63,2.37-2.88.85-4.57.44-.72,4.93,7.81,3,10.11,3.09,4.83.2,7,1.41,11.34,3.86a61.2,61.2,0,0,0,11.89,5.64c3.26,1,7.5,3.14,8.78,6.93s1.05,3.64-1,6.86c-1.31,2-1.72,3.21-3.79,3.91-4.74,1.56-6.27,1.78-10.95.68-8.75-2.07-15.87-4.07-24-8.16,2.36,2.39,9.14,6.88,9.14,10.45s-.61,10.86,2.64,12.25c3.7,1.61,8.45,5.85,12.07,4.34,2.13-.88,1-4.31-1.1-4.31-2.27,0-3-1.95-4.5-3.82,3.36-3.06,3.58-2.35,7.71-.91,3.36,1.19,6.73,2.32,10.09,3.5-.3-.87-2.95-7.44-2.59-7.66q3.81-2.58,7.59-5.1c1.32-.9,3.81-3.48,5.4-3l8,2.4c.34-1.52,1.62-4.36,1.06-5.82-.13-.44-2.77-4.65-2.92-4.11.61-2.48,1.21-4.91,1.78-7.37.22-.87-2.65-3.48-3.23-4.22,3.23.44,6.48.83,9.72,1.27,2.43.31,4,4,5.55,6-1.61.17-6.36-.3-7.21,1.21-1.41,2.41,1.21,4,2.74,6,1.69,2.16,4.21.8,6.68.42,3-.41.85-2.71,2.5-4.88.74-1,3.54-1.6,4.6-2.09l8.78-4c4.46-2,8.93-4,13.37-6.07,1.28,4.2,1.26,4.17,5.18,5.15,2.56.63,3.89-4.14,6.09-3.9,3.32.4,5.29.88,8.29-.57,3.45-1.65,4.4-1.52,8.15-.68-.57,1-1.16,2-1.73,2.95,4.12,1.23,3.94,1.43,6.67-2.21,2.53-3.4.88-3.69-1.63-7,5.78-2.53,14.1-1.61,20,.74,4,1.59,8,3.18,12,4.76,2.87,1.16,5.76,4.37,8.3,6.28.19-1.51,1.68-6.56.49-7.43l-8.83-6.6c-2-1.42,1.17-5.55,2-7.55.73-1.64-3.83-3.4-5.15-4.26,2.88-2.28,5.78-4.6,8.68-6.91,2-1.58,2.8-7.22,3.62-9.69,1.1-3.11,14.84.16,18.07.48-1.24,3.38-2.47,6.79-3.71,10.15-.66,1.77,2.34,5.86,3.14,7.51,1.45,3-3.34,16.27-1,17.87,2.84,1.9,6.07,2.24,4.56,5.86-.87,2-1.84,6.7-3.64,7.81l-9.33,5.72c-1.35.85-5.58-.61-7.21-.81,4,3.26,8.5,6.11,13.86,4.34,4.23-1.38,9-7.3,12.16-10.49,3.52-3.57-5.57-9,1.88-11.24,1.42-.42,5.46-2.62,6.57-1.32,1.87,2.2,3.78,4.39,5.67,6.56-.43-2.87-.09-5.63-2.39-7.28-3-2.17-3.37-2.19-7-1.65-.86.15-8.16,1.75-8.35,1.07-.54-2-2.36-5.53-1.48-7.47,1.15-2.4,3.89-5.57,2.28-7.93-1.25-1.88-5.19-5.65-3.82-7.77,1.77-2.78,4.4-3.23,7.29-4.43,2.13-.89.3-5.89-.26-7.18,1.58-.4,4.68,3.87,3.75,5.63-2.16,4.16-1.92,4.06.36,8.15,1.55,2.78,13,2.8,15.89,3a125.89,125.89,0,0,1-12.21-5c-4.65-2.19,3.41-5.65,5.24-6.23,5.59-1.78,7.91-.41,13.48,1.69a29.52,29.52,0,0,1,4.83,3c1.51,1,3.63.08,5.35-.18-.56-1.49-1.14-5-2.22-6.06s-5-.84-6.48-1.1c-1.89-.31-2.27-8.58-2.63-10.69q9.36-1,18.75-1.92c3.53-.35,7.08-.73,10.6-1.07,2.35-.25,1.42-2.72,1.48-5.09.14-4.64-.23-4.69,3.35-6.82,2.55-1.52,5.25-3.68,8-4.72,5.8-2.17,12.88-2.36,18.92-3.51,11.44-2.09,22.47-3.47,33.4-7.64,2.55-1,1.4-5.16,3.48-6.22,3.23-1.68,6.48-3.3,9.68-5,3.86-2,10.83-2,13.69,2.21-3,.94-6.11,1.86-9.14,2.79,4.82.67,9.65,1.39,14.47,2.07l-6,5.21c2.65.18,5.33.33,8,.52,0-1-.41-5,.58-5,2.09.06,4.17.16,6.23.23,3.14.09,6.62-.58,9.34,1.28s7.29,3.77,9.37,6.5c.52.71,3.21,3.43,2.84,4.22-.46,1-1.25,4.05-2.12,4.61L1301,275.67l26.93-7.61c-2.32-.37-4.63-.71-6.92-1.06,2.76-2.37,7-4.56,10.28-2.15,4.9,3.6,6,3.43,12,2.87,7.72-.73,15.55.89,23.24,1.72l-4.41,2.59c1.89.92,5.33,3.58,7.32,3.46l9.23-.47c1.83-.11,6.89.82,7.22-1.52.65-4.73.2-4.58,4.39-4.63,2.88,0,6,.3,8.81-.22,2.13-.42,6.62-2.34,8.66-1.65s4.83,5.44,6.33,7.15c.92,1-1.09,6.74-1.1,8.29,0,1.25.22,8.27,1.07,8.74,2.82,1.64,5.64,3.24,8.47,4.84,1.26.72,5-5.65,5.9-6.8,2.42-3.24,2-3.62,5.27-1.49s4,3.25,7.73,2.07c2.37-.75,5.2-2.52,7.56-1.36,1.68.87,5.43,3.86,7.25,3.14,2.87-1.21,5.74-2.38,8.69-3.59-.83-1.47-3.59-4.61-2.51-6.05.81-1.1,3.47-6,4.75-5.86l16.73,2.16c4.21.55,8.5,2.14,12.62,3.23,4.38,1.13,10.49,1.49,14.48,3.75,2.45,1.38,8,10.48,10.5,10l16.64-2.83c4.56-.79,8.94,1.38,13.38,2.67,2.68.78,4,.4,4.83,3.26.91,3,.77,3.72-.16,6.8,4.69,1.56,8.32,3.32,13.13,2.46,5.6-1,9.14-1.23,14.72-.27,2,.33,4.8,1.56,6.56.26,2.75-2.05,2.42-2.1,4.81.29,1.76,1.68,4.25,5.39,6.41,6.28,1.58.63,4.93-.5,6.62-.68-.51-3.71-1-7.41-1.56-11.11l23.83,1.87c6.23.47,12.2,4.82,17.85,7.56,6.52,3.19,12.8,6.54,19.12,10.17,3.9,2.24,4.45,2.45,6.12,6.89,1.86,5,1.32,6.62,6.25,6.62-.58-2-1.13-4-1.73-6.06a32.63,32.63,0,0,1,12.16,1.83c3.21,1.11,6.24,4.82,8.93,7-1.64,1.34-4,4.31-6,4.86-1.71.49-4.82-.77-6.6-1.05Zm-624,171.53h0c-.85-.77-.83-3.13-1.7-3.68-3.86-2.36-4.47,3.68-4.51,5.89-2.2-3.74-2.67-5.31-.84-9.35-1.6-.74-5.16-1.47-6.31-2.88-.89-1.14-.86-5.2-1.11-6.71,0-.12-5.37-2.22-3-2.79s2.92,2.21,5.27.47c-1.56-1.47-3.08-1.75-1.77-3.69a4.35,4.35,0,0,1,3.71-1.52c2.73.45,7,.31,9.29,1.39a5.36,5.36,0,0,0-3.25,5c1.69-2.42,2.35-3.92,5.26-4.28-1.45-4.57-2.48-1.56-6.31-2.77.6-2,1.92-4.26.89-6.14-.43-.82-2.13-4.84-3.51-3.21-1.47,1.78-3.68-.07-5.6-.82-1.42-.56-3.85,1.82-5.33,2.09-3.75.67-3.51-1.32-4.6,3.38-.33,1.31-4.58,2.29-5.69,2.79-2.63,1.1-2.43,1.22-3.06,4.3-.28,1.42-2.48,2.95-3.42,4,2.33.14,5,2,4.89,4.76-.07,4.09.5,5.67,2.13,9.36,1,2.26,3.58,3,4.79,5.12,2,3.46,2.66,4.57,6,6.2-2.77.84-3.32.53-4.06,3.59a42.1,42.1,0,0,1-1.92,5.5c-.87,2.24-.57,3.64-.37,6.07.24,2.65.95,2.15,3.35,2.73,2.08.5,2.18,2.07,3.84,2.57,2,.65,4.1,1.3,6.1,1.91,2.62.82,7.12-.85,9.86-1.19-.35-3.32-1.06-6.49-.41-9.73,1-5-1.28-2.69-3.25-6.25a14.57,14.57,0,0,0,1.87.14c-.22-.8-.42-2.47-1-3s-2.23.14-2.73-.45c-1.33-1.68-.5-3.33.24-4.91-.14.32,7.58,1.16,9,.5.51-2.19-1.43-3-2.8-4.31ZM272.93,235.89h0c2,.39,4.49,1.59,6.4.13a9.44,9.44,0,0,0-1.49-1.29c-1.72.07-3.62-.36-4.91,1.16ZM443.77,645.42h0a16.32,16.32,0,0,0,5.33,2.82c1,.3,2.39-1.49,4.37-.83a13.54,13.54,0,0,0-1.13-1.73c-2.4-.81-6.62-3.17-8.57-.26Zm-16.42-157.8h0c-.2.22-.42.44-.65.66l.45.31c.8-1,1.17-1.41.8-2.45-.17.23-.37.47-.53.72-.49-1.51-1.77-1.68-3-1.13-1.59.67-2.2-.87-3.82.34l1.31.3c1.54.68,3.89,2.22,5.42,1.25ZM418,483.93h0c-1-.69-1.16-.28-1.42-.07.31.35.65.66,1,1,.16-.33.28-.62.46-.95Zm2.23,2.22h0a6.12,6.12,0,0,1-.06-.63c-.44-.24-.82-.43-1.39-.75l-.94.83a5.27,5.27,0,0,0,2.39.55Zm128.63-33.82h0c.63-1.36,1.28-2.7,1.88-4.05-3.87-1.58-8.06,3.7-9.5,7.14-2.4,5.79-4.46,8.44-8.71,12.82-.75.79-1.11,5.05-.57,6,1,1.52,4.34,1.08,5.69.92,4.43-.51,9-.45,13.09,1.77-1.45.54-2.49,1.51-2.29,3.2,3.89-.8,4.71-3.5,8.77-3.78-.55,3-1,3,1.68,4.07,2.19.85,2.54.9,3.85-1.07,1.46-2.2-.2-7.32-.74-9.69-.36-1.56-3.08-2.22-2.94-3.12.37-2.62,0-2.68-1.68-4.66-1.31-1.51-6.81.5-8.41,1-.12-1,.15-3.19-.76-3.59-.71-.35-2.34-.63-2.36-1.57,0-3.06.87-3.33,3-5.3ZM496,646.44h0c1.09,2.72,5.8.54,6.89-1.16a8.37,8.37,0,0,0-.75-.8c-2.12-.17-7.71-1.94-6.14,2Zm-38.78-9.61h0c1.92-.49,3.81-1.09,5.72-1.67-1.55-1.25-2.63-2.35-4.51-2.69-1.35-.24-2.07-2.29-2.7-2.24a9.55,9.55,0,0,1-7.69-3.73c-.11.22-.24.45-.34.7-5.56-3.7-11.64-7.09-18-7.72-3.84-.38-6.78.46-10.55,1.39-3,.76-3.82,3.68-6.27,5.2,4.82,2.55,10.33-8.31,15.11-3.49a3.2,3.2,0,0,1-2.46.49,3.37,3.37,0,0,0,3.49,1.27c1.5-.47,1.64.7,3.25.75,2.63.09,5.1,2,7.92,2.36,2.62.36,2.7,3.45,5.58,4.8.76.34,3.6-.4,3.57,1.58,0,.64-2.41,2.46-2.87,2.94,3.55.64,7.16-.25,10.8.06Zm53-158.21h0c-2.27,4.21,1.66,4.9,4.5,6.22s3.6-.33,5.57-2.51c-2.93-.22-5.87-.45-8.79-.71-.43-1-.86-2-1.28-3ZM508.43,460h0c2.9,2.33,9.55,7.91,13.23,5-3.45-3.89-8.6-5.1-13.23-5ZM645.28,775.61h0c1.42,6.18,1.55,6.07-1.83,11q-6.21,9-12.47,18c-1.93,2.85-4.3,5-4.55,8.57q-1,13.26-1.9,26.54c-.41,5.85-6.5,11.87-9.51,16.52-1.33,2-2.43,5.37-4.8,5.5s-7.59-.66-9.53.68c-5.83,4-11.65,8-17.48,12-1.15.83-1.13,9.54-1.31,11.09-.2,1.84.1,5-1.07,6.5-4.83,6.22-9.67,12.46-14.51,18.66q-6.63,8.58-13.29,17.1c-1,1.29-15-4.73-17.11-5.4-1.26,4.78,6.71,5.3,7.53,9.43.42,2,2,5.91,1.61,7.92-.36,1.83-3,4.44-4,5.93-2.93,4.29-6.85,4.2-11.57,5.48-4.52,1.22-6.69,1.11-11.34.2.89,2.92,1.62,4.16.54,6.93-.64,1.74.16,4.55-.84,5.26-4.62,3.23-7.31,1.84-12.14-.58,0,2.42-.68,5.66-.16,8,.39,1.71,3.2,4.59,2.47,6.23-1.48,3.18-2.93,6.33-4.4,9.51s-1.95,2.82-5.18,3.6c-2.79.68-3.31,3.1-4.75,5.76-.9,1.67,2.54,4.85,3.54,6.29,1.29,1.82,5.54.24,4.66,3.2a13.87,13.87,0,0,1-3.24,6.22c-1.64,2-4,4-4.79,6.5-1.2,3.82-2.18,4-5.47,5.92s.37,11.92,1,15.56c.26,1.33.2,4.51,1.27,5.37,2.46,2.14,4.93,4.24,7.37,6.34,4.3,3.67,7.22,3,12.74,3.15-5,2.24-10,4.54-15,6.8-4,1.83-4.78.79-8.87-1.21-5.91-2.83-11.8-5.71-17.71-8.53-3.05-1.47-3.54-4.88-4.93-8.17-3.32-7.81-8.72-15.48-7.74-24.18q2.2-19.47,4.41-38.88c1.41-12.46,2-25.47,4.31-37.81q4.41-23.28,8.82-46.6,2.69-14.19,5.37-28.31c.76-4,2.21-8.52,2.39-12.62.13-3.46-.9-7.43-1.35-10.86-.27-2.25,0-7.69-1.18-9.61s-5.47-3.81-7.33-5.12q-5.48-3.78-10.91-7.6c-3.69-2.57-4.73-5.13-7-9.36q-6.71-12.57-13.45-25.16c-3.68-6.92-7.38-13.81-11.08-20.74-2.27-4.25,1.58-12.12,2.63-16.56.53-2.19.79-7.11,2.17-8.83,2.13-2.73,4.21-5.43,6.32-8.13,4.7-6,8.74-9.52,7.52-18-.29-1.92-1.45-3,0-4.38.2-.19-.5-2.93-.26-3.92.59-2.58-5.12-5-4.53-7.45.78-3.09.61-2.73-1.93-4.17-1.82-1.08-1.81-1-3.7.07a19.86,19.86,0,0,0-3.72,3c-.65.6,1.21,2.79,1.62,3.52-3.63,1.55-3.47,2-5.13-2-.74,2.17-4.38-1.5-6.4-1.89-1.05-.2-1.77,1-2.41.53-1.1-.84-2.2-1.71-3.32-2.54-2.27-1.71-6.76-3.83-8.33-6.33-1.33-2.09-.66-5.3-2.36-7.26-4.3-5-6.92-9.37-12.92-11.06-4.66-1.29-12.4-1.63-16.07-5.23-3.21-3.18-6.47-6.36-9.68-9.56-2.11-2.07-5.09.11-7.62.91-5.73,1.77-11.58-2.4-17-4.6-4.41-1.79-8.83-3.56-13.23-5.35-1.35-.55-4-1-5.11-2.1-2.87-2.91-5.72-5.83-8.6-8.75-2.65-2.68-1.08-4.3,0-8.06.71-2.44-3.85-7.25-5.12-9.2a27.09,27.09,0,0,0-4.54-5.49c-3.09-2.88-6.19-5.72-9.28-8.62-.7-.66.18-2.64.34-3.54s-1.51-2.44-2-3.1c-2.21-2.85-4-5.36-6.78-7.5-2.33-1.8-4.79-2.9-5.68-5.91-.5-1.68-1.8-9.74-3.2-10.39-2.88-1.3-5.73-2.63-8.59-3.93.95,3.25,1.61,9.56,3.65,12,3.12,3.72,5.79,6.63,7.64,11.22a10.61,10.61,0,0,0,3.82,5.17c1.55,1.35,2,3.49,2.71,5.51s1.75,4,1.85,6.32c.17,3.51,1.68,1,2.74,1.79s3.49,3,3.25,4.8c-.33,2.4-2.42,3-3.43,1.13-2.07-3.81-5.73-6.06-9-8.47-.94-.7-.6-5.05-.69-6.27-.14-1.9-2.88-3.17-4.17-4.25s-2.51-.55-3.89-1.78c-1.59-1.38-3.18-2.81-4.75-4.23,1.88-.22,6.35-.61,3.86-4.28-2.17-3.23-3.14-4.82-6.45-6.44-2.17-1.06-2.72-4.68-3.62-7-1.53-3.92-3.05-7.82-4.56-11.74-1.65-4.27-7.22-8-11.28-9.13-3.34-.91-4.48-.63-6-3.89-1.64-3.55-3.27-7.11-4.9-10.65-2.39-5.25-7.15-8.46-8.83-14.19-2.18-7.44-2-12.26-1.65-20.15.3-6.56.65-13.09,1-19.64.33-6.34-1.16-10.32-3.16-16.4a84.73,84.73,0,0,1,10.71,3.28c.14-5.34.37-6-3.07-9.69a47.62,47.62,0,0,0-8.08-6.87c-2.68-1.91-5.55-1.91-8.47-3.17-4.76-2.1-5.47-2.26-7.61-7.3-2.45-5.82-11.1-8.86-10.53-15.34.51-5.92.08-5.46-4.66-8.46-.67-.43-3.53,5.87-5.54,2.79-1.49-2.31-3.91-8.2-6.24-9.32-3.32-1.59-4-2.38-6.12-5.59s-4-7.35-6.57-9.92c-2.13-2.16-5.3-3.66-7.73-5.34-5.94-4.11-11.16-6.26-17.85-8.7-2.63-1-5.83,1.25-8.49.64s-6.05-3.71-8.51-5.23c-3.41-2.1-4.37-2.86-8.19-2.49-3.4.33-5.09,1.24-3.79,5.55,1.06,3.63-12.82,7.39-15.88,8.42-.67-1.58.07-2.69,1.59-3.13-2.34-.72-.57-7.5.92-8.32,3.46-1.86,5.18-2,9.07-1.92-.89-.79-1.79-1.62-2.68-2.43,1-.73,2-1.51,3.07-2.26-6.16,1.19-8.71,2.51-13.89,6.44-4.48,3.37-6.27,7.17-9.17,12.3,1.42.36,2.84.69,4.27,1.05-4.27,5.68-8.53,8.91-14.13,13-2.79,2-11.63,4.28-12,8.45-.33,3.75-11.81,5.87-15.08,6.82a24.21,24.21,0,0,1-4.08.62c-1.71.19-.85,1.1-2.13,2-2.78,1.84-4.71,2.38-7.7,1.64,2.73-2.66,5.58-3.34,8.69-5.28,2.36-1.46,9.27-8.09,11.37-4.44,1.48-2.65,7-8.76,10-6.65-1-2.84,4.15-4.66,4.73-7.82.48-2.64.52-3.28,2.26-5,1.14-1.14,2.25-1.73,1.09-3.47-3.73,2.06-7.77,5.39-11.61,2.57-1.32-1-3.85-3.83-5.43-3.15-1.95.86-3.91,1.7-5.84,2.57q-1.05-6-2.05-11.89c-1,.54-6,4.25-6.77,3.7-1.9-1.56-5.57-3.42-6.85-5.62-1.39-2.35-1.54-7-2.14-9.7-.51-2.29,1.32-4.06,2.46-6,2.21-3.78,1.94-4.77,6-4.38,3.36.33,3.86-2.4,6.82-3.61s5.35,1.12,6.78-2.53c1.14-2.9-.55-3.43-2.54-5.64.9-.52,1.8-1,2.68-1.54-1.27-3.82-4.3-.42-6.48.83-2.77,1.6-3.2-.31-6,0-5.52.73-11.73,1.85-14.77-4.17.7-.2,1.34-.92,2.05-1.06-2.73-.92-6.31-1.33-8.19-4,4-2.09,6.78-4,11.17-4-.29-.4-.62-.82-.93-1.22a17.59,17.59,0,0,1,9.12-2.6c-.17,4.4,3.19,3.73,6.57,4.63,2.95.75,3.9-.57,6.48-2.38-1.2-.53-2.4-1-3.59-1.55.45-.16.92-.36,1.4-.54-1.31-1.06-1.74-2.27-.31-3.28a36.51,36.51,0,0,1-8.84-1.78C43,328.07,43,324.17,40.64,323c-1.62-.77-8.61-2.68-9.29-4.34-.33-.74,1.22-4.07,1.48-4.92.18-.62,1.74-.41,2.26-.44,2.6-.18,6.59.65,8.28-1.77,1.93-2.72,3.67-5.67,6.1-7.89a30.61,30.61,0,0,1,15.21-7c3.5-.6,6.37-.6,9.21-2.86,3.92-3.14,3.68-3.21,8-.92,3.83,2,14.7-.76,16.38,3.93,1.22,3.45,12.55,3.14,16.3,3.63,5.66.73,11.33,1.39,17,2.41l25,4.4c5.48,1,10.64,4.14,15.76,6.45.9.39,6.72-6.68,7.66-7.59,1.53-1.6,4.53,3.08,6.32,2.28,3-1.3,16.2-9.38,18.15-6.23l-14.48,7.65c3.73,2.58,16-8.18,17.1-3.6,1.45-1.69,2.87-3.36,4.31-5.07,1.17-1.36-1.73-1.75.41-3.48a166.42,166.42,0,0,0,11.42,12.15c1.3-4.13,1.79-5.53,4.82-8.22,1.83,1.93-1.38,2.79,1.12,4.24.93.54-.58,2.52-1,3.41,1.6-.42,4.6-.47,5.89-1.51.48-.4-.59-2.35.31-2.46s1.81-.27,2.72-.41c3.22-.45,7.49,2.62,10.46,3.91,6.14,2.65,13.15,3.62,19.57,5.32-.14-.46-.3-.92-.43-1.4,4.11.16,6.24,2.09,9.8,4.49,2.64,1.83-5.43,4.62-6,4.88,2.72.85,5.6,2.31,8.43,2.09l14-1.11c2.17-.15,6-.81,7.48,1.5,2.14,3.18,4.28,6.35,6.41,9.55-.33-1.38-.66-2.78-1-4.17-.21-.85.66-1.63.54-2.42-.51-3.32-1.94-2.49-.15-5.7,1.26-2.18,10.78-2.44,8.65-5.75-4.62,1.87-8,3.37-12.9,3.25,1.1-4.22,2.81-3.77,6.6-5.05,4-1.3,4.48-1.69,8.11.37,1,.58,1.68,3,2.23,4.05.72,1.45,1.8,1.25,3.27,1.6a58.34,58.34,0,0,1,8.61,2.68c2.42.91,15.71,2.43,16.26.58,1.14-3.82,1.31-5.63,5.5-5.61,2.59,0,5.63,1.42,8.19,2.08-.36,1.26-2,5.07-1.6,6.22s4.11,2.77,5.15,3.47c-1.35-4.32-2.93-8.1,2.33-8.92,2.19-.36,3.46-2.33,5.06-3.91,1.14-1.11.34-2.59.07-4.17l-4.09,2c-.5-4.27,2.57-4.93,5.56-5.19-.14-3.34-3.28-1-5.32-1.74-1.6-.64-7.16-1.69-7.86-3.42-1.49-3.61-1.4-5.93-1.35-9.93s1.85-4.38,4.76-3.19c.51-1.85-.74-2.52-2.3-2.32,2.87-1.84,3.27-1.61,3.17-5.2-.12-3.24-.17-4.48-1.61-7.23-1.08-2.08-.29-5.1-.15-7.45.11-1.84,3.14-.85,4.56-.82-5.2-5.74,3.95-4.12,7.51-4.09A39.76,39.76,0,0,1,387.66,266c-2,2.9-4.71,9.18-7.55,10.9-2.53,1.51-8.74.26-11.43.21,8.57,1.27-1.29,6.85-.75,9.6,4.36-.78,6.84,3.07,7.63,7.19.51,2.66,4.8,5.86,6.54,8-2.15,1.43-4.27,2.86-6.38,4.28,2.11.82,3.81,2.23,5.75.87s3.7.31,5.77,1.33l-3,2.08c2,1.74,3.12,1.8,2.44,4.56s-1.11,3.34,1.32,4.91c1.43-2.13,2.29-3.17,2.53-5.77.08-1,.94-5,2.71-3.93,1.14.71,5.05,2.2,5.33,3.6.52,2.34,2,5.06-.91,6,0-.57-.31-1.19-.29-1.75-5.95,3.31,7.3,15.21,7.88,8.76.16-1.82-.08-2.9,1.21-4,.62-.59,2.63-1.78,2.63-2.76,0-4.81.07-4.56,4.11-6.35-1.62-2.54-3.13-3.77-2.53-6.76s2.27-2.27,4.93-1.81c1.75.3,6.54.11,7.76,1.53,2.3,2.6,3,3.08,6.3,3.8-1.38,2.52.82,4.14-.64,5.89-.94,1.11-4.09.69-5.44.82,1.21,2.61,2,5,4,6.81,2.15,2,3.14,3.61.8,6.59-1.54,2-5.31,3.25-7.36,4.51s-3.44-1.42-5.08-2.94c.83,1.87,1.64,3.73,2.48,5.6-1.3-.67-2.56-1.35-3.84-2,.14.52.31,1,.48,1.56-1.32-.29-2.6-.62-3.91-.92-.86-.2-.17-2.47-1-2.43-2,.07-4.73-.75-5.74,1.54,1.21.74,2.43,1.44,3.65,2.15-1.32,2-2.4,4.38-4.41,5.51-2.91,1.63-4,.27-6.93-1.32-4.66-2.43-8.76-2.23-13.95-2.45l10.75,5.42c2.62,1.32,7,.86,9.82,1.25-1.14,1.94-3.05,7.27-5,8.16-1.11.53-2.61,1.67-3.82,1.6-1.51-.16-3-.69-4.25.22-4,2.8-4.27,3-8.77,1.6-2.83-.85-5.7-1.54-8.54-2.32,1.89.87,3.78,1.72,5.67,2.6-.41.36-.67.88-1.11,1.23,3-.72,3.49-.67,6.21.83,1.42.8,3.64,2.91,1.25,4s-3.73,1.21-6.53,1.06c-.9-.07-2.36,3.17-2.84,3.89-2.27,3.58-5.88,7.42-6.79,11.77-1,4.9-2,9.84-3.09,14.75,2,.46,6.29.5,7.76,1.85,1.64,1.48,2.6,7.25,3.42,9.42,1.42,4,2.32,2.53,6.14,1.68,2-.45,4.28.95,6.17,1.62a55.6,55.6,0,0,1,14.93,7.62c1.6,1.14,4.68,4.46,6.62,4.64,2.85.32,5.72.63,8.55.92,1,.11,6.47,0,6.43,1.21-.16,4-.35,7.92-.5,11.88-.23,5.5,5.28,9.69,8.47,13.69s9.78-3.33,9.24-6.68c-.57-3.52-1.17-7-1.75-10.59-.31-1.87-2.77-4.37-3.81-6,3.47-2.27,10.18-4.78,12.59-8.24,2.2-3.1,2.74-11.58,0-14.27a41.49,41.49,0,0,1-5.36-5.71c-2.19-3.08-2.9-2.82-.16-5.35,3-2.72,3.27-2.35,2.15-6.39-.6-2.18-2-4.8-1.28-7,1.26-4,1.36-4.75.14-8.74-.77-2.51.81-3.36,3.38-3.69,4.71-.58,9,3.5,13.65,1.35,2.93-1.37,3.69.16,6.39,2.09,1.28.94,4.95,2.53,5.38,4.25.65,2.58,2.12,4.58,5,4.15,2.32-.33,3.88.78,6,1.82-1.24,2.1-2,2.69-1.57,5.06.39,2.21,1.08,4.33.19,6.51.62-.14,1.29.16,1.9,0-1.13,1.42-4.38,3.72-2.63,5.32,3-9,13.82,10.61,16.05-1.49.49.54,1.41.6,1.91,1.14,1.21-2.58,3.15-5.06,2.63-8-.38-2,2.57-6,4.6-5.56-.26,1.07-.5,2.15-.72,3.23,4.67.23,7.8,9.81,10,13.67,1.24,2.15,5,6.44,5.17,8.89.09,1.33-2.27,3.22-2,4.51.13.6,2.46,2,2.88,2.34,1.06.84,3.12,1.89,3.84,3.07.86,1.43-.53,3,1.37,3.08,3.59.2,5.1.26,8.1,2.28,2,1.42,6.1,3.35,1.65,4a49.28,49.28,0,0,0-7.41,2.16c1.5.56,3.47-.53,5.08-1-1.1,2-4.62,2.17-6.61,2.78s-1.3,4.44-.27,3.08c.88-1.17,1.54-1.32,2.88-1.84,1.18-.43.73-1.09,1.42-1.48a13.79,13.79,0,0,1,5.76-1.61,3,3,0,0,1-2.12-1.16c1.41-.06,4.21.13,4.81,1.81.81,2.18-1.65,2-.3,3.71,1.61-3,3.54-1.41,6.07-.59,2,.68.45,4.53,0,5.69-.82,2.25,1.74,3,0,5.59-.74,1.1-4.35,3.11-5.56,3.42-2,.51-3.86.09-6.08.8s-3.13,2.07-4.77,3.89c-3.38,3.71-6.16,4.26-11.15,3.75a88.42,88.42,0,0,0-14.73-.33c-4.43.27-9-1.24-10.2,4.7-.33,1.55-4.62,2-5.8,2.84-1.93,1.34-3.61,3.85-5.23,5.61-3,3.17-4.56,7-8.06,9.54,6-2.9,9.17-9.2,15.14-12.1,4.09-2,15.2-8.24,18.12-.91-.48-.26-1-.34-1.52-.58,3,2-1.08,3.55-2.59,4.87-1.93,1.68-3.51-1.26-5.74.28.91.24,3.08,2.64,3.2,2.61a6.72,6.72,0,0,1,4.09-.23,7.09,7.09,0,0,1-2.69,4.17c.68-.26,1.54.06,2.27-.08-1.13,3.13,2.18,5.65,4.57,6.23-.27.21-.53.42-.8.6,3.46,1.67,6.84,3.1,9.85.91.1.56.2,1.09.32,1.64a4.74,4.74,0,0,0,2-.61c-2.06-2.66,2.09-6.48,3.5-8.66,2.72,1,1.16,3.37.55,5.5,2-1.56,4.79,1.5,3.1,2.23-2.25,1-4.3,2.31-6.81,1.88.56.45.83,1.27,1.36,1.74-2.83,1.15-5.65,2.31-8.48,3.44a10.07,10.07,0,0,0-3.12,1.53c-1.21,1.08-1.54-1.39-2.56-.56-1.92,1.53-3.64,4.52-5.72,6.5-1.39,1.33-2.75-.57-3.61-.88-3-4.24,4.2-7.93,6.61-9.67,1.72-1.25.88.22,1.68.93,1.6,1.38,2.58-.53,4-1.85-1.89-.08-4.29-.77-5.92.39,0-1,.89-2,1.56-3-2.22-.55-5,2.32-6.84,3.51-1.18.79-1.16-1-2.54.66-.7.81-2.3.33-3.29.33,1.44,4.59-6.32,2.93-7.36,5-.31-.31-.62-.64-.94-.95-1.19,2.46-2.33,2.73-4.63,3.59-1.54.59-1.59,1.7-2.23,3.38-.94,2.41-5.35,10.53.69,9.89-.17-.38-.32-.79-.48-1.15a6.75,6.75,0,0,1,1.26,1.48c-1.79,1.26-3.92.17-5.81-.29-.94-.22-.62,2.57-2,2.66-4.44.35-6.43.59-10.25,3.14,2.72-.35,4.93-1.69,7.6-2.09-.3.22-.57.48-.87.68.76-.05,1.51.19,2.25.09-1.85,1-3.16,1.9-5.2,2-1.69.13-4.66-.49-5.66,1.3,4.13.47-1.82,8.33-3.34,9.63,1-1.72-2-2.85-2.66-4.85.14,2.42,3.19,5.7,2.09,7.91s-3.13,4.95-3.72,7.22l-.45-.13c0-1.7.8-3.05,1.43-4.59-1.08-.68-.56-2.86-2.72-2.27a20.63,20.63,0,0,1,1.07-4.81c.14-.26,1.51-3.39,0-2.33-3.52,2.55-2.47,4.23-1.51,8.55a9.26,9.26,0,0,0-3.38-1.75c.88,1.3,3,1.71,3.74,3,.52,1-.74,3.87-.46,4.81.5,1.74,2.92.84,2.26,3.72-.49,2.31-1.94,2.09-4,2.75,1.75,0,4.79-.58,4.35,2-.16,1.08-3.81,1.13-4.78,1.3.53.3.95.83,1.5,1.12-.81.27-1.21.8-2.21.79.85,2.12,2.12.2,3.56,1-1,.53-2,1.09-3,1.63-.78.39-1.86-.85-2.47-.5-1.19.7-2.4,3.5-3.24,4.73-.61.89-2.74.5-3.87,1.91s-1.91,2.93-3.28,3.74c-4.73,2.79-5.56,4.06-8.12,9.26-1.19,2.46-.42,6.81.72,9.27A87.46,87.46,0,0,1,435,595.87c.7,2.38,1.32,8.52-.41,10.23-1.3,1.32-2.41,3.06-3.93.91-.48-.67-3.27-3.18-3.32-3.4a30.85,30.85,0,0,0-2.09-5.11c-.82-1.85-1.76-2.93-1.2-5.12-.34.28-.68.58-1,.86-.83-2.82,1.76-6.86-1-8.8-2.48-1.71-3.83-5.09-6.75-4.15-1.58.51-3.24,1.67-4.71.7-1.31-.86-3-2.51-4.5-2.93-2.57-.7-6.9,2.73-7.65-1.64-.48,3.81-8.92,1.06-11.4,3,1.74.17,8.2,1,3.37,3.29.51.26,3.14,1.17,3.22,1.64.32,1.35-.85,1.91-1.77,1.73.68-1.76-1.92-2.42-3.17-3.2.27,1.24-.27,1.66-.3,2.6-1.18-2.45-2.22.11-3.81-1.1-2-1.52-2.9-2.95-5.23-2.13-1.32.46-3.19-.78-4.43-1.27-2.39-.89-6.16,1.82-8.45,2.79-3.75,1.54-12.72,8.19-12.76,13.58,0,1.66,2.19,3.36,2.29,5,.07,1.12-.84,3-1.14,4-.82,2.94-2.12,6-2.1,9.07,0,7.78,1.05,13.36,5.34,19.86,2.53,3.81,3.48,6.47,7.62,7.68.85.28,2.21,2.41,2.94,2.14,1.71-.67,3.41-1.31,5.12-1.92a15.11,15.11,0,0,1,4.57-1c1.23-.1,2.2,1.5,2.82,1.22a9.75,9.75,0,0,0,2.16-1c.4-.35-.6-1.38,0-1.92,1.48-1.33,2.2-1.8,2.77-3.77,1-3.29.68-7.15,4.17-8.53,1.45-.58,6.21-1.73,7.69-1.53,2,.24,7.58-.92,5.81,3.32-.71,1.67-3,6.65-4.21,6.75.63.35.27,1,1.68.93-.54.45-.94,1.08-1.48,1.46l.27.36c.26-.19.51-.36.78-.53a32.93,32.93,0,0,0-1.65,6.1,4,4,0,0,1-1-3.55,11.54,11.54,0,0,0-1.38,2.33c2.63.12-.38,5.17.5,7,.79,1.69-2,4.82-3.19,5.89,3.73,1.3,7.34.3,11.44.93,1.59.21,2.75-1.2,4.33-.93,1.75.22,4.13.11,5.77.83,3.48,1.52,5.71,4,5.09,8-.43,2.6-.83,5.17-1.23,7.76-.24,1.51-1.46,2.81-1.66,4.25-.87,7,7.63,18.48,14,15.87,4-1.61,6-3.22,10.1-2s5.56,3.38,8.53,6.66c-.21-5,6-11.73,8.34-15.76.73-1.24,5.34-2,6.57-2.45,3.34-1.18,6.7-2.41,10.07-3.61,3.06-1.12,8.62,1.56,11.65,2.27,8,1.86,15.88,3.68,23.84,5.55,4.3,1,8.65,1.06,12,4.24,6.2,6,12.39,11.9,18.59,17.86,3.92,3.74,12.48,3.83,17.45,5.06,4.67,1.16,8.33,8.91,11.27,12.76s6,7.81,9,11.71c.71,1,2.32,4.07,3.43,4.47l19.15,6.91,19.17,6.93c5.28,1.93,10.77,7.75,15.47,11.12.87.1,6.8.17,6.95.83.64,2.87,1.32,5.71,2,8.55Zm-205-272.18h0c0,2-6.48,3.57-8.4,3.49-2.85-.11-3.14,0-5.38,2-1.45,1.29-2.44,2.73-4.48,1.73a3.55,3.55,0,0,1,2.76-2.68c-.73-1.1-.87-.28-1.26-1.74a36.26,36.26,0,0,0-4,6.06c1.08.28,2.11.56,3.15.88-.23.29-.45.63-.7,1,4.28.4,6.08-1.7,9.75-3.05a33.76,33.76,0,0,0,9.22-5.38c0-1,.17-1.58-.71-2.26Zm5.57-1.36h0c3.29,3.15,10.28-2.92,6.71-4.36,1-.86,2-1.72,3-2.6-2,.82-6.3,4.06-7.76,3.44-2.57-1.15-5.86.4-8.53,1-5.66,7.38,4.28.34,6.59,2.54Zm-66.26-21.89h0c2,1,3.88-.27,5.81-.91-.17.41-.34.85-.52,1.27,4.63,2.49,11.29-7,14.78-4.23a6,6,0,0,0-3.55,3.87c1.62-.89,3.17-1,4.28.55s2.17.8,3.71,1.68c.64.34,7.34-2,8.48-2.16-.64,2.08,1.31,1.53,2.6,2.16,1,.45,1.44,2.17,2.33,3-1.62-.22-3.31-1.2-4,.74-2.32-2.71-7-1.22-8.62,1.55l-.45-.38c.24-.39.48-.73.74-1.11-.64.46-1.2.46-1.84,1.05-.08-.44-.14-.86-.19-1.29-1.63,1.67-4.41,6-4.82,8.21,1.9.4,2.8-3.24,4.33-4.24.27,1.74-1.48,4.38-2,6.22-.62,2.36-1.83,5.09-1.67,7.6.24,3.92,2.21,14,6.11,6.17,2-4.15,1.33-7,.56-11.19-.86-4.68,2.55-5.4,3.87-8.3-.09.83.07,1.82-.07,2.63,1.3-1.38.75-3.79,3.29-4-2.17-2.85,2.25-2.33,3.52-1,1.48,1.57,3.58.85,4.16,3.5a2.64,2.64,0,0,0-.79-.1c.86,1.48,1.28,4-.27,5-.31.2-2.3,2.32-2.08,3.12.39,1.44,3.95-1.83,4.79-1.79,1.92.1,2,5.11,2.29,6.63,1.08-1.24,2.16-2.43,3.24-3.62.67-.75.07-2.9.43-4,.76-2.29,3.17-4.9-.26-6.53,2.45-1.24,1.35,1.91,3.41,1.65-.31.62-.14.81-.71,1.36.57.39.56.29.77.87,1.15-1.09,3.25.46,4.49.12.19,0-.51-2.18,1.54-1-2.3-2.06-2.09-6.89-5.75-7.69-3-.67-6.77-.78-9.9-1.41-1.14-.23-7.56-2.11-7.07-3s-.11-1.47-.6-2.18.6-1.36.36-2.16c-.68-2.22-2.55-1-1.41-4.27-4.66.81-4.63-1.22-7-4.85-1.24-1.94-2.8.26-4.07-.3-1.58-.71-3.08-1.69-4.79-1.55,1.71,1.44.21,2.49-1.29,3.4a4.76,4.76,0,0,0,.86-2.42c-1.42.76-1.16,2.54-2.63,3.16a14.44,14.44,0,0,0,.64-1.67c-2.47.44-1.42,2.74-3.16,3.5l-6.29,2.79c-1.91,1.84-3.78,3.69-5.66,5.5Zm-119.12-145h0c-.62-.05-1.25-.6-1.88-.6.53-.4.91-1.11,1.49-1.46-2.17-.28-3.64,2.4-5.83,2.74-2.94.44-4.12.62-6.85-.58.76-2.31,4.26-3,6.16-3.9-4-1.47-4.95-1.84-8.88-.3-2.43.95-4.88,1.79-7.33,2.62-2.65.89-5.41,1.26-8,2.15-1.37.43-7.24.71-3,3.5l1.17-.85-.42-.83c1.73-.7,6.17-.7,8-.14a3.54,3.54,0,0,0-.47-.93,11.48,11.48,0,0,1,8.47,1.58c-1.35,2.22-5,.28-7.13.89a7.47,7.47,0,0,1,2.4,2.38,10,10,0,0,0-3.08,1.62c1.82,2.18-1.28,2.43-2.7,2.69,1.94,1.51,4.16.43,6.16,1.34,1.41.66,3.29-2.94,4.57-3.78,2.07-1.38,5.81-.29,2.84,1.64-1.18.76-1.38,1.81-1.94,2.28s-1.74.45-2.27.88c2.92,2.66,5.83-4.86,9.51-3.74a3.53,3.53,0,0,0-2.67-2.34c3-3.13,8.9,1.5,10.24-1.91a6.79,6.79,0,0,1-1.73.18c.12-2.07,1.52-1,2-2.15.41-1,.82-2,1.21-3Zm40.15,30.14h0c-3.13-1.34-8.1-2.32-11.09.1-1.15.95-1.92,2.6-2.8,3.51a6.09,6.09,0,0,1-4.54,2.37c-2,.23-5.32.08-6.3-2.49-.27-.7-3.74.12-4.71-1.66-.25-.5-3.5-1.87-3.91-1.49-.71.63,3.25,2.42,3.88,2.31-1.14,2.69,4.89,4.79,1.2,5.68-1.15.3-2.17-.66-3,.61s-.37,1.86-1.95,2.21a7.36,7.36,0,0,1,.74.62c-1.21,1-2.64,0-4.14,0,.06.26.12.54.16.8-1.55.05-2.76-.82-4.25-.69,2,2.67,7,3.26,10.05,3.75,1.93.3,9.45-.8,8.2-3.29,2.36-2.06,3.77-1.39,6.34-2.57,1.45-.66,3-2.69,4.26-3.82a10,10,0,0,1-1.1.08c1.6-1.46,2.54-2.4,4.42-2.89,1.63-.42,2.7.29,4.1-1.27-1.24.56-1.4.35-2.57,0,1.11-.28,2.26-.59,3.43-.85a4.2,4.2,0,0,1-3.07-.62c.82.07,1.69-.06,2.53.07-3.07-1.07-5.76,1.08-8.64,2.87,1-3.57,10.58-5.74,11.08-1.63a14.55,14.55,0,0,0,1.68-1.74Zm52.08,81h0c.28-1.94.08-1.05,1.25-1.71-.07.51-.19,1-.27,1.5a1.75,1.75,0,0,0,.5-.88c1.5.56,1.06,2.52.88,4,.42-.87,1.22-1.8,2.21-1.3.72.34-.59,2.32-.81,3.12a7.54,7.54,0,0,1,1.74-.91c-1.75,1.18-2.12,3.58-1.49,5.69s1.85-.34,1.74-1.45c.39.23.83.23,1.2.45-.83-1.81.7-3.82-.53-4.87s-2.09-3.93-2.58-5.25c-.94-2.43-5.61-12.62-3.54-13.81l-.5-.2c-.67.83-.83.69-1.8.87a2.85,2.85,0,0,1,1.94-2.17,11.62,11.62,0,0,0-1-.88c-1.49,2.69-1.46,3.5.69,5-1.66-.74-4.8-2.34-5.49.31-1.23,4.49-.5,3.61,2.78,4.46-3.81.83.85,5.35,1.81,7.24l1.32.75ZM35.18,385h0c-3.14-1.32-4.69,1-8,.63,1.39,2.16,3.52,2.53,5.69,3.3.36-1.18,1.67-.83,2.91-1,0-.27-.06-.53-.1-.8-.16-.93-1-.83-.46-2.17Zm189-100.42h0c2.89,1.44,5.22,2.36,7.39,4.86,3.5,4,3.05,4,7.51,1.42.68-.4,1.38-.82,2.08-1.22s.44,1,.89.93a29,29,0,0,0,4.38-2l1.29-6.37c2.06,1.36,4.25-.37,4.83-2.59.5-1.95,1.48-1.87,3.21-2.63,3.74-1.65,9.67-2.85,12.81-5.61,2-1.79,1.85-2.71-.44-4.32a27.22,27.22,0,0,0-5-3.29c-3.65-1.48-7.56-3-10.7.51.24-.55.18-1.27.38-1.83-4.23,1.21-8-3.76-11.91-3.2-4.67.69-9.37,1.33-14.05,2,.79,1.45,4.28,6.1,3.51,6.82-1.57,1.48-5.39,5.11-3,7.15-4.12.39-1.08,1.93-2.62,3.94-1.3,1.68-3.46,3.38-2.89,5.85a9.76,9.76,0,0,0,2.35-.44Zm18.15-39h0c2.39.33,1.11-1.6,1.81-2.3,1.35-1.27,3.18.51,2.81,2.95,1.23-.42,3.13-.6,4-1.65s-1.71-3.21,0-4c1-.47,1.8,3.26,3.61,1.21a1.67,1.67,0,0,0-.9-2.82c1.53-.95,3,.38,3-2.32,0-1.3,2.09-1.09,2.71-.46-3.52,2.29-.07,5.83,3.05,5,2.07-.56,7.52-4.59,3.69-6.54a4.77,4.77,0,0,1,2.51-.51c-5-.91-.53-3.18,1.59-4-3.23-1.75-4.42-3-7.81-1.72.56.32.69.77,1.49,1-1.49,1.41-2.91.38-4.53-.23-1.18-.43-3,.23-4.19.38-3.27.44-4.45,1.79-7.1,4-1.76,1.51-5.1,5.73-7.37,6-3.65.39-6.41,1.49-3.4,5.22,1.68.25,3.34.48,5,.71Zm36.39-21h0c-3.14-2.77-3.18-3.11-7-1.62,1.37,1,2.73,1.89,4.11,2.83l2.87-1.21ZM93.66,402h0c1.51,1.09,3.61-.56,4.26-1.55.25.23.49.48.74.7.26-.36.53-.7.77-1l-3-1.28A5.05,5.05,0,0,0,93.66,402ZM194,432.05h0c.25-2.69-6.33-1.72-6.39-1.14-.3,3.4,7.07,16,9.57,12.95-.72-.68-1.46-1.34-2.2-2-.74-3.55-1.37-6.18-1-9.8ZM90.25,405.48h0c-4.21-2.54-4.81,6.31-.43,6,1.25-.09,2.25-2.2,3.81-2.4s2.63-.91,2.54-2.69c1.11.53,1.88.18,2.37-1-.43-.1-.84-.2-1.26-.28,1-2.78-7.46-3.3-7,.44Zm140.8,59.61h0c-.58-1-2.43-1.32-3.41-1.65-1.48-.47-1.69-1.49-2.5-3-2.43-4.42-3.16-3.44-7.55-4.89-3.46-1.17-4.59-2.78-8.16-1.65C215.2,461,221.32,465,229,469.18c5,1.79,4.43,0,2-4.09ZM1043.2,808.21h0c-1.21-1.69-5.12-7.75-5.38-1.92-.18,4.63-1.46,4.66-4.33,7.93-2.3,2.64-3.36,5.16-6.37,6.69a31.81,31.81,0,0,1-9.37,3.44c-1.35.22-2.83,6.34-2.46,8,.66,2.87,2.68,7.55,2.34,10.48-.35,3.17-3.92,6.3-4.91,9.34-1.21,3.68-.38,6.36.6,9.87a81,81,0,0,1,1.86,10c.21,1.27,5.9,3.38,7.09,2.83.81-.4,6.82-2.19,6.93-2.52.75-2.56,1.53-5.14,2.3-7.69q4.17-14,8.37-28c1.9-6.32,2.33-9.22,1.8-15.92.79.8,1.61,1.61,2.41,2.39,2.09-5.06.35-9.24-.73-14.66l-.15-.24Zm327-152.81h0c-1.08,2,.16,5.08.57,7.3.29,1.75,2.66,1.94,4.08,2.49-3,1.55-.92,4.38,1.42,4.68,2.12.26,1.34-1.47,4,0a7.57,7.57,0,0,1,2.21,2.57c.21-1.26.43-2.49.63-3.73,2.56,1,3,.62,3.07,3.63,0,1.1,2.89,2.37,3.79,3,1.5-3.26-1.81-2.36-1.66-5.3,2.23,1.14,3.81-.09,1.86-2.12-.92-1-1,1.12-1.79.91a14.69,14.69,0,0,1-2.84-1.73,8.07,8.07,0,0,0-2.69-1c-1.19-.27-1.4,1.64-2.25,1.6-2.44-.12-1.51-2.49-2.4-4.25-1.74-3.47.52-2.3.36-5.45-.06-1.22,1.71,0,2.12-.61a11.67,11.67,0,0,0,.84-2.93c1.15-3.73-.16-2.13-.84-5.41-.37-1.72,1.66-2.55.55-4.93-3.51,1.74-2-.08-5-.7-1-.21-3,.51-3.2,1.61-.47,2.85-1,5.73-1.42,8.58-.25,1.57,1.34,2,.84,3.78-.74-.68-1.47-1.32-2.22-2Zm8.22-39.85h0c.57-2.6,3.14-9.32-1.73-7-2.74,1.28-5,4.84-5.69,8.18-.73,3.69,1.73,6.12,3.55,8.85a38.63,38.63,0,0,0,3.87-10ZM1367.57,681h0c-.83,3.86-1.21,5.92-4,8.52a28.36,28.36,0,0,0-6.2,8c3.64-2.24,7.14-3,7.91-7.63.18-1.24,3-2.65,4-3.38.26-.19-.64-3.26-.34-4.25a7.86,7.86,0,0,0-1.4-1.3Zm31.17,11.81h0a3.85,3.85,0,0,0-2.77-2.88c.21,1.37.44,2.7.65,4.06-1.58-.27-1.27-.49-2,.56-1.54-1-2.05.17-1.85,2-2.09-1.55-3,2-5,2.72,1.13-1.37,1-3.68-1-3.8-2.27-.14-1.46,2.93-2.66,3.28-2.2.66-6.17,3.23-3.88,6.46,1-.86,3.06-7.66,3.89-2.71.45-1.18.63-.86,1.3-1.61.14,1.48.14,1,1.25,1.77-.23-.66,0-1.49-.14-2.15,5.12-.69,1.73,4.15,2.71,6.71.63,1.64,4.74,4.68,5.48,2l.42,0c-1.09,3.54,2.48,2.16,1.84-.9-.49-2.28-1.91-3.8.75-5.74,1.32,1.8.51,3.66,1.65,5.49.07-1.08.12-2.16.17-3.24.26.18.52.32.79.49.34-1.46,2.15-6.89,0-7a4.34,4.34,0,0,0,.07-1.72c-.63,0-.89-.4-1.26-.44.32-.36.67-.71,1-1.05.2-1.24-.17-2.91-1.43-2.37Zm-25.13,98.69h0c-.87-2.05-7.91-4.63-7.69-1,2.34.93,9.69,5.66,7.69,1Zm-15.11-6.69h0c-.68-1-3.36-1.85-4.34-1.87-2.23-.06-2.07,1-3,3.13,4.61,1.5,7.67,1.14,12.33.36,6.81-1.15-.49-4.91-3.35-3.82.75,1.55-.16,2.17-1.62,2.2Zm19.76,2h0c.82-.09,1.06-1.11,2-1,2.1.37,3.08-1.68,4.39-1.71,2.84-.06,7.85,1.34,10.24-.84-3.43-1.29-5.48-.13-8.93-.39-2.07-.14-2.24.06-3.9,1.51-.91.8-2-.92-3.08-.33-2.15,1.27-6.65-2.62-8.77-.23-2.43,2.69,4,2,5,3.08,1.66-1.44,2,0,3.06-.14Zm2.89-18.8h0c.9.82,1.81,1.65,2.71,2.5,1.06-1.61,2.2-2.14,1-3.73-.82-1.16.12-2,1.15-1.78-.75-2.53-2.54-1.57-2.28.73-1.13-3.32-2.36,1.06-2.61,2.28Zm-62.24-30.68h0c-.14,1.12,1.24,2,1.48,3.07.14.6-1,.89-.74,1.69s.56,1.71.81,2.6c.36,1.23,1,.14.64,2.18,1.45-.7,1.23-.07,1.66-1.48,2.44,2.13,2,6.69,2.34,9.8.28,2.74,5.58.54,6.9-.09.2,1.23.4,2.48.61,3.7,4.12-2.32,4.55-3.26,8.55-.74.64.38,2.09-.26,3.07.1s1.14,2.7,1.42,3.78c2.16-1.08,4.33-2.18,6.51-3.23-.44,1.44-.4,2.72,1.12,2.54.07-3.12.13-6.18.17-9.28.06-2.88.81-3,2.94-4.84,2.9-2.55,2.88-2.52,2.59-6.62-.11-1.85,1.19-5.17,2.87-4.82,3.4.74,4.93.23,1.82-2.63-.75-.72-2.46-1.71-2.94-2.71-.29-.59.67-1.86.43-2.53-1.3-3.7-2.63-3.44-2.52-7.76.06-2.1,4.31-2.07,5.57-2.31-.67-.91-1.33-1.84-2-2.76,1.67-.46,3.3-1,4.93-1.38-.55-1.49-1.4-1.3-2.78-1.65-1.08-.25-1.93-2-2.62-2.91-1-1.24-4.49-4.66-5.81-4.48s-4.68,5.32-5.72,6.49c-1.88,2.15-.25,3.8-3,4.51-3.38.87-3.92.87-5.92,3.91-1.41,2.15-2.27,4.46-4.61,5.23-2.58.83-4.86.87-6.31,3.37-1.87,3.17-2.55,3.09,0,5.64-2.42-.62-7.23-.47-7.78-3.82-1,.59-2,1.23-3.06,1.85-.19,1.85-.45,3.71-.68,5.58Zm73.23,55h0c1.08-1.48,1.61-2.44,3.13-3.16,2.35-1.1,8.21-2.6,9-5.58a58.85,58.85,0,0,0-6.52.75,15,15,0,0,0-3,.63c-.54.27-.54,1.41-1.15,1.69-1.89.91-4,1.54-5.56,3-1.73,1.61,1,2.49-1.15,4.45,1.78-.37,4-.14,5.2-1.77ZM469.7,646h0c1.08.17,2.81-.45,3.78,0,.72.38.43,3.72,2.37,3,.88-.3.88-3.37,1.68-3.93,1.41-1,1.78.4,2.26.39,2.5-.08,4.25-.91,7.08-.91,2.1,0,1.68,1.85,3.14-.6.58-1-1.58-2.3-2.55-2.52-2.34-.49-2.47-.49-3.63-2.79-.89-1.7-1-.55-2.52-1.06-1.14-.36-3-1.58-4.14-1a10.55,10.55,0,0,1-3.06.82c-3.45-.06-4.4-1.13-7.7.41,3.44,1.63,3,2.72,5.19,5.9-2.07,1.54-10.73-2-9.7,1.12,2.94,2.09,4.14.53,7.8,1.09ZM738.08,353.18h0c2.57.72,4.18-1.32,4.08-4.18,2.08,1.14,3.2-.94,4.66-2.37-1.72-1.17-.41-3.61-1.29-4.15-1.75-1-3.14-2.33-5.22-1.56,2.54-4.26-9.79-9.28-7.63-3.71-3.68-.37-4.66,1.47-8.2-.13.2,1.35.37,2.67.58,4-1.39-2-1.83-3.68-4.15-3.74-1.86-.06-2.59,2.05-2,3.79-1.32-1.4-2.49-3.73-4.46-3.29,1.56,3.72-.47,1.86-1.48,3.51a38.39,38.39,0,0,0-1.85,4.3,46.75,46.75,0,0,1-2.75-4.46,1.6,1.6,0,0,0,2-1.69c-.09-1-2.16-1.4-2.68-1.84-2.69-2.32-2.52-2.88-6-2.83.46,1.76,1.71,1.4,3.26,1.67.48,4.58-4.17-.51-5.63,1.28-1.76,2.16,1.43,2.09.91,3.14s-2.06.23-2.93-.3c0,.49,0,1-.06,1.49-1.32-.21-1.06.2-2.12.76,3,1.3,3.87.68,7-.54,1.45-.57,4.48.88,6,1.23-1.27.61-2.52,1.24-3.77,1.86a3.77,3.77,0,0,0,3.61.29c0,.33.07.68.1,1-3.68-.1-7.33,1.39-10.63,1.34.54,2.73,6.52,1.38,8.56,1.38-1.09,1.19-.46,2.18,1.05,1.95-.09.4-.16.77-.23,1.16l1.15.12c-.91,2.64-5.36,1.82-4.23,4.84,2.91-.35,5.81-.74,8.71-1.12.77-.1,1.45,2,2.09,2.41.95.61,2.86.64,3.92.87,2.39.53,4.34.75,6.68-.42,1.14-.56.86-1.55,2.25-1.74l4-.57c1.55-1,5-4.27,6.75-3.79Zm-30.43-57.95h0c-.54-2.19-2.77-7.28-2-9.46,1.93-5.55,3.07-12.57,6.94-16.82,2.55-2.86,5.14-5.7,7.74-8.56.71-.79-1.09-7.34-1.26-8.45-.42-2.48-.15-6.43-2.22-7.85-2.59-1.76-5.18-3.54-7.78-5.29l11.33-11.1c-4-2.69-6.55-3.77-8.48-8.41-1.48-3.54,3.11-8.14,4.93-11.15,2-3.32,5.78-4.7,8.82-6.81a43.23,43.23,0,0,0,8.81-7.87c-1-.84-2-1.7-3-2.53,3.48-.7,7.46-.83,10.62-2.65,3.93-2.29,7.89-4.56,11.84-6.85-4.33-1.7-9.13-4.52-13.65-5.32-3.28-.59-10.06-1.31-12.32,1.51-1.43,1.81-2.44,4.45-4.72,4-2.73-.43-5.46-.9-8.19-1.35-3.11-.52-9.32,3.78-12.32,5.06.47-.9,6.27-10.06,2.12-10.19-3.63-.12-7.08.6-10.11-1.85,4.91-1.76,9.79-3.54,14.7-5.32-9.55-4.19-18-8.51-28.18-9.93-11.35-1.59-22.11-3.72-33.48-2.72l-12.2,1.07c-1.37.12-4.2-.24-5.47.49-1.94,1.12-2.21,5.6-4.76,5.15-3.25-.56-6.48-1.15-9.75-1.71-4-.69-8.69-2.72-12.43-1l-16.5,7.55c5.19,3.33,10.92,5.76,14.28,11.33a180.55,180.55,0,0,0-27.59-8.08c-2.94-.59-7.22.92-10.17,1.3-6.66.88-13.31,1.78-20,2.65-2.9.4-7.49,0-10.19,1.42-3.78,1.95-7.56,3.92-11.35,5.86l-27.94,14.41c3.43,3.78,7.59,3.18,12.37,3.71L503,207.35c-1.13,2.92-1.56,2.35-4.53,2.49a53.23,53.23,0,0,0-12,2.34q-8.14,2.37-16.31,4.71c-1.3.38-1.28,3.64-1.55,5-.21,1,2.28,3.48,2.84,4.23,1.62,2.23,3.68,6.64,6,8,3.18,1.87,6.35,3.76,9.54,5.62,1.59,1,6.07,4.83,7.9,4.59,3.6-.44,7.19-.92,10.78-1.38,6.47-.83,12.13.48,18.6,1.57,3.31.55,6.61,1.14,9.89,1.67,1.62.27,5,6.33,6.06,7.69,4.45,5.71,6.85,12.52,9.86,19.29,1.63,3.66,2.15,4,.88,7.77-1.19,3.53-3.17,5.67-.64,8.38s5.92,4.35,4.94,8.4-2.61,6.15.05,9.08c3.34,3.69,3.12,3.63,7.62,2.31,3.27-1,6.54-1.93,9.82-2.9-.31,2.47-.61,4.92-.92,7.38-.09.81-3.16,1.58-3.81,1.83-2.26,1-4.52,1.95-6.78,2.9-.51.21-.57,3.45-.63,4-.42,3.29-2.24,9-1.13,12.11q2.49,7,5,13.94c2.68,7.53,7.41,13.68,11.63,20.28,2.51,3.94,5,7.85,7.51,11.77,1.23,2,4.77,2.32,6.71,3,4,1.49,8,2.95,12,4.4,1,.36,6.49.49,6.68-.17q3.72-11.59,7.44-23.22c2-6.22,4.15-12.28,6.4-18.36,1.21-3.31,1.07-3.37,4.11-4.37l12-3.93c2.49-.82,6.18-1.26,8.43-2.77,2.52-1.72,4.77-6,6.75-8.41,1.76-2.19,2.43-3.58,4.9-4.22,3.76-1,7.53-2,11.27-3,5.41-1.43,12-2,16.93-5q9.19-5.61,18.35-11.23c2.91-3.54,3.13-3.4,2.08-7.87Zm615.11,349.38h0c1.14-.52,3.31-.57,3.56-2.3s.62-3.91,2.3-3.78c.34-1.6-.14-2.83-1.62-3.09-.07.36-.17.76-.24,1.12-4.27-2.4-6.35,1.53-9.33,3.44,0,3-.52,3.62,1.88,5a4.58,4.58,0,0,0,2.59.77c1.29.1.08-.83.86-1.16ZM1303.89,771h0c.75-3.87-.06-9,1.15-12.43,1.41-4.09-3.54-7.23-6.31-3.88,2.19-2.19.07-2.09-.27-3.92-.19-1-.33-4.26-1.17-4.63s-3.5-.81-3.66-2c-.32-1.92,1.4-2.5,1.11-3.95-.42-2.14-3.26-1.91-3.26-3.22,0-2.44-.91-1.33-2.5-2.55s.28-1.62-2.45-2.13c-1.66-.29-2.81-.13-3.85-1.55-1.92-2.65-4.83-3.51-7.19-5.77-2-1.86-5.13-3.94-6.78-6.17-2.18-3.11-1.54-4.67-5.62-5.13-1.26-.15-7.39-2.49-8-1.59-1,1.46,3.88,7.58,4.73,8.32,1.89,1.68,6,2.45,6.1,6,.16,3.91,4.69,3.14,5.64,6.71.56,2.1,1.14,4.22,1.7,6.35.39,1.46,1.79.94,2.69,1.9,2.21,2.3,3.54,7.78,4.91,10.75,1.22,2.7,3.34,4.56,5.28,6.72,3.95,4.33,7.92,8.58,12.4,12.71,0-.88.33-1.8.31-2.66,2.09,2.58,3.37-1.2,5.05,2.19Zm10.33-17.48h0c-2.51-2-1.56,3.15-1.38,4,3.3,1.08,3.46-2.34,1.38-4Zm26.67,26.71h0c-2.29.53-5.52-1.22-4.87-4.35-1.62.76-5.82.35-6.92-1.05-1.35-1.68-2.09-.8-2.64,1-.33,1.07-1.59.43-2.49.35-3.51-.37-6,.37-7.94-2.93-.29-.53-5.06-1.6-6.07-2.28-.57,1.67-2,.64-3.34.3s-1.45.25-2.44,1.43c-2.92,3.38,1,3.66,3.41,4.22-.09.47-.2,1-.29,1.4,2.93.57,5.64,2.26,8.37,2.79,1.43.28,3.09-.79,4.54-.66s3,1.11,4.36,1.58a17.44,17.44,0,0,0,3.71,1.25c1,.11,2,.27,3,.38.64.08.88-.81,1.37-.79,3,.27,4.15,1.26,7.19.68,1.82.78,3.65,1.6,5.46,2.41-2.18-2.78.62-6.89-4.42-5.76ZM1301.13,751h0a2.41,2.41,0,0,0,2.23.53c.54,0,.89,1.27,1.39,1.84.68.75.29,1.29,1.17,2a4,4,0,0,0,2.69,1.17c-.78-.92-.63-1.81.44-2.67-4,.14-2-5.81-5.19-5.52.06.47.13.9.22,1.33-1.37-2.09-2,0-2.95,1.29Z"/><path class="cls-4" d="M976.46,587c56.28-18.2,100-52.52,132.19-153.23,21.2-66.29,8.4-122,8.4-122"/><polyline class="cls-5" points="985.42 567.73 974.38 589.78 1000.05 591.11"/><path class="cls-6" d="M929.44,431.46c8.39-44.85.2-86-15.28-120.68s-75.23-79.94-75.23-79.94"/><polyline class="cls-5" points="921.29 410.23 928.77 433.73 948.09 416.77"/><path class="cls-4" d="M799.74,428.33c-26-31.83-75.23-55.64-111-64.68-67.48-17-122-8.4-122-8.4"/><polyline class="cls-5" points="777.91 421.66 800.98 430.38 799.66 404.7"/><path class="cls-4" d="M764.06,543c-50.94-18.8-118.86-24.72-197.53,15.82-61.86,31.88-92.18,80.3-92.18,80.3"/><polyline class="cls-5" points="740.72 547 765.13 543.5 751.59 521.65"/><path class="cls-4" d="M756.93,629.34C702.39,649,649.19,687.81,618.55,783.61c-21.2,66.29-8.4,122-8.4,122"/><polyline class="cls-5" points="743.44 647.79 758.83 628.52 734 621.88"/><path class="cls-4" d="M887.33,728.12c24.26,45.2,67.48,90.74,144.3,115.31,66.29,21.2,122,8.4,122,8.4"/><polyline class="cls-5" points="906.72 739.61 886.53 725.44 881.44 750.63"/><path class="cls-4" d="M981.75,681.65c50,16.62,125.51,22.89,200.36-15.68,61.86-31.88,92.18-80.3,92.18-80.3"/><polyline class="cls-5" points="1004.09 676.36 979.01 680.67 994.09 696.93"/><path class="cls-7" d="M869,701.45c-23.77,0-47.55-5.23-65.66-15.68-17.51-10.11-27.16-23.55-27.16-37.84s9.65-27.72,27.16-37.83,40.84-15.69,65.66-15.69S917.1,600,934.63,610.1s27.16,23.55,27.16,37.83-9.64,27.73-27.16,37.84C916.53,696.22,892.75,701.45,869,701.45Z"/><path class="cls-8" d="M946,635.4V618.31h-5.91c-3.76-5.23-9.3-10.12-16.65-14.37-30.1-17.37-78.88-17.37-109,0-7.35,4.25-12.9,9.14-16.65,14.37h-5.91V635.4h0c0,11.39,7.52,22.77,22.57,31.46,30.09,17.37,78.88,17.37,109,0C938.5,658.17,946,646.79,946,635.4Z"/><ellipse class="cls-9" cx="868.97" cy="618.31" rx="77.05" ry="44.49"/><path class="cls-7" d="M940.13,617.65V594.32h-5.46c-3.47-4.83-8.59-9.34-15.38-13.27-27.79-16-72.85-16-100.64,0a48.43,48.43,0,0,0-15.38,13.27h-5.46v23.33h0c0,10.52,7,21,20.84,29.05,27.79,16,72.85,16,100.64,0C933.19,638.68,940.13,628.17,940.13,617.65Z"/><path class="cls-10" d="M940.13,612V588.7h-5.46a48.53,48.53,0,0,0-15.38-13.26c-27.79-16.05-72.85-16.05-100.64,0a48.53,48.53,0,0,0-15.38,13.26h-5.46V612h0c0,10.52,7,21,20.84,29.06,27.79,16,72.85,16,100.64,0C933.19,633.06,940.13,622.55,940.13,612Z"/><ellipse class="cls-11" cx="868.97" cy="594.32" rx="71.16" ry="41.08"/><path class="cls-12" d="M946,593.94V576.85h-5.91c-3.76-5.22-9.3-10.12-16.65-14.36-30.1-17.38-78.88-17.38-109,0-7.35,4.24-12.9,9.14-16.65,14.36h-5.91v17.09h0c0,11.39,7.52,22.77,22.57,31.46,30.09,17.37,78.88,17.37,109,0C938.5,616.71,946,605.33,946,593.94Z"/><ellipse class="cls-9" cx="868.97" cy="576.85" rx="77.05" ry="44.49"/><path class="cls-7" d="M940.13,575.33V552h-5.46a48.53,48.53,0,0,0-15.38-13.26c-27.79-16-72.85-16-100.64,0A48.68,48.68,0,0,0,803.27,552h-5.46v23.33h0c0,10.52,7,21,20.84,29,27.79,16,72.85,16,100.64,0C933.19,596.36,940.13,585.85,940.13,575.33Z"/><path class="cls-10" d="M940.13,570V546.66h-5.46a48.53,48.53,0,0,0-15.38-13.26c-27.79-16-72.85-16-100.64,0a48.53,48.53,0,0,0-15.38,13.26h-5.46V570h0c0,10.51,7,21,20.84,29,27.79,16,72.85,16,100.64,0C933.19,591,940.13,580.51,940.13,570Z"/><ellipse class="cls-9" cx="868.97" cy="552" rx="71.16" ry="41.08"/><path class="cls-13" d="M946,551.63v-17.1h-5.91c-3.76-5.22-9.3-10.11-16.65-14.36-30.1-17.37-78.88-17.37-109,0-7.35,4.25-12.9,9.14-16.65,14.36h-5.91v17.1h0c0,11.38,7.52,22.77,22.57,31.45,30.09,17.38,78.88,17.38,109,0C938.5,574.4,946,563,946,551.63Z"/><ellipse class="cls-9" cx="868.97" cy="534.53" rx="77.05" ry="44.49"/><path class="cls-7" d="M940.13,533V509.68h-5.46a48.53,48.53,0,0,0-15.38-13.26c-27.79-16.05-72.85-16.05-100.64,0a48.53,48.53,0,0,0-15.38,13.26h-5.46V533h0c0,10.51,7,21,20.84,29.05,27.79,16,72.85,16,100.64,0C933.19,554.05,940.13,543.53,940.13,533Z"/><g class="cls-14"><path class="cls-10" d="M940.13,526.49V503.15h-5.46a48.53,48.53,0,0,0-15.38-13.26c-27.79-16.05-72.85-16.05-100.64,0a48.53,48.53,0,0,0-15.38,13.26h-5.46v23.34h0c0,10.51,7,21,20.84,29,27.79,16,72.85,16,100.64,0C933.19,547.52,940.13,537,940.13,526.49Z"/></g><ellipse class="cls-11" cx="868.97" cy="509.68" rx="71.16" ry="41.08"/><path class="cls-15" d="M946,509.31v-17.1h-5.91c-3.76-5.22-9.3-10.11-16.65-14.36-30.1-17.37-78.88-17.37-109,0-7.35,4.25-12.9,9.14-16.65,14.36h-5.91v17.1h0c0,11.38,7.52,22.77,22.57,31.46,30.09,17.37,78.88,17.37,109,0C938.5,532.08,946,520.69,946,509.31Z"/><ellipse class="cls-11" cx="868.97" cy="492.21" rx="77.05" ry="44.49"/><ellipse class="cls-11" cx="868.97" cy="492.21" rx="77.05" ry="44.49"/><path class="cls-16" d="M946,509.31v-17.1h-5.91c-3.76-5.22-9.3-10.11-16.65-14.36-30.1-17.37-78.88-17.37-109,0-7.35,4.25-12.9,9.14-16.65,14.36h-5.91v17.1h0c0,11.38,7.52,22.77,22.57,31.46,30.09,17.37,78.88,17.37,109,0C938.5,532.08,946,520.69,946,509.31Z"/><ellipse class="cls-11" cx="868.97" cy="492.21" rx="77.05" ry="44.49"/><ellipse class="cls-9" cx="868.97" cy="492.21" rx="77.05" ry="44.49"/><path class="cls-17" d="M923.46,522.29c-30.09,17.37-78.88,17.37-109,0-14.75-8.51-22.25-19.61-22.54-30.77-.31,11.62,7.19,23.29,22.54,32.15,30.09,17.37,78.88,17.37,109,0,15.35-8.86,22.85-20.53,22.54-32.14C945.7,502.68,938.2,513.78,923.46,522.29Z"/><g class="cls-18"><g id="icons"><g id="Layer_3-2" data-name="Layer 3"><path class="cls-19" d="M458.53,723.94c-16.84-3.11-28.22-11.29-28.22-18.49s.42-27.75.42-27.75l-20.59-.38h-.21l-20.6.38a259.53,259.53,0,0,1,4.21,28.3c0,7.2-7.45,16-23.54,17.94-16,3.29-21.06,18.92-21.53,28.69l61.84-3.37h67.47C477.15,739.49,471.34,730.6,458.53,723.94Z"/><path class="cls-20" d="M410.56,716.53a30.3,30.3,0,0,0,19.88-9.69,8.07,8.07,0,0,1,0-1.39c0-7.16.42-27.75.42-27.75l-20.6-.38h-.21l-20.59.38a259.53,259.53,0,0,1,4.21,28.3,10.52,10.52,0,0,1-.42,3A29.46,29.46,0,0,0,410.56,716.53Z"/><path class="cls-19" d="M448.05,665.35a12.84,12.84,0,0,0-4.22-10.48c.43-7.5.51-17.23-4.21-21.06-5-16-21.65-16.22-35.34-16.22s-23.12,6.07-28.43,21.06a39.13,39.13,0,0,0,.47,15.8,12.62,12.62,0,0,0-4.22,10.61c0,6.23,2.91,11.29,6.45,11.29h0c5.05,24,22.2,34.33,32.05,34.33s26.71-10.16,31.55-34.42C445.43,676,448.05,671.25,448.05,665.35Z"/><path class="cls-21" d="M404.28,617.59c-13.26,0-23.08,6.07-28.43,21.06a39.13,39.13,0,0,0,.47,15.8c1.93,1,1.89,4.21,2.56,9,.76,1.48,3.12.59,3.12.59a66.76,66.76,0,0,1,1.14-9.77c-1.85-6.49-1.31-8.43,3.37-10.32a82.65,82.65,0,0,0,45.28-2.11,8.44,8.44,0,0,1,3.54,9.9,48.79,48.79,0,0,0,.88,15.8c.29,1.3,1.64,1,2.36.59a23.16,23.16,0,0,1,5.35-13.69c.42-7.5.46-17.15-4.21-21.06C434.61,617.84,418,617.59,404.28,617.59Z"/><path class="cls-22" d="M434.06,763.2c20.85-1,37.32-3.45,44-6.57-1.44-9.18-4.72-25.27-10.49-29.23a305.36,305.36,0,0,0-29.95-11.33l-5.05,10.32-13.82,6.1L413,734.77l-9-1.27s-13.14-17.22-15.25-17.6c-5,4.93-28.18,11.2-28.18,11.2-5.68,4.21-11.33,13-12.63,29.49,6.7,3.07,23.12,5.51,43.93,6.52Z"/><path class="cls-23" d="M435.33,715.52a37.19,37.19,0,0,1-20.39,21.06,32.75,32.75,0,0,1,14.36,16.47s9-23.21,9-34.37A8.42,8.42,0,0,0,435.33,715.52Z"/><path class="cls-23" d="M391.35,715.52a37.17,37.17,0,0,0,20.43,21.06,32.7,32.7,0,0,0-14.4,16.47s-9.06-23.21-8.81-34.37A8.47,8.47,0,0,1,391.35,715.52Z"/><path class="cls-24" d="M420.79,763.62l-3.58-22.7-9,.46-3.58,22.24h16.21Z"/><path class="cls-23" d="M407.86,742.48a3.8,3.8,0,0,0,1.94.59h5.06a4.26,4.26,0,0,0,2.48-.93l-.13-1.22-9,.46Z"/><rect class="cls-25" x="405.72" y="733.76" width="13.18" height="8.38" rx="4.04"/><path class="cls-26" d="M391.1,712.7a37.16,37.16,0,0,0,20.39,21.06,32.72,32.72,0,0,0-14.37,16.47s-9.05-23.13-8.8-34.58A8.36,8.36,0,0,1,391.1,712.7Z"/><path class="cls-27" d="M435.58,712.7a37.17,37.17,0,0,1-20.43,21.06,32.71,32.71,0,0,1,14.41,16.47s9-23.13,8.71-34.58A8.37,8.37,0,0,0,435.58,712.7Z"/><path class="cls-28" d="M481.19,753.55a.53.53,0,0,0,0-.25c-3.24-9.35-8.42-22.36-13.64-25.9A162.63,162.63,0,0,0,443,717.88v44.77C465.57,761,481.19,757.55,481.19,753.55Z"/><path class="cls-29" d="M382.34,762.61v-43a140.53,140.53,0,0,0-24.52,7.75c-5.26,3.66-10.19,17.39-13,26.74C346.24,757.85,361.11,761.05,382.34,762.61Z"/></g></g></g><g class="cls-30"><g id="icons-2" data-name="icons"><g id="Layer_3-3" data-name="Layer 3"><path class="cls-21" d="M815.83,107.61c-7.41-20.17-17.52-26.95-35.89-25.94s-33.69,9.6-40.22,34.33c-6.62,25.86,5.52,52.52-12.34,79.81-2.78,4.21,101.08,0,101.08,0C816.46,169.23,832.72,153,815.83,107.61Z"/><path class="cls-19" d="M828.09,190.08c-16.85-3.11-28.27-11.28-28.27-18.49s.47-27.75.47-27.75l-20.64-.38h0l-20.6.38a257.47,257.47,0,0,1,4.21,28.3c0,7.2-7.45,16-23.58,17.94-16,3.29-20.85,18.92-21.49,28.69L780,215.4h67.35C846.66,205.63,840.85,196.74,828.09,190.08Z"/><path class="cls-20" d="M780.11,182.67A30.21,30.21,0,0,0,800,173a8.07,8.07,0,0,1,0-1.39c0-7.16.46-27.75.46-27.75l-20.64-.38h0l-20.59.38a259.89,259.89,0,0,1,4.21,28.3,12.21,12.21,0,0,1-.42,3A29.47,29.47,0,0,0,780.11,182.67Z"/><path class="cls-31" d="M836.93,193.54a289.61,289.61,0,0,0-28.22-10.78h0s-7.92,24.05-26,24.05S758.21,182,758.21,182c-4.93,4.93-28.14,11.12-28.14,11.12-5.68,4.21-11.33,13-12.63,29.48,6.61,3.25,22.91,5.69,44,6.7h42.12c20.85-1,37.32-3.45,44-6.57C846,213.59,842.7,197.54,836.93,193.54Z"/><path class="cls-32" d="M850.66,219.69a.53.53,0,0,0,0-.25c-3.24-9.35-8.42-22.36-13.64-25.9A163.7,163.7,0,0,0,812.46,184v44.77C835,227.15,850.66,223.7,850.66,219.69Z"/><path class="cls-33" d="M751.85,228.75v-43a143.82,143.82,0,0,0-24.56,7.75c-5.26,3.66-10.19,17.39-13,26.74C715.71,224,730.58,227.19,751.85,228.75Z"/><path class="cls-19" d="M813.43,121v-.38c-1.18.63-3.08,2.61-3.58,9-1.81-9.27-6.57-22.2-8.89-23.42-6.57,12.26-35.09,31.51-52.61,37.91,5.35,23.08,22,33.15,31.72,33.15s26.7-10.15,31.59-34.41c3.28-.51,5.9-5.27,5.9-11.17A13,13,0,0,0,813.43,121Z"/></g></g></g><g class="cls-34"><g id="Icons-3" data-name="Icons"><path class="cls-35" d="M597.08,1032.68l-.14,5.22-23.24,6.71c-12.4,3.64-22.24,12.34-26.46,23.49l-6.14,16.24s68.38,28.18,142.69.11l-6.14-16.25c-4.22-11.14-14-19.84-26.46-23.49l-23.54-6.84.16-5.5"/><path class="cls-36" d="M628.09,1037.83c0,17.23-31.29,17.06-31.29-.15v-7.14h31.29Z"/><path class="cls-37" d="M628.09,1029.83c0,17.23-31.29,17.06-31.29-.15v-7.14h31.29Z"/><path class="cls-38" d="M621,973.29c11.31,22.18,7.19,14,12.6,23.41s1.79,27.38,1.79,27.38c15.33-10,14.28-31.66,14.28-31.66a48.11,48.11,0,0,0-11-30.12A34.86,34.86,0,0,0,622,950.77a34.11,34.11,0,0,0-19.53-.55c-15.23,3.86-28.36,18-28.36,42.14h0s-1.32,21.76,15.24,31.72c0,0-8.24-15.37-2.42-24.72s22-3.92,34.18-26.05"/><path class="cls-38" d="M626.31,940.56a13.59,13.59,0,0,1-4.35,10,34.11,34.11,0,0,0-19.53-.56,13.51,13.51,0,0,1-3.81-9.48,13.85,13.85,0,1,1,27.69,0Z"/><path class="cls-36" d="M621,972.19a38.91,38.91,0,0,1-21.86,18c-15.5,5-17.49,5.29-17,15.81s11.3,29.65,27.57,31,26.81-9.07,30.52-23.87.6-17.45-4.77-21.49S622.38,976.58,621,972.19Z"/></g></g><g class="cls-39"><g id="icons-4" data-name="icons"><g id="Icons-5" data-name="Icons"><path class="cls-40" d="M1145.55,259l-6.6-67.86c-1.81-18.6-16.53-32.65-35.26-32.83h-.89c-18.78.17-34.65,14.3-36.39,33l-6.36,66.89"/><path class="cls-41" d="M1088.33,240.3l-.39,4.84-21.43,6.26c-11.56,3.39-20.75,11.49-24.68,21.86l-5.74,15.13s63.8,26.23,133.14.1l-5.74-15.13c-3.93-10.38-13.07-18.47-24.68-21.87l-21.43-6.25L1117,240"/><path class="cls-42" d="M1117.75,244.92c0,15.11-29.9,15-29.9-.13v-6.27h29.9Z"/><path class="cls-43" d="M1128.74,222.33c3.56.67,4.46-4.06,5.5-8.57a23.25,23.25,0,0,0,.88-6.1,3.21,3.21,0,0,0-4.31-2.61l-2.89,1v-8.11h-50.66V206c0-.25-3-1.28-3.32-1.38a3.24,3.24,0,0,0-3.45.43c-2,2-.66,6.29-.11,8.67,1,4.51,1.94,9.24,5.5,8.57,3.5,12.56,13.95,22.47,26.33,22.47,12.6,0,23.23-9.46,26.53-22.38"/></g></g></g><g class="cls-44"><g id="icons-6" data-name="icons"><g id="Layer_3-4" data-name="Layer 3"><path class="cls-19" d="M1271.77,900.44c-16.85-3.12-28.26-11.29-28.26-18.49s.42-27.76.42-27.76l-20.6-.42h-.21l-20.6.42a257.32,257.32,0,0,1,4.22,28.31c0,7.16-7.5,16-23.59,17.94-15.92,3.24-21,19-21.65,28.69l61.83-3.37H1291C1290.34,916,1284.53,907.05,1271.77,900.44Z"/><path class="cls-20" d="M1223.75,893a30.46,30.46,0,0,0,19.88-9.69,8.07,8.07,0,0,1,0-1.39c0-7.16.42-27.76.42-27.76l-20.59-.42h-.21l-20.6.42a254.92,254.92,0,0,1,4.21,28.31,11.35,11.35,0,0,1-.42,2.9A29.25,29.25,0,0,0,1223.75,893Z"/><path class="cls-19" d="M1261.24,841.85a13,13,0,0,0-4.21-10.49c.38-7.49.46-17.22-4.22-21.06-5.09-16-21.73-16.09-35.42-16.09s-23.08,6.07-28.43,21.06a39.32,39.32,0,0,0,.46,15.84,12.68,12.68,0,0,0-4.21,10.62c0,6.23,2.91,11.24,6.49,11.24h0c5,24,22.2,34.33,32,34.33s26.71-10.15,31.55-34.41C1258.63,852.51,1261.24,847.83,1261.24,841.85Z"/><path class="cls-45" d="M1294.39,930.05a.71.71,0,0,0,0-.29c-3-8.43-7.63-20-12.3-24.64a6.78,6.78,0,0,0-1.35-1.22c-7.71-3.71-26.49-10.2-27.29-10.49-5.94,25.27-47.3,25.56-54.42,1.05-1,.55-20.22,5.73-27.93,9.44-5.26,3.66-10.19,17.39-13,26.74a5.63,5.63,0,0,0,3.07,2.44h0c10.28,4.68,23.38,5.19,34.46,6h0l9.47.59h42.16l8.93-.55h0a141,141,0,0,0,32-4.85h0c1-.33,2-.71,2.91-1.13h0C1293.25,932.07,1294.39,931.1,1294.39,930.05Z"/><path class="cls-21" d="M1217.48,794.21c-13.27,0-23.09,6.07-28.44,21.06a39.32,39.32,0,0,0,.47,15.84c1.94,1,1.89,4.21,2.57,9,.76,1.51,3.11.63,3.11.63a69.61,69.61,0,0,1,1.14-9.77c-1.85-6.49-1.3-8.22,3.37-10.28a82.93,82.93,0,0,0,45.28-2.15,8.43,8.43,0,0,1,3.54,9.9,48.71,48.71,0,0,0,.88,15.79c.3,1.35,1.65,1.06,2.36.59a23.26,23.26,0,0,1,5.35-13.64c.42-7.5.46-17.19-4.21-21.06C1247.8,794.34,1231.16,794.21,1217.48,794.21Z"/></g></g><g id="Icons-7" data-name="Icons"><path class="cls-46" d="M1210.4,877l-.48,5.53-21.31,5.71c-11.56,3.1-20.67,10.51-24.59,20l-5.71,13.83s65,42.71,132.55.11l-5.71-13.83c-3.92-9.5-13-16.91-24.59-20l-21.31-5.71-.43-5.35"/><path class="cls-40" d="M1210,881.84a1.77,1.77,0,0,1-.51,0,6.5,6.5,0,0,1-2-.35,5.47,5.47,0,0,1-3.52-4.38c-.42-.22-.9-.43-1.33-.65a5,5,0,0,1-2.4.69,5.65,5.65,0,0,1-3.13-1,5.45,5.45,0,0,1-2.45-5.07,12.21,12.21,0,0,1-1.07-1,3.7,3.7,0,0,1-1.37.26,5.62,5.62,0,0,1-5.24-7.33c-.25-.39-.55-.73-.81-1.12-.09,0-.17.08-.26.08a5.48,5.48,0,0,1-4.68-2.86,5.59,5.59,0,0,1-.64-3.94,4.92,4.92,0,0,1,.73-1.74c-.17-.43-.39-.87-.56-1.3a5.39,5.39,0,0,1-4.12-3.82,5.31,5.31,0,0,1,1.42-5.37c-.13-.52-.17-1-.26-1.56a4.83,4.83,0,0,1-2.27-1.78,6.09,6.09,0,0,1-.3-5.81,4.94,4.94,0,0,1,2.06-2c0-.52,0-1,0-1.52a5.34,5.34,0,0,1-2-5.24,5.39,5.39,0,0,1,3.69-4.25c.13-.48.26-.91.39-1.35a5.51,5.51,0,0,1-.77-5.63,5.4,5.4,0,0,1,4.63-3.3c.22-.43.47-.78.69-1.17a5.47,5.47,0,0,1,.51-5.72,5.31,5.31,0,0,1,5.28-2.13c.3-.35.6-.69.9-1a5.42,5.42,0,0,1,1.8-5.42,5.84,5.84,0,0,1,3.74-1.34,4.73,4.73,0,0,1,1.88.43l1.08-.65a4.94,4.94,0,0,1,.81-2.9,5.77,5.77,0,0,1,5.11-2.6,4.56,4.56,0,0,1,2.79,1.08c.42-.17.85-.3,1.28-.48a5.07,5.07,0,0,1,1.33-2.6,5.66,5.66,0,0,1,5.58-1.34,4.84,4.84,0,0,1,2.4,1.73c.48,0,.9-.17,1.38-.22a5.53,5.53,0,0,1,9.65,0c.47.05.9.18,1.37.22a5.1,5.1,0,0,1,2.41-1.73,5.71,5.71,0,0,1,5.57,1.34,5,5,0,0,1,1.33,2.6c.48.18.9.35,1.33.48a5.29,5.29,0,0,1,5.67-.48,5.79,5.79,0,0,1,2.7,2.95,5.1,5.1,0,0,1,.26,1.91c.38.26.77.48,1.11.69a5,5,0,0,1,1.89-.43,5.34,5.34,0,0,1,3.73,1.34,5.41,5.41,0,0,1,1.81,5.42c.3.31.6.65.9,1a5,5,0,0,1,3,.3,5.94,5.94,0,0,1,3.43,4.64,5,5,0,0,1-.56,2.95c.22.39.43.78.69,1.17a5.41,5.41,0,0,1,4.59,3.3,5.51,5.51,0,0,1-.77,5.63c.13.44.25.87.38,1.35a5.1,5.1,0,0,1,1.72.82,5.42,5.42,0,0,1,2,3.47,5.28,5.28,0,0,1-2,5.2c0,.52,0,1,0,1.52a4.94,4.94,0,0,1,2.06,2,5.88,5.88,0,0,1-.3,5.81,4.81,4.81,0,0,1-2.28,1.78c-.08.52-.12,1-.25,1.56a5.28,5.28,0,0,1,1.41,5.37,5.38,5.38,0,0,1-4.12,3.82c-.17.43-.38.91-.55,1.34a5.54,5.54,0,0,1,.08,5.64,5.48,5.48,0,0,1-3,2.56,4.72,4.72,0,0,1-1.63.26c-.09,0-.18,0-.26,0-.26.39-.56.73-.82,1.12a5.52,5.52,0,0,1-1.2,5.55,5.6,5.6,0,0,1-4,1.78,3.85,3.85,0,0,1-1.37-.26,12.34,12.34,0,0,1-1.08,1,5.39,5.39,0,0,1-2.44,5.07,5.66,5.66,0,0,1-3.14,1,5,5,0,0,1-2.4-.69l-1.33.65a6.3,6.3,0,0,1-.47,1.78,5.86,5.86,0,0,1-3,2.6,6.25,6.25,0,0,1-2,.35,2.12,2.12,0,0,1-.56,0"/><path class="cls-19" d="M1239.25,882.68c0,16.73-29.28,16.57-29.28-.14V875.6h29.28Z"/><path class="cls-19" d="M1247.69,861.79c3.4.6,7.11-2.33,8.1-6.45s-.87-9.36-4.27-10l-5.89,8.91-.48-14h0a6.15,6.15,0,0,0-6.78-7.09l-13.79,1.69-13.79-1.69a6.15,6.15,0,0,0-6.78,7.09h0l-.73,14.42-5.87-9.5c-3.16.61-5,6-4.05,10.14s4.23,7,7.4,6.36c3.1,11.49,12.38,20.55,23.37,20.55C1235.33,882.25,1244.77,873.6,1247.69,861.79Z"/><path class="cls-47" d="M1247.69,861.79c3.4.6,7.11-2.33,8.1-6.45s-.87-9.36-4.27-10l-5.89,8.91-.48-14h0c0-4.71-2.75-7.59-6.78-7.09l-13.79,1.69-13.79-1.69c-4-.5-6.61,2.32-6.78,7.09h0l-.73,14.42-5.87-9.5c-3.16.61-5,6-4.05,10.14s4.23,7,7.4,6.36c3.1,11.49,12.38,20.55,23.37,20.55C1235.33,882.25,1244.77,873.6,1247.69,861.79Z"/><path class="cls-47" d="M1210,881.84a1.77,1.77,0,0,1-.51,0,6.5,6.5,0,0,1-2-.35,5.47,5.47,0,0,1-3.52-4.38c-.42-.22-.9-.43-1.33-.65a5,5,0,0,1-2.4.69,5.65,5.65,0,0,1-3.13-1,5.45,5.45,0,0,1-2.45-5.07,12.21,12.21,0,0,1-1.07-1,3.7,3.7,0,0,1-1.37.26,5.62,5.62,0,0,1-5.24-7.33c-.25-.39-.55-.73-.81-1.12-.09,0-.17.08-.26.08a5.48,5.48,0,0,1-4.68-2.86,5.59,5.59,0,0,1-.64-3.94,4.92,4.92,0,0,1,.73-1.74c-.17-.43-.39-.87-.56-1.3a5.39,5.39,0,0,1-4.12-3.82,5.31,5.31,0,0,1,1.42-5.37c-.13-.52-.17-1-.26-1.56a4.83,4.83,0,0,1-2.27-1.78,6.09,6.09,0,0,1-.3-5.81,4.94,4.94,0,0,1,2.06-2c0-.52,0-1,0-1.52a5.34,5.34,0,0,1-2-5.24,5.39,5.39,0,0,1,3.69-4.25c.13-.48.26-.91.39-1.35a5.51,5.51,0,0,1-.77-5.63,5.4,5.4,0,0,1,4.63-3.3c.22-.43.47-.78.69-1.17a5.47,5.47,0,0,1,.51-5.72,5.31,5.31,0,0,1,5.28-2.13c.3-.35.6-.69.9-1a5.42,5.42,0,0,1,1.8-5.42,5.84,5.84,0,0,1,3.74-1.34,4.73,4.73,0,0,1,1.88.43l1.08-.65a4.94,4.94,0,0,1,.81-2.9,5.77,5.77,0,0,1,5.11-2.6,4.56,4.56,0,0,1,2.79,1.08c.42-.17.85-.3,1.28-.48a5.07,5.07,0,0,1,1.33-2.6,5.66,5.66,0,0,1,5.58-1.34,4.84,4.84,0,0,1,2.4,1.73c.48,0,.9-.17,1.38-.22a5.53,5.53,0,0,1,9.65,0c.47.05.9.18,1.37.22a5.1,5.1,0,0,1,2.41-1.73,5.71,5.71,0,0,1,5.57,1.34,5,5,0,0,1,1.33,2.6c.48.18.9.35,1.33.48a5.29,5.29,0,0,1,5.67-.48,5.79,5.79,0,0,1,2.7,2.95,5.1,5.1,0,0,1,.26,1.91c.38.26.77.48,1.11.69a5,5,0,0,1,1.89-.43,5.34,5.34,0,0,1,3.73,1.34,5.41,5.41,0,0,1,1.81,5.42c.3.31.6.65.9,1a5,5,0,0,1,3,.3,5.94,5.94,0,0,1,3.43,4.64,5,5,0,0,1-.56,2.95c.22.39.43.78.69,1.17a5.41,5.41,0,0,1,4.59,3.3,5.51,5.51,0,0,1-.77,5.63c.13.44.25.87.38,1.35a5.1,5.1,0,0,1,1.72.82,5.42,5.42,0,0,1,2,3.47,5.28,5.28,0,0,1-2,5.2c0,.52,0,1,0,1.52a4.94,4.94,0,0,1,2.06,2,5.88,5.88,0,0,1-.3,5.81,4.81,4.81,0,0,1-2.28,1.78c-.08.52-.12,1-.25,1.56a5.28,5.28,0,0,1,1.41,5.37,5.38,5.38,0,0,1-4.12,3.82c-.17.43-.38.91-.55,1.34a5.54,5.54,0,0,1,.08,5.64,5.48,5.48,0,0,1-3,2.56,4.72,4.72,0,0,1-1.63.26c-.09,0-.18,0-.26,0-.26.39-.56.73-.82,1.12a5.52,5.52,0,0,1-1.2,5.55,5.6,5.6,0,0,1-4,1.78,3.85,3.85,0,0,1-1.37-.26,12.34,12.34,0,0,1-1.08,1,5.39,5.39,0,0,1-2.44,5.07,5.66,5.66,0,0,1-3.14,1,5,5,0,0,1-2.4-.69l-1.33.65a6.3,6.3,0,0,1-.47,1.78,5.86,5.86,0,0,1-3,2.6,6.25,6.25,0,0,1-2,.35,2.12,2.12,0,0,1-.56,0"/></g></g><g class="cls-48"><g id="icons-8" data-name="icons"><g id="Layer_3-5" data-name="Layer 3"><path class="cls-19" d="M1000.75,1094.37c-16.85-3.12-28.26-11.29-28.26-18.49s.42-27.76.42-27.76l-20.6-.42h-.21l-20.6.42a255.09,255.09,0,0,1,4.21,28.3c0,7.17-7.49,16-23.58,17.95-15.92,3.24-21,19-21.65,28.68l61.83-3.37H1020C1019.32,1109.91,1013.51,1101,1000.75,1094.37Z"/><path class="cls-20" d="M952.73,1087a30.45,30.45,0,0,0,19.88-9.68,8.07,8.07,0,0,1,0-1.39c0-7.16.42-27.76.42-27.76l-20.59-.42h-.21l-20.6.42a255.09,255.09,0,0,1,4.21,28.3,11.43,11.43,0,0,1-.42,2.91A29.23,29.23,0,0,0,952.73,1087Z"/><path class="cls-19" d="M990.22,1035.78a13,13,0,0,0-4.21-10.49c.38-7.5.46-17.23-4.22-21.06-5.09-16-21.73-16.09-35.42-16.09s-23.08,6.07-28.43,21.06a39.32,39.32,0,0,0,.46,15.84,12.66,12.66,0,0,0-4.21,10.61c0,6.24,2.91,11.25,6.49,11.25h0c5.05,24,22.2,34.33,32.05,34.33s26.71-10.15,31.55-34.42C987.61,1046.44,990.22,1041.76,990.22,1035.78Z"/><path class="cls-49" d="M1023.37,1124a1.5,1.5,0,0,0,0-.3c-3-8.42-7.63-20-12.3-24.64a7.45,7.45,0,0,0-1.35-1.22c-7.71-3.7-26.49-10.19-27.29-10.49-5.94,25.28-47.3,25.57-54.42,1.06-1,.54-20.22,5.73-27.93,9.43-5.26,3.67-10.19,17.4-13,26.75a5.67,5.67,0,0,0,3.07,2.44h0c10.28,4.68,23.38,5.18,34.46,6h0l9.47.59h42.16l8.93-.55h0a141,141,0,0,0,32-4.84h0c1-.34,2-.72,2.91-1.14h0C1022.23,1126,1023.37,1125,1023.37,1124Z"/><path class="cls-21" d="M946.46,988.14c-13.27,0-23.09,6.07-28.44,21.06a39.32,39.32,0,0,0,.47,15.84c1.94,1,1.89,4.21,2.57,9,.76,1.52,3.11.63,3.11.63a69.79,69.79,0,0,1,1.14-9.77c-1.85-6.48-1.3-8.21,3.37-10.28a82.93,82.93,0,0,0,45.28-2.14,8.42,8.42,0,0,1,3.54,9.89,48.77,48.77,0,0,0,.88,15.8c.3,1.35,1.65,1,2.36.59a23.29,23.29,0,0,1,5.35-13.65c.42-7.49.46-17.18-4.21-21.06C976.78,988.27,960.14,988.14,946.46,988.14Z"/></g></g></g><g class="cls-50"><g id="Icons-9" data-name="Icons"><path class="cls-51" d="M499.83,373.69l-.54,6.3L475,387.16c-1.21.32-2.64.23-3.77.57-.13,0-.16-.42-.3-.37-11.4,4.05-20.45,12.2-24.5,21.91L439.88,425a185.35,185.35,0,0,0,24.45,6.63c6.4,1.35,14-2.59,22.34-1.58,6.29.76,12.95,6.6,20.13,6.91,5.6.24,11.44.31,17.48.15,7.84-.2,15.88-7.2,24.3-8.28,6-.77,12.23,4.63,18.43,3.31a215.7,215.7,0,0,0,25.43-7l-6.57-15.75c-4.14-9.93-13.67-18.07-25.43-22-1.06-.35-2.05.54-3.15.25l-24.75-6.8V374"/><path class="cls-36" d="M499.83,372.72l-.54,7.27L502,388.7l14.21-.51,11.55.51,5.42-8.17-.69-7.81S518.06,386.47,499.83,372.72Z"/><path class="cls-52" d="M550.87,350.27c-2.66,8.26-7.87,6-7.87,6-1.56,11.13-11.8,18.11-11.8,18.11a20.88,20.88,0,0,1-13.33,5.71,17.3,17.3,0,0,1-3.39-.08,28.75,28.75,0,0,1-13.16-5.16c-9.43-6.56-12.94-18.49-12.94-18.49-7.28-.6-8.21-7.83-8.21-7.83a10.78,10.78,0,0,1,4.9-12.1,88.63,88.63,0,0,1,1.61-15.58c.13-5.92,4.32-12.22,4.32-12.22,1.44-2.37,6,.59,11.3,1.56s17.05-1.69,26.57-3.26,13,2,14.43,5.55,0,5.12,3.22,10.83.59,13.67.59,13.67A12.52,12.52,0,0,1,550.87,350.27Z"/><path class="cls-51" d="M516.38,293.23H516c-3.46,0-29.32.47-32,22.85,0,0-1.91,12.57,1.23,20.86,0,0-.67-10,3-12s-1.53-15.91,8.72-14.75c4.19.48,7.94.88,11,1.2,4.72.49,15.32.1,15.32.1,3.26-.28,7.4-.76,12.11-1.3,10.24-1.16,5.05,12.81,8.71,14.75s3,12,3,12c3.15-8.29,1.24-20.86,1.24-20.86-2.65-22.38-28.51-22.89-32-22.85H516"/></g></g><g class="cls-53"><path class="cls-54" d="M1299.35,528.21c8.31,3.48,20.23,5.67,33.67,5.67s25.36-2.19,33.66-5.67Z"/><path class="cls-54" d="M1304.67,477.18h56.7l5.67,51h-68Z"/><path class="cls-55" d="M1310.34,539.55c-13,6.23-25.93,12.47-38.88,19.28-5.07,2.83-7,9.07-6.48,14.74.23,3.4-1,7.94,2.5,10.2,3.35,1.7,7.27.57,10.91,1.14H1396c4.36-.57,5.51-5.11,5.09-8.51.08-5.67.38-11.34-3.73-15.31-3.35-3.4-8.14-5.1-12.23-7.37-9.8-4.53-19.61-9.64-29.4-14.17Z"/><rect class="cls-20" x="1316.01" y="522.54" width="34.02" height="28.35"/><path class="cls-19" d="M1333,448.83c-16.8,0-30.72,15.31-33.49,35.15-.65,0-1.36-.57-2-.57-3,1.14-3.71,6.81-1.77,13,1.14,3.4,3,6.23,5,7.37,4.4,17.57,17.09,30.05,32.25,30.05s27.84-12.48,32.25-30.05c1.93-1.14,3.82-4,5-7.37,1.94-6.24,1.21-11.91-1.77-13-.59,0-1.3.57-2,.57C1363.74,464.14,1349.82,448.83,1333,448.83Z"/><path class="cls-56" d="M1310.34,539.55c0,11.9,10.15,51,22.68,51s22.68-39.13,22.68-51Z"/><path class="cls-57" d="M1333,448.83c-20.34,0-40.41,20.41-39.69,39.69-.3,12.47,5.66,26.08,5.88,38.55,5.94-7.37,5.73-16.44,5.49-25.51,1.2-6.24.06-15.31,5.64-18.71,13.46-6.81,21.65-19.85,26-34Z"/><path class="cls-19" d="M1310.34,539.55c0,7.94,10.15,34,22.68,34s22.68-26.08,22.68-34Z"/><path class="cls-58" d="M1333,448.83c20.33,0,40.41,20.41,39.69,39.69.29,12.47-5.67,26.08-5.89,38.55-5.94-7.37-5.73-16.44-5.49-25.51-1.2-6.24,0-15.31-5.63-18.71-13.46-6.81-21.66-19.85-26-34Z"/></g><path class="cls-4" d="M810.71,715.74c-12.6,47.86-35.19,123.79-.22,191.63,31.88,61.86,80.3,92.18,80.3,92.18"/><polyline class="cls-5" points="817.92 737.3 811.81 713.41 791.55 729.23"/></g></svg>
diff --git a/web/pgadmin/static/js/pgadmin.js b/web/pgadmin/static/js/pgadmin.js
index 4377b0a27..a9abcfa90 100644
--- a/web/pgadmin/static/js/pgadmin.js
+++ b/web/pgadmin/static/js/pgadmin.js
@@ -178,5 +178,7 @@ define([], function() {
     };
   }
 
+  pgAdmin.ui = {dialogs: {}};
+
   return pgAdmin;
 });
diff --git a/web/pgadmin/static/scss/_pgadmin.style.scss b/web/pgadmin/static/scss/_pgadmin.style.scss
index 861c9b08f..88a64129c 100644
--- a/web/pgadmin/static/scss/_pgadmin.style.scss
+++ b/web/pgadmin/static/scss/_pgadmin.style.scss
@@ -932,19 +932,31 @@ table.table-empty-rows{
 }
 
 .login_page {
-  background-color: $color-primary;
+  background-color: $login-page-background;
   height: 100%;
   position:relative;
   z-index:1;
   color: $security-text-color;
 
+  & a {
+    color: $security-text-color;
+  }
+
+  & .panel-container {
+    background-color: rgba($security-btn-color, 0.25);
+    padding: 0px;
+  }
+
   & .panel-header {
     padding-bottom: 1.0rem;
   }
   & .panel-body {
     padding-bottom: 0.8rem;
   }
-  & .btn-login {
+  & .btn-login  {
+    background-color: $security-btn-color;
+  }
+  & .btn-validate {
     background-color: $security-btn-color;
   }
   & .btn-oauth {
@@ -978,8 +990,11 @@ table.table-empty-rows{
     z-index: 100;
 }
 
+.auth_page {
+  background-color: $color-gray-dark;
+}
+
 .change_pass {
-  background-color: $color-gray-light;
   height: 100%;
   position:relative;
   z-index:1;
diff --git a/web/pgadmin/static/scss/resources/_default.variables.scss b/web/pgadmin/static/scss/resources/_default.variables.scss
index d9fb6653a..201b51767 100644
--- a/web/pgadmin/static/scss/resources/_default.variables.scss
+++ b/web/pgadmin/static/scss/resources/_default.variables.scss
@@ -364,6 +364,7 @@ $erd-canvas-grid: $color-gray !default;
 $erd-link-color: $color-fg !default;
 $erd-link-selected-color: $color-fg !default;
 
+$login-page-background: $color-primary !default;
 
 @function url-friendly-colour($colour) {
   @return '%23' + str-slice('#{$colour}', 2, -1)
diff --git a/web/pgadmin/static/scss/resources/dark/_theme.variables.scss b/web/pgadmin/static/scss/resources/dark/_theme.variables.scss
index 2fa907b87..3be703fa6 100644
--- a/web/pgadmin/static/scss/resources/dark/_theme.variables.scss
+++ b/web/pgadmin/static/scss/resources/dark/_theme.variables.scss
@@ -79,6 +79,8 @@ $color-editor-operator: #d6aaaa;
 $color-editor-foldmarker: #0000FF !default;
 $color-editor-activeline: #323e43 !default;
 
+$login-page-background: $color-bg;
+
 $explain-sev-2-bg: #ded17e;
 $explain-sev-3-bg: #824d18;
 $explain-sev-4-bg: #880000;
diff --git a/web/pgadmin/static/scss/resources/high_contrast/_theme.variables.scss b/web/pgadmin/static/scss/resources/high_contrast/_theme.variables.scss
index b4783bce0..86a6ba319 100644
--- a/web/pgadmin/static/scss/resources/high_contrast/_theme.variables.scss
+++ b/web/pgadmin/static/scss/resources/high_contrast/_theme.variables.scss
@@ -37,6 +37,8 @@ $color-gray: #1F2932;
 $color-gray-light: #2D3A48;
 $color-gray-lighter: #8B9CAD;
 
+$login-page-background: $color-bg;
+
 $sql-gutters-bg: $color-gray-light;
 $sql-title-bg: #1F2932;
 $sql-title-fg: $color-fg;
diff --git a/web/pgadmin/templates/base.html b/web/pgadmin/templates/base.html
index ce375ec44..74f42d51b 100644
--- a/web/pgadmin/templates/base.html
+++ b/web/pgadmin/templates/base.html
@@ -31,6 +31,7 @@
         window.resourceBasePath = "{{ url_for('static', filename='js') }}/generated/";
     </script>
     <!-- Base template scripts -->
+{% if requirejs is defined and requirejs is true %}
     <script type="application/javascript"
             src="{{ url_for('static', filename='vendor/require/require.js' if config.DEBUG else 'vendor/require/require.min.js') }}"></script>
     <script type="application/javascript">
@@ -56,11 +57,13 @@
             });
 
     </script>
-
+{% endif %}
+{% if basejs is defined and basejs is true %}
     <!-- View specified scripts -->
     <script type="application/javascript" src="{{ url_for('static', filename='js/generated/vendor.main.js') }}" ></script>
     <script type="application/javascript" src="{{ url_for('static', filename='js/generated/vendor.others.js') }}" ></script>
     <script type="application/javascript" src="{{ url_for('static', filename='js/generated/pgadmin_commons.js') }}" ></script>
+{% endif %}
 
 </head>
 <body>
@@ -72,7 +75,6 @@
 {% block body %}{% endblock %}
 <script type="application/javascript">
             {% block init_script %}{% endblock %}
-
 </script>
 
 </body>
diff --git a/web/pgadmin/templates/security/change_password.html b/web/pgadmin/templates/security/change_password.html
index 0420e9059..3436bce01 100644
--- a/web/pgadmin/templates/security/change_password.html
+++ b/web/pgadmin/templates/security/change_password.html
@@ -1,7 +1,7 @@
 {% extends "base.html" %}
 {% from "security/fields.html" import render_field_with_errors %}
 {% block body %}
-<div class="container-fluid change_pass">
+<div class="container-fluid change_pass auth_page">
     {% include "security/messages.html" %}
     <div class="row align-items-center h-100">
         <div class="col-md-4"></div>
diff --git a/web/pgadmin/templates/security/panel.html b/web/pgadmin/templates/security/panel.html
index 46aa0524c..82944f991 100644
--- a/web/pgadmin/templates/security/panel.html
+++ b/web/pgadmin/templates/security/panel.html
@@ -2,7 +2,7 @@
 {% from "security/fields.html" import render_field_with_errors, render_username_with_errors %}
 {% block title %}{{ config.APP_NAME }}{% endblock %}
 {% block body %}
-<div class="container-fluid h-100 login_page">
+<div class="container-fluid h-100 login_page{% if auth_page is defined and auth_page is true %} auth_page{% endif %}">
     {% if config.LOGIN_BANNER is defined and config.LOGIN_BANNER != "" %}
     <div class="login_banner alert alert-danger" role="alert">
         {{ config.LOGIN_BANNER|safe }}
@@ -11,12 +11,21 @@
     {% include "security/messages.html" %}
     <div class="row h-100 align-items-center justify-content-center">
         <div class="col-md-6">{% block panel_image %}{% endblock %}</div>
-        <div class="col-md-3">
-            <div class="panel-header text-color h4"><i class="app-icon pg-icon" aria-hidden="true"></i> {{ _('%(appname)s', appname=config.APP_NAME) }}</div>
-            <div class="panel-body">
-                <div class="d-block text-color pb-3 h5">{% block panel_title %}{% endblock %}</div>
-                {% block panel_body %}
-                {% endblock %}
+        <div class="col-md-3 panel-container mh-100">
+            <div class="panel-header h4 pt-2 pb-1 m-0 rounded-top">
+              <span class="d-flex justify-content-center pgadmin_header_logo"
+                    onclick="return false;"
+                    href="#"
+                    title="{{ _('%(appname)s', appname=config.APP_NAME) }}"
+                    aria-label="{{ _('%(appname)s', appname=config.APP_NAME) }} logo">
+                <i class="app-icon pg-icon"
+                   aria-hidden="true"
+                   style="width: auto; background-size: auto; min-width: 100px;"></i>
+              </span>
+            </div>
+            <div class="panel-body p-3 overflow-auto" style="max-height: calc(100vh - 3em);">
+              <div class="d-block text-color pb-2 h4 text-center">{% block panel_title %}{% endblock %}</div>
+              {% block panel_body %}{% endblock %}
             </div>
         </div>
     </div>
diff --git a/web/pgadmin/tools/datagrid/__init__.py b/web/pgadmin/tools/datagrid/__init__.py
index 05ed998c6..1a3c855b0 100644
--- a/web/pgadmin/tools/datagrid/__init__.py
+++ b/web/pgadmin/tools/datagrid/__init__.py
@@ -291,6 +291,8 @@ def panel(trans_id):
         bgcolor=bgcolor,
         fgcolor=fgcolor,
         layout=layout,
+        requirejs=True,
+        basejs=True,
         macros=macros
     )
 
diff --git a/web/pgadmin/tools/debugger/__init__.py b/web/pgadmin/tools/debugger/__init__.py
index 1831229fb..995c90f62 100644
--- a/web/pgadmin/tools/debugger/__init__.py
+++ b/web/pgadmin/tools/debugger/__init__.py
@@ -682,6 +682,8 @@ def direct_new(trans_id):
         is_linux=is_linux_platform,
         client_platform=user_agent.platform,
         function_name_with_arguments=function_name_with_arguments,
+        requirejs=True,
+        basejs=True,
         layout=layout
     )
 
diff --git a/web/pgadmin/tools/erd/__init__.py b/web/pgadmin/tools/erd/__init__.py
index 6d16cbd79..aeac45c40 100644
--- a/web/pgadmin/tools/erd/__init__.py
+++ b/web/pgadmin/tools/erd/__init__.py
@@ -447,6 +447,8 @@ def panel(trans_id):
         "erd/index.html",
         title=underscore_unescape(params['title']),
         close_url=close_url,
+        requirejs=True,
+        basejs=True,
         params=json.dumps(params),
     )
 
diff --git a/web/pgadmin/tools/psql/__init__.py b/web/pgadmin/tools/psql/__init__.py
index 99b1cd62a..79fb04211 100644
--- a/web/pgadmin/tools/psql/__init__.py
+++ b/web/pgadmin/tools/psql/__init__.py
@@ -127,6 +127,8 @@ def panel(trans_id):
                            title=underscore_unescape(params['title']),
                            theme=params['theme'],
                            o_db_name=o_db_name,
+                           requirejs=True,
+                           basejs=True,
                            platform=_platform
                            )
 
diff --git a/web/pgadmin/tools/schema_diff/__init__.py b/web/pgadmin/tools/schema_diff/__init__.py
index 596b976ad..3e33d5f16 100644
--- a/web/pgadmin/tools/schema_diff/__init__.py
+++ b/web/pgadmin/tools/schema_diff/__init__.py
@@ -135,6 +135,8 @@ def panel(trans_id, editor_title):
         "schema_diff/index.html",
         _=gettext,
         trans_id=trans_id,
+        requirejs=True,
+        basejs=True,
         editor_title=editor_title
     )
 
diff --git a/web/pgadmin/tools/user_management/static/js/user_management.js b/web/pgadmin/tools/user_management/static/js/user_management.js
index 6d351f24f..3fc54de5a 100644
--- a/web/pgadmin/tools/user_management/static/js/user_management.js
+++ b/web/pgadmin/tools/user_management/static/js/user_management.js
@@ -11,10 +11,10 @@ define([
   'sources/gettext', 'sources/url_for', 'jquery', 'underscore', 'pgadmin.alertifyjs',
   'pgadmin.browser', 'backbone', 'backgrid', 'backform', 'pgadmin.browser.node', 'pgadmin.backform',
   'pgadmin.user_management.current_user', 'sources/utils', 'pgadmin.browser.constants',
-  'backgrid.select.all', 'backgrid.filter',
+  'pgadmin.browser.dialog','backgrid.select.all', 'backgrid.filter',
 ], function(
   gettext, url_for, $, _, alertify, pgBrowser, Backbone, Backgrid, Backform,
-  pgNode, pgBackform, userInfo, commonUtils, pgConst,
+  pgNode, pgBackform, userInfo, commonUtils, pgConst, pgDialog,
 ) {
 
   // if module is already initialized, refer to that.
@@ -87,93 +87,10 @@ define([
 
     // Callback to draw change password Dialog.
     change_password: function(url) {
-      var title = gettext('Change Password');
-
-      if (!alertify.ChangePassword) {
-        alertify.dialog('ChangePassword', function factory() {
-          return {
-            main: function(alertTitle, alertUrl) {
-              this.set({
-                'title': alertTitle,
-                'url': alertUrl,
-              });
-            },
-            build: function() {
-              alertify.pgDialogBuild.apply(this);
-            },
-            settings: {
-              url: undefined,
-            },
-            setup: function() {
-              return {
-                buttons: [{
-                  text: '',
-                  key: 112,
-                  className: 'btn btn-primary-icon pull-left fa fa-question pg-alertify-icon-button',
-                  attrs: {
-                    name: 'dialog_help',
-                    type: 'button',
-                    label: gettext('Change Password'),
-                    url: url_for(
-                      'help.static', {
-                        'filename': 'change_user_password.html',
-                      }),
-                  },
-                }, {
-                  text: gettext('Close'),
-                  key: 27,
-                  className: 'btn btn-secondary fa fa-lg fa-times pg-alertify-button',
-                  attrs: {
-                    name: 'close',
-                    type: 'button',
-                  },
-                }],
-                // Set options for dialog
-                options: {
-                  //disable both padding and overflow control.
-                  padding: !1,
-                  overflow: !1,
-                  modal: false,
-                  resizable: true,
-                  maximizable: true,
-                  pinnable: false,
-                  closableByDimmer: false,
-                  closable: false,
-                },
-              };
-            },
-            hooks: {
-              // Triggered when the dialog is closed
-              onclose: function() {
-                // Clear the view
-                return setTimeout((function() {
-                  return alertify.ChangePassword().destroy();
-                }), 500);
-              },
-            },
-            prepare: function() {
-              // create the iframe element
-              var iframe = document.createElement('iframe');
-              iframe.frameBorder = 'no';
-              iframe.width = '100%';
-              iframe.height = '100%';
-              iframe.src = this.setting('url');
-              // add it to the dialog
-              this.elements.content.appendChild(iframe);
-            },
-            callback: function(e) {
-              if (e.button.element.name == 'dialog_help') {
-                e.cancel = true;
-                pgBrowser.showHelp(e.button.element.name, e.button.element.getAttribute('url'),
-                  null, null);
-                return;
-              }
-            },
-          };
-        });
-      }
-
-      alertify.ChangePassword(title, url).resizeTo(pgBrowser.stdW.lg, pgBrowser.stdH.md);
+      console.warn(pgDialog);
+      pgDialog.url_dialog(
+        gettext('Chagne Password'), url, 'change_user_password.html',
+      );
     },
 
     isPgaLoginRequired(xhr) {
diff --git a/web/webpack.shim.js b/web/webpack.shim.js
index 9788f2640..b1fb3558e 100644
--- a/web/webpack.shim.js
+++ b/web/webpack.shim.js
@@ -201,6 +201,7 @@ var webpackShimConfig = {
     'pgadmin.browser.activity': path.join(__dirname, './pgadmin/browser/static/js/activity'),
     'pgadmin.browser.quick_search': path.join(__dirname, './pgadmin/browser/static/js/quick_search'),
     'pgadmin.browser.messages': '/browser/js/messages',
+    'pgadmin.browser.dialog': path.join(__dirname, './pgadmin/browser/static/js/dialog'),
     'pgadmin.browser.node': path.join(__dirname, './pgadmin/browser/static/js/node'),
     'pgadmin.browser.node.ui': path.join(__dirname, './pgadmin/browser/static/js/node.ui'),
     'pgadmin.browser.dependencies': path.join(__dirname, './pgadmin/misc/dependencies/static/js/dependencies'),
